      SUBROUTINE AIRPRC(NAMLEN, NIDLEN, NVARBL, NSPECS, NUNITS, NSTATS,
     $  NSBRGN,
     $  NPARAM, NVPARM, NPRFHT, NSCRTC, NXCELL, NYCELL, NZCELL,
     $  INFILE, MFILNM, MFILID,
     $  LPRINT, LUAMV , JINTSC, JSCRTC, REALSC, FACMLT, FACADD, SMOLWT,
     $  XSTATL, YSTATL, STATHT, PARAMS, VPARAM, MVARBL, MUNITS,
     $  MSTATS, MSBRGN, MPARAM, MVPARM, JRGRID, JMTHDN, JPARMP, JPARMC,
     $  JVMTHN, JVPRMP, JVPRMC, BASGRD, ALTGRD, STAVAL, SMTHMN, SMTHMX,
     $  VMTHMN, VMTHMX, XPROFL, YPROFL, DIFBRK, REGTOP, TOPCON,
     $  TOPSPR, TOPMAT, PRFHGT, PRFVAL, OUTMAT, JFLAG)
C
C NAME -- AIR QUALITY PROCESS
C
C DESCRIPTION -- PROCESSES ALL INPUT PACKETS AND CALCULATES AIR QUALITY
C         VALUES
C
C PROGRAMMER -- DAVID C WHITNEY/SAI  JULY 1977
C
C INPUTS --
C         INCARD    I  INPUT UNIT (FROM JINTSC)
C         IPRINT    I  OUTPUT UNIT (FROM JINTSC)
C         IOUTFL    I  OUTPUT FILE NUMBER (FROM JINTSC)
C         IMATFL    I  MATRIX FILE NUMBER (FROM JINTSC)
C         IDFBRK    I  DIFFUSION BREAK FILE NUMBER (FROM INFILE)
C         IRGTOP    I  REGION TOP FILE NUMBER (FROM INFILE)
C         ITPCON    I  TOP CONCENTRATION FILE NUMBER (FROM INFILE)
C         NAMLEN    I  NAME LENGTH
C         NIDLEN    I  IDENTIFICATION FIELD LENGTH
C         NVARBL    I  TOTAL NUMBER OF VARIABLES
C         NUNITS    I  NUMBER OF UNITS
C         NSTATS    I  NUMBER OF STATIONS
C         NSBRGN    I  NUMBER OF SUBREGIONS
C         NPARAM    I  NUMBER OF PARAMETERS
C         NVPARM    I  NUMBER OF VERTICAL PARAMETERS
C         NPRFHT    I  NUMBER OF PROFILE HEIGHTS
C         NSCRTC    I  NUMBER OF AVAILABLE SCRATCH WORDS
C         NXCELL    I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL    I  NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL    I  NUMBER OF CELLS IN Z-DIRECTION
C         NZLOWR    I  NUMBER OF CELLS IN LOWER VERTICAL LAYER (FROM JIN
C         NZUPPR    I  NUMBER OF CELLS IN UPPER VERTICAL LAYER (FROM JIN
C         JBEGDT    I  BEGINNING DATE (FROM JINTSC)
C         JENDDT    I  ENDING DATE (FROM JINTSC)
C         JUTMZN    I  UTM ZONE NUMBER (FROM JINTSC)
C         JMISSV    I  MISSING VALUE (FROM JINTSC)
C         LINPTP    L  PRINT FLAG FOR INPUT CARD (FROM LPRINT)
C         LGRIDP    L  PRINT FLAG FOR OUTPUT CARD (FROM LPRINT)
C         LUNITP    L  PRINT FLAG FOR UNITS TABLE (FROM LPRINT)
C         LSTATP    L  PRINT FLAG FOR STATION LOCATION (FROM LPRINT)
C         LSBRGP    L  PRINT FLAG FOR SUBREGION GRID (FROM LPRINT)
C         LMTHDP    L  PRINT FLAG FOR METHOD TABLE (FROM LPRINT)
C         LSTRDP    L  PRINT FLAG FOR STATION READING (FROM LPRINT)
C         LVMTHP    L  PRINT FLAG FOR VERTICAL METHOD TABLE (FROM LPRINT
C         LVPRFP    L  PRINT FLAG FOR VERTICAL PROFILES (FROM LPRINT)
C         LUAMV     L  UAMV FILE FORMAT OPTION
C         BEGTIM    R  BEGINNING TIME (FROM REALSC)
C         ENDTIM    R  ENDING TIME (FROM REALSC)
C         XUTMOR    R  X-COORDINATE OF UTM ORIGIN (FROM REALSC)
C         YUTMOR    R  Y-COORDINATE OF UTM ORIGIN (FROM REALSC)
C         XREGOR    R  X-COORDINATE OF REGION ORIGIN (FROM REALSC)
C         YREGOR    R  Y-COORDINATE OF REGION ORIGIN (FROM REALSC)
C         XCELLD    R  LENGTH OF CELL IN X-DIRECTION (FROM REALSC)
C         YCELLD    R  LENGTH OF CELL IN Y-DIRECTION (FROM REALSC)
C         ZHTSUR    R  CELL HEIGHT, SURFACE LAYER (FROM REALSC)
C         ZMINLW    R  MINIMUM CELL HEIGHT, LOWER LAYER (FROM REALSC)
C         ZMINUP    R  MINIMUM CELL HEIGHT, UPPER LAYER (FROM REALSC)
C         RMISSV    R  MISSING VALUE (FROM REALSC)
C         INFILE    I  FILE UNIT NUMBERS
C         MFILNM    I  FILE NAME
C         MFILID    I  FILE IDENTIFICATION
C         LPRINT    I  PRINT FLAGS
C         JINTSC    I  INTEGER SCALARS FOR PASSING TO PROCESSING ROUTINE
C         JSCRTC    I  SCRATCH FOR PARTITIONING
C         REALSC    R  REAL SCALARS FOR PASSING TO PROCESSING ROUTINE
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         XSTATL    R  STATION X-LOCATIONS
C         YSTATL    R  STATION Y-LOCATIONS
C         STATHT    R  STATION Z-LOCATIONS
C         PARAMS    R  METHOD PARAMETERS
C         VPARAM    R  VERTICAL METHOD PARAMETERS
C         MVARBL    I  VARIABLE NAMES
C         MUNITS    I  UNIT NAMES
C         MSTATS    I  STATION NAMES
C         MSBRGN    I  SUBREGION NAMES
C         MPARAM    I  PARAMETER NAMES
C         MVPARM    I  VERTICAL PARAMETER NAMES
C         JRGRID    I  REGIONAL GRID
C         JMTHDN    I  METHOD NUMBERS
C         JPARMP    I  PARAMETER POINTERS
C         JPARMC    I  PARAMETER COUNTERS
C         JVMTHN    I  VERTICAL METHOD NUMBERS
C         JVPRMP    I  VERTICAL PARAMETER POINTERS
C         JVPRMC    I  VERTICAL PARAMTER COUNTERS
C         BASGRD    I  BASE GRID
C         ALTGRD    I  ALTERNATE GRID
C         STAVAL    R  STATION VALUES
C         SMTHMN    R  METHOD MINIMUM
C         SMTHMX    R  METHOD MAXIMUM
C         VMTHMN    R  VERTICAL METHOD MINIMUM
C         VMTHMX    R  VERTICAL METHOD MAXIMUM
C         XPROFL    R  PROFILE X-LOCATION
C         YPROFL    R  PROFILE Y-LOCATION
C         DIFBRK    R  DIFFUSION BREAK
C         REGTOP    R  REGION TOP
C         TOPCON    R  CONCENTRATIONS ALOFT
C         PRFHGT    R  PROFILE HEIGHTS
C         PRFVAL    R  PROFILE VALUES
C         OUTMAT    R  OUTPUT MATRIX
C
C OUTPUTS --
C         JFLAG
C
C LOCAL VARIABLES --
C
C         NTILEN    I  NUMBER OF WORDS IN TITLE
C         NTIHDR    I  NUMBER OF TIME-INVARIANT HEADERS
C         NTVHDR    I  NUMBER OF TIME VARIANT HEADERS
C         NMETHD    I  NUMBER OF METHODS
C         NVMTHD    I  NUMBER OF VERTICAL METHODS
C         NSGMNT    I  NUMBER OF SEGMENTS
C         NPACKD    I  NUMBER OF WORDS IN PACKED NAME
C         NPARMC    I  NUMBER OF PARAMETERS FOR THIS METHOD
C         NVPRMC    I  NUMBER OF VERTICAL PARAMETERS FOR THIS METHOD
C         NFILSC    I  NUMBER OF WORDS NEEDED BY FILE SCRATCH
C         NFLVAR    I  NUMBER OF VARIABLES FOR FILE WRITE
C         NFLZCL    I  NUMBER OF Z-CELLS FOR FILE WRITE
C         KVRBL     I  POINTER TO CURRENT VARIABLE
C         KUNIT     I  POINTER TO CURRENT UNIT
C         KSBRG     I  POINTER TO CURRENT SUBREGION
C         KMTHD     I  POINTER TO CURRENT METHOD
C         KPRMP     I  POINTER TO CURRENT PARAMETER
C         KVMTH     I  POINTER TO CURRENT VERTICAL METHOD
C         KVPRP     I  POINTER TO CURRENT VERTICAL PARAMETER
C         KXCLL     I  POINTER TO CURRENT X-CELL
C         KYCLL     I  POINTER TO CURRENT Y-CELL
C         KZCLL     I  POINTER TO CURRENT Z-CELL
C         KZPTR     I  POINTER TO CURRENT Z-LEVEL
C         KTITL     I  POINTER TO CURRENT LOCATION IN TITLE
C         KFRMT     I  POINTER TO CURRENT FORMAT FOR PRINTED GRID OUTPUT
C         KSBTN     I  POINTER TO CURRENT SUBROUTINE
C         JCURDT    I  CURRENT DATE
C         JSTRDT    I  STARTING DATE
C         JSTPDT    I  STOPPING DATE
C         CURTIM    R  CURRENT TIME
C         STRTIM    R  STARTING TIME
C         STPTIM    R  STOPPING TIME
C         MHEADR    I  CURRENT PACKET HEADER
C         MCRDID    I  CURRENT CARD IDENTIFICATION
C         MTITLE    I  TITLE OF OUTPUT PRINT GRID
C         MTIHDR    I  TIME-INVARIANT HEADER LIST
C         MTVHDR    I  TIME-VARIANT HEADER LIST
C         MMETHD    I  METHOD NAME LIST
C         MVMTHD    I  VERTICAL METHOD NAME LIST
C         MDFBRK    I  DIFFUSION BREAK VARIABLE NAME
C         MRGTOP    I  REGION TOP VARIABLE NAME
C
C
C ROUTINES CALLED --
C         TXTPAK    LEFT JUSTIFIES NAME FIELD
C         COMPAR    COMPARES TWO FIELDS
C         UNITRD    UNITS PACKET
C         STATRD    STATIONS PACKET
C         TIMERD    TIME CARD PACKET
C         DFBKRD    READS FROM DIFFUSION BREAK FILE
C         HTPRRD    READS FROM HEIGHT/PRESSURE FILE
C         RGTPRD    READS FROM REGION TOP FILE
C         TPCNRD    READS FROM TOP CONCENTRATION FILE
C         TPUVRD    READS FROM UAMV TOP CONCENTRATION FILE
C         SBRGRD    SUBREGION DEFINITION PACKET
C         MTHDRD    METHOD DEFINITION PACKET
C         CNSTRD    CONSTANTS DEFINITION PACKET
C         GDVLRD    GRID VALUES DEFINITION PACKET
C         STVLRD    STATION VALUES DEFINITION PACKET
C         VPRFRD    VERTICAL PROFILES DEFINITION PACKET
C         MATGET    GETS OUTPUT GRID FROM OUTPUT MATRIX
C         MATPUT    PUTS OUTPUT GRID TO OUTPUT MATRIX
C         STASGN    STATION INTERPOLATION
C         SPLITC    SPLIT-COMBINATION
C         EWINTR    EAST-WEST INTERPOLATION
C         NSINTR    NORTH-SOUTH INTERPOLATION
C         POISSN    POISSON INTERPOLATION
C         AIRUSR    USER-SUPPLIED SUBROUTINE
C         RELPRF    RELATIVE PROFILE INTERPOLATION
C         ABSPRF    ABSOLUTE PROFILE INTERPOLATION
C         ABSPRV    ABSOLUTE PROFILE INTERPOLATION FOR UAMV
C         RLPRFR    RELATIVE PROFILE RATIO INTERPOLATION
C         ABPRFR    ABSOLUTE PROFILE RATIO INTERPOLATION
C         ABPRVR    ABSOLUTE PROFILE RATIO INTERPOLATION FOR UAMV
C         AIRVUS    USER-SUPPLIED VERTICAL SUBROUTINE
C         FLTMWR    WRITES TIME RECORD
C         FLAQWR    WRITES AIR QUALITY RECORDS
C         GRIDPR    PRINTS AIR QUALITY GRIDS
C
C ERROR CONDITIONS --
C         -1        NON-POSITIVE NAME LENGTH
C         -2        NON-POSITIVE NUMBER OF VARIABLES
C         -3        NON-POSITIVE NUMBER OF SUBREGIONS
C         -4        NON-POSITIVE NUMBER OF X-CELLS
C         -5        NON-POSITIVE NUMBER OF Y-CELLS
C         -6        NON-POSITIVE NUMBER OF Z-CELLS
C         -7        INSUFFICIENT SCRATCH STORAGE
C         -11       ERROR IN TXTPAK OF TIME-INVARIANT HEADER
C         -12       ERROR IN COMPAR OF TIME-INVARIANT HEADER
C         -13       NO MATCH OF TIME-INVARIANT HEADER
C         -14       ERROR IN UNITRD
C         -15       ERROR IN STATRD
C         -16       ERROR IN TIMERD
C         -17       GAP IN TIMING
C         -21       ERROR IN DFBKRD
C         -22       ERROR IN RGTPRD
C         -23       ERROR IN TPCNRD
C         -24       ERROR IN TPUVRD
C         -25       ERROR IN HTPRRD
C         -31       ERROR IN TIME-VARIANT HEADER
C         -32       ERROR IN COMPAR OF TIME-VARIANT HEADER
C         -33       NO MATCH FOR TIME-VARIANT HEADER
C         -41       ERROR IN SBRGRD
C         -42       ERROR IN MTHDRD
C         -43       ERROR IN VERTICAL MTHDRD
C         -44       ERROR IN CNSTRD
C         -45       ERROR IN GDVLRD
C         -46       ERROR IN STVLRD
C         -47       ERROR IN VPRFRD
C         -50       ERROR IN MATGET FOR GROUND LEVEL
C         -51       ILLEGAL SUBREGION
C         -52       ILLEGAL METHOD
C         -53       ILLEGAL PARAMETER COUNT ON STATION VALUES
C         -54       ILLEGAL PARAMETER POINTER ON STATION VALUES
C         -55       ERROR IN STASGN
C         -56       ILLEGAL PARAMETER COUNT ON SPLIT/COMBINATION
C         -57       ILLEGAL PARAMETER POINTER ON SPLIT/COMBINATION
C         -58       ERROR IN SPLITC
C         -59       ILLEGAL PARAMETER COUNT ON POISSON METHOD
C         -61       ILLEGAL PARAMETER POINTER ON POISSON METHOD
C         -62       ERROR IN POISSN
C         -63       ILLEGAL PARAMETER COUNT ON USER SUBROUTINE
C         -64       ILLEGAL PARAMETER POINTER ON USER SUBROUTINE
C         -65       ERROR IN AIRUSR
C         -66       ERROR IN EWINTR
C         -67       ERROR IN NSINTR
C         -68       ERROR IN MATPUT FOR GROUND LEVEL
C         -70       ERROR IN MATGET FOR UPPER LEVEL
C         -71       ILLEGAL VERTICAL SUBREGION
C         -72       ILLEGAL VERTICAL METHOD
C         -73       ERROR IN ABSPRF OR ABSPRV
C         -74       ERROR IN RELPRF
C         -75       ERROR IN ABPRFR OR ABPRVR
C         -76       ERROR IN RLPRFR
C         -77       ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE
C         -78       ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTIN
C         -79       ERROR IN AIRVUS
C         -81       ERROR IN VERTICAL EWINTR
C         -82       ERROR IN VERTICAL NSINTR
C         -83       ERROR IN MATPUT FOR UPPER LEVEL
C         -91       ERROR IN FLTMWR
C         -92       ERROR IN MATGET FOR OUTPUT
C         -93       ERROR IN FLAQWR
C         -94       ERROR IN GRIDPR
C
C OTHER INFORMATION --
C
C
C
C DECLARE PRINT FLAG ARRAY AND MEMBERS
C
      LOGICAL LPRINT
      LOGICAL LINPTP
      LOGICAL LGRIDP
      LOGICAL LUNITP
      LOGICAL LSTATP
      LOGICAL LSBRGP
      LOGICAL LMTHDP
      LOGICAL LSTRDP
      LOGICAL LVMTHP
      LOGICAL LVPRFP
      LOGICAL LUAMV
C
C SET DIMENSIONS ON INPUT VARIABLES
C
      DIMENSION INFILE(6)
      DIMENSION LPRINT(9)
      DIMENSION JINTSC(11)
      DIMENSION REALSC(12)
      DIMENSION OUTMAT(1)
      DIMENSION TOPMAT(1)
      CHARACTER*4 MFILNM(NAMLEN)
      CHARACTER*4 MFILID(NIDLEN)
      DIMENSION JSCRTC(NSCRTC)
      DIMENSION FACMLT(NUNITS)
      DIMENSION FACADD(NUNITS)
      DIMENSION SMOLWT(NUNITS)
      DIMENSION XSTATL(NSTATS)
      DIMENSION YSTATL(NSTATS)
      DIMENSION STATHT(NSTATS)
      DIMENSION PARAMS(NPARAM)
      DIMENSION VPARAM(NVPARM)
      CHARACTER*4 MVARBL(NAMLEN, NUNITS)
      CHARACTER*4 MUNITS(NAMLEN, NUNITS)
      CHARACTER*4 MSTATS(NAMLEN, NSTATS)
      CHARACTER*4 MSBRGN(NAMLEN, NSBRGN)
      CHARACTER*4 MPARAM(NAMLEN, NPARAM)
      CHARACTER*4 MVPARM(NAMLEN, NVPARM)
      DIMENSION JRGRID(NXCELL, NYCELL)
      DIMENSION JMTHDN(NSBRGN, NVARBL)
      DIMENSION JPARMP(NSBRGN, NVARBL)
      DIMENSION JPARMC(NSBRGN, NVARBL)
      DIMENSION JVMTHN(NSBRGN, NVARBL)
      DIMENSION JVPRMP(NSBRGN, NVARBL)
      DIMENSION JVPRMC(NSBRGN, NVARBL)
      DIMENSION BASGRD(NXCELL, NYCELL)
      DIMENSION ALTGRD(NXCELL, NYCELL)
      DIMENSION STAVAL(NSTATS, NVARBL)
      DIMENSION SMTHMN(NSBRGN, NVARBL)
      DIMENSION SMTHMX(NSBRGN, NVARBL)
      DIMENSION VMTHMN(NSBRGN, NVARBL)
      DIMENSION VMTHMX(NSBRGN, NVARBL)
      DIMENSION XPROFL(NSBRGN, NVARBL)
      DIMENSION YPROFL(NSBRGN, NVARBL)
      DIMENSION DIFBRK(NXCELL, NYCELL)
      DIMENSION REGTOP(NXCELL, NYCELL)
      DIMENSION TOPCON(NXCELL, NYCELL)
      DIMENSION TOPSPR(NXCELL, NYCELL)
      DIMENSION PRFHGT(NPRFHT, NSBRGN, NVARBL)
      DIMENSION PRFVAL(NPRFHT, NSBRGN, NVARBL)
C
C SET DIMENSIONS OF LOCAL VARIABLES
C
      CHARACTER*4 MTIHDR(10,3)
      CHARACTER*4 MTVHDR(10,8)
      CHARACTER*4 MMETHD(10,8)
      CHARACTER*4 MVMTHD(10,9)
      CHARACTER*4 MHEADR(60)
      CHARACTER*4 MCRDID(20)
      CHARACTER*4 MTITLE(60)
      CHARACTER*4 MDFBRK(10)
      CHARACTER*4 MRGTOP(10)
C
C SET LOCAL SCALARS
C
      DATA NFLVAR /1/
      DATA NFLZCL /1/
      DATA NTIHDR /3/
      DATA NTVHDR /8/
      DATA NMETHD /8/
      DATA NVMTHD /9/
      DATA NFILSC /100/
      DATA NTILEN /60/
      DATA KPRML /1/
      DATA KVPRL /1/
      DATA KCNST /1/
      DATA KGDVL /2/
      DATA KTITL /50/
      DATA KZCLL /1/
      DATA NSGMNT /1/
C
C SET TIME-INVARIANT PACKET HEADER NAMES
C
      DATA  MTIHDR             /'U','N','I','T','S',' ',' ',' ',' ',' ',
     &                          'S','T','A','T','I','O','N','S',' ',' ',
     &                          'T','I','M','E','I','N','T','E','R','V'/
C
C SET TIME VARIANT PACKET HEADER NAMES
C
      DATA  MTVHDR             /'S','U','B','R','E','G','I','O','N',' ',
     &                          'M','E','T','H','O','D',' ',' ',' ',' ',
     &                          'V','E','R','T','I','C','A','L','M','E',
     &                          'C','O','N','S','T','A','N','T','S',' ',
     &                          'G','R','I','D','V','A','L','U','E','S',
     &                          'S','T','A','T','I','O','N','R','E','A',
     &                          'V','E','R','T','I','C','A','L','P','R',
     &                          'E','N','D','T','I','M','E',' ',' ',' '/
C
C SET METHOD NAMES
C
      DATA  MMETHD             /'C','O','N','S','T','A','N','T',' ',' ',
     &                          'G','R','I','D','V','A','L','U','E',' ',
     &                          'S','T','A','T','I','N','T','E','R','P',
     &                          'S','P','L','I','T','/','C','O','M','B',
     &                          'E','-','W','I','N','T','E','R','P',' ',
     &                          'N','-','S','I','N','T','E','R','P',' ',
     &                          'P','O','I','S','S','O','N',' ',' ',' ',
     &                          'U','S','E','R',' ',' ',' ',' ',' ',' '/
C
C SET VERTICAL METHOD NAMES
C
      DATA  MVMTHD             /'C','O','N','S','T','A','N','T',' ',' ',
     &                          'A','B','S','P','R','O','F','I','L','E',
     &                          'R','E','L','P','R','O','F','I','L','E',
     &                          'E','-','W','I','N','T','E','R','P',' ',
     &                          'N','-','S','I','N','T','E','R','P',' ',
     &                          'A','B','S','P','R','O','F','R','A','T',
     &                          'R','E','L','P','R','O','F','R','A','T',
     &                          'V','E','R','T','U','S','E','R',' ',' ',
     &                          'F','I','X','P','R','O','F','I','L','E'/
C
C SET TITLE
C
      DATA MTITLE /'A', 'I', 'R', ' ', 'Q', 'U', 'A', 'L', 'I', 'T',
     $             'Y', ' ', 'V', 'A', 'L', 'U', 'E', 'S', ' ', '(',
     $             'I', 'N', ' ', 'P', 'A', 'R', 'T', 'S', ' ', 'P',
     $             'E', 'R', ' ', 'M', 'I', 'L', 'L', 'I', 'O', 'N',
     $             ')', ' ', 'S', 'P', 'E', 'C', 'I', 'E', 'S', ' ',
     $             ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' '/
C
C SET INPUT FILE VARIABLE NAMES
C
      DATA MDFBRK /'D', 'I', 'F', 'F', 'B', 'R', 'E', 'A', 'K', ' '/
      DATA MRGTOP /'R', 'E', 'G', 'I', 'O', 'N', 'T', 'O', 'P', ' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C TEST NAME LENGTH FOR POSITIVE VALUE
C
      IF (NAMLEN .LE. 0) GO TO 901
C
C TEST NUMBER OF VARIABLES FOR POSITIVE VALUE
C
      IF (NVARBL .LE. 0) GO TO 902
C
C TEST NUMBER OF SUBREGIONS FOR POSITIVE VALUE
C
      IF (NSBRGN .LE. 0) GO TO 903
C
C TEST NUMBER OF X-CELLS FOR POSITIVE VALUE
C
      IF (NXCELL .LE. 0) GO TO 904
C
C TEST NUMBER OF Y-CELLS FOR POSITIVE VALUE
C
      IF (NYCELL .LE. 0) GO TO 905
C
C TEST NUMBER OF Z CELLS FOR POSITIVE VALUE
C
      IF (NZCELL .LE. 0) GO TO 906
C
C TEST AVAILABLE SCRATCH
C
      IF (NSCRTC .LT. MAX0(NAMLEN * NVARBL, NFILSC)) GO TO 907
C
C TAKE APART THE FILE UNIT NUMBER VECTOR
C
      IDFBRK = INFILE(1)
      IRGTOP = INFILE(2)
      ITPCON = INFILE(3)
C
C TAKE APART THE PRINT FLAG VECTOR
C
      LINPTP = LPRINT(1)
      LGRIDP = LPRINT(2)
      LUNITP = LPRINT(3)
      LSTATP = LPRINT(4)
      LSBRGP = LPRINT(5)
      LMTHDP = LPRINT(6)
      LSTRDP = LPRINT(7)
      LVMTHP = LPRINT(8)
      LVPRFP = LPRINT(9)
C
C TAKE APART THE INTEGER SCALARS VECTOR
C
      INCARD = JINTSC(1)
      IPRINT = JINTSC(2)
      IOUTFL = JINTSC(3)
      IMATFL = JINTSC(4)
      NZLOWR = JINTSC(5)
      NZUPPR = JINTSC(6)
      JBEGDT = JINTSC(7)
      JENDDT = JINTSC(8)
      JUTMZN = JINTSC(9)
      JMISSV = JINTSC(10)
      ITCFIL = JINTSC(11)
C
C TAKE APART THE REAL SCALARS VECTOR
C
      BEGTIM = REALSC( 1)
      ENDTIM = REALSC( 2)
      XUTMOR = REALSC(3)
      YUTMOR = REALSC(4)
      XREGOR = REALSC( 5)
      YREGOR = REALSC( 6)
      XCELLD = REALSC( 7)
      YCELLD = REALSC( 8)
      ZHTSUR = REALSC( 9)
      ZMINLW = REALSC(10)
      ZMINUP = REALSC(11)
      RMISSV = REALSC(12)
C
C SET CURRENT DATE AND TIME TO BEGINNING DATE AND TIME
C
      JCURDT = JBEGDT
      CURTIM = BEGTIM
C
C READ AND PRINT A TIME-INVARIANT HEADER CARD
C
  105 READ (INCARD,1105) MHEADR, MCRDID
      WRITE(IPRINT,2105) MHEADR, MCRDID
C
C PACK HEADER AND SET COMPARISON LOOP
C
      CALL TXTPAK(IPRINT, NIDLEN, MHEADR, NPACKD, JFLAG)
      IF (JFLAG .LT. 0) GO TO 911
      DO 110 J = 1, NTIHDR
C
C COMPARE THIS HEADER VALUE WITH THE ACCEPTABLE ONES
C
         CALL COMPAR(IPRINT, NAMLEN, MHEADR, MTIHDR(1,J), JFLAG)
         IF (JFLAG .LT. 0) GO TO 912
         IF (JFLAG .EQ. 0) GO TO 110
C
C SAVE MODULE NUMBER AND SKIP TO TRANSFER
C
         KSBTN = J
         GO TO 115
C
C END LOOP -- IF NO MATCH, TERMINATE
C
  110 CONTINUE
      GO TO 913
C
C TRANSFER TO THE APPROPRIATE SUBROUTINE CALL
C
  115 GO TO (125, 135, 145), KSBTN
C
C UNITS PACKET TO BE PROCESSED
C
  125 CALL UNITRD(INCARD, IPRINT, NAMLEN, NUNITS, LINPTP, LUNITP,
     $    RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MUNITS, JFLAG)
      IF (JFLAG .LT. 0) GO TO 914
C
C GO BACK FOR ANOTHER TIME-INVARIANT HEADER CARD
C
      GO TO 105
C
C STATION IDENTIFICATION PACKET TO BE PROCESSED
C
  135 CALL STATRD(INCARD, IPRINT, NAMLEN, NUNITS, NSTATS, LINPTP,
     $    LSTATP, XREGOR, YREGOR, XCELLD, YCELLD, RMISSV, FACMLT,
     $    FACADD, SMOLWT, MVARBL, XSTATL, YSTATL, STATHT, MSTATS,
     $    JFLAG)
      IF (JFLAG .LT. 0) GO TO 915
C
C GO BACK FOR ANOTHER TIME-INVARIANT HEADER CARD
C
      GO TO 105
C
C TIME INTERVAL PACKET HEADER -- READ AND CHECK DATES AND TIMES
C
  145 CALL TIMERD(INCARD, IPRINT, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 916
      IF (JSTRDT .EQ. JCURDT .AND. STRTIM .EQ. CURTIM) GO TO 155
C
C IF INTERVAL START IS AFTER CURRENT TIME, NOTE ERROR
C
      IF (JSTRDT .GT. JCURDT) GO TO 917
      IF (JSTRDT .EQ. JCURDT .AND. STRTIM .GT. CURTIM) GO TO 917
C
C RESET STARTING DATE AND TIME WITH MESSAGE
C
      WRITE (IPRINT, 2145) JSTRDT, STRTIM, JCURDT, CURTIM
      JSTRDT = JCURDT
      STRTIM = CURTIM
C
C VERIFY THAT ENDING DATE AND TIME ARE WITHIN FILE VALUES
C
  155 IF (JENDDT .GT. JSTPDT) GO TO 165
      IF( JENDDT .EQ. JSTPDT  .AND.  ENDTIM .GE. STPTIM ) GO TO 165
C
C THIS TIME INTERVAL TOO LONG -- RESET TO FILE VALUE WITH MESSAGE
C
      WRITE (IPRINT, 2155) JSTPDT, STPTIM,JENDDT, ENDTIM
      JSTPDT = JENDDT
      STPTIM = ENDTIM
C
C SET CURRENT DATE AND TIME TO THE END OF THIS PACKET INTERVAL
C
  165 JCURDT = JSTPDT
      CURTIM = STPTIM
C
C GET  DIFFUSION BREAK VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IDFBRK .GT. 0) THEN
        IF (LUAMV) THEN
          CALL HTPRRD(IPRINT, IDFBRK, NXCELL, NYCELL, NZCELL,
     $        JSTRDT, STRTIM, DIFBRK, JFLAG)
          IF (JFLAG .LT. 0) GO TO 925
        ELSE
          CALL DFBKRD(IPRINT, IDFBRK, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $        JSTRDT, STRTIM, MDFBRK, JSCRTC, DIFBRK, JFLAG)
          IF (JFLAG .LT. 0) GO TO 921
        ENDIF
      ENDIF
C
C GET REGION TOP VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IRGTOP .GT. 0)
     $     CALL RGTPRD(IPRINT, IRGTOP, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $         JSTRDT, STRTIM, MRGTOP, JSCRTC, REGTOP, JFLAG)
      IF (JFLAG .LT. 0) GO TO 922
C
C GET TOP CONCENTRATION VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (ITPCON .GT. 0) THEN
        IF (LUAMV) THEN
          CALL TPUVRD(IPRINT, ITPCON, ITCFIL, NAMLEN, NSPECS,
     $        NXCELL, NYCELL, JSTRDT, STRTIM, MVARBL, JSCRTC,
     $        TOPCON, TOPMAT, JFLAG)
          IF (JFLAG .LT. 0) GO TO 924
        ELSE
          CALL TPCNRD(IPRINT, ITPCON, ITCFIL, NAMLEN, NSPECS,
     $        NXCELL, NYCELL, JSTRDT, STRTIM, MVARBL, JSCRTC,
     $        TOPCON, TOPMAT, JFLAG)
          IF (JFLAG .LT. 0) GO TO 923
        ENDIF
      ENDIF
C
C READ AND PRINT A TIME-VARIANT HEADER CARD
C
  205 READ (INCARD,1205) MHEADR, MCRDID
      WRITE(IPRINT,2205) MHEADR, MCRDID
C
C PACK HEADER AND SET COMPARISON LOOP
C
      CALL TXTPAK(IPRINT, NIDLEN, MHEADR, NPACKD, JFLAG)
      IF (JFLAG .LT. 0) GO TO 931
      DO 210 J = 1, NTVHDR
C
C COMPARE THIS HEADER VALUE WITH THE ACCEPTABLE ONES
C
         CALL COMPAR(IPRINT, NAMLEN, MHEADR, MTVHDR(1,J), JFLAG)
         IF (JFLAG .LT. 0) GO TO 932
         IF (JFLAG .EQ. 0) GO TO 210
C
C SET MODULE NUMBER AND SKIP TO TRANSFER
C
         KSBTN = J
         GO TO 215
C
C END LOOP -- IF NO MATCH, TERMINATE
C
  210 CONTINUE
      GO TO 933
C
C TRANSFER TO THE APPROPRIATE SUBROUTINE CALL
C
  215 GO TO (225, 235, 245, 255, 265, 275, 285, 295), KSBTN
C
C SUBREGION PACKET TO BE PROCESSED
C
  225 CALL SBRGRD(INCARD, IPRINT, NAMLEN, NIDLEN, NSBRGN, NXCELL,
     $    NYCELL, LINPTP, LSBRGP, JBEGDT, JENDDT, BEGTIM, ENDTIM,
     $    MFILNM, MFILID, MSBRGN, JRGRID, JFLAG)
      IF (JFLAG .LT. 0) GO TO 941
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C METHOD PACKET TO BE PROCESSED
C
  235 CALL MTHDRD(INCARD, IPRINT, NAMLEN, NVARBL, NSBRGN, NMETHD,
     $    NPARAM,  KPRML, LINPTP, LMTHDP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MSBRGN, MMETHD, PARAMS, MPARAM, JMTHDN,
     $    JPARMP, JPARMC, SMTHMN, SMTHMX, JFLAG)
      IF (JFLAG .LT. 0) GO TO 942
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C VERTICAL METHOD PACKET TO BE PROCESSED
C
  245 CALL MTHDRD(INCARD, IPRINT, NAMLEN, NVARBL, NSBRGN, NVMTHD,
     $    NVPARM,  KVPRL, LINPTP, LVMTHP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MSBRGN, MVMTHD, VPARAM, MVPARM, JVMTHN,
     $    JVPRMP, JVPRMC, VMTHMN, VMTHMX, JFLAG)
      IF (JFLAG .LT. 0) GO TO 943
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C CONSTANTS PACKET TO BE PROCESSED
C
  255 CALL CNSTRD(INCARD, IPRINT, IMATFL, NAMLEN, NVARBL, NSBRGN,
     $    NXCELL, NYCELL,  KCNST, LINPTP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MSBRGN, JRGRID, JMTHDN,
     $    SMTHMN, SMTHMX, BASGRD, OUTMAT, JFLAG)
      IF (JFLAG .LT. 0) GO TO 944
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C GRID VALUES PACKET TO BE PROCESSED
C
  265 CALL GDVLRD(INCARD, IPRINT, IMATFL, NAMLEN, NVARBL, NSBRGN,
     $    NXCELL, NYCELL,  KGDVL, LINPTP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MSBRGN, JRGRID, JMTHDN, SMTHMN, SMTHMX,
     $    BASGRD, OUTMAT, JFLAG)
      IF (JFLAG .LT. 0) GO TO 945
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C STATION READINGS PACKET TO BE PROCESSED
C
  275 CALL STVLRD(INCARD, IPRINT, NAMLEN, NVARBL, NSTATS, LINPTP,
     $    LSTRDP, RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MSTATS,
     $    STAVAL, JFLAG)
      IF (JFLAG .LT. 0) GO TO 946
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C VERTICAL PROFILES PACKET TO BE PROCESSED
C
  285 CALL VPRFRD(INCARD, IPRINT, NAMLEN, NVARBL, NUNITS, NSBRGN,
     $    NPRFHT, NXCELL, NYCELL,
     $    LINPTP, LVPRFP, XREGOR, YREGOR, XCELLD, YCELLD, RMISSV,
     $    FACMLT, FACADD, SMOLWT, MVARBL, MSBRGN, XPROFL,
     $    YPROFL, PRFHGT, PRFVAL, JFLAG)
      IF (JFLAG .LT. 0) GO TO 947
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C END TIME PACKET TERMINATOR -- SET REVERSE LOOP FOR VARIABLES
C
  295 DO 700 N = 1, NVARBL
         KVRBL = NVARBL - N + 1
C
C LOAD GROUND LEVEL OUTPUT GRID FOR THIS VARIABLE
C
         KZCLL = 1
         CALL MATGET(IPRINT, IMATFL, NXCELL, NYCELL, NZCELL, NVARBL,
     $       KZCLL, KVRBL, BASGRD, OUTMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 949
C
C IF WANTED, LOAD TOP CONCENTRATION FOR THIS VARIABLE
C
         IF (ITPCON .LE. 0) GO TO 297
         IF (KVRBL .GT. NSPECS) GO TO 297
         CALL MATGET(IPRINT, ITCFIL, NXCELL, NYCELL, NFLZCL, NVARBL,
     $       KZCLL, KVRBL, TOPCON, TOPMAT, JFLAG)
         IF (JFLAG .LT. 0)  GO TO 950
C
C FIRST PASS AT SURFACE LEVEL -- SET Y AND X LOOPS
C
  297    DO 390 J = 1, NYCELL
            KYCLL = J
            DO 380 I = 1, NXCELL
               KXCLL = I
C
C ISOLATE AND CHECK THE SUBEGION AND METHOD NUMBERS
C
               KSBRG = JRGRID(I,J)
               IF (KSBRG .LT. 1) GO TO 951
               IF (KSBRG .GT. NSBRGN) GO TO 951
               KMTHD = JMTHDN(KSBRG, KVRBL)
               IF (KMTHD .EQ. 0) GO TO 952
               IF (KMTHD .GT. NMETHD) GO TO 952
C
C CHECK FOR NEGATIVE METHOD NUMBER -- INDICATES SKIP TO NEXT PASS
C
               IF (KMTHD .LT. 0) GO TO 380
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL (IF ANY) FOR THIS METHOD
C
               GO TO (378, 378, 325, 335, 378, 378, 365, 375), KMTHD
C
C STATION VALUES -- LOCATE PARAMETERS FOR THIS SUBREGION AND VARIABLE
C
  325          NPARMC = JPARMC(KSBRG, KVRBL)
               IF (NPARMC .LT. 1) GO TO 953
               IF (NPARMC .GT. NPARAM) GO TO 953
               KPRMP = JPARMP(KSBRG, KVRBL)
               IF (KPRMP .LT. 1) GO TO 954
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 954
C
C CALL THE STATION VALUES PROCESSING ROUTINE
C
               CALL STASGN(IPRINT, NAMLEN, NSTATS, NXCELL, NYCELL,
     $             KXCLL, KYCLL, RMISSV, SMTHMN(KSBRG, KVRBL),
     $             SMTHMX(KSBRG, KVRBL), PARAMS(KPRMP),
     $             PARAMS(KPRMP + 1), PARAMS(KPRMP + 2),
     $             PARAMS(KPRMP + 3), MVARBL(1, KVRBL), XSTATL,
     $             YSTATL, STAVAL(1, KVRBL), MSTATS, JRGRID,
     $             BASGRD(I, J), JFLAG)
               IF (JFLAG .LT. 0) GO TO 955
C
C SKIP TO END OF INNERMOST (X) LOOP
C
               GO TO 380
C
C SPLIT/COMBINE -- LOCATE PARAMETERS FOR THIS SUBREGION AND VARIABLE
C
  335          NPARMC = JPARMC(KSBRG, KVRBL)
               IF (NPARMC .LT. 1) GO TO 956
               IF (NPARMC .GT. NPARAM) GO TO 956
               KPRMP = JPARMP(KSBRG, KVRBL)
               IF (KPRMP .LT. 1) GO TO 957
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 957
C
C CALL THE SPLIT/COMBINE PROCESSING ROUTINE
C
               CALL SPLITC (IPRINT, IMATFL, NAMLEN, NVARBL, NXCELL,
     $             NYCELL, NPARMC, KVRBL, KXCLL, KYCLL, RMISSV,
     $             SMTHMN(KSBRG, KVRBL), SMTHMX(KSBRG, KVRBL),
     $             PARAMS(KPRMP), MVARBL, MPARAM(1, KPRMP),
     $             BASGRD, ALTGRD, OUTMAT, JFLAG)
               IF (JFLAG .LT. 0) GO TO 958
C
C SKIP TO END OF INNERMOST (X) LOOP
C
               GO TO 380
C
C POISSON DISTN. -- LOCATE PARAMETERS FOR THIS SUBREGION AND VARIABLE
C
  365          NPARMC = JPARMC(KSBRG, KVRBL)
               IF (NPARMC .LT. 1) GO TO 959
               IF (NPARMC .GT. NPARAM) GO TO 959
               KPRMP = JPARMP(KSBRG, KVRBL)
               IF (KPRMP .LT. 1) GO TO 961
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 961
C
C CALL THE POISSON DISTRIBUTION PROCESSING ROUTINE
C
                CALL POISSP(IPRINT, NAMLEN, NSTATS, NXCELL, NYCELL,
     $             KSBRG, XCELLD, YCELLD, RMISSV, SMTHMN(KSBRG, KVRBL),
     $             SMTHMX(KSBRG, KVRBL), PARAMS(KPRMP),
     $             PARAMS(KPRMP + 1), PARAMS(KPRMP + 2),
     $             MVARBL(1,KVRBL), MSBRGN(1,KSBRG), XSTATL, YSTATL,
     $             STAVAL(1, KVRBL), MSTATS, JRGRID, ALTGRD, BASGRD,
     $             JFLAG)
               IF (JFLAG .LT. 0) GO TO 962
C
C SKIP TO METHOD NEGATION, SINCE POISSON DOES ENTIRE GRID
C
               GO TO 378
C
C USER SUBROUTINE -- LOCATE PARAMETERS FOR THIS SUBREGION AND VARIABLE
C
  375          NPARMC = JPARMC(KSBRG, KVRBL)
               IF (NPARMC .LT. 1) GO TO 376
               IF (NPARMC .GT. NPARAM) GO TO 963
               KPRMP = JPARMP(KSBRG, KVRBL)
               IF (KPRMP .LT. 1) GO TO 964
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 964
C
C CALL THE USER SUBROUTINE PROCESSING ROUTINE
C
  376           CALL AIRUSR(INCARD, IPRINT, IMATFL, NAMLEN, NIDLEN,
     $             NSTATS, NSBRGN, NPARMC, NXCELL, NYCELL, NSCRTC,
     $             JMISSV, JSTRDT, JSTPDT, JUTMZN, STRTIM, STPTIM,
     $             XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD, YCELLD,
     $             RMISSV, SMTHMN(KSBRG, KVRBL),
     $             SMTHMX(KSBRG, KVRBL), MFILNM, MFILID,
     $             MVARBL(1, KVRBL), INFILE, JSCRTC, XSTATL,
     $             YSTATL, STATHT, PARAMS(KPRMP), JRGRID,
     $             STAVAL, BASGRD, ALTGRD, OUTMAT, JFLAG)
               IF (JFLAG .LT. 0) GO TO 965
C
C SET THIS METHOD NUMBER SO IT WON'T BE REFERENCED AGAIN -- END LOOPS
C
  378          JMTHDN(KSBRG, KVRBL) = -KMTHD
  380       CONTINUE
  390    CONTINUE
C
C SET SECOND PASS LOOPS TO DO INTERPOLATIONS
C
         DO 490 J=1, NYCELL
            KYCLL = J
            DO 480 I = 1, NXCELL
               KXCLL = I
C
C ISOLATE SUBREGION AND METHOD NUMBERS -- THEY HAVE ALREADY BEEN TESTED
C
               KSBRG = JRGRID(I,J)
               KMTHD = JMTHDN(KSBRG, KVRBL)
C
C IF METHOD NUMBER IS NEGATIVE, SET IT POSITIVE FOR THIS PASS
C
               IF (KMTHD .GT. 0) GO TO 403
               KMTHD = -KMTHD
               JMTHDN(KSBRG, KVRBL) = KMTHD
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL (IF ANY) FOR THIS METHOD
C
  403          GO TO (480, 480, 480, 480, 445, 455, 480, 480), KMTHD
C
C CALL THE EAST-WEST INTERPOLATION ROUTINE
C
  445          CALL EWINTR(IPRINT, NAMLEN, NXCELL, NYCELL, KXCLL,
     $             KYCLL, RMISSV, SMTHMN(KSBRG, KVRBL),
     $             SMTHMX(KSBRG, KVRBL), MVARBL(1, KVRBL),
     $             MSBRGN(1, KSBRG), JRGRID, BASGRD, JFLAG)
               IF (JFLAG .LT. 0) GO TO 966
C
C SKIP TO END OF INNER LOOP
C
               GO TO 480
C
C CALL THE NORTH-SOUTH INTERPOLATION ROUTINE
C
  455          CALL NSINTR(IPRINT, NAMLEN, NXCELL, NYCELL, KXCLL,
     $             KYCLL, RMISSV, SMTHMN(KSBRG, KVRBL),
     $             SMTHMX(KSBRG, KVRBL), MVARBL(1, KVRBL),
     $             MSBRGN(1, KSBRG), JRGRID, BASGRD, JFLAG)
               IF (JFLAG .LT. 0) GO TO 967
C
C END LOOPS
C
  480       CONTINUE
  490    CONTINUE
C
C REPLACE GROUND LEVEL OUTPUT GRID
C
         CALL MATPUT(IPRINT, IMATFL, NXCELL, NYCELL, NZCELL, NVARBL,
     $       KZCLL, KVRBL, BASGRD, OUTMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 968
C
C SET UP A LOOP TO RUN OVER ALL Z-CELLS ABOVE THE SURFACE
C
         DO 695 K = 2, NZCELL
            KZCLL = K
C
C LOAD OUTPUT GRID FOR THIS LEVEL AND VARIABLE
C
            CALL MATGET(IPRINT, IMATFL, NXCELL, NYCELL, NZCELL, NVARBL,
     $          KZCLL, KVRBL, ALTGRD, OUTMAT, JFLAG)
            IF (JFLAG .LT. 0) GO TO 970
C
C SET X AND Y LOOPS FOR FIRST PASS AT THIS LEVEL
C
            DO 640 J = 1,NYCELL
               KYCLL = J
               DO 635 I = 1, NXCELL
                  KXCLL = I
C
C ISOLATE AND CHECK THE SUBEGION AND METHOD NUMBERS
C
                  KSBRG = JRGRID(I,J)
                  IF (KSBRG .LT. 1) GO TO 971
                  IF (KSBRG .GT. NSBRGN) GO TO 971
                  KVMTH = JVMTHN(KSBRG, KVRBL)
                  IF (KVMTH .EQ. 0) GO TO 972
                  IF (KVMTH .GT. NVMTHD) GO TO 972
C
C CHECK FOR NEGATIVE METHOD NUMBER -- INDICATES SKIP TO NEXT PASS
C
                  IF (KVMTH .LT. 0) GO TO 635
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL (IF ANY) FOR THIS METHOD
C
                  GO TO (505, 515, 525, 578, 578, 555, 565, 575, 570), 
     $                   KVMTH
C
C CONSTANT PROJECTION -- MOVE SURFACE VALUE TO THIS LEVEL
C
  505             ALTGRD(I, J) = BASGRD(I, J)
C
C SKIP TO END OF INNER (X) LOOP
C
                  GO TO 635
C
C CALL THE ABSOLUTE PROFILE ROUTINE
C
  515             IF (LUAMV) THEN
                    CALL ABSPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1,KVRBL), MSBRGN(1,KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ELSE
                    CALL ABSPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1,KVRBL), MSBRGN(1,KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK, REGTOP,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ENDIF
C
C SKIP TO END OF INNER (X) LOOP
C
                  GO TO 635
C
C CALL THE RELATIVE PROFILE ROUTINE
C
  525             CALL RELPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                XPROFL(KSBRG, KVRBL), YPROFL(KSBRG, KVRBL),
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1, KVRBL), MSBRGN(1, KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK, REGTOP,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 974
C
C SKIP TO END OF INNER (X) LOOP
C
                  GO TO 635
C
C CALL THE ABSOLUTE PROFILE RATIO ROUTINE
C
  555             IF (LUAMV) THEN
                    CALL ABPRVR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, KXCLL, KYCLL, KZCLL,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1, KVRBL), MSBRGN(1, KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK, TOPCON,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 975
                  ELSE
                    CALL ABPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1, KVRBL), MSBRGN(1, KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 975
                  ENDIF
C
C SKIP TO END OF INNER (X) LOOP
C
                  GO TO 635
C
C CALL THE RELATIVE PROFILE RATIO ROUTINE
C
  565             CALL RLPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                XPROFL(KSBRG, KVRBL), YPROFL(KSBRG, KVRBL),
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1, KVRBL), MSBRGN(1, KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 976
C
C SKIP TO END OF INNER (X) LOOP
C
                  GO TO 635
C
C CALL THE FIXED PROFILE ROUTINE
C
  570             IF (LUAMV) THEN
                    CALL FIXPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1,KVRBL), MSBRGN(1,KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 980
                  ELSE
                    CALL FIXPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BASGRD(KXCLL, KYCLL), RMISSV,
     $                VMTHMN(KSBRG, KVRBL), VMTHMX(KSBRG, KVRBL),
     $                MVARBL(1,KVRBL), MSBRGN(1,KSBRG),
     $                PRFHGT(1, KSBRG, KVRBL), PRFVAL(1, KSBRG, KVRBL),
     $                DIFBRK, REGTOP,
     $                ALTGRD(KXCLL, KYCLL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 980
                  ENDIF
C
C SKIP TO END OF INNER (X) LOOP
C
                  GO TO 635
C
C USER VERT. SUBROUTINE -- LOCATE PARAMETERS FOR THIS SUBREGION AND VARI
C
  575             NVPRMC = JVPRMC(KSBRG, KVRBL)
                  IF (NVPRMC .LT. 1) GO TO 576
                  IF (NVPRMC .GT. NPARAM) GO TO 977
                  KVPRP = JVPRMP(KSBRG, KVRBL)
                  IF (KVPRP .LT. 1) GO TO 978
                  IF (KVPRP .GT. NVPARM - NVPRMC + 1) GO TO 978
C
C CALL THE USER VERT. SUBROUTINE PROCESSING ROUTINE
C
  576             CALL AIRVUS(INCARD, IPRINT, IMATFL, NAMLEN, NIDLEN,
     $                NSBRGN, NVPRMC, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, NSCRTC, KSBRG,
     $                NVPRMC, KZCLL, JSTRDT, JSTPDT, JUTMZN, JMISSV,
     $                STRTIM, STPTIM, XUTMOR, YUTMOR, XREGOR,
     $                YREGOR, XCELLD, YCELLD, ZHTSUR,
     $                ZMINLW, ZMINUP, RMISSV, VMTHMN(KSBRG, KVRBL),
     $                VMTHMX(KSBRG, KVRBL), MFILNM, MFILID,
     $                MVARBL(1, KVRBL), INFILE, JSCRTC,
     $                VPARAM(KVPRP), XPROFL(1, KVRBL), YPROFL(1, KVRBL),
     $                JRGRID, DIFBRK, REGTOP, TOPCON, BASGRD, ALTGRD,
     $                PRFHGT(1, 1, KVRBL), PRFVAL(1, 1, KVRBL),
     $                OUTMAT, JFLAG)
                  IF (JFLAG .LT. 0) GO TO 979
C
C SET THIS METHOD NUMBER SO IT WON'T BE REFERENCED AGAIN -- END LOOPS
C
  578             JVMTHN(KSBRG, KVRBL) = -KVMTH
  635          CONTINUE
  640       CONTINUE
C
C SET SECOND PASS LOOPS TO DO INTERPOLATIONS
C
            DO 690 J = 1, NYCELL
               KYCLL = J
               DO 680 I = 1, NXCELL
                  KXCLL = I
C
C ISOLATE SUBREGION AND METHOD NUMBERS -- THEY HAVE ALREADY BEEN TESTED
C
                  KSBRG = JRGRID(I, J)
                  KVMTH = JVMTHN(KSBRG, KVRBL)
C
C IF METHOD NUMBER IS NEGATIVE, SET IT POSITIVE FOR THIS PASS
C
                  IF (KVMTH .GT. 0) GO TO 660
                  KVMTH = -KVMTH
                  JVMTHN(KSBRG, KVRBL) = KVMTH
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL (IF ANY) FOR THIS METHOD
C
  660             GO TO (680, 680, 680, 670, 675, 680, 680, 680, 680), 
     $                   KVMTH
C
C CALL THE EAST-WEST INTERPOLATION ROUTINE
C
  670             CALL EWINTR(IPRINT, NAMLEN, NXCELL, NYCELL, KXCLL,
     $                KYCLL, RMISSV, VMTHMN(KSBRG, KVRBL),
     $                VMTHMX(KSBRG, KVRBL), MVARBL(1, KVRBL),
     $                MSBRGN(1, KSBRG), JRGRID,
     $                ALTGRD, JFLAG)
                  IF (JFLAG .LT. 0) GO TO 981
C
C SKIP TO END OF INNER LOOP
C
                  GO TO 680
C
C CALL THE NORTH-SOUTH INTERPOLATION ROUTINE
C
  675             CALL NSINTR(IPRINT, NAMLEN, NXCELL, NYCELL, KXCLL,
     $                KYCLL, RMISSV, VMTHMN(KSBRG, KVRBL),
     $                VMTHMX(KSBRG, KVRBL), MVARBL(1, KVRBL),
     $                MSBRGN(1, KSBRG), JRGRID,
     $                ALTGRD, JFLAG)
                  IF (JFLAG .LT. 0) GO TO 982
C
C END INNER LOOPS
C
  680          CONTINUE
  690       CONTINUE
C
C REPLACE OUTPUT GRID FOR THIS LEVEL AND VARIABLE
C
            CALL MATPUT(IPRINT, IMATFL, NXCELL, NYCELL, NZCELL, NVARBL,
     $          KZCLL, KVRBL, ALTGRD, OUTMAT, JFLAG)
            IF (JFLAG .LT. 0) GO TO 983
  695    CONTINUE
  700 CONTINUE
C
C IF THE OUTPUT FILE IS TO BE WRITTEN, PUT OUT THE TIME RECORD
C
      IF (IOUTFL .LE. 0) GO TO 705
      CALL FLTMWR(IPRINT, IOUTFL, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 991
C
C SET VARIABLE LOOP
C
  705 DO 730 N = 1, NVARBL
         KVRBL = N
C
C LOAD VARIABLE NAME INTO TITLE
C
         DO 710 I = 1, NAMLEN
            MTITLE(I + KTITL) = MVARBL(I,KVRBL)
  710    CONTINUE
C
C SET Z-LEVEL LOOP
C
         DO 720 K = 1, NZCELL
            KZCLL = K
C
C LOAD THE OUTPUT GRID FOR THIS LEVEL AND VARIABLE
C
            CALL MATGET(IPRINT, IMATFL, NXCELL, NYCELL, NZCELL, NVARBL,
     $          KZCLL, KVRBL, BASGRD, OUTMAT, JFLAG)
            IF (JFLAG .LT. 0) GO TO 992
C
C WRITE THE AIR QUALITY RECORD, IF WANTED
C
            IF (IOUTFL .LE. 0) GO TO 715
            IF (KVRBL .GT. NSPECS) GO TO 715
            CALL FLAQWR(IPRINT, IOUTFL, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $          NSGMNT, MVARBL(1, KVRBL), BASGRD, JFLAG)
            IF (JFLAG .LT. 0) GO TO 993
C
C PRINT OUT THE GRID, IF WANTED
C
  715       IF (.NOT. LGRIDP) GO TO 720
C
C CALL THE GRID PRINT ROUTINE WITH 10F10.4 FORMAT, 30 LINES PER PAGE
C
            KFRMT = 125
            KTYPE = KFRMT -(KFRMT/10)*10
            IF (KTYPE .LE. 2)
     $      CALL GRIDPI(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL,
     $          NYCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM,
     $          STPTIM, MFILNM, MFILID, MTITLE, BASGRD, JFLAG)
C           * IF ARRAY IS REAL CALL GRIDPR
            IF (KTYPE .GT. 2)
     $      CALL GRIDPR(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL,
     $          NYCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM,
     $          STPTIM, MFILNM, MFILID, MTITLE, BASGRD, JFLAG)
            IF (JFLAG .LT. 0) GO TO 994
C
C END LOOPS
C
  720    CONTINUE
  730 CONTINUE
C
C SEE WHETHER THIS PACKET ENDS THE FILE -- IF NOT, GET NEXT PACKET
C
      IF (JSTPDT .NE. JENDDT) GO TO 105
      IF (STPTIM .NE. ENDTIM) GO TO 105
C
C REWIND ALL OPEN FILES
C
      IF (IOUTFL .GT. 0) REWIND IOUTFL
      IF (IDFBRK .GT. 0) REWIND IDFBRK
      IF (IRGTOP .GT. 0) REWIND IRGTOP
      IF (ITPCON .GT. 0) REWIND ITPCON
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NAME LENGTH
C
  901 WRITE (IPRINT, 2901) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF VARIABLES
C
  902 WRITE (IPRINT, 2902) NVARBL
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF SUBREGIONS
C
  903 WRITE (IPRINT, 2903) NSBRGN
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF X-CELLS
C
  904 WRITE (IPRINT, 2904) NXCELL
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF Y-CELLS
C
  905 WRITE (IPRINT, 2905) NYCELL
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF Z-CELLS
C
  906 WRITE (IPRINT, 2906) NZCELL
      JFLAG = -6
      GO TO 1000
C
C ERROR MESSAGE FOR INSUFFICIENT SCRATCH STORAGE FOR FILES
C
  907 WRITE (IPRINT, 2907) NSCRTC
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TXTPAK OF TIME-INVARIANT HEADER
C
  911 WRITE (IPRINT, 2911) JFLAG
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COMPAR OF TIME-INVARIANT HEADER
C
  912 WRITE (IPRINT, 2912) JFLAG
      JFLAG = -12
      GO TO 1000
C
C ERROR MESSAGE FOR NO MATCH OF TIME-INVARIANT HEADER
C
  913 WRITE (IPRINT, 2913) (MHEADR(I), I=1, NAMLEN)
      JFLAG = -13
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN UNITRD
C
  914 WRITE (IPRINT, 2914) JFLAG
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN STATRD
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -15
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TIMERD
C
  916 WRITE (IPRINT, 2916) JFLAG
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR GAP IN TIMING
C
  917 WRITE (IPRINT, 2917) JCURDT, CURTIM, JSTRDT, STRTIM
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN DFBKRD
C
  921 WRITE (IPRINT, 2921) JFLAG
      JFLAG = -21
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RGTPRD
C
  922 WRITE (IPRINT, 2922) JFLAG
      JFLAG = -22
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TPCNRD
C
  923 WRITE (IPRINT, 2923) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -23
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TPUVRD
C
  924 WRITE (IPRINT, 2924) JFLAG
      JFLAG = -24
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN HTPRRD
C
  925 WRITE (IPRINT, 2925) JFLAG
      JFLAG = -25
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TIME-VARIANT HEADER
C
  931 WRITE (IPRINT, 2931) JFLAG
      JFLAG = -31
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COMPAR OF TIME-VARIANT HEADER
C
  932 WRITE (IPRINT, 2932) JFLAG
      JFLAG = -32
      GO TO 1000
C
C ERROR MESSAGE FOR NO MATCH FOR TIME-VARIANT HEADER
C
  933 WRITE (IPRINT, 2933) (MHEADR(I), I = 1,NAMLEN)
      JFLAG = -33
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SBRGRD
C
  941 WRITE (IPRINT, 2941) JFLAG
      JFLAG = -41
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MTHDRD
C
  942 WRITE (IPRINT, 2942) JFLAG
      JFLAG = -42
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VERTICAL MTHDRD
C
  943 WRITE (IPRINT, 2943) JFLAG
      JFLAG = -43
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN CNSTRD
C
  944 WRITE (IPRINT, 2944) JFLAG
      JFLAG = -44
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GDVLRD
C
  945 WRITE (IPRINT, 2945) JFLAG
      JFLAG = -45
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN STVLRD
C
  946 WRITE (IPRINT, 2946) JFLAG
      JFLAG = -46
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VPRFRD
C
  947 WRITE (IPRINT, 2947) JFLAG
      JFLAG = -47
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATGET FOR GROUND LEVEL
C
  949 WRITE (IPRINT, 2949) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -49
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATGET FOR TOP CONCENTRATION
C
  950 WRITE (IPRINT, 2950) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -50
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL SUBREGION
C
  951 WRITE (IPRINT, 2951) KXCLL, KYCLL, KSBRG, NSBRGN
      JFLAG = -51
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL METHOD
C
  952 WRITE (IPRINT, 2952) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -52
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON STATION VALUES
C
  953 WRITE (IPRINT, 2953) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -53
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON STATION VALUES
C
  954 WRITE (IPRINT, 2954) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -54
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN STASGN
C
  955 WRITE (IPRINT, 2955) JFLAG
      JFLAG = -55
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON SPLIT/COMBINATION
C
  956 WRITE (IPRINT, 2956) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -56
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON SPLIT/COMBINATION
C
  957 WRITE (IPRINT, 2957) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -57
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SPLITC
C
  958 WRITE (IPRINT, 2958) JFLAG
      JFLAG = -58
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON POISSON METHOD
C
  959 WRITE (IPRINT, 2959) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $    (MSBRGN(I, KSBRG), I = 1, NAMLEN), NPARMC, NPARAM
      JFLAG = -59
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON POISSON METHOD
C
  961 WRITE (IPRINT, 2961) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -61
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN POISSN
C
  962 WRITE (IPRINT, 2962) JFLAG
      JFLAG = -62
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER SUBROUTINE
C
  963 WRITE (IPRINT, 2963) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -63
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER SUBROUTINE
C
  964 WRITE (IPRINT, 2964) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -64
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN AIRUSR
C
  965 WRITE (IPRINT, 2965) JFLAG
      JFLAG = -65
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN EWINTR
C
  966 WRITE (IPRINT, 2966) JFLAG
      JFLAG = -66
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN NSINTR
C
  967 WRITE (IPRINT, 2967) JFLAG
      JFLAG = -67
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATPUT FOR GROUND LEVEL
C
  968 WRITE (IPRINT, 2968) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -68
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATGET FOR UPPER LEVEL
C
  970 WRITE (IPRINT, 2970) JFLAG, KZCLL, (MVARBL(I,KVRBL),I=1,NAMLEN)
      JFLAG = -70
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL VERTICAL SUBREGION
C
  971 WRITE (IPRINT, 2971) KXCLL, KYCLL, KSBRG, NSBRGN
      JFLAG = -71
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL VERTICAL METHOD
C
  972 WRITE (IPRINT, 2972) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -72
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN ABSPRF
C
  973 WRITE (IPRINT, 2973) JFLAG
      JFLAG = -73
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RELPRF
C
  974 WRITE (IPRINT, 2974) JFLAG
      JFLAG = -74
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN ABPRFR
C
  975 WRITE (IPRINT, 2975) JFLAG
      JFLAG = -75
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RLPRFR
C
  976 WRITE (IPRINT, 2976) JFLAG
      JFLAG = -76
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE
C
  977 WRITE (IPRINT, 2977) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -77
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTIN
C
  978 WRITE (IPRINT, 2978) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MSBRGN(I,KSBRG), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -78
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN AIRVUS
C
  979 WRITE (IPRINT, 2979) JFLAG
      JFLAG = -79
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FIXPRF
C
  980 WRITE (IPRINT, 2980) JFLAG
      JFLAG = -80
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VERTICAL EWINTR
C
  981 WRITE (IPRINT, 2981) JFLAG
      JFLAG = -81
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VERTICAL NSINTR
C
  982 WRITE (IPRINT, 2982) JFLAG
      JFLAG = -82
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATPUT FOR UPPER LEVEL
C
  983 WRITE (IPRINT, 2983) JFLAG, KZCLL, (MVARBL(I,KVRBL),I=1,NAMLEN)
      JFLAG = -83
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLTMWR
C
  991 WRITE (IPRINT, 2991) JFLAG
      JFLAG = -91
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATGET DURING OUTPUT OPERATIONS
C
  992 WRITE (IPRINT, 2992) JFLAG, KZCLL, (MVARBL(I,KVRBL),I=1,NAMLEN)
      JFLAG = -92
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLAQWR
C
  993 WRITE (IPRINT, 2993) JFLAG
      JFLAG = -93
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GRIDPR
C
  994 WRITE (IPRINT, 2994) JFLAG
      JFLAG = -94
      GO TO 1000
C
C RETURN TO CALLING PROGRAM
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (60A1, 20A1)
 1205 FORMAT (60A1, 20A1)
 2105 FORMAT (1X, 60A1, 20A1)
 2205 FORMAT (1X, 60A1, 20A1)
 2145 FORMAT (38H ****** NOTE ****** THE STARTING DATE , I10,
     $        10H AND TIME , F10.2, 16H FOR THIS PACKET , //,
     $        33H ARE PRIOR TO THE STARTING DATE , I10, 10H AND TIME ,
     $        F10.2, 14H FOR THIS FILE , //, 21H THE PACKET DATE AND ,
     $        46HTIME HAVE BEEN RESET TO THE FILE DATE AND TIME , //)
 2155 FORMAT (38H ****** NOTE ****** THE STOPPING DATE , I10,
     $        10H AND TIME , F10.2, 16H FOR THIS PACKET , //,
     $        29H ARE AFTER THE STOPPING DATE , I10, 10H AND TIME ,
     $        F10.2, 14H FOR THIS FILE , //, 21H THE PACKET DATE AND ,
     $        46HTIME HAVE BEEN RESET TO THE FILE DATE AND TIME , //)
 2901 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        22H NAME LENGTH VALUE IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2902 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        24H NUMBER OF VARIABLES IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2903 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        25H NUMBER OF SUBREGIONS IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2904 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN X-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2905 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN Y-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2906 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN Z-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2907 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        41H NUMBER OF WORDS OF SCRATCH STORAGE IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2911 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TXTPAK , //,
     $        44H DURING READ OF TIME-INVARIANT PACKET HEADER, //)
 2912 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE COMPAR , //,
     $        44H DURING READ OF TIME-INVARIANT PACKET HEADER, //)
 2913 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H PACKET HEADER , 10A1, //, 23H DOES NOT MATCH ANY OF ,
     $        47HTHE ALLOWABLE NAMES FOR TIME-INVARIANT HEADERS   , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2914 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE UNITRD , //)
 2915 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE STATRD , //)
 2916 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TIMERD , //)
 2917 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        39H THE PREVIOUS PACKET STOPPED WITH DATE, I10,
     $        10H AND TIME , F10.2, //, 25H THIS PACKET STARTS WITH ,
     $        5HDATE , I10, 10H AND TIME , F10.2, //, 11H.  PACKETS ,
     $        47HMUST FOLLOW CONSECUTIVELY IN TIME, WITH NO GAPS, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2921 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE DFBKRD , //)
 2922 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RGTPRD , //)
 2923 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TPCNRD ,
     $        14H FOR VARIABLE , 10A1, //)
 2924 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TPUVRD , //)
 2925 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE HTPRRD , //)
 2931 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TXTPAK , //,
     $        42H DURING READ OF TIME-VARIANT PACKET HEADER, //)
 2932 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE COMPAR , //,
     $        42H DURING READ OF TIME-VARIANT PACKET HEADER, //)
 2933 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H PACKET HEADER , 10A1, //, 23H DOES NOT MATCH ANY OF ,
     $        45HTHE ALLOWABLE NAMES FOR TIME-VARIANT HEADERS   , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2941 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE SBRGRD , //)
 2942 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MTHDRD , //)
 2943 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        46H WAS RETURNED FROM SUBROUTINE VERTICAL MTHDRD , //)
 2944 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE CNSTRD , //)
 2945 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE GDVLRD , //)
 2946 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE STVLRD , //)
 2947 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE VPRFRD , //)
 2949 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MATGET , //,
     $        18H FOR GROUND LEVEL , 14H AND VARIABLE , 10A1, //)
 2950 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MATGET ,
     $        35H FOR TOP CONCENTRATION OF VARIABLE , 10A1, //)
 2951 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        26H THE CELL WITH X-LOCATION , I10, 16H AND Y-LOCATION ,
     $        I10, //, 37H CONTAINS THE SUBREGION DESIGNATION , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2952 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        32H THE METHOD NUMBER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2953 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        44H THE STATION PARAMETER COUNTER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2954 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        44H THE STATION PARAMETER POINTER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2955 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE STASGN , //)
 2956 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER COUNTER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2957 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER POINTER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2958 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE SPLITC , //)
 2959 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        44H THE POISSON PARAMETER COUNTER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2961 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        44H THE POISSON PARAMETER POINTER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2962 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE POISSN , //)
 2963 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER COUNTER FOR VARIABLE ,10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2964 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER POINTER FOR VARIABLE ,10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2965 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE AIRUSR , //)
 2966 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE EWINTER , //)
 2967 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE NSINTR , //)
 2968 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MATPUT , //,
     $        18H FOR GROUND LEVEL , 14H AND VARIABLE , 10A1, //)
 2970 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MATGET , //,
     $        20H FOR VERTICAL LEVEL , I10, 14H AND VARIABLE , 10A1, //)
 2971 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        26H THE CELL WITH X-LOCATION , I10, 16H AND Y-LOCATION ,
     $        I10, //, 37H CONTAINS THE SUBREGION DESIGNATION , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2972 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        41H THE VERTICAL METHOD NUMBER FOR VARIABLE , 10A1,
     $        14H IN SUBREGION , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2973 FORMAT (' ****** ERROR TRACE ******  ERROR FLAG ', I10,
     $        ' WAS RETURNED FROM SUBROUTINE ABSPRF OR ABSPRV ', //)
 2974 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RELPRF , //)
 2975 FORMAT (' ****** ERROR TRACE ******  ERROR FLAG ', I10,
     $        ' WAS RETURNED FROM SUBROUTINE ABPRFR OR ABPRVR ', //)
 2976 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RLPRFR , //)
 2977 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        48H THE USER VERTICAL ROUTINE PARAMETER COUNTER FOR ,
     $        9HVARIABLE , 10A1, 14H IN SUBREGION , 10A1, //, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2978 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        48H THE USER VERTICAL ROUTINE PARAMETER POINTER FOR ,
     $        9HVARIABLE , 10A1, 14H IN SUBREGION , 10A1, //, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2979 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE AIRVUS , //)
 2980 FORMAT (' ****** ERROR TRACE ******  ERROR FLAG ', I10,
     $        ' WAS RETURNED FROM SUBROUTINE FIXPRF OR FIXPRV ', //)
 2981 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        46H WAS RETURNED FROM SUBROUTINE VERTICAL EWINTR , //)
 2982 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        46H WAS RETURNED FROM SUBROUTINE VERTICAL NSINTR , //)
 2983 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MATPUT , //,
     $        20H FOR VERTICAL LEVEL , I10, 14H AND VARIABLE , 10A1, //)
 2991 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE FLTMWR , //)
 2992 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MATGET , //,
     $        20H FOR VERTICAL LEVEL , I10, 14H AND VARIABLE , 10A1,
     $        26H DURING OUTPUT OPERATIONS , //)
 2993 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE FLAQWR , //)
 2994 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE GRIDPR , //)
      END
