C    AIRQUL
C     PROGRAM AIRQUL(INPUT, OUTPUT, TAPE5=INPUT, TAPE6=OUTPUT, TAPE11,
C    $               TAPE12, TAPE13, TAPE21)
C   *************************************************************
C
C     PROGRAM DEVELOPED BY:
C
C             SYSTEMS APPLICATIONS, INC.
C             101 LUCAS VALLEY ROAD
C             SAN RAFAEL, CALIFORNIA  94903
C                     (415)-472-4011
C
C   *************************************************************
C
C NAME -- AIR QUALITY
C
C DESCRIPTION -- DATA PREPARATION PROGRAM FOR THE PRODUCTION OF THE
C                AIR QUALITY (INITIAL CONDITIONS) FILE
C
C PROGRAMMER -- DC WHITNEY, SAI, JULY 1977
C
C  --MODIFIED 6/11/99, TCM - READ UAMV MET FILE HEADERS FOR 
C                            NEW FILE FORMAT IF NECESSARY.
C
C  --MODIFIED 12/6/96, TCM - READ UAMV HEIGHT FILE AND ALLOW
C                            PREPARATION OF SIMPLE UAMV BOUNDARY
C                            DATA FILES.
C
C LOCAL VARIABLES --
C         INCARD     I  INPUT UNIT
C         IPRINT     I  OUTPUT UNIT
C         IAIRQU     I  OUTPUT FILE NUMBER
C         IOUTFL     I  OUTPUT FILE NUMBER
C         IMATFL     I  MATRIX FILE NUMBER
C         IDFBRK     I  DIFFUSION BREAK FILE NUMBER
C         IRGTOP     I  REGION TOP FILE NUMBER
C         ITPCON     I  TOP CONCENTRATION FILE NUMBER
C         KVBNM      I  START OF VARIABLE NAMES IN SCRATCH
C         KUNNM      I  START OF UNIT NAME IN SCRATCH
C         KMULT      I  START OF MULTIPLICATIVE FACTOR IN SCRATCH
C         KADTV      I  START OF ADDITIVE FACTOR IN SCRATCH
C         KMOLW      I  START OF MOLECULAR WEIGHT IN SCRATCH
C         KSTNM      I  START OF STATION NAMES IN SCRATCH
C         KSTVL      I  START OF STATION VALUES IN SCRATCH
C         KSTNX      I  START OF STATION X-LOCATION IN SCRATCH
C         KSTNY      I  START OF STATION Y-LOCATION IN SCRATCH
C         KSTNZ      I  START OF STATION Z-LOCATION IN SCRATCH
C         KSBNM      I  START OF SUBREGION NAMES IN SCRATCH
C         KRGRD      I  START OF REGIONAL GRID IN SCRATCH
C         KMTHN      I  START OF METHOD NUMBERS IN SCRATCH
C         KMINV      I  START OF METHOD MINIMUM VALUES IN SCRATCH
C         KMAXV      I  START OF METHOD MAXIMUM VALUES IN SCRATCH
C         KPRMP      I  START OF METHOD PARAMETER POINTERS IN SCRATCH
C         KPRMC      I  START OF METHOD PARAMETER COUNTERS IN SCRATCH
C         KPRNM      I  START OF METHOD PARAMETER NAMES IN SCRATCH
C         KPRMV      I  START OF METHOD PARAMETER VALUES IN SCRATCH
C         KVMTN      I  START OF VERTICAL METHOD NUMBER IN SCRATCH
C         KVMNV      I  START OF VERTICAL METHOD MINIMUM VALUES IN SCRAT
C         KVMXV      I  START OF VERTICAL METHOD MAXIMUM VALUES IN SCRAT
C         KVPRP      I  START OF VERTICAL METHOD PARAMETER POINTERS IN S
C         KVPRC      I  START OF VERTICAL METHOD PARAMETER COUNTERS IN S
C         KVPNM      I  START OF VERTICAL METHOD PARAMETER NAMES IN SCRA
C         KVPRV      I  START OF VERTICAL METHOD PARAMETER VALUES IN SCR
C         KPRFX      I  START OF VERTICAL PROFILE X-LOCATION IN SCRATCH
C         KPRFY      I  START OF VERTICAL PROFILE Y-LOCATION IN SCRATCH
C         KPRFH      I  START OF VERTICAL PROFILE HEIGHTS IN SCRATCH
C         KPRFV      I  START OF VERTICAL PROFILE VALUES IN SCRATCH
C         KDFBK      I  START OF DIFFUSION BREAK IN SCRATCH
C         KRGTP      I  START OF REGION TOP IN SCRATCH
C         KTPCN      I  START OF TOP CONCENTRATION IN SCRATCH
C         KBASE      I  START OF BASE GRID IN SCRATCH
C         KALTN      I  START OF ALTERNATE GRID IN SCRATCH
C         KOUTM      I  START OF OUTPUT MATRIX IN SCRATCH
C         KSPTR      I  START OF RESIDUAL SCRATCH STORAGE
C         LINPTP     L  PRINT FLAG FOR INPUT CARD
C         LGRIDP     L  PRINT FLAG FOR OUTPUT GRID
C         LUNITP     L  PRINT FLAG FOR UNITS TABLE
C         LSTATP     L  PRINT FLAG FOR STATION LOCATION
C         LSBRGP     L  PRINT FLAG FOR SUBREGION GRID
C         LMTHDP     L  PRINT FLAG FOR METHOD TABLE
C         LSTRDP     L  PRINT FLAG FOR STATION READINGS
C         LVMTHP     L  PRINT FLAG FOR VERTICAL METHOD TABLE
C         LVPRFP     L  PRINT FLAG FOR VERTICAL PROFILES
C         LUAMV      L  FLAG INDICATING UAMV FORMAT FILES
C         NAMLEN     I  NAME LENGTH
C         NIDLEN     I  IDENTIFICATION FIELD LENGTH
C         NSGMNT     I  NUMBER OF SEGMENTS
C         NOPTIN     I  NUMBER OF CONTROL OPTIONS
C         NINVAR     I  NUMBER OF INTRINSIC VARIABLES
C         NSPECS     I  NUMBER OF SPECIES
C         NUSVAR     I  NUMBER OF USER-DEFINED VARIABLES
C         NUNVAR     I  NUMBER OF UNIT-ONLY VARIABLES
C         NVARBL     I  TOTAL NUMBER OF VARIABLES
C         NUNITS     I  NUMBER OF UNITS
C         NSTATS     I  NUMBER OF STATIONS
C         NBLINE     I  NUMBER OF BOUNDARY LINES
C         NPTSRC     I  NUMBER OF POINT SOURCES
C         NPTSRT     I  NUMBER OF POINT SOURCE TYPES
C         NSUBRG     I  NUMBER OF SUBREGIONS
C         NMETHD     I  NUMBER OF METHODS
C         NPARAM     I  NUMBER OF PARAMETERS
C         NVMETH     I  NUMBER OF VERTICAL METHODS
C         NVPARM     I  NUMBER OF VERTICAL PARAMETERS
C         NPRFHT     I  NUMBER OF PROFILE HEIGHTS
C         NMETSC     I  NUMBER OF METEOROLOGICAL SCALARS
C         NINFIL     I  NUMBER OF INPUT FILES
C         NSCRTC     I  MAXIMUM AVAILABLE SCRATCH
C         NSCPTR     I  NUMBER OF DIMENSIONED VARIABLE POINTERS TO SCRAT
C         NXCELL     I   NUMBER OF CELLS IN X-DIRECTION
C         NYCELL     I   NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL     I  NUMBER OF CELLS IN Z-DIRECTION
C         NZLOWR     I  NUMBER OF CELLS IN LOWER VERTICAL LAYER
C         NZUPPR     I  NUMBER OF CELLS IN UPPER VERTICAL LAYER
C         NWORDS     I  NUMBER OF WORDS IN AN ARRAY
C         NSCLFT     I  NUMBER OF WORDS LEFT IN SCRATCH
C         NBUFFR     I  SIZE OF OUTPUT MATRIX BUFFER
C         JBEGDT     I  BEGINNING DATE
C         JENDDT     I  ENDING DATE
C         JUTMZN     I  UTM ZONE NUMBER
C         JXSGOR     I  X-COORDINATE OF SEGMENT ORIGIN IN REGION
C         JYSGOR     I  Y-COORDINATE OF SEGMENT ORIGIN IN REGION
C         BEGTIM     R  BEGINNING TIME
C         ENDTIM     R  ENDING TIME
C         XUTMOR     R  X-COORDINATE OF UTM ORIGIN
C         YUTMOR     R  Y-COORDINATE OF UTM ORIGIN
C         XREGOR     R  X-COORDINATE OF REGION ORIGIN
C         YREGOR     R  Y-COORDINATE OF REGION ORIGIN
C         XCELLD     R  LENGTH OF CELL IN X-DIRECTION
C         YCELLD     R  LENGTH OF CELL IN Y-DIRECTION
C         ZHTSUR     R  CELL HEIGHT, SURFACE LAYER
C         ZMINLW     R  MINIMUM CELL HEIGHT, LOWER LAYER
C         ZMINUP     R  MINIMUM CELL HEIGHT, UPPER LAYER
C         INFILE     I  FILE UNIT NUMBERS
C         MFILNM     I  FILE NAME
C         MFILID     I  FILE IDENTIFICATION
C         MUNVAR     I  UNIT-ONLY VARIABLE NAMES
C         LPRINT     I  PRINT FLAGS
C         JOPTIN     I  CONTROL OPTIONS
C         JSCRTC     I  SCRATCH FOR PARTITIONING
C         JSCPTR     I  POINTERS TO EACH DIMENSIONED VARIABLE IN SCRATCH
C         JBUFFR    I  OUTPUT MATRIX BUFFER
C         JINTSC     I  INTEGER SCALARS FOR PASSING TO PROCESSING ROUTIN
C         REALSC     R  REAL SCALARS FOR PASSING TO PROCESSING ROUTINE
C         JFLAG      I  COMPLETION FLAG
C         MVERSN     C  VERSION IDENTIFIER
C
C ROUTINES CALLED --
C         CNTLRD     CONTROL PACKET READ
C         REGNRD     REGION PACKET READ
C         FLHDWR     FILE HEADER WRITE
C         FLRGWR     FILE REGION WRITE
C         FLSGWR     FILE SEGMENT WRITE
C         FLSPWR     FILE SPECIES WRITE
C         FLHDCK     FILE HEADER CHECK
C         SCRPRT     SCRATCH PARTITION
C         COREXT     SETS UP EXTENDED CORE
C         AIRPRC     AIR QUALITY PROCESS
C
C ERROR CONDITIONS --
C
C          -1   NEGATIVE ERROR FLAG FROM CONTROL READ SUBROUTINE
C          -2   NONPOSITIVE SPECIES COUNT
C          -3   NEGATIVE ERROR FLAG FROM REGION READ SUBROUTINE
C          -4   INSUFFICIENT NUMBER OF VERTICAL CELLS
C          -5   NEGATIVE ERROR FLAG FROM FILE HEADER VERIFICATION
C............   SUBROUTINE FOR DIFFUSION BREAK
C          -6   NEGATIVE ERROR FLAG FROM FILE HEADER VERIFICATION
C...............SUBROUTINE FOR REGION TOP
C          -7   NEGATIVE ERROR FLAG FROM FILE HEADER VERIFICATION
C.............. SUBROUTINE FOR TOP CONCENTRATION
C          -11  NEGATIVE ERROR FLAG FROM FILE HEADER WRITE SUBROUTINE
C          -12  NEGATIVE ERROR FLAG FROM FILE REGION WRITE SUBROUTINE
C          -13  NEGATIVE ERROR FLAG FROM FILE SEGMENT DESCRIPTION
C               WRITE SUBROUTINE
C          -14  NEGATIVE ERROR FLAG FROM FILE SPECIES WRITE SUBROUTINE
C          -15  NEGATIVE ERROR FLAG FROM SCRATCH PARTITION SUBROUTINE
C          -16  NEGATIVE ERROR FLAG FROM CORE EXTENSION ROUTINE
C          -17  NEGATIVE ERROR FLAG FROM AIR QUALITY PROCESS SUBROUTINE
C
C OTHER INFORMATION --
C
C
C
C DECLARE THE PRINT FLAG ARRAY AND ITS MEMBERS
C
      LOGICAL LPRINT
      LOGICAL LINPTP
      LOGICAL LGRIDP
      LOGICAL LUNITP
      LOGICAL LSTATP
      LOGICAL LSBRGP
      LOGICAL LMTHDP
      LOGICAL LSTRDP
      LOGICAL LVMTHP
      LOGICAL LVPRFP
      LOGICAL LUAMV
C
C SET ARRAY SIZES
C
      CHARACTER*4 MFILNM(10)
      CHARACTER*4 MDIFBK(10)
      CHARACTER*4 MREGTP(10)
      CHARACTER*4 MTOPCN(10)
      CHARACTER*10 MZP
      CHARACTER*4 MFILID(60)
      DIMENSION JOPTIN(30)
      DIMENSION INFILE(6)
      COMMON /SCRATC/ JSCRTC(20000000)
      CHARACTER*4 MSCRTC(20000000)
      EQUIVALENCE (MSCRTC(1), JSCRTC(1))
      DIMENSION JSCPTR(39)
      DIMENSION JBUFFR(513)
      DIMENSION JTCBUF(513)
      DIMENSION LPRINT(9)
      CHARACTER*4 MUNVAR(10,2)
      DIMENSION JINTSC(11)
      DIMENSION REALSC(12)
C
      CHARACTER*80 FNAME
      CHARACTER*24 MVERSN
C
C SET EQUIVALENCE FOR SCRATCH POINTERS
C
      EQUIVALENCE (JSCPTR( 1), KVBNM)
      EQUIVALENCE (JSCPTR( 2), KUNNM)
      EQUIVALENCE (JSCPTR( 3), KMULT)
      EQUIVALENCE (JSCPTR( 4), KADTV)
      EQUIVALENCE (JSCPTR( 5), KMOLW)
      EQUIVALENCE (JSCPTR( 7), KSTNM)
      EQUIVALENCE (JSCPTR( 8), KSTVL)
      EQUIVALENCE (JSCPTR( 9), KSTNX)
      EQUIVALENCE (JSCPTR(10), KSTNY)
      EQUIVALENCE (JSCPTR(11), KSTNZ)
      EQUIVALENCE (JSCPTR(12), KSBNM)
      EQUIVALENCE (JSCPTR(13), KRGRD)
      EQUIVALENCE (JSCPTR(14), KMTHN)
      EQUIVALENCE (JSCPTR(15), KMINV)
      EQUIVALENCE (JSCPTR(16), KMAXV)
      EQUIVALENCE (JSCPTR(17), KPRMP)
      EQUIVALENCE (JSCPTR(18), KPRMC)
      EQUIVALENCE (JSCPTR(19), KPRNM)
      EQUIVALENCE (JSCPTR(20), KPRMV)
      EQUIVALENCE (JSCPTR(22), KVMTN)
      EQUIVALENCE (JSCPTR(23), KVMNV)
      EQUIVALENCE (JSCPTR(24), KVMXV)
      EQUIVALENCE (JSCPTR(25), KVPRP)
      EQUIVALENCE (JSCPTR(26), KVPRC)
      EQUIVALENCE (JSCPTR(27), KVPNM)
      EQUIVALENCE (JSCPTR(28), KVPRV)
      EQUIVALENCE (JSCPTR(29), KPRFX)
      EQUIVALENCE (JSCPTR(30), KPRFY)
      EQUIVALENCE (JSCPTR(31), KPRFH)
      EQUIVALENCE (JSCPTR(32), KPRFV)
      EQUIVALENCE (JSCPTR(33), KDFBK)
      EQUIVALENCE (JSCPTR(34), KRGTP)
      EQUIVALENCE (JSCPTR(35), KTPCN)
C
C SET EQUIVALENCE FOR CONTROL OPTIONS VECTOR
C
      EQUIVALENCE (JOPTIN( 1), NSPECS)
      EQUIVALENCE (JOPTIN( 2), NUSVAR)
      EQUIVALENCE (JOPTIN( 3), NSTATS)
      EQUIVALENCE (JOPTIN( 4), NSUBRG)
      EQUIVALENCE (JOPTIN( 5), NPARAM)
      EQUIVALENCE (JOPTIN( 7), IAIRQU)
      EQUIVALENCE (JOPTIN(19), NVPARM)
      EQUIVALENCE (JOPTIN(20), NPRFHT)
      EQUIVALENCE (JOPTIN(25), IDFBRK)
      EQUIVALENCE (JOPTIN(26), IRGTOP)
      EQUIVALENCE (JOPTIN(27), ITPCON)
C
C SET EQUIVALENCE FOR PRINT FLAGS
C
      EQUIVALENCE (LPRINT(1), LINPTP)
      EQUIVALENCE (LPRINT(2), LGRIDP)
      EQUIVALENCE (LPRINT(3), LUNITP)
      EQUIVALENCE (LPRINT(4), LSTATP)
      EQUIVALENCE (LPRINT(5), LSBRGP)
      EQUIVALENCE (LPRINT(6), LMTHDP)
      EQUIVALENCE (LPRINT(7), LSTRDP)
      EQUIVALENCE (LPRINT(8), LVMTHP)
      EQUIVALENCE (LPRINT(9), LVPRFP)
C
C SET EQUIVALENCES FOR INPUT FILES
C
      EQUIVALENCE (INFILE(1), IDFBRK)
      EQUIVALENCE (INFILE(2), IRGTOP)
      EQUIVALENCE (INFILE(3), ITPCON)
C
C SET EQUIVALENCE FOR INTEGER SCALARS
C
      EQUIVALENCE (JINTSC( 1), INCARD)
      EQUIVALENCE (JINTSC( 2), IPRINT)
      EQUIVALENCE (JINTSC( 3), IOUTFL)
      EQUIVALENCE (JINTSC( 4), IMATFL)
      EQUIVALENCE (JINTSC( 5), NZLOWR)
      EQUIVALENCE (JINTSC( 6), NZUPPR)
      EQUIVALENCE (JINTSC( 7), JBEGDT)
      EQUIVALENCE (JINTSC( 8), JENDDT)
      EQUIVALENCE (JINTSC( 9), JUTMZN)
      EQUIVALENCE (JINTSC(10), JMISSV)
      EQUIVALENCE (JINTSC(11), ITCFIL)
C
C SET EQUIVALENCE FOR REAL SCALARS
C
      EQUIVALENCE (REALSC( 1), BEGTIM)
      EQUIVALENCE (REALSC( 2), ENDTIM)
      EQUIVALENCE (REALSC( 3), XUTMOR)
      EQUIVALENCE (REALSC( 4), YUTMOR)
      EQUIVALENCE (REALSC( 5), XREGOR)
      EQUIVALENCE (REALSC( 6), YREGOR)
      EQUIVALENCE (REALSC( 7), XCELLD)
      EQUIVALENCE (REALSC( 8), YCELLD)
      EQUIVALENCE (REALSC( 9), ZHTSUR)
      EQUIVALENCE (REALSC(10), ZMINLW)
C     
      EQUIVALENCE (REALSC(12), RMISSV)
C
C SET CERTAIN VARIABLE VALUES
C
      DATA JFLAG /0/
      DATA IMATFL /1/
      DATA ITCFIL /2/
      DATA INCARD /3/
      DATA IPRINT /4/
      DATA NAMLEN /10/
      DATA NIDLEN /60/
      DATA NSGMNT /1/
      DATA NOPTIN /30/
      DATA NINVAR /0/
      DATA NUNVAR /2/
      DATA NSCRTC /20000000/
      DATA NSCPTR /39/
      DATA NBUFFR /513/
      DATA NTCBUF /513/
      DATA NFLZCL /1/
      DATA RMISSV /-9.0/
      DATA JMISSV /-9/
      DATA JXSGOR /0/
      DATA JYSGOR /0/
      DATA NMETHD /1/
      DATA NVMETH /1/
      DATA NPTSRC /0/
      DATA NPTSRT /0/
      DATA NMETSC /0/
      DATA NBLINE /0/
      DATA NINFIL /6/
      DATA LPRINT /9 * .FALSE./
      DATA LUAMV  /.FALSE./
C
C SET THE FILE NAME AND UNIT-ONLY VARIABLE NAMES
C
      DATA MFILNM /'A', 'I', 'R', 'Q', 'U', 'A', 'L', 'I', 'T', 'Y'/
C     DATA (MUNVAR(I,1),I=1,10)/1HC,1HO,1HO,1HR,1HD,1H ,1H ,1H ,1H ,1H /
C     DATA (MUNVAR(I,2),I=1,10)/1HH,1HE,1HI,1HG,1HH,1HT,1H ,1H ,1H ,1H /
      DATA MUNVAR             /'C','O','O','R','D',' ',' ',' ',' ',' ',
     1                         'H','E','I','G','H','T',' ',' ',' ',' '/
C
C SET INPUT FILE NAMES
C
      DATA MDIFBK/'D', 'I', 'F', 'F', 'B', 'R', 'E', 'A', 'K', ' '/
      DATA MREGTP/'R', 'E', 'G', 'I', 'O', 'N', 'T', 'O', 'P', ' '/
      DATA MTOPCN/'T', 'O', 'P', 'C', 'O', 'N', 'C', ' ', ' ', ' '/
      DATA MZP /'HEIGHT    '/
C
C SET VERSION NUMBER
C
      DATA MVERSN /'AIRQUL V2.12, 6/11/99   '/
c
c   ver 2.11:  character variables declared character*4
C
C  RESET OPTION TABLE TO ALLOW 0 AS FIRST DIMENSION
C
C     CALL ERRSET(187,256,-1,1,1,1)
C
C
C    OPEN STANDARD INPUT AND OUTPUT FILES
C
      WRITE(*,'(1X,A)') MVERSN
      READ (*,'(20X,A)') FNAME
      OPEN (INCARD,FILE=FNAME,FORM='FORMATTED',STATUS='OLD')
      READ (*,'(20X,A)') FNAME
      OPEN (IPRINT,FILE=FNAME,FORM='FORMATTED')
C
C  SET PRINT WIDTH TO 132 COLUMNS
C
C     CALL ATTDEV(INTS(6), INTS(7), INTS(2), INTS(66))
C
C READ THE CONTROL INFORMATION
C
      CALL CNTLRD(INCARD, IPRINT, NAMLEN, NIDLEN, NOPTIN, MFILNM,
     $            JBEGDT, JENDDT, BEGTIM, ENDTIM,
     $            MFILID, JOPTIN, JSCRTC, JFLAG)
      IF (JFLAG .LT. 0) GO TO 905
C
C PRINT VERSION NUMBER
C
      WRITE(IPRINT,'(1H1,A)') MVERSN
C
C SET THE VALUE OF IOUTFL
C
      IOUTFL = IAIRQU
C
C SET THE LOGICAL PRINT VECTOR
C
      IF (JOPTIN( 6) .GT. 0) LUAMV  = .TRUE.
      IF (JOPTIN( 8) .GT. 0) LINPTP = .TRUE.
      IF (JOPTIN( 9) .GT. 0) LGRIDP = .TRUE.
      IF (JOPTIN(13) .GT. 0) LUNITP = .TRUE.
      IF (JOPTIN(14) .GT. 0) LSTATP = .TRUE.
      IF (JOPTIN(15) .GT. 0) LSBRGP = .TRUE.
      IF (JOPTIN(16) .GT. 0) LMTHDP = .TRUE.
      IF (JOPTIN(17) .GT. 0) LSTRDP = .TRUE.
      IF (JOPTIN(21) .GT. 0) LVMTHP = .TRUE.
      IF (JOPTIN(22) .GT. 0) LVPRFP = .TRUE.
C
C WRITE OUTPUT HEADER INFORMATION
C
      WRITE (IPRINT, 2005) MFILNM, MFILID
C
C IF WANTED, PRINT THE OPERATING PARAMETERS
C
      IF (.NOT.LINPTP) GO TO 210
      WRITE (IPRINT, 2010) NUSVAR
      WRITE (IPRINT, 2015) NSTATS
      WRITE (IPRINT, 2020) NSUBRG
      WRITE (IPRINT, 2025) NPARAM
      WRITE (IPRINT, 2030) NVPARM
      WRITE (IPRINT, 2035) NPRFHT
C
C PRINT THE UAMV FORMAT OPTION
C
      IF (LUAMV) THEN
        WRITE(IPRINT, 2037)
      ELSE
        WRITE(IPRINT, 2038)
      ENDIF
C
C PRINT THE FILES TO BE ACCESSED
C
      IF (IAIRQU .GT. 0) WRITE (IPRINT, 2040) IAIRQU
      IF (IDFBRK .GT. 0) THEN
        IF (LUAMV) THEN
          WRITE (IPRINT, 2046) IDFBRK
        ELSE
          WRITE (IPRINT, 2045) IDFBRK
        ENDIF
      ENDIF
      IF (IRGTOP .GT. 0) WRITE (IPRINT, 2050) IRGTOP
      IF (ITPCON .GT. 0) WRITE (IPRINT, 2055) ITPCON
C
C   OPEN BINARY OUTPUT FILE AND INPUT FILES
C       (ADDED 8/03/88, HH/SAI)
C
      CALL OPENA(IAIRQU, IDFBRK, IRGTOP, ITPCON, LUAMV)
C
      IF (.NOT. LINPTP) WRITE (IPRINT, 2105)
      IF (LINPTP) WRITE (IPRINT, 2110)
      IF (.NOT. LGRIDP) WRITE (IPRINT, 2115)
      IF (LGRIDP) WRITE (IPRINT, 2120)
      IF (.NOT. LUNITP) WRITE (IPRINT, 2125)
      IF (LUNITP) WRITE (IPRINT, 2130)
      IF (.NOT. LSTATP) WRITE (IPRINT, 2135)
      IF (LSTATP) WRITE (IPRINT, 2140)
      IF (.NOT. LSBRGP) WRITE (IPRINT, 2145)
      IF (LSBRGP) WRITE (IPRINT, 2150)
      IF (.NOT. LMTHDP) WRITE (IPRINT, 2155)
      IF (LMTHDP) WRITE (IPRINT, 2160)
      IF (.NOT. LSTRDP) WRITE (IPRINT, 2165)
      IF (LSTRDP) WRITE (IPRINT, 2170)
      IF (.NOT. LVMTHP) WRITE (IPRINT, 2175)
      IF (LVMTHP) WRITE (IPRINT, 2180)
      IF (.NOT. LVPRFP) WRITE (IPRINT, 2185)
      IF (LVPRFP) WRITE (IPRINT, 2190)
C
C PRINT THE DATES AND TIMES
C
      WRITE (IPRINT, 2205) JBEGDT, BEGTIM, JENDDT, ENDTIM
C
C CHECK FOR PRESENCE OF SPECIES NAMES
C
      IF (NSPECS .LE. 0) GO TO 910
      NWORDS = NAMLEN * NSPECS
      WRITE (IPRINT, 2210) NSPECS, (JSCRTC(I),I=1,NWORDS)
C
C READ THE REGION DEFINITION
C
  210 CALL REGNRD(INCARD, IPRINT, NXCELL, NYCELL, NZCELL, NZLOWR,
     $            NZUPPR, JUTMZN, XUTMOR, YUTMOR,
     $            XREGOR, YREGOR, XCELLD, YCELLD,
     $            ZHTSUR, ZMINLW, ZMINUP, JFLAG)
      IF (JFLAG .LT. 0) GO TO 915
C
C VERIFY THE EXISTENCE OF ONE VERTICAL LAYER
C
      IF (NZCELL .LT. 1) GO TO 920
C
C IF WANTED, PRINT THE REGION DEFINITION
C
      IF (.NOT. LINPTP) GO TO 310
      WRITE (IPRINT,2305) XUTMOR, YUTMOR, JUTMZN, XREGOR, YREGOR,
     $                    XCELLD, YCELLD, NXCELL, NYCELL
      WRITE (IPRINT,2310) NZCELL,NZLOWR, NZUPPR, ZHTSUR, ZMINLW, ZMINUP
C
C CHECK FOR PRESENCE OF INPUT FILES AND SET SPECIES NAME SIZE
C
  310 IF (NINFIL .LE. 0) GO TO 410
      NWORDS = NAMLEN * NSPECS + 1
      NSCLFT = NSCRTC - NWORDS
C
C DIFFUSION BREAK
C
      IF (IDFBRK .GT. 0) THEN
        IF (.NOT.LUAMV) THEN
          CALL FILVER(IPRINT, IDFBRK, NAMLEN, NIDLEN,
     $        NSGMNT, NSPECS, NSCLFT, NXCELL, NYCELL, NZCELL,
     $        NZLOWR, NZUPPR, JBEGDT, JENDDT, JUTMZN,
     $        BEGTIM, ENDTIM, XUTMOR, YUTMOR, XREGOR,
     $        YREGOR, XCELLD, YCELLD, ZHTSUR, ZMINLW, ZMINUP,
     $        JXSGOR, JYSGOR, NXCELL, NYCELL, MDIFBK,
     $        JSCRTC(NWORDS), JSCRTC(NWORDS), JSCRTC(1), JFLAG)
          IF (JFLAG .LT. 0) GO TO 925
        ELSE
          CALL HDRCHK(IDFBRK, IPRINT, MZP, NXCELL, NYCELL, NZCELL)
        ENDIF
      ENDIF
C
C REGION TOP
C
      IF (IRGTOP .GT. 0) CALL FILVER(IPRINT, IRGTOP, NAMLEN, NIDLEN,
     $     NSGMNT, NSPECS, NSCLFT, NXCELL, NYCELL, NZCELL,
     $     NZLOWR, NZUPPR, JBEGDT, JENDDT, JUTMZN,
     $     BEGTIM, ENDTIM, XUTMOR, YUTMOR, XREGOR,
     $     YREGOR, XCELLD, YCELLD, ZHTSUR, ZMINLW, ZMINUP,
     $     JXSGOR, JYSGOR, NXCELL, NYCELL, MREGTP,
     $     JSCRTC(NWORDS), JSCRTC(NWORDS), JSCRTC(1), JFLAG)
      IF (JFLAG .LT. 0) GO TO 930
C
C TOP CONCENTRATION
C
      IF (ITPCON .GT. 0) THEN
        IF (.NOT.LUAMV) THEN
          CALL FILVER(IPRINT, ITPCON, NAMLEN, NIDLEN,
     $        NSGMNT, NSPECS, NSCLFT, NXCELL, NYCELL, NZCELL,
     $        NZLOWR, NZUPPR, JBEGDT, JENDDT, JUTMZN,
     $        BEGTIM, ENDTIM, XUTMOR, YUTMOR, XREGOR,
     $        YREGOR, XCELLD, YCELLD, ZHTSUR, ZMINLW, ZMINUP,
     $        JXSGOR, JYSGOR, NXCELL, NYCELL, MTOPCN,
     $        JSCRTC(NWORDS), JSCRTC(NWORDS), JSCRTC(1), JFLAG)
          IF (JFLAG .LT. 0) GO TO 935
        ENDIF
      ENDIF
C
C IF THERE IS TO BE AN OUTPUT FILE, WRITE ITS HEADER RECORDS
C
  410 IF (IAIRQU .LE. 0) GO TO 510
C
C FILE PARAMETERS (HEADER)
C
      CALL FLHDWR(IPRINT, IAIRQU, NAMLEN, NIDLEN, NSGMNT, NSPECS,
     $     JBEGDT, JENDDT, BEGTIM, ENDTIM, MFILNM, MFILID, JFLAG)
      IF (JFLAG .LT. 0) GO TO 955
C
C REGION DESCRIPTION
C
      CALL FLRGWR(IPRINT, IAIRQU, NXCELL, NYCELL, NZCELL, NZLOWR,
     $            NZUPPR, JUTMZN, XUTMOR, YUTMOR,
     $            XREGOR, YREGOR, XCELLD, YCELLD,
     $            ZHTSUR, ZMINLW, ZMINUP, JFLAG)
      IF (JFLAG .LT. 0) GO TO 960
C
C SEGMENTATION
C
      CALL FLSGWR(IPRINT, IAIRQU, NSGMNT, JXSGOR, JYSGOR,
     $     NXCELL, NYCELL, JFLAG)
      IF (JFLAG .LT. 0) GO TO 965
C
C SPECIES NAMES
C
      CALL FLSPWR(IPRINT, IAIRQU, NAMLEN, NSPECS, JSCRTC(1), JFLAG)
      IF (JFLAG .LT. 0) GO TO 970
C
C SET CURRENT SCRATCH LOCATION -- PARTITION SCRATCH
C
  510 NSCLFT = NSCRTC
      IF (LUAMV .AND. IDFBRK .GT. 0) IDFBRK = IDFBRK + 1000
      CALL SCRPRT(IPRINT, NAMLEN, NINVAR, NSPECS, NUSVAR, NUNVAR,
     $     NSTATS, NPTSRC, NPTSRT, NBLINE, NSUBRG, NMETHD, NPARAM,
     $     NVMETH, NVPARM, NPRFHT, NMETSC, NSCLFT, NSCPTR, NXCELL,
     $     NYCELL, NZCELL, NINFIL, INFILE, JSCRTC, JSCPTR, NVARBL,
     $     NUNITS, JFLAG)
      IF (JFLAG .LT. 0) GO TO 975
      IF (LUAMV .AND. IDFBRK .GT. 0) IDFBRK = IDFBRK - 1000
C
C SET POINTER TO NEXT AVAILABLE SCRATCH LOCATION AND ALLOCATE OUTPUT ARR
C
      KSPTR = NSCRTC - NSCLFT + 1
      CALL COREXT(IPRINT, IMATFL, NXCELL, NYCELL, NZCELL, NVARBL,
     $    NBUFFR, NSCLFT,  KSPTR, RMISSV,
     $    JBUFFR, JSCRTC, KBASE, KALTN, KOUTM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 980
C
C IF TOP CONCENTRATION PRESENT, ALLOCATE ARRAY
C
      IF (ITPCON .LE. 0) GO TO 515
      CALL COREXT(IPRINT, ITCFIL, NXCELL, NYCELL, NFLZCL, NVARBL,
     $    NTCBUF, NSCLFT, KSPTR, RMISSV,
     $    JTCBUF, JSCRTC, KTCVR, KTCSP, KTPCN, JFLAG)
      IF (JFLAG .LT. 0) GO TO 983
C
C PLACE UNIT-ONLY VARIABLES INTO THE VARIABLE NAMES
C
  515 NWORDS = (NUNITS - NUNVAR) * NAMLEN
      DO 525 I=1,NAMLEN
         MSCRTC(NWORDS + I) = MUNVAR(I,1)
         MSCRTC(NWORDS + NAMLEN +I) = MUNVAR(I,2)
  525 CONTINUE
C
C CALL THE DATA PROCESSING ROUTINE
C
      CALL AIRPRC(NAMLEN, NIDLEN, NVARBL, NSPECS, NUNITS, NSTATS,
     $    NSUBRG,
     $    NPARAM, NVPARM, NPRFHT, NSCLFT, NXCELL, NYCELL, NZCELL,
     $    INFILE, MFILNM, MFILID, LPRINT, LUAMV ,
     $    JINTSC, JSCRTC(KSPTR), REALSC,
     $    JSCRTC(KMULT), JSCRTC(KADTV), JSCRTC(KMOLW), JSCRTC(KSTNX),
     $    JSCRTC(KSTNY), JSCRTC(KSTNZ), JSCRTC(KPRMV), JSCRTC(KVPRV),
     $    JSCRTC(KVBNM), JSCRTC(KUNNM), JSCRTC(KSTNM), JSCRTC(KSBNM),
     $    JSCRTC(KPRNM), JSCRTC(KVPNM), JSCRTC(KRGRD), JSCRTC(KMTHN),
     $    JSCRTC(KPRMP), JSCRTC(KPRMC), JSCRTC(KVMTN), JSCRTC(KVPRP),
     $    JSCRTC(KVPRC), JSCRTC(KBASE), JSCRTC(KALTN), JSCRTC(KSTVL),
     $    JSCRTC(KMINV), JSCRTC(KMAXV), JSCRTC(KVMNV), JSCRTC(KVMXV),
     $    JSCRTC(KPRFX), JSCRTC(KPRFY), JSCRTC(KDFBK), JSCRTC(KRGTP),
     $    JSCRTC(KTCVR), JSCRTC(KTCSP),
     $    JSCRTC(KTPCN), JSCRTC(KPRFH), JSCRTC(KPRFV), JSCRTC(KOUTM),
     $    JFLAG)
      IF (JFLAG .LT. 0) GO TO 985
C
C END OF PROCESSING -- SKIP TO TERMINATOR
C
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN CNTLRD
C
  905 WRITE(IPRINT, 2905) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SPECIES COUNT
C
  910 WRITE(IPRINT, 2910) NSPECS
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN REGNRD
C
  915 WRITE(IPRINT, 2915) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VERTICAL CELL COUNT
C
  920 WRITE(IPRINT, 2920) NZCELL
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FILVER FOR IDFBRK
C
  925 WRITE(IPRINT, 2925) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FILVER FOR IRGTOP
C
  930 WRITE(IPRINT,2930) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FILVER FOR ITPCON
C
  935 WRITE(IPRINT,2935) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLHDWR
C
  955 WRITE(IPRINT, 2955) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLRGWR
C
  960 WRITE(IPRINT, 2960) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLSGWR
C
  965 WRITE(IPRINT, 2965) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLSPWR
C
  970 WRITE(IPRINT, 2970) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SCRPRT
C
  975 WRITE(IPRINT, 2975) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COREXT FOR OUTPUT MATRIX
C
  980 WRITE(IPRINT, 2980) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COREXT FOR TOP CONCENTRATION
C
  983 WRITE (IPRINT, 2983) JFLAG
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN AIRPRC
C
  985 WRITE (IPRINT, 2985) JFLAG
      GO TO 1000
C
C TERMINATE PROCESSING
C
 1000 WRITE (IPRINT,2999)
      STOP
C
C FORMATS
C
 2005 FORMAT (1H1, 48HPROCESSING OF INPUT DATA FOR THE PREPARATION OF ,
     $        5HFILE , 10A1, //, 1X, 60A1, //)
 2010 FORMAT (36H NUMBER OF USER-DEFINED VARIABLES = ,I10,/)
 2015 FORMAT (22H NUMBER OF STATIONS = , I10, /)
 2020 FORMAT (24H NUMBER OF SUBREGIONS = , I10, /)
 2025 FORMAT (31H NUMBER OF METHOD PARAMETERS = , I10, /)
 2030 FORMAT (40H NUMBER OF VERTICAL METHOD PARAMETERS = , I10, /)
 2035 FORMAT (38H NUMBER OF VERTICAL PROFILE HEIGHTS = , I10, /)
 2037 FORMAT (' DATA FILES ARE TO BE UAM-V FORMAT', /)
 2038 FORMAT (' DATA FILES ARE TO BE STANDARD UAM-IV FORMAT', /)
 2040 FORMAT (45H PROGRAM OUTPUT WILL BE PLACED ON FILE NUMBER ,I10,/)
 2045 FORMAT (49H INPUT DATA FOR DIFFUSION BREAK WILL BE OBTAINED ,
     $        17HFROM FILE NUMBER , I10, /)
 2046 FORMAT (49H INPUT DATA FOR HEIGHT/PRESSURE WILL BE OBTAINED ,
     $        17HFROM FILE NUMBER , I10, /)
 2050 FORMAT (44H INPUT DATA FOR REGION TOP WILL BE OBTAINED ,
     $        17HFROM FILE NUMBER , I10, /)
 2055 FORMAT (52H INPUT DATA FOR TOP CONCENTRATIONS WILL BE OBTAINED ,
     $        17HFROM FILE NUMBER , I10, /)
 2105 FORMAT (33H INPUT VALUES WILL NOT BE PRINTED, /)
 2110 FORMAT (29H INPUT VALUES WILL BE PRINTED, /)
 2115 FORMAT (32H OUTPUT GRID WILL NOT BE PRINTED, /)
 2120 FORMAT (28H OUTPUT GRID WILL BE PRINTED, /)
 2125 FORMAT (31H UNIT TABLE WILL NOT BE PRINTED, /)
 2130 FORMAT (27H UNIT TABLE WILL BE PRINTED, /)
 2135 FORMAT (38H STATION LOCATIONS WILL NOT BE PRINTED, /)
 2140 FORMAT (34H STATION LOCATIONS WILL BE PRINTED, /)
 2145 FORMAT (35H SUBREGION GRID WILL NOT BE PRINTED, /)
 2150 FORMAT (31H SUBREGION GRID WILL BE PRINTED, /)
 2155 FORMAT (33H METHOD TABLE WILL NOT BE PRINTED, /)
 2160 FORMAT (29H METHOD TABLE WILL BE PRINTED, /)
 2165 FORMAT (35H STATION VALUES WILL NOT BE PRINTED, /)
 2170 FORMAT (31H STATION VALUES WILL BE PRINTED, /)
 2175 FORMAT (42H VERTICAL METHOD TABLE WILL NOT BE PRINTED, /)
 2180 FORMAT (38H VERTICAL METHOD TABLE WILL BE PRINTED, /)
 2185 FORMAT (44H VERTICAL PROFILE VALUES WILL NOT BE PRINTED, /)
 2190 FORMAT (40H VERTICAL PROFILE VALUES WILL BE PRINTED, /)
 2205 FORMAT (24H BEGINNING DATE OF FILE , I10,
     $        24H BEGINNING TIME OF FILE , F10.2, //,
     $        21H ENDING DATE OF FILE , I10,
     $        21H ENDING TIME OF FILE , F10.2, /)
 2210 FORMAT (12H A TOTAL OF , I10, 26H SPECIES NAMES WERE READ. ,
     $        25HTHE SPECIES NAMES ARE -- , //, (1X, 10A1) )
 2305 FORMAT (1H1, 40X, 19HREGIONAL DEFINITION, ///,
     $        40H UTM ORIGIN X-COORDINATE                , F10.0,//,
     $        40H UTM ORIGIN Y-COORDINATE                , F10.0,//,
     $        40H UTM ORIGIN ZONE NUMBER                 , I10, //,
     $        40H REGION ORIGIN X-COORDINATE             , F10.0, //,
     $        40H REGION ORIGIN Y-COORDINATE             , F10.0, //,
     $        40H CELL LENGTH IN X-DIRECTION             , F10.2, //,
     $        40H CELL LENGTH IN Y-DIRECTION             , F10.2, //,
     $        40H NUMBER OF CELLS IN X-DIRECTION         , I10, //,
     $        40H NUMBER OF CELLS IN Y-DIRECTION         , I10, /)
 2310 FORMAT (40H NUMBER OF CELLS IN Z-DIRECTION         , I10, //,
     $        40H NUMBER OF CELLS IN LOWER VERTICAL LAYER, I10, //,
     $        40H NUMBER OF CELLS IN UPPER VERTICAL LAYER, I10, //,
     $        40H HEIGHT OF SURFACE LAYER                , F10.2, //,
     $        40H MINIMUM CELL HEIGHT IN LOWER LAYER     , F10.2, //,
     $        40H MINIMUM CELL HEIGHT IN UPPER LAYER     , F10.2, /)
 2905 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE CNTLRD, //)
 2910 FORMAT (1H1, 36H ****** SYSTEM OR INPUT ERROR ******,
     $        45H SUBROUTINE CNTLRD RETURNED SPECIES COUNT OF , I10, /,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE REGNRD, //)
 2920 FORMAT (1H1, 36H ****** SYSTEM OR INPUT ERROR ******,
     $        51HSUBROUTINE REGNRD RETURNED A VERTICAL CELL COUNT OF,
     $        I10, /, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2925 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE FILVER,
     $        20H FOR DIFFUSION BREAK, //)
 2930 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE FILVER,
     $        15H FOR REGION TOP, //)
 2935 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE FILVER,
     $        22H FOR TOP CONCENTRATION,//)
 2955 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE FLHDWR, //)
 2960 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE FLRGWR, //)
 2965 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE FLSGWR, //)
 2970 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE FLSPWR, //)
 2975 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE SCRPRT, //)
 2980 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE COREXT ,
     $        19H FOR OUTPUT MATRIX , //)
 2983 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE COREXT ,
     $        23H FOR TOP CONCENTRATION , //)
 2985 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        36H WAS RETURNED FROM SUBROUTINE AIRPRC, //)
 2999 FORMAT (1H1, 10HEND OF JOB)
      END
