      SUBROUTINE BINTRP(IPRINT, ICLL, NX, VALMN, VALMX, 
     $               BCONC, JFLAG)
C
C  ROUTINE TO LINEARLY INTERPOLATE BETWEEN BOUNDARY VALUES
C  
C  -- BY TCM, 10/17/89
C
C  INPUTS VARIABLES
C
C     IPRINT  UNIT FOR PRINTED OUTPUT
C     ICLL    INDEX OF CELL TO GET VALUE FOR
C     NX      NUMBER OF CELLS ON THIS EDGE
C     VALMN   MINIMUM ALLOWABLE VALUE
C     VALMX   MAXIMUM ALLOWABLE VALUE
C
C  OUTPUT VARIABLES
C
C     BCONC   VALUES ON THIS BOUNDARY
C     JFLAG   COMPLETION FLAG
C
      DIMENSION BCONC(NX)
C
C  FIND CELLS ABOVE AND BELOW CELL NEEDED FOR INTERPOLATION
C
      I1 = ICLL + 1
      IF (I1 .GT. NX) THEN
         JFLAG = -1
         GO TO 810
      ENDIF
      DO 50 I=I1,NX
         IF (BCONC(I) .NE. -9.) THEN
            IEND = I
            GO TO 70
         ENDIF
   50 CONTINUE
      JFLAG = -2
      GO TO 820
C
   70 I2 = ICLL - 1
      IF (I2 .LT. 1) THEN
         JFLAG = -3
         GO TO 810
      ENDIF
      DO 80 I=I2,1,-1
         IF (BCONC(I) .NE. -9.) THEN
            ISTRT = I
            GO TO 100
         ENDIF
   80 CONTINUE
      JFLAG = -4
      GO TO 820
C
C  INTERPOLATE TO GET THE VALUE FOR THE CURRENT CELL
C
  100 F1 = FLOAT(IEND-ICLL)/FLOAT(IEND-ISTRT)
      F2 = 1. - F1
      BCONC(ICLL) = F1*BCONC(ISTRT) + F2*BCONC(IEND)
      IF (BCONC(ICLL) .LT. VALMN) THEN
         WRITE(IPRINT,2000) BCONC(ICLL), ICLL, VALMN
         BCONC(ICLL) = VALMN
      ENDIF
      IF (BCONC(ICLL) .GT. VALMX) THEN
         WRITE(IPRINT,2010) BCONC(ICLL), ICLL, VALMX
         BCONC(ICLL) = VALMX
      ENDIF
      RETURN
C
C  ERROR EXITS
C
C    BAD CELL NUMBER
C
  810 WRITE(IPRINT,2810) ICLL, JFLAG
      STOP1
C
C    NO VALID VALUE TO INTERPOLATE
C
  820 WRITE(IPRINT,2820) ICLL, JFLAG
      STOP2
C
C  FORMATS
C
 2000 FORMAT(/,' THE CALCULATED VALUE ',1PE10.3,' IN CELL ',I5,
     $       ' IS BELOW THE MINIMUM VALUE OF ',E10.3,/,
     $       ' VALUE WILL BE RESET TO THE MINIMUM.')
 2010 FORMAT(/,' THE CALCULATED VALUE ',1PE10.3,' IN CELL ',I5,
     $       ' IS ABOVE THE MAXIMUM VALUE OF ',E10.3,/,
     $       ' VALUE WILL BE RESET TO THE MAXIMUM.')
 2810 FORMAT(/,' THE VALUE ',I5,' IS NOT A VALID CELL VALUE.',/,
     $       ' ERROR FLAG SET TO ',I5)
 2820 FORMAT(/,' NO VALID VALUE TO USE FOR INTERPOLATING TO CELL ',
     $       I5,/,' ERROR FLAG SET TO ',I5)
      END
