      SUBROUTINE BLINRD(INCARD, IPRINT, NAMLEN, NIDLEN, NUNITS, NBLINE,
     $  NXCELL, NYCELL, LINPTP, LBTABP, LBMAPP, JSTRDT, JSTPDT,
     $  XREGOR, YREGOR, XCELLD, YCELLD, STRTIM, STPTIM,
     $  RMISSV, MFILNM, MFILID, FACMLT, FACADD, SMOLWT, MVARBL,
     $  JBLRFW, JBLRFE, JBLRFS, JBLRFN, JBINDW, JBINDE, JBINDS, JBINDN,
     $  JADJSW, JADJSE, JADJSS, JADJSN, JADJXW, JADJXE, JADJXS, JADJXN,
     $  JADJYW, JADJYE, JADJYS, JADJYN,
     $  XBLBEG, YBLBEG, XBLEND, YBLEND, MBLINE, JBGRID, JFLAG)
      SAVE
C
C NAME -- BOUNDARY LINE IDENTIFICATION PACKET READ
C
C DESCRIPTION -- READS THE BOUNDARY LINE IDENTIFICATION PACKET AS PART OF
C                TIME-INVARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NIDLEN    I  NUMBER OF WORDS IN FILE IDENTIFICATION
C         NUNITS    I  NUMBER OF UNITS
C         NBLINE    I  NUMBER OF BOUNDARY LINES
C         LINPTP    I  INPUT PRINT FLAG
C         LBTABP    I  BOUNDARY LINES TABLE PRINT FLAG
C         LBMAPP    I  BOUNDARY LINES MAP PRINT FLAG
C         JBEGDT    I  BEGINNING DATE OF SIMULATION
C         JENDDT    I  ENDING DATE OF SIMULATION
C         XREGOR    R  X-COORDINATE OF MODELING REGION
C         YREGOR    R  Y-COORDINATE OF MODELING REGION
C         XCELLD    R  CELL DISTANCE IN X-DIRECTION
C         YCELLD    R  CELL DISTANCE IN Y-DIRECTION
C         BEGTIM    R  BEGINNING TIME OF SIMULATION
C         ENDTIM    R  ENDING TIME OF SIMULATION
C         RMISSV    R  MISSING VALUE INDICATOR
C         MFILNM    I  NAME OF FILE TO BE CREATED
C         MFILID    I  IDENTIFICATION FIELD OF NEW FILE
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C
C OUTPUTS --
C         JBLRFW    I  BOUNDARY LINE REFERENCE -- WEST
C         JBLRFE    I  BOUNDARY LINE REFERENCE -- EAST
C         JBLRFS    I  BOUNDARY LINE REFERENCE -- SOUTH
C         JBLRFN    I  BOUNDARY LINE REFERENCE -- NORTH
C         JBINDW    I  BOUNDARY LINE INDEX -- WEST
C         JBINDE    I  BOUNDARY LINE INDEX -- EAST
C         JBINDS    I  BOUNDARY LINE INDEX -- SOUTH
C         JBINDN    I  BOUNDARY LINE INDEX -- NORTH
C         JADJSW    I  BOUNDARY LINE ADJACENT SEGMENT -- WEST
C         JADJSE    I  BOUNDARY LINE ADJACENT SEGMENT -- EAST
C         JADJSS    I  BOUNDARY LINE ADJACENT SEGMENT -- SOUTH
C         JADJSN    I  BOUNDARY LINE ADJACENT SEGMENT -- NORTH
C         JADJXW    I  BOUNDARY LINE ADJACENT SEGMENT X-CELL -- WEST
C         JADJXE    I  BOUNDARY LINE ADJACENT SEGMENT X-CELL -- EAST
C         JADJXS    I  BOUNDARY LINE ADJACENT SEGMENT X-CELL -- SOUTH
C         JADJXN    I  BOUNDARY LINE ADJACENT SEGMENT X-CELL -- NORTH
C         JADJYW    I  BOUNDARY LINE ADJACENT SEGMENT Y-CELL -- WEST
C         JADJYE    I  BOUNDARY LINE ADJACENT SEGMENT Y-CELL -- EAST
C         JADJYS    I  BOUNDARY LINE ADJACENT SEGMENT Y-CELL -- SOUTH
C         JADJYN    I  BOUNDARY LINE ADJACENT SEGMENT Y-CELL -- NORTH
C         XBLBEG    R  BOUNDARY LINE BEGINNNING X-COORDINATE
C         YBLBEG    R  BOUNDARY LINE BEGINNNING Y-COORDINATE
C         XBLEND    R  BOUNDARY LINE ENDING X-COORDINATE
C         YBLEND    R  BOUNDARY LINE ENDING Y-COORDINATE
C         MBLINE    I  BOUNDARY LINE NAMES
C         JBGRID    I  BOUNDARY GRID
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         KCOOR     I  POINTER TO 'COORD' IN VARIABLE NAME LIST
C         KZCLL     I  POINTER TO Z-CELL LOCATION
C         KBLIN     I  POINTER TO BOUNDARY LINE NAME
C         MENDBL    I  PACKET TRAILER NAME
C         MBLNNM    I  INPUT BOUNDARY LINE NAME
C         MCOORD    I  REFERENCE NAME FOR 'COORD'
C         MBLANK    I  BLANK CHARACTER
C         MCRDID    I  CARD IDENTIFICATION
C         BLINXB    R  X-LOCATION OF BOUNDARY LINE BEGINNING
C         BLINYB    R  Y-LOCATION OF BOUNDARY LINE BEGINNING
C         BLINXE    R  X-LOCATION OF BOUNDARY LINE ENDING
C         BLINYE    R  Y-LOCATION OF BOUNDARY LINE ENDING
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C         SINVAL    INSERTS A SINGLE VALUE INTO AN ARRAY
C         GRIDPR    PRINTS BOUNDARY GRID
C
C ERROR CONDITIONS --
C         -9        'COORD' NOT IN VARIABLE NAME LIST
C         -11       BLANK NAME
C         -14       NO SPACE FOR NEW BOUNDARY LINE NAME
C         -16       BOUNDARY LINE CELL OUT OF REGION
C         -17       SINGLE BOUNDARY LINE IN A COLUMN
C         -18       SINGLE BOUNDARY LINE IN A ROW
C         -19       ERROR IN GRIDPR
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LBTABP
      LOGICAL LBMAPP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      CHARACTER*4 MFILNM(NAMLEN)
      CHARACTER*4 MFILID(NIDLEN)
      DIMENSION FACMLT(NUNITS)
      DIMENSION FACADD(NUNITS)
      DIMENSION SMOLWT(NUNITS)
      DIMENSION JBLRFW(NYCELL)
      DIMENSION JBLRFE(NYCELL)
      DIMENSION JBLRFS(NXCELL)
      DIMENSION JBLRFN(NXCELL)
      DIMENSION JBINDW(NYCELL)
      DIMENSION JBINDE(NYCELL)
      DIMENSION JBINDS(NXCELL)
      DIMENSION JBINDN(NXCELL)
      DIMENSION JADJSW(NYCELL)
      DIMENSION JADJSE(NYCELL)
      DIMENSION JADJSS(NXCELL)
      DIMENSION JADJSN(NXCELL)
      DIMENSION JADJXW(NYCELL)
      DIMENSION JADJXE(NYCELL)
      DIMENSION JADJXS(NXCELL)
      DIMENSION JADJXN(NXCELL)
      DIMENSION JADJYW(NYCELL)
      DIMENSION JADJYE(NYCELL)
      DIMENSION JADJYS(NXCELL)
      DIMENSION JADJYN(NXCELL)
      DIMENSION XBLBEG(NBLINE)
      DIMENSION YBLBEG(NBLINE)
      DIMENSION XBLEND(NBLINE)
      DIMENSION YBLEND(NBLINE)
      CHARACTER*4 MVARBL(NAMLEN,NUNITS)
      CHARACTER*4 MBLINE(NAMLEN,NBLINE)
      DIMENSION JBGRID(NXCELL, NYCELL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
      CHARACTER*4 MENDBL(10), MBLNNM(10), MCOORD(10), MCRDID(20)
      CHARACTER*4 MTITLE(60)
      CHARACTER*4 MBLANK
C
C DECLARE PACKET TRAILER AND DISTANCE UNIT NAMES
C
      DATA MENDBL /'E', 'N', 'D', 7*' '/
      DATA MCOORD /'C', 'O', 'O', 'R', 'D', ' ', ' ', ' ', ' ', ' '/
C
C SET TITLE FOR MAP
C
      DATA MTITLE /'M', 'A', 'P', ' ', 'O', 'F', ' ', 'B', 'O', 'U',
     $             'N', 'D', 'A', 'R', 'Y', ' ', 'L', 'I', 'N', 'E',
     $             ' ', 'N', 'U', 'M', 'B', 'E', 'R', 'S', ' ', 'O',
     $             'N', ' ', 'T', 'H', 'E', ' ', 'R', 'E', 'G', 'I',
     $             'O', 'N', 'A', 'L', ' ', 'G', 'R', 'I', 'D', ' ',
     $             ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' '/
C
C DECLARE MISCELLANEOUS SCALARS
C
      DATA MBLANK /' '/
      DATA JZEROS /0/
      DATA KZCLL /0/
      DATA NTILEN /60/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C FIND COORD IN VARIABLE LIST
C
      DO 45 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MCOORD, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 45
C
C FOUND IT -- SAVE LOCATION
C
         KCOOR = J
         GO TO 105
C
C END LOOP -- IF NOT FOUND, COORD IS MISSING FROM LIST
C
   45 CONTINUE
      GO TO 945
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MBLNNM, BLINXB, BLINYB, BLINXE, BLINYE,
     $     MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MBLNNM, BLINXB, BLINYB,
     $                   BLINXE, BLINYE, MCRDID
C
C PACK BOUNDARY LINE NAME AND CHECK FOR BLANK
C
      CALL TXTPAK(IPRINT, NAMLEN, MBLNNM, NPACKD, JFLAG)
      IF (NPACKD .EQ. 0) GO TO 955
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MBLNNM, MENDBL, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 210
C
C SET LOOP TO FIND BOUNDARY LINE NAME
C
      DO 115 K = 1, NBLINE
C
C COMPARE INPUT BOUNDARY LINE NAME WITH THE LIST OF NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MBLNNM, MBLINE(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND BOUNDARY LINE NAME -- SAVE LOCATION AND SKIP OUT
C
         KBLIN = K
         GO TO 140
  115 CONTINUE
C
C NAME NOT FOUND -- SET LOOP TO FIND BLANK SPOT
C
      DO 135 K = 1, NBLINE
C
C COMPARE FIRST LETTER WITH BLANK
C
         IF (MBLINE(1,K) .NE. MBLANK) GO TO 135
C
C FOUND ONE -- STUFF THE NAME IN HERE
C
         KBLIN = K
         DO 125 J = 1, NAMLEN
            MBLINE(J,K) = MBLNNM(J)
C
C END INNER LOOP AND SKIP TO LOCATION PROCESSING
C
  125    CONTINUE
         GO TO 140
C
C FINISH OUTER LOOP -- IF NO BLANKS, ERROR IN COUNT OR SPELLING
C
  135 CONTINUE
      GO TO 970
C
C DO UNIT CONVERSION FOR X-AND Y-LOCATIONS
C
  140 CALL UNTCNV(BLINXB, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, BLINXB)
      CALL UNTCNV(BLINYB, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, BLINYB)
      CALL UNTCNV(BLINXE, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, BLINXE)
      CALL UNTCNV(BLINYE, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, BLINYE)
C
C CONVERT COORDINATES TO GRID UNITS AND GO BACK FOR NEXT BOUNDARY LINE
C
      XBLBEG(KBLIN) = (BLINXB - XREGOR) / XCELLD
      YBLBEG(KBLIN) = (BLINYB - YREGOR) / YCELLD
      XBLEND(KBLIN) = (BLINXE - XREGOR) / XCELLD
      YBLEND(KBLIN) = (BLINYE - YREGOR) / YCELLD
      GO TO 105
C
C END OF PACKET -- PRINT BOUNDARY LINES TABLE IF WANTED
C
  210 IF (.NOT. LBTABP) GO TO 225
      WRITE (IPRINT, 2210)
C
C PRINT VALUES IN LOOP
C
      DO 215 J = 1, NBLINE
         WRITE (IPRINT, 2215)(MBLINE(I,J), I=1,NAMLEN),
     $       XBLBEG(J), XBLEND(J), YBLBEG(J), YBLEND(J)
  215 CONTINUE
C
C CLEAR GRID TO ZEROES
C
  225 NWORDS = NXCELL * NYCELL
      CALL SINVAL(IPRINT, NWORDS, JZEROS, JBGRID, JFLAG)
C
C SET LOOP TO FILL BOUNDARY GRID -- GET X-CELL LOCATION AND SET COUNT
C
      DO 250 K = 1, NXCELL
         XVALUE = FLOAT(K) - 0.5
         NVALUE = 0
         KXCLL = K
C
C SET LOOP TO GET BOUNDARY LINE INTERCEPT (IF ANY) FOR EACH LINE
C
         DO 240 J = 1, NBLINE
            KBLIN = J
C
C SEE IF THIS LINE HAS THIS X-VALUE
C
C
C SWITCH ENDS OF LINE IF NECESSARY
C
            IF (XBLBEG(J) .LE. XBLEND(J) ) GO TO 230
              SAVER = XBLBEG(J)
              XBLBEG(J) = XBLEND(J)
              XBLEND(J) = SAVER
              SAVER = YBLBEG(J)
              YBLBEG(J) = YBLEND(J)
              YBLEND(J) = SAVER
  230       IF (XVALUE .LT. XBLBEG(J)) GO TO 240
            IF(XVALUE .GT. XBLEND(J) ) GO TO 240
            IF (XBLEND(J) .EQ. XBLBEG(J) ) GO TO 240
C
C IT DOES -- FIND AND TEST THE Y-CELL
C
            YVALUE = (YBLEND(J) - YBLBEG(J) ) * (XVALUE - XBLBEG(J) ) /
     $               (XBLEND(J) - XBLBEG(J) ) + YBLBEG(J)
            KYCLL = IFIX(YVALUE + 0.5)
            IF (KYCLL .LT. 1) GO TO 980
            IF (KYCLL .GT. NYCELL) GO TO 980
C
C INCREMENT COUNT AND, IF CELL IS IN USE, WRITE WARNING MESSAGE
C
            NVALUE = NVALUE + 1
            IF (JBGRID(KXCLL, KYCLL) .EQ. 0) GO TO 235
            KBOLD = JBGRID(KXCLL, KYCLL)
            WRITE (IPRINT, 2235) (MBLINE(I, KBLIN), I = 1, NAMLEN),
     $           (MBLINE(I, KBOLD), I = 1, NAMLEN), KXCLL, KYCLL
            GO TO 240
C
C STORE LOCATION AND END LOOP
C
  235       JBGRID(KXCLL, KYCLL) = KBLIN
  240    CONTINUE
C
C IF ONLY ONE ENTRY IN THIS COLUMN, BAD NEWS -- END LOOP
C
         IF (NVALUE .EQ. 1) GO TO 985
  250 CONTINUE
C
C SET LOOP TO FILL BOUNDARY GRID -- GET Y-CELL LOCATION AND SET COUNT
C
      DO 280 K = 1, NYCELL
         YVALUE = FLOAT(K) - 0.5
         NVALUE = 0
         KYCLL = K
C
C SET LOOP TO GET BOUNDARY LINE INTERCEPT (IF ANY) FOR EACH LINE
C
         DO 270 J = 1, NBLINE
            KBLIN = J
C
C SEE IF THIS LINE HAS THIS Y-VALUE
C
C
C SWITCH ENDS OF LINE IF NECESSARY
C
            IF (YBLBEG(J) .LE. YBLEND(J) ) GO TO 260
              SAVER = YBLBEG(J)
              YBLBEG(J) = YBLEND(J)
              YBLEND(J) = SAVER
              SAVER = XBLBEG(J)
              XBLBEG(J) = XBLEND(J)
              XBLEND(J) = SAVER
  260       IF (YVALUE .LT. YBLBEG(J) ) GO TO 270
            IF (YVALUE .GT. YBLEND(J) ) GO TO 270
            IF (YBLEND(J) .EQ. YBLBEG(J) ) GO TO 270
C
C IT DOES -- FIND AND TEST THE X-CELL
C
            XVALUE = (XBLEND(J) - XBLBEG(J) ) * (YVALUE - YBLBEG(J) ) /
     $               (YBLEND(J) - YBLBEG(J) ) + XBLBEG(J)
            KXCLL = IFIX(XVALUE + 0.5)
            IF (KXCLL .LT. 1) GO TO 980
            IF (KXCLL .GT. NXCELL) GO TO 980
C
C INCREMENT COUNT AND, IF CELL IS IN USE, WRITE WARNING MESSAGE
C
            NVALUE = NVALUE + 1
            IF (JBGRID(KXCLL, KYCLL) .EQ. 0) GO TO 265
            KBOLD = JBGRID(KXCLL, KYCLL)
            WRITE (IPRINT, 2235) (MBLINE(I, KBLIN), I = 1, NAMLEN),
     $           (MBLINE(I, KBOLD), I = 1, NAMLEN), KXCLL, KYCLL
            GO TO 270
C
C STORE LOCATION AND END LOOP
C
  265       JBGRID(KXCLL, KYCLL) = KBLIN
  270    CONTINUE
C
C IF ONLY ONE ENTRY IN THIS ROW, BAD NEWS -- END LOOP
C
         IF (NVALUE .EQ. 1) GO TO 990
  280 CONTINUE
C
C SET LOOP TO FILL EAST-WEST BOUNDARY VECTORS -- INITIALIZE TO ZERO
C
      DO 340 K = 1, NYCELL
         JBLRFW(K) = 0
         JBLRFE(K) = 0
         JBINDW(K) = 0
         JBINDE(K) = 0
         JADJSW(K) = 0
         JADJSE(K) = 0
         JADJXW(K) = 0
         JADJXE(K) = 0
         JADJYW(K) = 0
         JADJYE(K) = 0
C
C SET LOOP TO LOOK AT COLUMNS FROM WEST
C
         DO 320 J = 1, NXCELL
C
C IF NON-ZERO ENTRY IN GRID, SAVE LOCANTS AND SKIP TO EASTERN LOOP
C
            IF (JBGRID(J, K) .EQ. 0) GO TO 320
            JBLRFW(K) = JBGRID(J, K)
            JBINDW(K) = J
            GO TO 325
C
C END WESTERN LOOP -- IF NO HIT, SKIP EASTERN LOOP
C
  320    CONTINUE
         GO TO 340
C
C SET LOOP TO LOOK AT COLUMNS FROM EAST
C
  325    DO 330 JJ = 1, NXCELL
            J = NXCELL - JJ + 1
C
C IF NON-ZERO, SAVE LOCANTS AND SKIP TO END OF LOOP
C
            IF (JBGRID(J, K) .EQ. 0) GO TO 330
            JBLRFE(K) = JBGRID(J, K)
            JBINDE(K) = J
            GO TO 340
C
C END LOOPS
C
  330    CONTINUE
  340 CONTINUE
C
C SET LOOP TO FILL NORTH-SOUTH BOUNDARY VECTORS -- INITIALIZE TO ZERO
C
      DO 390 K = 1, NXCELL
         JBLRFS(K) = 0
         JBLRFN(K) = 0
         JBINDS(K) = 0
         JBINDN(K) = 0
         JADJSS(K) = 0
         JADJSN(K) = 0
         JADJXS(K) = 0
         JADJXN(K) = 0
         JADJYS(K) = 0
         JADJYN(K) = 0
C
C SET LOOP TO LOOK AT ROWS FROM SOUTH
C
         DO 370 J = 1, NYCELL
C
C IF NON-ZERO ENTRY IN GRID, SAVE LOCANTS AND SKIP TO NORTHERN LOOP
C
            IF (JBGRID(K, J) .EQ. 0) GO TO 370
            JBLRFS(K) = JBGRID(K, J)
            JBINDS(K) = J
            GO TO 375
C
C END SOUTHERN LOOP -- IF NO HIT, SKIP NORTHERN LOOP
C
  370    CONTINUE
         GO TO 390
C
C SET LOOP TO LOOK AT ROWS FROM NORTH
C
  375    DO 380 JJ = 1, NYCELL
            J = NYCELL - JJ + 1
C
C IF NON-ZERO, SAVE LOCANTS AND SKIP TO END OF LOOP
C
            IF (JBGRID(K, J) .EQ. 0) GO TO 380
            JBLRFN(K) = JBGRID(K, J)
            JBINDN(K) = J
            GO TO 390
C
C END LOOPS
C
  380    CONTINUE
  390 CONTINUE
C
C IF WANTED, PRINT THE BOUNDARY LINE MAP
C
      IF (.NOT. LBMAPP) GO TO 1000
C
C CALL THE GRID PRINT ROUTINE WITH FORMAT 24I5, 30 LINES/PAGE
C
      KFRMT = 221
      CALL GRIDPI(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL,
     $    NYCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM, STPTIM,
     $     MFILNM, MFILID, MTITLE, JBGRID, JFLAG)
      IF (JFLAG .LT. 0) GO TO 995
C
C PRINT THE BOUNDARY LINENAMES TABLE
C
      WRITE (IPRINT, 2405)
      DO 410 J = 1, NBLINE
         WRITE (IPRINT, 2410) J, (MBLINE(I, J), I = 1, NAMLEN)
  410 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR 'COORD' NOT IN VARIABLE NAME LIST
C
  945 WRITE (IPRINT, 2945) MCOORD
      JFLAG = -9
      GO TO 1000
C
C ERROR MESSAGE FOR BLANK NAME
C
  955 WRITE (IPRINT, 2955)
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR NO SPACE FOR NEW BOUNDARY LINE NAME
C
  970 WRITE (IPRINT, 2970) MBLNNM
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR CELL OUT OF RANGE ON BOUNDARY LINE
C
  980 WRITE (IPRINT, 2980) (MBLINE(I, KBLIN), I = 1, NAMLEN), KXCLL,
     $     KYCLL, NXCELL, NYCELL
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR ONLY ONE LINE IN A COLUMN
C
  985 WRITE (IPRINT, 2985) (MBLINE(I, KBLIN), I = 1, NAMLEN), KXCLL
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR ONLY ONE LINE IN A ROW
C
  990 WRITE (IPRINT, 2990) (MBLINE(I, KBLIN), I = 1, NAMLEN), KYCLL
      JFLAG = -18
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GRIDPR
C
  995 WRITE (IPRINT, 2995) JFLAG
      JFLAG = -19
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 4F10.0, 10X, 20A1)
 2105 FORMAT (1X, 10A1, 4F10.0, 10X, 20A1)
 2210 FORMAT (1H1, 40X, 28HBOUNDARY LINE LOCATION TABLE, //,
     $        52H B. LINE NAME      X-BEGINNING(GRID SQ)    X-ENDING ,
     $        48H(GRID SQ)     Y-BEGINNING (GRID SQ)     Y-ENDING ,
     $        9H(GRID SQ) , //)
 2215 FORMAT (1X, 5X, 10A1, 4(10X, F10.2), /)
 2235 FORMAT (1X, 35H****** NOTE ******  BOUNDARY LINES , 10A1, 5H AND ,
     $        10A1, 20H INTERSECT IN CELL (, I10, 1H,, I10, 2H)., //,
     $        51H THIS CELL WILL TAKE ITS VALUE FROM THE LATTER LINE,//)
 2405 FORMAT (1H1, 29H BOUNDARY LINE IDENTIFICATION , //,
     $        5X, 6HNUMBER, 8X, 4HNAME, //)
 2410 FORMAT (1X, I10, 5X, 10A1, /)
 2945 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        45H BLANK BOUNDARY LINE NAMES ARE NOT ACCEPTABLE,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        52H INSUFFICIENT SPACE IN BOUNDARY LINE NAME TABLE FOR ,
     $        14HBOUNDARY LINE , 10A1, //, 21H TOTAL BOUNDARY LINE ,
     $        52H COUNT MAY BE TOO SMALL, OR A NAME MAY BE MISSPELLED,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2980 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H BOUNDARY LINE , 10A1, 16H CONTAINS CELL (, I10, 1H,,
     $        I10, 2H)., //,
     $        45H THIS CELL IS OUTSIDE THE REGIONAL BOUNDS OF , I10,
     $        19H (X-DIRECTION) AND , I10, 15H (Y-DIRECTION). , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2985 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H BOUNDARY LINE , 10A1, 28H IS THE ONLY LINE IN COLUMN ,
     $        I10, //, 37H EACH COLUMN MUST CONTAIN TWO LINES. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2990 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H BOUNDARY LINE , 10A1, 25H IS THE ONLY LINE IN ROW ,
     $        I10, //, 34H EACH ROW MUST CONTAIN TWO LINES. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2995 FORMAT (26H ****** ERROR TRACE ****** , 12H ERROR FLAG , I10,
     $        42H RETURNED TO BLINRD FROM SUBROUTINE GRIDPR , //)
      END
