      SUBROUTINE BLVLRD (INCARD, IPRINT, NAMLEN, NVARBL, NBLINE, LINPTP,
     $                   LBLRDP, RMISSV, FACMLT, FACADD, SMOLWT, MVARBL,
     $                   MBLINE, BLINVL, JFLAG)
      SAVE
C
C NAME -- BOUNDARY LINE VALUES PACKET READ
C
C DESCRIPTION -- READS THE BOUNDARY LINE VALUES PACKET AS PART OF TIME-
C                INVARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NBLINE    I  NUMBER OF BOUNDARY LINES
C         LINPTP    I  INPUT PRINT FLAG
C         LBLRDP    I  BOUNDARY LINE VALUES TABLE PRINT FLAG
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MBLINE    I  BOUNDARY LINE NAMES
C
C OUTPUTS --
C         BLINVL    R  BOUNDARY LINE VALUES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         MENDBV    I  PACKET TRAILER NAME
C         MCRDID    I  CARD IDENTIFICATION
C         MBLNNM    I  BOUNDARY LINE NAME
C         MVARNM    I  VARIABLE NAME
C         MALLNM    I  REFERENCE NAME FOR 'ALL'
C         KBLIN     I  BOUNDARY LINE POINTER
C         KVRBL     I  VARIABLE POINTER
C         VALBLN    R  BOUNDARY LINE VALUE
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -8        BOUNDARY LINE NAME NOT IN BOUNDARY LINE LIST
C         -12       VARIABLE NAME NOT IN VARIABLE LIST
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LBLRDP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NVARBL)
      DIMENSION FACADD(NVARBL)
      DIMENSION SMOLWT(NVARBL)
      CHARACTER*4 MVARBL(NAMLEN,NVARBL)
      CHARACTER*4 MBLINE(NAMLEN,NBLINE)
      DIMENSION BLINVL(NBLINE,NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
      CHARACTER*4 MENDBV(10), MBLNNM(10), MVARNM(10), MCRDID(20)
      CHARACTER*4 MALLNM(10)
C
C DECLARE PACKET TRAILER
C
      DATA MENDBV /'E', 'N', 'D', 7*' '/
      DATA MALLNM /'A', 'L', 'L', 7*' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MBLNNM, MVARNM, VALBLN, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MBLNNM, MVARNM, VALBLN, MCRDID
C
C PACK BOUNDARY LINE NAME
C
      CALL TXTPAK(IPRINT, NAMLEN, MBLNNM, NPACKD, JFLAG)
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MBLNNM, MENDBV, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 210
C
C COMPARE BOUNDARY LINE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MBLNNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET BOUNDARY LINE POINTER TO ZERO TO INDICATE 'ALL'
C
      KBLIN = 0
      GO TO 140
C
C SET LOOP TO FIND BOUNDARY LINE NAME
C
  113 DO 115 J = 1, NBLINE
C
C COMPARE INPUT BOUNDARY LINE NAME WITH THE LIST OF BOUNDARY LINE NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MBLNNM, MBLINE(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND BOUNDARY LINE NAME -- SAVE LOCATION AND SKIP OUT
C
         KBLIN = J
         GO TO 140
C
C END LOOP AND ERROR MESSAGE
C
  115 CONTINUE
      GO TO 940
C
C PACK VARIABLE NAME
C
  140 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 143
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 150
C
C SET LOOP TO FIND VARIABLE NAME
C
  143 DO 145 J = 1, NVARBL
C
C FIND THIS VARIABLE NAME IN LIST OF STANDARD VARIABLES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 145
C
C SAVE LOCATION AND SKIP TO UNIT CONVERSION
C
      KVRBL = J
         GO TO 150
C
C END LOOP AND ERROR MESSAGE
C
  145 CONTINUE
      GO TO 960
C
C DO UNIT CONVERSION ON INPUT VALUE, UNLESS MISSING
C
  150 IF (VALBLN .EQ. RMISSV) GO TO 160
      KBEGV = KVRBL
      IF(KVRBL .EQ. 0) KVRBL = 1
      CALL UNTCNV(VALBLN, FACMLT(KVRBL), FACADD(KVRBL), SMOLWT(KVRBL),
     $            RMISSV, RMISSV, VALBLN)
      KVRBL = KBEGV
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
  160 KBEGV = KVRBL
      KENDV = KVRBL
      KBEGB = KBLIN
      KENDB = KBLIN
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KBLIN .EQ. 0) KBEGB = 1
      IF (KBLIN .EQ. 0) KENDB = NBLINE
C
C SET LOOPS FOR STORING INPUT
C
      DO 185 KVRBL = KBEGV, KENDV
         DO 175 KBLIN = KBEGB, KENDB
C
C STORE VALUE IN TABLE
C
            BLINVL(KBLIN, KVRBL) = VALBLN
C
C END LOOPS AND GET NEXT CARD
C
  175    CONTINUE
  185 CONTINUE
      GO TO 105
C
C END OF PACKET, PRINT VALUES TABLE IF WANTED, ELSE RETURN
C
  210 IF (.NOT. LBLRDP) GO TO 1000
      WRITE (IPRINT, 2210)
C
C PRINT VALUES IN LOOP
C
      DO 225 K = 1, NBLINE
         DO 215 J = 1, NVARBL
            WRITE (IPRINT, 2215)(MBLINE(I,K), I=1,NAMLEN),
     $                       (MVARBL(I,J), I=1,NAMLEN), BLINVL(K,J)
  215    CONTINUE
  225 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR BOUNDARY LINE NAME NOT IN BOUNDARY LINE LIST
C
  940 WRITE (IPRINT, 2940) MBLNNM
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT IN VARIABLE LIST
C
  960 WRITE (IPRINT, 2960) MVARNM
      JFLAG = -12
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 10A1, F10.0, 30X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, F10.4, 30X, 20A1)
 2210 FORMAT (1H1, 14X, 26HBOUNDARY LINE VALUES TABLE, //,
     $        46H B. LINE NAME   VARIABLE NAME   B. LINE VALUE , //)
 2215 FORMAT (1X, 10A1, 5X, 10A1, F15.4, /)
 2940 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        31H UNABLE TO LOCATE B. LINE NAME , 10A1,
     $        18H IN B. LINES TABLE, //,
     $        27H CHECK B. LINE SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2960 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        19H IN VARIABLES TABLE, //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
