      SUBROUTINE BNDPRC(NAMLEN, NIDLEN, NVARBL, NSPECS, NUNITS, NBLINE,
     $  NPARAM, NVPARM, NPRFHT, NBDTIV, NSCRTC, NXCELL, NYCELL, NZCELL,
     $  INFILE, MFILNM, MFILID, LPRINT, LUAMV , JINTSC,
     $  JBDTIV, JBDVEC, JSCRTC, REALSC, FACMLT, FACADD, SMOLWT,
     $  XBLBEG, YBLBEG, XBLEND, YBLEND, PARAMS, VPARAM, MVARBL, MUNITS,
     $  MBLINE, MPARAM, MVPARM, JBGRID, JMTHDN,
     $  JPARMP, JPARMC,
     $  JVMTHN, JVPRMP, JVPRMC, BLNVAL, SMTHMN, SMTHMX, VMTHMN,
     $  VMTHMX, XPROFL, YPROFL, DIFBRK, REGTOP, TOPCON,
     $  TOPSPR, TOPMAT,
     $  PRFHGT, PRFVAL, BCONCW, BCONCE, BCONCS,
     $  BCONCN, JFLAG)
      SAVE
C
C NAME -- BOUNDARY PROCESS
C
C DESCRIPTION -- PROCESSES ALL INPUT PACKETS AND CALCULATES
C         BOUNDARY VALUES
C
C PROGRAMMER -- DAVID C WHITNEY/SAI  JULY 1977
C
C INPUTS --
C         INCARD    I  INPUT UNIT (FROM JINTSC)
C         IPRINT    I  OUTPUT UNIT (FROM JINTSC)
C         IOUTFL    I  OUTPUT FILE NUMBER (FROM JINTSC)
C         IDFBRK    I  DIFFUSION BREAK FILE NUMBER (FROM INFILE)
C         IRGTOP    I  REGION TOP FILE NUMBER (FROM INFILE)
C         ITPCON    I  TOP CONCENTRATION FILE NUMBER (FROM INFILE)
C         NAMLEN    I  NAME LENGTH
C         NIDLEN    I  IDENTIFICATION FIELD LENGTH
C         NVARBL    I  TOTAL NUMBER OF VARIABLES
C         NUNITS    I  NUMBER OF UNITS
C         NBLINE    I  NUMBER OF BOUNDARY LINES
C         NPARAM    I  NUMBER OF PARAMETERS
C         NVPARM    I  NUMBER OF VERTICAL PARAMETERS
C         NPRFHT    I  NUMBER OF PROFILE HEIGHTS
C         NBDTIV    I  NUMBER OF TIME-INVARIANT BOUNDARY VECTORS
C         NSCRTC    I  NUMBER OF AVAILABLE SCRATCH WORDS
C         NXCELL    I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL    I  NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL    I  NUMBER OF CELLS IN Z-DIRECTION
C         NZLOWR    I  NUMBER OF CELLS IN LOWER VERTICAL LAYER (FROM JINTSC)
C         NZUPPR    I  NUMBER OF CELLS IN UPPER VERTICAL LAYER (FROM JINTSC)
C         JBEGDT    I  BEGINNING DATE (FROM JINTSC)
C         JENDDT    I  ENDING DATE (FROM JINTSC)
C         JUTMZN    I  UTM ZONE NUMBER (FROM JINTSC)
C         JMISSV    I  MISSING VALUE (FROM JINTSC)
C         LINPTP    L  PRINT FLAG FOR INPUT CARD (FROM LPRINT)
C         LGRIDP    L  PRINT FLAG FOR OUTPUT GRID (FROM LPRINT)
C         LUNITP    L  PRINT FLAG FOR UNITS TABLE (FROM LPRINT)
C         LBTABP    L  PRINT FLAG FOR BOUNDARY LINE TABLE (FROM LPRINT)
C         LBMAPP    L  PRINT FLAG FOR BOUNDARY LINE MAP (FROM LPRINT)
C         LMTHDP    L  PRINT FLAG FOR METHOD TABLE (FROM LPRINT)
C         LBLRDP    L  PRINT FLAG FOR BOUNDARY LINE READING (FROM LPRINT)
C         LVMTHP    L  PRINT FLAG FOR VERTICAL METHOD TABLE (FROM LPRINT)
C         LVPRFP    L  PRINT FLAG FOR VERTICAL PROFILES (FROM LPRINT)
C         LUAMV     L  UAMV FILE FORMAT OPTION
C         BEGTIM    R  BEGINNING TIME (FROM REALSC)
C         ENDTIM    R  ENDING TIME (FROM REALSC)
C         XUTMOR    R  X-COORDINATE OF UTM ORIGIN (FROM REALSC)
C         YUTMOR    R  Y-COORDINATE OF UTM ORIGIN (FROM REALSC)
C         XREGOR    R  X-COORDINATE OF REGION ORIGIN (FROM REALSC)
C         YREGOR    R  Y-COORDINATE OF REGION ORIGIN (FROM REALSC)
C         XCELLD    R  LENGTH OF CELL IN X-DIRECTION (FROM REALSC)
C         YCELLD    R  LENGTH OF CELL IN Y-DIRECTION (FROM REALSC)
C         ZHTSUR    R  CELL HEIGHT, SURFACE LAYER (FROM REALSC)
C         ZMINLW    R  MINIMUM CELL HEIGHT, LOWER LAYER (FROM REALSC)
C         ZMINUP    R  MINIMUM CELL HEIGHT, UPPER LAYER (FROM REALSC)
C         RMISSV    R  MISSING VALUE (FROM REALSC)
C         INFILE    I  FILE UNIT NUMBERS
C         MFILNM    I  FILE NAME
C         MFILID    I  FILE IDENTIFICATION
C         LPRINT    I  PRINT FLAGS
C         JINTSC    I  INTEGER SCALARS FOR PASSING TO PROCESSING ROUTINE
C         JBDTIV    I  LOCATIONS OF TIME-INVARIANT VECTORS IN SCRATCH
C         JBDVEC    I  SCRATCH VECTOR CONTAINING BOUNDARY LINE VECTORS
C         JSCRTC    I  SCRATCH FOR PARTITIONING
C         REALSC    R  REAL SCALARS FOR PASSING TO PROCESSING ROUTINE
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         XBLBEG    R  BOUNDARY LINE X-LOCATION BEGINNING
C         YBLBEG    R  BOUNDARY LINE Y-LOCATION BEGINNING
C         XBLEND    R  BOUNDARY LINE X-LOCATION ENDING
C         YBLEND    R  BOUNDARY LINE Y-LOCATION ENDING
C         PARAMS    R  METHOD PARAMETERS
C         VPARAM    R  VERTICAL METHOD PARAMETERS
C         MVARBL    I  VARIABLE NAMES
C         MUNITS    I  UNIT NAMES
C         MBLINE    I  BOUNDARY LINE NAMES
C         MPARAM    I  PARAMETER NAMES
C         MVPARM    I  VERTICAL PARAMETER NAMES
C         JBGRID    I  REGIONAL GRID
C         JMTHDN    I  METHOD NUMBERS
C         JPARMP    I  PARAMETER POINTERS
C         JPARMC    I  PARAMETER COUNTERS
C         JVMTHN    I  VERTICAL METHOD NUMBERS
C         JVPRMP    I  VERTICAL PARAMETER POINTERS
C         JVPRMC    I  VERTICAL PARAMTER COUNTERS
C         BLNVAL    R  BOUNDARY LINE VALUES
C         SMTHMN    R  METHOD MINIMUM
C         SMTHMX    R  METHOD MAXIMUM
C         VMTHMN    R  VERTICAL METHOD MINIMUM
C         VMTHMX    R  VERTICAL METHOD MAXIMUM
C         XPROFL    R  PROFILE X-LOCATION
C         YPROFL    R  PROFILE Y-LOCATION
C         DIFBRK    R  DIFFUSION BREAK
C         REGTOP    R  REGION TOP
C         TOPCON    R  CONCENTRATIONS ALOFT
C         PRFHGT    R  PROFILE HEIGHTS
C         PRFVAL    R  PROFILE VALUES
C         BCONCW    R  BOUNDARY CONCENTRATIONS - WEST
C         BCONCE    R  BOUNDARY CONCENTRATIONS - EAST
C         BCONCS    R  BOUNDARY CONCENTRATIONS - SOUTH
C         BCONCN    R  BOUNDARY CONCENTRATIONS - NORTH
C
C OUTPUTS --
C         JFLAG
C
C LOCAL VARIABLES --
C
C         NTILEN    I  NUMBER OF WORDS IN TITLE
C         NTIHDR    I  NUMBER OF TIME-INVARIANT HEADERS
C         NTVHDR    I  NUMBER OF TIME VARIANT HEADERS
C         NMETHD    I  NUMBER OF METHODS
C         NVMTHD    I  NUMBER OF VERTICAL METHODS
C         NSGMNT    I  NUMBER OF SEGMENTS
C         NPACKD    I  NUMBER OF WORDS IN PACKED NAME
C         NPARMC    I  NUMBER OF PARAMETERS FOR THIS METHOD
C         NVPRMC    I  NUMBER OF VERTICAL PARAMETERS FOR THIS METHOD
C         NFILSC    I  NUMBER OF WORDS NEEDED BY FILE SCRATCH
C         NFLVAR    I  NUMBER OF VARIABLES FOR FILE WRITE
C         KVRBL     I  POINTER TO CURRENT VARIABLE
C         KUNIT     I  POINTER TO CURRENT UNIT
C         KBLIN     I  POINTER TO CURRENT BOUNDARY LINE
C         KMTHD     I  POINTER TO CURRENT METHOD
C         KPRMP     I  POINTER TO CURRENT PARAMETER
C         KVMTH     I  POINTER TO CURRENT VERTICAL METHOD
C         KVPRP     I  POINTER TO CURRENT VERTICAL PARAMETER
C         KXCLL     I  POINTER TO CURRENT X-CELL
C         KYCLL     I  POINTER TO CURRENT Y-CELL
C         KZCLL     I  POINTER TO CURRENT Z-CELL
C         KZPTR     I  POINTER TO CURRENT Z-LEVEL
C         KTITL     I  POINTER TO CURRENT LOCATION IN TITLE
C         KFRMT     I  POINTER TO CURRENT FORMAT FOR PRINTED GRID OUTPUT
C         KSBTN     I  POINTER TO CURRENT SUBROUTINE
C         JCURDT    I  CURRENT DATE
C         JSTRDT    I  STARTING DATE
C         JSTPDT    I  STOPPING DATE
C         CURTIM    R  CURRENT TIME
C         STRTIM    R  STARTING TIME
C         STPTIM    R  STOPPING TIME
C         MHEADR    I  CURRENT PACKET HEADER
C         MCRDID    I  CURRENT CARD IDENTIFICATION
C         MTITLE    I  TITLE OF OUTPUT PRINT GRID
C         MTIHDR    I  TIME-INVARIANT HEADER LIST
C         MTVHDR    I  TIME-VARIANT HEADER LIST
C         MMETHD    I  METHOD NAME LIST
C         MVMTHD    I  VERTICAL METHOD NAME LIST
C         MDFBRK    I  DIFFUSION BREAK VARIABLE NAME
C         MRGTOP    I  REGION TOP VARIABLE NAME
C
C
C ROUTINES CALLED --
C         TXTPAK    LEFT JUSTIFIES NAME FIELD
C         COMPAR    COMPARES TWO FIELDS
C         UNITRD    UNITS PACKET
C         BLINRD    BOUNDARY LINES PACKET
C         TIMERD    TIME CARD PACKET
C         DFBKRD    READS FROM DIFFUSION BREAK FILE
C         HTPRRD    READS FROM HEIGHT/PRESSURE FILE
C         RGTPRD    READS FROM REGION TOP FILE
C         TPCNRD    READS FROM TOP CONCENTRATION FILE
C         TPUVRD    READS FROM UAMV TOP CONCENTRATION FILE
C         MTHDRD    METHOD DEFINITION PACKET
C         CNSTRD    CONSTANTS DEFINITION PACKET
C         BLVLRD    BOUNDARY LINE VALUES DEFINITION PACKET
C         VPRFRD    VERTICAL PROFILES DEFINITION PACKET
C         SPLITC    SPLIT-COMBINATION
C         BNDUSR    USER-SUPPLIED SUBROUTINE
C         RELPRF    RELATIVE PROFILE INTERPOLATION
C         ABSPRF    ABSOLUTE PROFILE INTERPOLATION
C         ABSPRV    ABSOLUTE PROFILE INTERPOLATION FOR UAMV 
C         RLPRFR    RELATIVE PROFILE RATIO INTERPOLATION
C         ABPRFR    ABSOLUTE PROFILE RATIO INTERPOLATION
C         ABPRVR    ABSOLUTE PROFILE RATIO INTERPOLATION FOR UAMV
C         BNDVUS    USER-SUPPLIED VERTICAL SUBROUTINE
C         FLTMWR    WRITES TIME RECORD
C         FLBVWR    WRITES BOUNDARY RECORDS
C         GRIDPR    PRINTS BOUNDARY GRIDS
C
C ERROR CONDITIONS --
C         -1        NON-POSITIVE NAME LENGTH
C         -2        NON-POSITIVE NUMBER OF VARIABLES
C         -3        NON-POSITIVE NUMBER OF BOUNDARY LINES
C         -4        NON-POSITIVE NUMBER OF X-CELLS
C         -5        NON-POSITIVE NUMBER OF Y-CELLS
C         -6        NON-POSITIVE NUMBER OF Z-CELLS
C         -7        INSUFFICIENT SCRATCH STORAGE
C         -11       ERROR IN TXTPAK OF TIME-INVARIANT HEADER
C         -12       ERROR IN COMPAR OF TIME-INVARIANT HEADER
C         -13       NO MATCH OF TIME-INVARIANT HEADER
C         -14       ERROR IN UNITRD
C         -15       ERROR IN BLINRD
C         -16       ERROR IN FLBIWR
C         -17       ERROR IN TIMERD
C         -18       GAP IN TIMING
C         -21       ERROR IN DFBKRD
C         -22       ERROR IN RGTPRD
C         -23       ERROR IN TPCNRD
C         -24       ERROR IN TPUVRD
C         -25       ERROR IN HTPRRD
C         -31       ERROR IN TIME-VARIANT HEADER
C         -32       ERROR IN COMPAR OF TIME-VARIANT HEADER
C         -33       NO MATCH FOR TIME-VARIANT HEADER
C         -42       ERROR IN MTHDRD
C         -43       ERROR IN VERTICAL MTHDRD
C         -44       ERROR IN CNSTRD
C         -46       ERROR IN BLVLRD
C         -47       ERROR IN VPRFRD
C         -52       ILLEGAL METHOD -- WEST OR EAST BOUNDARY
C         -53       ILLEGAL PARAMETER COUNT ON SPLIT-COMBINATION -- W-E
C         -54       ILLEGAL PARAMETER POINTER ON SPLIT-COMBINATION -- W-E
C         -55       ERROR IN SPLITC -- WEST OR EAST
C         -57       ILLEGAL PARAMETER COUNT ON USER SUBROUTINE -- W-E
C         -58       ILLEGAL PARAMETER POINTER ON USER SUBROUTINE -- W-E
C         -59       ERROR IN BNDUSR
C         -62       ILLEGAL METHOD -- SOUTH OR NORTH BOUNDARY
C         -63       ILLEGAL PARAMETER COUNT ON SPLIT-COMBINATION -- S-N
C         -64       ILLEGAL PARAMETER POINTER ON SPLIT-COMBINATION -- S-N
C         -65       ERROR IN SPLITC -- SOUTH OR NORTH
C         -67       ILLEGAL PARAMETER COUNT ON USER SUBROUTINE -- S-N
C         -68       ILLEGAL PARAMETER POINTER ON USER SUBROUTINE -- S-N
C         -69       ERROR IN BNDUSR
C         -72       ILLEGAL VERTICAL METHOD -- WEST OR EAST BOUNDARY
C         -73       ERROR IN ABSPRF OR ABSPRV -- WEST OR EAST
C         -74       ERROR IN RELPRF -- WEST OR EAST
C         -75       ERROR IN ABPRFR OR ABPRVR -- WEST OR EAST
C         -76       ERROR IN RLPRFR -- WEST OR EAST
C         -77       ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE -- W-E
C         -78       ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTINE -- W-E
C         -79       ERROR IN BNDVUS -- WEST OR EAST
C         -82       ILLEGAL VERTICAL METHOD -- SOUTH OR NORTH BOUNDARY
C         -83       ERROR IN ABSPRF OR ABSPRV -- SOUTH OR NORTH
C         -84       ERROR IN RELPRF -- SOUTH OR NORTH
C         -85       ERROR IN ABPRFR OR ABPRVR -- SOUTH OR NORTH
C         -86       ERROR IN RLPRFR -- SOUTH OR NORTH
C         -87       ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE -- S-N
C         -88       ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTINE -- S-N
C         -91       ERROR IN FLTMWR
C         -92       ERROR IN FLBVWR
C         -93       ERROR IN GRIDPR
C
C OTHER INFORMATION --
C
C
C
C DECLARE PRINT FLAG ARRAY AND MEMBERS
C
      LOGICAL LPRINT
      LOGICAL LINPTP
      LOGICAL LGRIDP
      LOGICAL LUNITP
      LOGICAL LBTABP
      LOGICAL LBMAPP
      LOGICAL LMTHDP
      LOGICAL LBLRDP
      LOGICAL LVMTHP
      LOGICAL LVPRFP
      LOGICAL LUAMV
C
C SET DIMENSIONS ON INPUT VARIABLES
C
      DIMENSION INFILE(3)
      DIMENSION LPRINT(10)
      DIMENSION JINTSC(10)
      DIMENSION REALSC(12)
      DIMENSION TOPMAT(1)
      CHARACTER*4 MFILNM(NAMLEN)
      CHARACTER*4 MFILID(NIDLEN)
      DIMENSION JSCRTC(NSCRTC)
      DIMENSION FACMLT(NUNITS)
      DIMENSION FACADD(NUNITS)
      DIMENSION SMOLWT(NUNITS)
      DIMENSION XBLBEG(NBLINE)
      DIMENSION YBLBEG(NBLINE)
      DIMENSION XBLEND(NBLINE)
      DIMENSION YBLEND(NBLINE)
      DIMENSION PARAMS(NPARAM)
      DIMENSION VPARAM(NVPARM)
      DIMENSION JBDTIV(NBDTIV)
      DIMENSION JBDVEC(NSCRTC)
      CHARACTER*4 MVARBL(NAMLEN, NVARBL)
      CHARACTER*4 MUNITS(NAMLEN, NUNITS)
      CHARACTER*4 MBLINE(NAMLEN, NBLINE)
      CHARACTER*4 MPARAM(NAMLEN, NPARAM)
      CHARACTER*4 MVPARM(NAMLEN, NVPARM)
      DIMENSION JBGRID(NXCELL, NYCELL)
      DIMENSION JMTHDN(NBLINE, NVARBL)
      DIMENSION JPARMP(NBLINE, NVARBL)
      DIMENSION JPARMC(NBLINE, NVARBL)
      DIMENSION JVMTHN(NBLINE, NVARBL)
      DIMENSION JVPRMP(NBLINE, NVARBL)
      DIMENSION JVPRMC(NBLINE, NVARBL)
      DIMENSION BLNVAL(NBLINE, NVARBL)
      DIMENSION SMTHMN(NBLINE, NVARBL)
      DIMENSION SMTHMX(NBLINE, NVARBL)
      DIMENSION VMTHMN(NBLINE, NVARBL)
      DIMENSION VMTHMX(NBLINE, NVARBL)
      DIMENSION XPROFL(NBLINE, NVARBL)
      DIMENSION YPROFL(NBLINE, NVARBL)
      DIMENSION DIFBRK(NXCELL, NYCELL)
      DIMENSION REGTOP(NXCELL, NYCELL)
      DIMENSION TOPCON(NXCELL, NYCELL)
      DIMENSION TOPSPR(NXCELL, NYCELL)
      DIMENSION PRFHGT(NPRFHT, NBLINE, NVARBL)
      DIMENSION PRFVAL(NPRFHT, NBLINE, NVARBL)
      DIMENSION BCONCW(NYCELL, NZCELL, NVARBL)
      DIMENSION BCONCE(NYCELL, NZCELL, NVARBL)
      DIMENSION BCONCS(NXCELL, NZCELL, NVARBL)
      DIMENSION BCONCN(NXCELL, NZCELL, NVARBL)
C
C SET DIMENSIONS OF LOCAL VARIABLES
C
      CHARACTER*4 MTIHDR(10,3)
      CHARACTER*4 MTVHDR(10,6)
      CHARACTER*4 MMETHD(10,6)
      CHARACTER*4 MVMTHD(10,9)
      CHARACTER*4 MHEADR(60)
      CHARACTER*4 MCRDID(20)
      CHARACTER*4 MTITLE(60)
      CHARACTER*4 MDFBRK(10)
      CHARACTER*4 MRGTOP(10)
C
C SET LOCAL SCALARS
C
      DATA NTIHDR /3/
      DATA NTVHDR /6/
      DATA NMETHD /6/
      DATA NVMTHD /9/
      DATA NFLVAR /1/
      DATA NFILSC /100/
      DATA NTILEN /60/
      DATA KPRML /1/
      DATA KVPRL /1/
      DATA KTITL /50/
      DATA KZCLL /1/
      DATA NSGMNT /1/
      DATA NFLZCL /1/
C
C SET TIME-INVARIANT PACKET HEADER NAMES
C
      DATA  MTIHDR             /'U','N','I','T','S',' ',' ',' ',' ',' ',
     &                          'B','O','U','N','D','A','R','I','E','S',
     &                          'T','I','M','E','I','N','T','E','R','V'/
C
C SET TIME VARIANT PACKET HEADER NAMES
C
      DATA  MTVHDR             /'M','E','T','H','O','D',' ',' ',' ',' ',
     &                          'V','E','R','T','I','C','A','L','M','E',
     &                          'C','O','N','S','T','A','N','T','S',' ',
     &                          'B','O','U','N','D','A','R','Y','R','E',
     &                          'V','E','R','T','I','C','A','L','P','R',
     &                          'E','N','D','T','I','M','E',' ',' ',' '/
C
C SET METHOD NAMES
C
      DATA  MMETHD             /'C','O','N','S','T','A','N','T',' ',' ',
     &                          'B','O','U','N','D','V','A','L','U','E',
     &                          'S','P','L','I','T','/','C','O','M','B',
     &                          'U','S','E','R',' ',' ',' ',' ',' ',' ',
     &                          'E','-','W','I','N','T','E','R','P',' ',
     &                          'N','-','S','I','N','T','E','R','P',' '/
C
C SET
C
      DATA  MVMTHD             /'C','O','N','S','T','A','N','T',' ',' ',
     &                          'A','B','S','P','R','O','F','I','L','E',
     &                          'R','E','L','P','R','O','F','I','L','E',
     &                          'A','B','S','P','R','O','F','R','A','T',
     &                          'R','E','L','P','R','O','F','R','A','T',
     &                          'V','E','R','T','U','S','E','R',' ',' ',
     &                          'E','-','W','I','N','T','E','R','P',' ',
     &                          'N','-','S','I','N','T','E','R','P',' ',
     &                          'F','I','X','P','R','O','F','I','L','E'/
C
C SET TITLE
C
      DATA MTITLE /'B', 'O', 'U', 'N', 'D', 'A', 'R', 'Y', ' ', 'C',
     $             'O', 'N', 'C', 'E', 'N', 'T', 'R', 'A', 'T', 'I',
     $             'O', 'N', 'S', ' ', '(', 'P', 'A', 'R', 'T', 'S',
     $             ' ', 'P', 'E', 'R', ' ', 'M', 'I', 'L', 'L', 'I',
     $             'O', 'N', ')', ' ', 'F', 'O', 'R', ' ', ' ', ' ',
     $             ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' '/
C
C SET INPUT FILE VARIABLE NAMES
C
      DATA MDFBRK /'D', 'I', 'F', 'F', 'B', 'R', 'E', 'A', 'K', ' '/
      DATA MRGTOP /'R', 'E', 'G', 'I', 'O', 'N', 'T', 'O', 'P', ' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C TAKE APART THE INTEGER SCALARS VECTOR
C
      INCARD = JINTSC(1)
      IPRINT = JINTSC(2)
      IOUTFL = JINTSC(3)
      NZLOWR = JINTSC(4)
      NZUPPR = JINTSC(5)
      JBEGDT = JINTSC(6)
      JENDDT = JINTSC(7)
      JUTMZN = JINTSC(8)
      JMISSV = JINTSC(9)
      ITCFIL = JINTSC(10)
C
C TEST NAME LENGTH FOR POSITIVE VALUE
C
      IF (NAMLEN .LE. 0) GO TO 901
C
C TEST NUMBER OF VARIABLES FOR POSITIVE VALUE
C
      IF (NVARBL .LE. 0) GO TO 902
C
C TEST NUMBER OF BOUNDARY LINES FOR POSITIVE VALUE
C
      IF (NBLINE .LE. 0) GO TO 903
C
C TEST NUMBER OF X-CELLS FOR POSITIVE VALUE
C
      IF (NXCELL .LE. 0) GO TO 904
C
C TEST NUMBER OF Y-CELLS FOR POSITIVE VALUE
C
      IF (NYCELL .LE. 0) GO TO 905
C
C TEST NUMBER OF Z CELLS FOR POSITIVE VALUE
C
      IF (NZCELL .LE. 0) GO TO 906
C
C TEST AVAILABLE SCRATCH
C
      IF (NSCRTC .LT. MAX0(NAMLEN * NVARBL, NFILSC)) GO TO 907
C
C TAKE APART THE FILE UNIT NUMBER VECTOR
C
      IDFBRK = INFILE(1)
      IRGTOP = INFILE(2)
      ITPCON = INFILE(3)
C
C TAKE APART THE PRINT FLAG VECTOR
C
      LINPTP = LPRINT(1)
      LGRIDP = LPRINT(2)
      LUNITP = LPRINT(3)
      LBTABP = LPRINT(4)
      LBMAPP = LPRINT(5)
      LMTHDP = LPRINT(6)
      LBLRDP = LPRINT(7)
      LVMTHP = LPRINT(8)
      LVPRFP = LPRINT(9)
C
C TAKE APART THE REAL SCALARS VECTOR
C
      BEGTIM = REALSC( 1)
      ENDTIM = REALSC( 2)
      XUTMOR = REALSC( 3)
      YUTMOR = REALSC( 4)
      XREGOR = REALSC( 5)
      YREGOR = REALSC( 6)
      XCELLD = REALSC( 7)
      YCELLD = REALSC( 8)
      ZHTSUR = REALSC( 9)
      ZMINLW = REALSC(10)
      ZMINUP = REALSC(11)
      RMISSV = REALSC(12)
C
C TAKE APART THE TIME-INVARIANT BOUNDARY VECTOR POINTERS VECTOR
C
      KBLRW = JBDTIV( 1)
      KBLRE = JBDTIV( 2)
      KBLRS = JBDTIV( 3)
      KBLRN = JBDTIV( 4)
      KBINW = JBDTIV( 5)
      KBINE = JBDTIV( 6)
      KBINS = JBDTIV( 7)
      KBINN = JBDTIV( 8)
      KBASW = JBDTIV( 9)
      KBASE = JBDTIV(10)
      KBASS = JBDTIV(11)
      KBASN = JBDTIV(12)
      KBAXW = JBDTIV(13)
      KBAXE = JBDTIV(14)
      KBAXS = JBDTIV(15)
      KBAXN = JBDTIV(16)
      KBAYW = JBDTIV(17)
      KBAYE = JBDTIV(18)
      KBAYS = JBDTIV(19)
      KBAYN = JBDTIV(20)
C
C SET CURRENT DATE AND TIME TO BEGINNING DATE AND TIME
C
      JCURDT = JBEGDT
      CURTIM = BEGTIM
C
C READ AND PRINT A TIME-INVARIANT HEADER CARD
C
  105 READ (INCARD,1105) MHEADR, MCRDID
      WRITE(IPRINT,2105) MHEADR, MCRDID
C
C PACK HEADER AND SET COMPARISON LOOP
C
      CALL TXTPAK(IPRINT, NIDLEN, MHEADR, NPACKD, JFLAG)
      IF (JFLAG .LT. 0) GO TO 911
      DO 110 J = 1, NTIHDR
C
C COMPARE THIS HEADER VALUE WITH THE ACCEPTABLE ONES
C
         CALL COMPAR(IPRINT, NAMLEN, MHEADR, MTIHDR(1,J), JFLAG)
         IF (JFLAG .LT. 0) GO TO 912
         IF (JFLAG .EQ. 0) GO TO 110
C
C SAVE MODULE NUMBER AND SKIP TO TRANSFER
C
         KSBTN = J
         GO TO 115
C
C END LOOP -- IF NO MATCH, TERMINATE
C
  110 CONTINUE
      GO TO 913
C
C TRANSFER TO THE APPROPRIATE SUBROUTINE CALL
C
  115 GO TO (125, 135, 145), KSBTN
C
C UNITS PACKET TO BE PROCESSED
C
  125 CALL UNITRD(INCARD, IPRINT, NAMLEN, NUNITS, LINPTP, LUNITP,
     $    RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MUNITS, JFLAG)
      IF (JFLAG .LT. 0) GO TO 914
C
C GO BACK FOR ANOTHER TIME-INVARIANT HEADER CARD
C
      GO TO 105
C
C BOUNDARY LINE IDENTIFICATION PACKET TO BE PROCESSED
C
  135 CALL BLINRD(INCARD, IPRINT, NAMLEN, NIDLEN, NUNITS, NBLINE,
     $    NXCELL, NYCELL, LINPTP, LBTABP, LBMAPP, JBEGDT, JENDDT,
     $    XREGOR, YREGOR, XCELLD, YCELLD, BEGTIM, ENDTIM, RMISSV,
     $    MFILNM, MFILID, FACMLT, FACADD, SMOLWT, MVARBL,
     $    JBDVEC(KBLRW), JBDVEC(KBLRE), JBDVEC(KBLRS), JBDVEC(KBLRN),
     $    JBDVEC(KBINW), JBDVEC(KBINE), JBDVEC(KBINS), JBDVEC(KBINN),
     $    JBDVEC(KBASW), JBDVEC(KBASE), JBDVEC(KBASS), JBDVEC(KBASN),
     $    JBDVEC(KBAXW), JBDVEC(KBAXE), JBDVEC(KBAXS), JBDVEC(KBAXN),
     $    JBDVEC(KBAYW), JBDVEC(KBAYE), JBDVEC(KBAYS), JBDVEC(KBAYN),
     $    XBLBEG, YBLBEG, XBLEND, YBLEND, MBLINE, JBGRID, JFLAG)
      IF (JFLAG .LT. 0) GO TO 915
C
C IF OUTPUT FILE WANTED, WRITE TIME-INVARIANT FILE RECORD FOR WEST EDGE
C
      IF (IOUTFL .LE. 0) GO TO 105
      KEDGE = 1
      CALL FLBIWR (IPRINT, IOUTFL, NYCELL, NSGMNT, KEDGE, JBDVEC(KBINW),
     $    JBDVEC(KBASW), JBDVEC(KBAXW), JBDVEC(KBAYW), JFLAG)
      IF (JFLAG .LT. 0) GO TO 916
C
C WRITE TIME INVARIANT FILE RECORD FOR EAST EDGE
C
      KEDGE = 2
      CALL FLBIWR (IPRINT, IOUTFL, NYCELL, NSGMNT, KEDGE, JBDVEC(KBINE),
     $    JBDVEC(KBASE), JBDVEC(KBAXE), JBDVEC(KBAYE), JFLAG)
      IF (JFLAG .LT. 0) GO TO 916
C
C WRITE TIME INVARIANT FILE RECORD FOR SOUTH EDGE
C
      KEDGE = 3
      CALL FLBIWR (IPRINT, IOUTFL, NXCELL, NSGMNT, KEDGE, JBDVEC(KBINS),
     $    JBDVEC(KBASS), JBDVEC(KBAXS), JBDVEC(KBAYS), JFLAG)
      IF (JFLAG .LT. 0) GO TO 916
C
C WRITE TIME INVARIANT FILE RECORD FOR NORTH EDGE
C
      KEDGE = 4
      CALL FLBIWR (IPRINT, IOUTFL, NXCELL, NSGMNT, KEDGE, JBDVEC(KBINN),
     $    JBDVEC(KBASN), JBDVEC(KBAXN), JBDVEC(KBAYN), JFLAG)
      IF (JFLAG .LT. 0) GO TO 916
C
C GO BACK FOR ANOTHER TIME-INVARIANT HEADER CARD
C
      GO TO 105
C
C TIME INTERVAL PACKET HEADER -- READ AND CHECK DATES AND TIMES
C
  145 CALL TIMERD(INCARD, IPRINT, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 917
      IF (JSTRDT .EQ. JCURDT .AND. STRTIM .EQ. CURTIM) GO TO 155
C
C IF INTERVAL START IS AFTER CURRENT TIME, NOTE ERROR
C
      IF (JSTRDT .GT. JCURDT) GO TO 918
      IF (JSTRDT .EQ. JCURDT .AND. STRTIM .GT. CURTIM) GO TO 918
C
C RESET STARTING DATE AND TIME WITH MESSAGE
C
      WRITE (IPRINT, 2145) JSTRDT, STRTIM, JCURDT, CURTIM
      JSTRDT = JCURDT
      STRTIM = CURTIM
C
C VERIFY THAT ENDING DATE AND TIME ARE WITHIN FILE VALUES
C
  155 IF (JENDDT .GT. JSTPDT) GO TO 165
      IF (JENDDT .EQ. JSTPDT .AND. ENDTIM .GE. STPTIM) GO TO 165
C
C THIS TIME INTERVAL TOO LONG -- RESET TO FILE VALUE WITH MESSAGE
C
      WRITE (IPRINT, 2155) JSTPDT, STPTIM,JENDDT, ENDTIM
      JSTPDT = JENDDT
      STPTIM = ENDTIM
C
C SET CURRENT DATE AND TIME TO THE END OF THIS PACKET INTERVAL
C
  165 JCURDT = JSTPDT
      CURTIM = STPTIM
C
C GET  DIFFUSION BREAK VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IDFBRK .GT. 0) THEN
        IF (LUAMV) THEN
          CALL HTPRRD(IPRINT, IDFBRK, NXCELL, NYCELL, NZCELL,
     $        JSTRDT, STRTIM, DIFBRK, JFLAG)
          IF (JFLAG .LT. 0) GO TO 925
        ELSE
          CALL DFBKRD(IPRINT, IDFBRK, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $        JSTRDT, STRTIM, MDFBRK, JSCRTC, DIFBRK, JFLAG)
          IF (JFLAG .LT. 0) GO TO 921
        ENDIF
      ENDIF
C
C GET REGION TOP VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IRGTOP .GT. 0)
     $     CALL RGTPRD(IPRINT, IRGTOP, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $         JSTRDT, STRTIM, MRGTOP, JSCRTC, REGTOP, JFLAG)
      IF (JFLAG .LT. 0) GO TO 922
C
C GET TOP CONCENTRATION VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (ITPCON .GT. 0) THEN
        IF (LUAMV) THEN
          CALL TPUVRD(IPRINT, ITPCON, ITCFIL, NAMLEN, NSPECS,
     $        NXCELL, NYCELL, JSTRDT, STRTIM, MVARBL, JSCRTC,
     $        TOPCON, TOPMAT, JFLAG)
          IF (JFLAG .LT. 0) GO TO 924
        ELSE
          CALL TPCNRD(IPRINT, ITPCON, ITCFIL, NAMLEN, NSPECS,
     $        NXCELL, NYCELL, JSTRDT, STRTIM, MVARBL, JSCRTC,
     $        TOPCON, TOPMAT, JFLAG)
          IF (JFLAG .LT. 0) GO TO 923
        ENDIF
      ENDIF
C
C READ AND PRINT A TIME-VARIANT HEADER CARD
C
  205 READ (INCARD,1205) MHEADR, MCRDID
      WRITE(IPRINT,2205) MHEADR, MCRDID
C
C PACK HEADER AND SET COMPARISON LOOP
C
      CALL TXTPAK(IPRINT, NIDLEN, MHEADR, NPACKD, JFLAG)
      IF (JFLAG .LT. 0) GO TO 931
      DO 210 J = 1, NTVHDR
C
C COMPARE THIS HEADER VALUE WITH THE ACCEPTABLE ONES
C
         CALL COMPAR(IPRINT, NAMLEN, MHEADR, MTVHDR(1,J), JFLAG)
         IF (JFLAG .LT. 0) GO TO 932
         IF (JFLAG .EQ. 0) GO TO 210
C
C SET MODULE NUMBER AND SKIP TO TRANSFER
C
         KSBTN = J
         GO TO 215
C
C END LOOP -- IF NO MATCH, TERMINATE
C
  210 CONTINUE
      GO TO 933
C
C TRANSFER TO THE APPROPRIATE SUBROUTINE CALL
C
  215 GO TO (235, 245, 255, 275, 285, 295), KSBTN
C
C METHOD PACKET TO BE PROCESSED
C
  235 CALL MTHDRD(INCARD, IPRINT, NAMLEN, NVARBL, NBLINE, NMETHD,
     $    NPARAM,  KPRML, LINPTP, LMTHDP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MBLINE, MMETHD, PARAMS, MPARAM, JMTHDN,
     $    JPARMP, JPARMC, SMTHMN, SMTHMX, JFLAG)
      IF (JFLAG .LT. 0) GO TO 942
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C VERTICAL METHOD PACKET TO BE PROCESSED
C
  245 CALL MTHDRD(INCARD, IPRINT, NAMLEN, NVARBL, NBLINE, NVMTHD,
     $    NVPARM,  KVPRL, LINPTP, LVMTHP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MBLINE, MVMTHD, VPARAM, MVPARM, JVMTHN,
     $    JVPRMP, JVPRMC, VMTHMN, VMTHMX, JFLAG)
      IF (JFLAG .LT. 0) GO TO 943
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C CONSTANTS PACKET TO BE PROCESSED
C
  255 CALL BLVLRD(INCARD, IPRINT, NAMLEN, NVARBL, NBLINE,
     $    LINPTP, LBLRDP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MBLINE,
     $    BLNVAL, JFLAG)
      IF (JFLAG .LT. 0) GO TO 944
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C BOUNDARY LINE READINGS PACKET TO BE PROCESSED
C
  275 CALL BLVLRD(INCARD, IPRINT, NAMLEN, NVARBL, NBLINE, LINPTP,
     $    LBLRDP, RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MBLINE,
     $    BLNVAL, JFLAG)
      IF (JFLAG .LT. 0) GO TO 946
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C VERTICAL PROFILES PACKET TO BE PROCESSED
C
  285 CALL VPRFRD(INCARD, IPRINT, NAMLEN, NVARBL, NUNITS, NBLINE,
     $    NPRFHT, NXCELL, NYCELL,
     $    LINPTP, LVPRFP, XREGOR, YREGOR, XCELLD, YCELLD, RMISSV,
     $    FACMLT, FACADD, SMOLWT, MVARBL, MBLINE, XPROFL,
     $    YPROFL, PRFHGT, PRFVAL, JFLAG)
      IF (JFLAG .LT. 0) GO TO 947
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C END TIME PACKET TERMINATOR -- SET Z-LEVEL AND REVERSE LOOP FOR VARIABLES
C
  295 DO 700 N = 1, NVARBL
         KVRBL = NVARBL - N + 1
         KZCLL = 1
C
C IF WANTED, LOAD TOP CONCENTRATION FOR THIS VARIABLE
C
         IF (ITPCON .LE. 0) GO TO 297
         IF (KVRBL .GT. NSPECS) GO TO 297
         CALL MATGET(IPRINT, ITCFIL, NXCELL, NYCELL, NFLZCL, NVARBL,
     $       KZCLL, KVRBL, TOPCON, TOPMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 949
C
C DO TWO PASSES AT SURFACE LEVEL-SET Y LOOP FOR WEST AND EAST BOUNDARIES
C
  297    DO 395 IPASS=1,2
         DO 390 J = 1, NYCELL
            KYCLL = J
            KXCLL = 0
C
C GET INDEX FOR WEST BOUNDARY AND CHECK FOR Y-CELL OUTSIDE BOUNDARY
C
            KBLRF = KBLRW + KYCLL - 1
            KBLIN = JBDVEC(KBLRF)
            IF (KBLIN .LE. 0) GO TO 350
C
C ISOLATE AND CHECK THE METHOD NUMBER
C
            KMTHD = JMTHDN(KBLIN, KVRBL)
            IF (KMTHD .EQ. 0) GO TO 952
            IF (KMTHD .GT. NMETHD) GO TO 952
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
              GO TO (315, 315, 335, 345, 3474, 3474), KMTHD
            ELSE IF (IPASS .EQ. 2) THEN
              GO TO (350, 350, 350, 350, 3475, 3475), KMTHD
            ENDIF
C
C LINE VALUE -- CHECK AND PLACE INTO OUTPUT MATRIX
C
  315       VALBND = BLNVAL(KBLIN, KVRBL)
            IF (VALBND .GE. SMTHMN(KBLIN, KVRBL)) GO TO 317
            WRITE (IPRINT, 2315) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMN(KBLIN, KVRBL)
            VALBND = SMTHMN(KBLIN, KVRBL)
            GO TO 319
  317       IF (VALBND .LE. SMTHMX(KBLIN, KVRBL)) GO TO 319
            WRITE (IPRINT, 2317) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMX(KBLIN, KVRBL)
            VALBND = SMTHMX(KBLIN, KVRBL)
  319       BCONCW(J, KZCLL, KVRBL) = VALBND
C
C SKIP TO PROCESS OF EAST BOUNDARY
C
               GO TO 350
C
C SPLIT/COMBINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  335          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 953
               IF (NPARMC .GT. NPARAM) GO TO 953
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 954
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 954
C
C CALL THE SPLIT/COMBINE PROCESSING ROUTINE
C
               CALL SPLTBC(IPRINT, NAMLEN, NVARBL, NYCELL, NZCELL,
     $             NPARMC, KVRBL, KYCLL, KZCLL, RMISSV,
     $             SMTHMN(KBLIN, KVRBL), SMTHMX(KBLIN, KVRBL),
     $             PARAMS(KPRMP), MVARBL, MPARAM(1, KPRMP),
     $               BCONCW, JFLAG)
               IF (JFLAG .LT. 0) GO TO 955
C
C SKIP TO PROCESS OF EAST BOUNDARY
C
               GO TO 350
C
C USER SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  345          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 347
               IF (NPARMC .GT. NPARAM) GO TO 956
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 957
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 957
C
C CALL THE USER SUBROUTINE PROCESSING ROUTINE
C
  347          CALL BNDUSR(INCARD, IPRINT, NAMLEN, NIDLEN,
     $             NBLINE, NPARMC, NBDTIV, NXCELL, NYCELL, NZCELL,
     $             NSCRTC, KBLIN, KXCLL, KYCLL, KZCLL,
     $             JMISSV, JSTRDT, JSTPDT, JUTMZN, STRTIM, STPTIM,
     $             XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD, YCELLD,
     $             RMISSV, SMTHMN(KBLIN, KVRBL),
     $             SMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $             MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $             XBLBEG, YBLBEG, XBLEND, YBLEND, PARAMS(KPRMP),
     $             JBRGID, BLNVAL, BCONCW(1, KZCLL, KVRBL), JFLAG)
               IF (JFLAG .LT. 0) GO TO 958
C
C SKIP TO PROCESS OF EAST BOUNDARY
C
               GO TO 350
C
C  SET ARRAY VALUE TO MISSING
C
 3474          BCONCW(J,KZCLL,KVRBL) = -9.
C
C SKIP TO PROCESS OF EAST BOUNDARY
C
               GO TO 350
C
C  E-W OR N-S INTERP
C
 3475          CALL BINTRP(IPRINT, KYCLL, NYCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCW(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C GET INDEX FOR EAST BOUNDARY AND CHECK FOR Y-CELL OUTSIDE BOUNDARY
C
  350       KBLRF = KBLRE + KYCLL - 1
            KBLIN = JBDVEC(KBLRF)
            IF (KBLIN .LE. 0) GO TO 390
C
C ISOLATE AND CHECK THE METHOD NUMBER
C
            KMTHD = JMTHDN(KBLIN, KVRBL)
            IF (KMTHD .EQ. 0) GO TO 952
            IF (KMTHD .GT. NMETHD) GO TO 952
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
              GO TO (365, 365, 375, 385, 3874, 3874), KMTHD
            ELSE IF (IPASS .EQ. 2) THEN
              GO TO (390, 390, 390, 390, 3875, 3875), KMTHD
            ENDIF
C
C LINE VALUE -- CHECK AND PLACE INTO OUTPUT MATRIX
C
  365        VALBND = BLNVAL(KBLIN, KVRBL)
             IF (VALBND .GE. SMTHMN(KBLIN, KVRBL)) GO TO 367
             WRITE (IPRINT, 2365) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMN(KBLIN, KVRBL)
            VALBND = SMTHMN(KBLIN, KVRBL)
            GO TO 369
  367       IF (VALBND .LE. SMTHMX(KBLIN, KVRBL) ) GO TO 369
            WRITE (IPRINT, 2367) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMX(KBLIN, KVRBL)
            VALBND = SMTHMX(KBLIN, KVRBL)
  369       BCONCE(J, KZCLL, KVRBL) = VALBND
C
C SKIP TO END OF LOOP
C
               GO TO 390
C
C SPLIT/COMBINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  375          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 963
               IF (NPARMC .GT. NPARAM) GO TO 963
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 964
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 964
C
C CALL THE SPLIT/COMBINE PROCESSING ROUTINE
C
               CALL SPLTBC(IPRINT, NAMLEN, NVARBL, NYCELL, NZCELL,
     $             NPARMC, KVRBL, KYCLL, KZCLL, RMISSV,
     $             SMTHMN(KBLIN, KVRBL), SMTHMX(KBLIN, KVRBL),
     $             PARAMS(KPRMP), MVARBL, MPARAM(1, KPRMP),
     $                BCONCE, JFLAG)
               IF (JFLAG .LT. 0) GO TO 965
C
C SKIP TO END OF LOOP
C
               GO TO 390
C
C USER SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  385          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 387
               IF (NPARMC .GT. NPARAM) GO TO 966
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 967
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 967
C
C CALL THE USER SUBROUTINE PROCESSING ROUTINE
C
  387          CALL BNDUSR(INCARD, IPRINT, NAMLEN, NIDLEN,
     $             NBLINE, NPARMC, NBDTIV, NXCELL, NYCELL, NZCELL,
     $             NSCRTC, KBLIN, KXCLL, KYCLL, KZCLL,
     $             JMISSV, JSTRDT, JSTPDT, JUTMZN, STRTIM, STPTIM,
     $             XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD, YCELLD,
     $             RMISSV, SMTHMN(KBLIN, KVRBL),
     $             SMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $             MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $             XBLBEG, YBLBEG, XBLEND, YBLEND, PARAMS(KPRMP),
     $             JBRGID, BLNVAL, BCONCE(1, KZCLL, KVRBL), JFLAG)
               IF (JFLAG .LT. 0) GO TO 968
C
C SKIP TO END OF LOOP
C
               GO TO 390
C
C  SET ARRAY VALUE TO MISSING
C
 3874          BCONCE(J,KZCLL,KVRBL) = -9.
C
C SKIP TO PROCESS OF EAST BOUNDARY
C
               GO TO 390
C
C  E-W OR N-S INTERP
C
 3875          CALL BINTRP(IPRINT, KYCLL, NYCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCE(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C END INNER LOOP ON Y
C
  390    CONTINUE
  395    CONTINUE
C
C SET X LOOP FOR SOUTH AND NORTH BOUNDARIES
C
         DO 495 IPASS=1,2
         DO 490 J = 1, NXCELL
            KXCLL = J
            KYCLL = 0
C
C GET INDEX FOR SOUTH BOUNDARY AND CHECK FOR X-CELL OUTSIDE BOUNDARY
C
            KBLRF = KBLRS + KXCLL - 1
            KBLIN = JBDVEC(KBLRF)
            IF (KBLIN .LE. 0) GO TO 450
C
C ISOLATE AND CHECK THE METHOD NUMBER
C
            KMTHD = JMTHDN(KBLIN, KVRBL)
            IF (KMTHD .EQ. 0) GO TO 952
            IF (KMTHD .GT. NMETHD) GO TO 952
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
              GO TO (415, 415, 435, 445, 4474, 4474), KMTHD
            ELSE IF (IPASS .EQ. 2) THEN
              GO TO (450, 450, 450, 450, 4475, 4475), KMTHD
            ENDIF
C
C LINE VALUE -- CHECK AND PLACE INTO OUTPUT MATRIX
C
  415       VALBND = BLNVAL(KBLIN, KVRBL)
            IF (VALBND .GE. SMTHMN(KBLIN, KVRBL)) GO TO 417
            WRITE (IPRINT, 2415) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMN(KBLIN, KVRBL)
            VALBND = SMTHMN(KBLIN, KVRBL)
            GO TO 419
  417       IF (VALBND .LE. SMTHMX(KBLIN, KVRBL)) GO TO 419
            WRITE (IPRINT, 2417) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMX(KBLIN, KVRBL)
            VALBND = SMTHMX(KBLIN, KVRBL)
  419       BCONCS(J, KZCLL, KVRBL) = VALBND
C
C SKIP TO PROCESS OF NORTH BOUNDARY
C
               GO TO 450
C
C SPLIT/COMBINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  435          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 963
               IF (NPARMC .GT. NPARAM) GO TO 963
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 964
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 964
C
C CALL THE SPLIT/COMBINE PROCESSING ROUTINE
C
               CALL SPLTBC(IPRINT, NAMLEN, NVARBL, NXCELL, NZCELL,
     $             NPARMC, KVRBL, KXCLL, KZCLL, RMISSV,
     $             SMTHMN(KBLIN, KVRBL), SMTHMX(KBLIN, KVRBL),
     $             PARAMS(KPRMP), MVARBL, MPARAM(1, KPRMP),
     $                BCONCS, JFLAG)
               IF (JFLAG .LT. 0) GO TO 965
C
C SKIP TO PROCESS OF NORTH BOUNDARY
C
               GO TO 450
C
C USER SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  445          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 447
               IF (NPARMC .GT. NPARAM) GO TO 966
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 967
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 967
C
C CALL THE USER SUBROUTINE PROCESSING ROUTINE
C
  447          CALL BNDUSR(INCARD, IPRINT, NAMLEN, NIDLEN,
     $             NBLINE, NPARMC, NBDTIV, NXCELL, NYCELL, NZCELL,
     $             NSCRTC, KBLIN, KXCLL, KYCLL, KZCLL,
     $             JMISSV, JSTRDT, JSTPDT, JUTMZN, STRTIM, STPTIM,
     $             XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD, YCELLD,
     $             RMISSV, SMTHMN(KBLIN, KVRBL),
     $             SMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $             MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $             XBLBEG, YBLBEG, XBLEND, YBLEND, PARAMS(KPRMP),
     $             JBRGID, BLNVAL, BCONCS(1, KZCLL, KVRBL), JFLAG)
               IF (JFLAG .LT. 0) GO TO 968
C
C SKIP TO PROCESS OF NORTH BOUNDARY
C
               GO TO 450
C
C  SET ARRAY VALUE TO MISSING
C
 4474          BCONCS(J,KZCLL,KVRBL) = -9.
C
C SKIP TO PROCESS OF NORTH BOUNDARY
C
               GO TO 450
C
C  E-W OR N-S INTERP
C
 4475          CALL BINTRP(IPRINT, KXCLL, NXCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCS(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C GET INDEX FOR NORTH BOUNDARY AND CHECK FOR X-CELL OUTSIDE BOUNDARY
C
  450       KBLRF = KBLRN + KXCLL - 1
            KBLIN = JBDVEC(KBLRF)
            IF (KBLIN .LE. 0) GO TO 490
C
C ISOLATE AND CHECK THE METHOD NUMBER
C
            KMTHD = JMTHDN(KBLIN, KVRBL)
            IF (KMTHD .EQ. 0) GO TO 962
            IF (KMTHD .GT. NMETHD) GO TO 962
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
              GO TO (465, 465, 475, 485, 4874, 4874), KMTHD
            ELSE IF (IPASS .EQ. 2) THEN
              GO TO (490, 490, 490, 490, 4875, 4875), KMTHD
            ENDIF
C
C LINE VALUE -- CHECK AND PLACE INTO OUTPUT MATRIX
C
  465       VALBND = BLNVAL(KBLIN, KVRBL)
            IF (VALBND .GE. SMTHMN(KBLIN, KVRBL)) GO TO 467
            WRITE (IPRINT, 2465) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMN(KBLIN, KVRBL)
            VALBND = SMTHMN(KBLIN, KVRBL)
            GO TO 469
  467       IF (VALBND .LE. SMTHMX(KBLIN, KVRBL)) GO TO 469
            WRITE (IPRINT, 2467) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $          VALBND, SMTHMX(KBLIN, KVRBL)
            VALBND = SMTHMX(KBLIN, KVRBL)
  469       BCONCN(J, KZCLL, KVRBL) = VALBND
C
C SKIP TO END OF X LOOP
C
               GO TO 490
C
C SPLIT/COMBINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  475          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 963
               IF (NPARMC .GT. NPARAM) GO TO 963
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 964
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 964
C
C CALL THE SPLIT/COMBINE PROCESSING ROUTINE
C
               CALL SPLTBC(IPRINT, NAMLEN, NVARBL, NXCELL, NZCELL,
     $             NPARMC, KVRBL, KXCLL, KZCLL, RMISSV,
     $             SMTHMN(KBLIN, KVRBL), SMTHMX(KBLIN, KVRBL),
     $             PARAMS(KPRMP), MVARBL, MPARAM(1, KPRMP),
     $                BCONCN, JFLAG)
               IF (JFLAG .LT. 0) GO TO 965
C
C SKIP TO END OF X LOOP
C
               GO TO 490
C
C USER SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  485          NPARMC = JPARMC(KBLIN, KVRBL)
               IF (NPARMC .LT. 1) GO TO 487
               IF (NPARMC .GT. NPARAM) GO TO 966
               KPRMP = JPARMP(KBLIN, KVRBL)
               IF (KPRMP .LT. 1) GO TO 967
               IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 967
C
C CALL THE USER SUBROUTINE PROCESSING ROUTINE
C
  487          CALL BNDUSR(INCARD, IPRINT, NAMLEN, NIDLEN,
     $             NBLINE, NPARMC, NBDTIV, NXCELL, NYCELL, NZCELL,
     $             NSCRTC, KBLIN, KXCLL, KYCLL, KZCLL,
     $             JMISSV, JSTRDT, JSTPDT, JUTMZN, STRTIM, STPTIM,
     $             XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD, YCELLD,
     $             RMISSV, SMTHMN(KBLIN, KVRBL),
     $             SMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $             MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $             XBLBEG, YBLBEG, XBLEND, YBLEND, PARAMS(KPRMP),
     $             JBRGID, BLNVAL, BCONCN(1, KZCLL, KVRBL), JFLAG)
               IF (JFLAG .LT. 0) GO TO 968
C
C SKIP TO END OF LOOP
C
               GO TO 490
C
C  SET ARRAY VALUE TO MISSING
C
 4874          BCONCN(J,KZCLL,KVRBL) = -9.
C
C SKIP TO END
C
               GO TO 490
C
C  E-W OR N-S INTERP
C
 4875          CALL BINTRP(IPRINT, KXCLL, NXCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCN(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C END X LOOP
C
  490    CONTINUE
  495    CONTINUE
C
C SET UP A LOOP TO RUN OVER ALL Z-CELLS ABOVE THE SURFACE
C
         DO 695 K = 2, NZCELL
            KZCLL = K
C
C SET X AND Y LOOPS FOR FIRST PASS AT THIS LEVEL
C
            DO 595 IPASS=1,2
            DO 590 J = 1,NYCELL
               KYCLL = J
C
C GET INDEX FOR WEST BOUNDARY AND CHECK FOR Y-CELL OUT OF BOUNDARY
C
               KBLRF = KBLRW + KYCLL - 1
               KBLIN = JBDVEC(KBLRF)
               IF (KBLIN .LE. 0) GO TO 550
C
C ISOLATE AND CHECK THE X-CELL LOCATION AND METHOD NUMBERS
C
               KBINF = KBINW + KYCLL - 1
               KXCLL = JBDVEC(KBINF)
               IF (KXCLL .LE. 0) GO TO 971
                  KVMTH = JVMTHN(KBLIN, KVRBL)
                  IF (KVMTH .EQ. 0) GO TO 972
                  IF (KVMTH .GT. NVMTHD) GO TO 972
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
                  GO TO (505, 510, 515, 520, 525, 530,
     $                   5354, 5354, 540), KVMTH
            ELSE IF (IPASS .EQ. 2) THEN
                  GO TO (550, 550, 550, 550, 550, 550,
     $                   5355, 5355, 550), KVMTH
            ENDIF
C
C CONSTANT PROJECTION -- MOVE SURFACE VALUE TO THIS LEVEL
C
  505             BCONCW(KYCLL, KZCLL, KVRBL) = BCONCW(KYCLL, 1, KVRBL)
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 550
C
C CALL THE ABSOLUTE PROFILE ROUTINE
C
  510             IF (LUAMV) THEN
                    CALL ABSPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ELSE
                    CALL ABSPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ENDIF
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 550
C
C CALL THE RELATIVE PROFILE ROUTINE
C
  515             CALL RELPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 974
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 550
C
C CALL THE ABSOLUTE PROFILE RATIO ROUTINE
C
  520             IF (LUAMV) THEN
                    CALL ABPRVR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, TOPCON,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 975
                  ELSE
                    CALL ABPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 975
                  ENDIF
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 550
C
C CALL THE RELATIVE PROFILE RATIO ROUTINE
C
  525             CALL RLPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 976
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 550
C
C USER VERT. SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  530             NVPRMC = JVPRMC(KBLIN, KVRBL)
                  IF (NVPRMC .LT. 1) GO TO 535
                  IF (NVPRMC .GT. NPARAM) GO TO 977
                  KVPRP = JVPRMP(KBLIN, KVRBL)
                  IF (KVPRP .LT. 1) GO TO 978
                  IF (KVPRP .GT. NVPARM - NVPRMC + 1) GO TO 978
C
C CALL THE USER VERT. SUBROUTINE PROCESSING ROUTINE
C
  535             CALL BNDVUS(INCARD, IPRINT, NAMLEN, NIDLEN,
     $                NBLINE, NVPRMC, NPRFHT, NBDTIV, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, NSCRTC, KBLIN, KXCLL,
     $                KYCLL, KZCLL, JSTRDT, JSTPDT, JUTMZN, JMISSV,
     $                STRTIM, STPTIM, XUTMOR, YUTMOR, XREGOR,
     $                YREGOR, XCELLD, YCELLD, ZHTSUR,
     $                ZMINLW, ZMINUP, RMISSV, VMTHMN(KBLIN, KVRBL),
     $                VMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $                MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $                VPARAM(KVPRP), XPROFL(1, KVRBL), YPROFL(1, KVRBL),
     $                JBGRID, DIFBRK, REGTOP, TOPCON, OUTGRD,
     $                PRFHGT(1, 1, KVRBL), PRFVAL(1, 1, KVRBL),
     $                BCONCW(1, 1, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 979
C
C SKIP TO EAST BOUNDARY
C
               GO TO 550
C
C CALL THE FIXED PROFILE ROUTINE
C
  540             IF (LUAMV) THEN
                    CALL FIXPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ELSE
                    CALL FIXPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCW(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCW(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ENDIF
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 550
C
C  SET ARRAY VALUE TO MISSING
C
 5354          BCONCW(J,KZCLL,KVRBL) = -9.
C
C SKIP TO PROCESS OF EAST BOUNDARY
C
               GO TO 550
C
C  E-W OR N-S INTERP
C
 5355          CALL BINTRP(IPRINT, KYCLL, NYCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCW(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C GET INDEX FOR EAST BOUNDARY AND CHECK FOR Y-CELL OUT OF BOUNDARY
C
  550          KBLRF = KBLRE + KYCLL - 1
               KBLIN = JBDVEC(KBLRF)
               IF (KBLIN .LE. 0) GO TO 590
C
C ISOLATE AND CHECK THE X-CELL LOCATION AND METHOD NUMBERS
C
               KBINF = KBINE + KYCLL - 1
               KXCLL = JBDVEC(KBINF)
               IF (KXCLL .LE. 0) GO TO 971
                  KVMTH = JVMTHN(KBLIN, KVRBL)
                  IF (KVMTH .EQ. 0) GO TO 972
                  IF (KVMTH .GT. NVMTHD) GO TO 972
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
                  GO TO (555, 560, 565, 570, 575, 580,
     $                   5854, 5854, 587), KVMTH
            ELSE IF (IPASS .EQ. 2) THEN
                  GO TO (590, 590, 590, 590, 590, 590,
     $                   5855, 5855, 590), KVMTH
            ENDIF
C
C CONSTANT PROJECTION -- MOVE SURFACE VALUE TO THIS LEVEL
C
  555             BCONCE(KYCLL, KZCLL, KVRBL) = BCONCE(KYCLL, 1, KVRBL)
C
C SKIP TO END OF Y LOOP
C
                  GO TO 590
C
C CALL THE ABSOLUTE PROFILE ROUTINE
C
  560             IF (LUAMV) THEN
                    CALL ABSPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ELSE
                    CALL ABSPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ENDIF
C
C SKIP TO END OF Y LOOP
C
                  GO TO 590
C
C CALL THE RELATIVE PROFILE ROUTINE
C
  565             CALL RELPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 974
C
C SKIP TO END OF Y LOOP
C
                  GO TO 590
C
C CALL THE ABSOLUTE PROFILE RATIO ROUTINE
C
  570             IF (LUAMV) THEN
                    CALL ABPRVR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, TOPCON,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 975
                  ELSE
                    CALL ABPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 975
                  ENDIF
C
C SKIP TO END OF Y LOOP
C
                  GO TO 590
C
C CALL THE RELATIVE PROFILE RATIO ROUTINE
C
  575             CALL RLPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 976
C
C SKIP TO END OF Y LOOP
C
                  GO TO 590
C
C USER VERT. SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  580             NVPRMC = JVPRMC(KBLIN, KVRBL)
                  IF (NVPRMC .LT. 1) GO TO 585
                  IF (NVPRMC .GT. NPARAM) GO TO 977
                  KVPRP = JVPRMP(KBLIN, KVRBL)
                  IF (KVPRP .LT. 1) GO TO 978
                  IF (KVPRP .GT. NVPARM - NVPRMC + 1) GO TO 978
C
C CALL THE USER VERT. SUBROUTINE PROCESSING ROUTINE
C
  585             CALL BNDVUS(INCARD, IPRINT, NAMLEN, NIDLEN,
     $                NBLINE, NVPRMC, NPRFHT, NBDTIV, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, NSCRTC, KBLIN, KXCLL,
     $                KYCLL, KZCLL, JSTRDT, JSTPDT, JUTMZN, JMISSV,
     $                STRTIM, STPTIM, XUTMOR, YUTMOR, XREGOR,
     $                YREGOR, XCELLD, YCELLD, ZHTSUR,
     $                ZMINLW, ZMINUP, RMISSV, VMTHMN(KBLIN, KVRBL),
     $                VMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $                MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $                VPARAM(KVPRP), XPROFL(1, KVRBL), YPROFL(1, KVRBL),
     $                JBGRID, DIFBRK, REGTOP, TOPCON, OUTGRD,
     $                PRFHGT(1, 1, KVRBL), PRFVAL(1, 1, KVRBL),
     $                BCONCE(1, 1, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 979
C
C SKIP TO END OF LOOP
C
               GO TO 590
C
C CALL THE FIXED PROFILE ROUTINE
C
  587             IF (LUAMV) THEN
                    CALL FIXPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ELSE
                    CALL FIXPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCE(KYCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCE(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 973
                  ENDIF
C
C SKIP TO END OF Y LOOP
C
                  GO TO 590
C
C  SET ARRAY VALUE TO MISSING
C
 5854          BCONCE(J,KZCLL,KVRBL) = -9.
C
C SKIP TO END
C
               GO TO 590
C
C  E-W OR N-S INTERP
C
 5855          CALL BINTRP(IPRINT, KYCLL, NYCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCE(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C END Y LOOP
C
  590       CONTINUE
  595       CONTINUE
C
C SET X LOOP FOR SOUTH AND NORTH BOUNDARIES
C
            DO 693 IPASS=1,2
            DO 690 J = 1, NXCELL
               KXCLL = J
C
C GET INDEX FOR SOUTH BOUNDARY AND CHECK FOR X-CELL OUT OF BOUNDARY
C
               KBLRF = KBLRS + KXCLL - 1
               KBLIN = JBDVEC(KBLRF)
               IF (KBLIN .LE. 0) GO TO 650
C
C ISOLATE AND CHECK THE Y-CELL LOCATION AND METHOD NUMBERS
C
               KBINF = KBINS + KXCLL - 1
               KYCLL = JBDVEC(KBINF)
               IF (KYCLL .LE. 0) GO TO 981
                  KVMTH = JVMTHN(KBLIN, KVRBL)
                  IF (KVMTH .EQ. 0) GO TO 982
                  IF (KVMTH .GT. NVMTHD) GO TO 982
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
                  GO TO (605, 610, 615, 620, 625, 630,
     $                   6354, 6354, 640), KVMTH
            ELSE IF (IPASS .EQ. 2) THEN
                  GO TO (650, 650, 650, 650, 650, 650,
     $                   6355, 6355, 650), KVMTH
            ENDIF
C
C CONSTANT PROJECTION -- MOVE SURFACE VALUE TO THIS LEVEL
C
  605             BCONCS(KXCLL, KZCLL, KVRBL) = BCONCS(KXCLL, 1, KVRBL)
C
C SKIP TO PROCESSING OF NORTH BOUNDARY
C
                  GO TO 650
C
C CALL THE ABSOLUTE PROFILE ROUTINE
C
  610             IF (LUAMV) THEN
                    CALL ABSPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ELSE
                    CALL ABSPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ENDIF
C
C SKIP TO PROCESSING OF NORTH BOUNDARY
C
                  GO TO 650
C
C CALL THE RELATIVE PROFILE ROUTINE
C
  615             CALL RELPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 984
C
C SKIP TO PROCESSING OF NORTH BOUNDARY
C
                  GO TO 650
C
C CALL THE ABSOLUTE PROFILE RATIO ROUTINE
C
  620             IF (LUAMV) THEN
                    CALL ABPRVR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, TOPCON,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 985
                  ELSE
                    CALL ABPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 985
                  ENDIF
C
C SKIP TO PROCESSING OF NORTH BOUNDARY
C
                  GO TO 650
C
C CALL THE RELATIVE PROFILE RATIO ROUTINE
C
  625             CALL RLPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 986
C
C SKIP TO PROCESSING OF NORTH BOUNDARY
C
                  GO TO 650
C
C USER VERT. SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  630             NVPRMC = JVPRMC(KBLIN, KVRBL)
                  IF (NVPRMC .LT. 1) GO TO 635
                  IF (NVPRMC .GT. NPARAM) GO TO 987
                  KVPRP = JVPRMP(KBLIN, KVRBL)
                  IF (KVPRP .LT. 1) GO TO 988
                  IF (KVPRP .GT. NVPARM - NVPRMC + 1) GO TO 988
C
C CALL THE USER VERT. SUBROUTINE PROCESSING ROUTINE
C
  635             CALL BNDVUS(INCARD, IPRINT, NAMLEN, NIDLEN,
     $                NBLINE, NVPRMC, NPRFHT, NBDTIV, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, NSCRTC, KBLIN, KXCLL,
     $                KYCLL, KZCLL, JSTRDT, JSTPDT, JUTMZN, JMISSV,
     $                STRTIM, STPTIM, XUTMOR, YUTMOR, XREGOR,
     $                YREGOR, XCELLD, YCELLD, ZHTSUR,
     $                ZMINLW, ZMINUP, RMISSV, VMTHMN(KBLIN, KVRBL),
     $                VMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $                MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $                VPARAM(KVPRP), XPROFL(1, KVRBL), YPROFL(1, KVRBL),
     $                JBGRID, DIFBRK, REGTOP, TOPCON, OUTGRD,
     $                PRFHGT(1, 1, KVRBL), PRFVAL(1, 1, KVRBL),
     $                BCONCS(1, 1, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 989
C
C SKIP TO NORTH BOUNDARY
C
               GO TO 650
C
C CALL THE FIXED PROFILE ROUTINE
C
  640             IF (LUAMV) THEN
                    CALL FIXPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ELSE
                    CALL FIXPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCS(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCS(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ENDIF
C
C SKIP TO PROCESSING OF NORTH BOUNDARY
C
                  GO TO 650
C
C  SET ARRAY VALUE TO MISSING
C
 6354          BCONCS(J,KZCLL,KVRBL) = -9.
C
C SKIP TO PROCESS OF NORTH BOUNDARY
C
               GO TO 650
C
C  E-W OR N-S INTERP
C
 6355          CALL BINTRP(IPRINT, KXCLL, NXCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCS(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C GET INDEX FOR NORTH BOUNDARY AND CHECK FOR X-CELL OUT OF BOUNDARY
C
  650          KBLRF = KBLRN + KXCLL - 1
               KBLIN = JBDVEC(KBLRF)
               IF (KBLIN .LE. 0) GO TO 690
C
C ISOLATE AND CHECK THE Y-CELL LOCATION AND METHOD NUMBERS
C
               KBINF = KBINN + KXCLL - 1
               KYCLL = JBDVEC(KBINF)
               IF (KYCLL .LE. 0) GO TO 981
                  KVMTH = JVMTHN(KBLIN, KVRBL)
                  IF (KVMTH .EQ. 0) GO TO 982
                  IF (KVMTH .GT. NVMTHD) GO TO 982
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
C  SKIP INTERP METHODS FOR 1ST PASS, ALL OTHERS FOR SECOND
C
            IF (IPASS .EQ. 1) THEN
                  GO TO (655, 660, 665, 670, 675, 680,
     $                   6854, 6854, 687), KVMTH
            ELSE IF (IPASS .EQ. 2) THEN
                  GO TO (690, 690, 690, 690, 690, 690,
     $                   6855, 6855, 690), KVMTH
            ENDIF
C
C CONSTANT PROJECTION -- MOVE SURFACE VALUE TO THIS LEVEL
C
  655             BCONCN(KXCLL, KZCLL, KVRBL) = BCONCN(KXCLL, 1, KVRBL)
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 690
C
C CALL THE ABSOLUTE PROFILE ROUTINE
C
  660             IF (LUAMV) THEN
                    CALL ABSPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ELSE
                    CALL ABSPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ENDIF
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 690
C
C CALL THE RELATIVE PROFILE ROUTINE
C
  665             CALL RELPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 984
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 690
C
C CALL THE ABSOLUTE PROFILE RATIO ROUTINE
C
  670             IF (LUAMV) THEN
                    CALL ABPRVR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, TOPCON,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 985
                  ELSE
                    CALL ABPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 985
                  ENDIF
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 690
C
C CALL THE RELATIVE PROFILE RATIO ROUTINE
C
  675             CALL RLPRFR(IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL,
     $                ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                XPROFL(KBLIN, KVRBL), YPROFL(KBLIN, KVRBL),
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1, KVRBL), MBLINE(1, KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP, TOPCON,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 986
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 690
C
C USER VERT. SUBROUTINE -- LOCATE PARAMETERS FOR THIS BOUNDARY LINE AND VARIABLE
C
  680             NVPRMC = JVPRMC(KBLIN, KVRBL)
                  IF (NVPRMC .LT. 1) GO TO 685
                  IF (NVPRMC .GT. NPARAM) GO TO 987
                  KVPRP = JVPRMP(KBLIN, KVRBL)
                  IF (KVPRP .LT. 1) GO TO 988
                  IF (KVPRP .GT. NVPARM - NVPRMC + 1) GO TO 988
C
C CALL THE USER VERT. SUBROUTINE PROCESSING ROUTINE
C
  685             CALL BNDVUS(INCARD, IPRINT, NAMLEN, NIDLEN,
     $                NBLINE, NVPRMC, NPRFHT, NBDTIV, NXCELL, NYCELL,
     $                NZCELL, NZLOWR, NZUPPR, NSCRTC, KBLIN, KXCLL,
     $                KYCLL, KZCLL, JSTRDT, JSTPDT, JUTMZN, JMISSV,
     $                STRTIM, STPTIM, XUTMOR, YUTMOR, XREGOR,
     $                YREGOR, XCELLD, YCELLD, ZHTSUR,
     $                ZMINLW, ZMINUP, RMISSV, VMTHMN(KBLIN, KVRBL),
     $                VMTHMX(KBLIN, KVRBL), MFILNM, MFILID,
     $                MVARBL(1, KVRBL), INFILE, JSCRTC, JBDTIV, JBDVEC,
     $                VPARAM(KVPRP), XPROFL(1, KVRBL), YPROFL(1, KVRBL),
     $                JBGRID, DIFBRK, REGTOP, TOPCON, OUTGRD,
     $                PRFHGT(1, 1, KVRBL), PRFVAL(1, 1, KVRBL),
     $                BCONCN(1, 1, KVRBL), JFLAG)
                  IF (JFLAG .LT. 0) GO TO 989
C
C SKIP TO END OF LOOP
C
               GO TO 690
C
C CALL THE FIXED PROFILE ROUTINE
C
  687             IF (LUAMV) THEN
                    CALL FIXPRV(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, KXCLL, KYCLL, KZCLL,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ELSE
                    CALL FIXPRF(IPRINT, NAMLEN, NPRFHT, NXCELL,
     $                NYCELL, NZCELL, NZLOWR, NZUPPR, KXCLL, KYCLL,
     $                KZCLL, ZHTSUR, ZMINLW, ZMINUP,
     $                BCONCN(KXCLL, 1, KVRBL), RMISSV,
     $                VMTHMN(KBLIN, KVRBL), VMTHMX(KBLIN, KVRBL),
     $                MVARBL(1,KVRBL), MBLINE(1,KBLIN),
     $                PRFHGT(1, KBLIN, KVRBL), PRFVAL(1, KBLIN, KVRBL),
     $                DIFBRK, REGTOP,
     $                BCONCN(J, KZCLL, KVRBL), JFLAG)
                    IF (JFLAG .LT. 0) GO TO 983
                  ENDIF
C
C SKIP TO PROCESSING OF EAST BOUNDARY
C
                  GO TO 690
C
C  SET ARRAY VALUE TO MISSING
C
 6854          BCONCN(J,KZCLL,KVRBL) = -9.
C
C SKIP TO PROCESS OF EAST BOUNDARY
C
               GO TO 690
C
C  E-W OR N-S INTERP
C
 6855          CALL BINTRP(IPRINT, KXCLL, NXCELL, SMTHMN(KBLIN,KVRBL),
     $                     SMTHMX(KBLIN,KVRBL), BCONCN(1,KZCLL,KVRBL),
     $                     JFLAG)
C
C END ALL LOOPS
C
  690       CONTINUE
  693       CONTINUE
  695    CONTINUE
  700 CONTINUE
C
C IF THE OUTPUT FILE IS TO BE WRITTEN, PUT OUT THE TIME RECORD
C
      IF (IOUTFL .LE. 0) GO TO 705
      CALL FLTMWR(IPRINT, IOUTFL, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 991
C
C SET VARIABLE LOOP
C
  705 DO 730 N = 1, NVARBL
         KVRBL = N
C
C LOAD VARIABLE NAME INTO TITLE
C
         DO 710 I = 1, NAMLEN
            MTITLE(I + KTITL) = MVARBL(I,KVRBL)
  710    CONTINUE
C
C IF FILE OUTPUT IS NOT WANTED, SKIP TO PRINT
C
         IF (IOUTFL .LE. 0) GO TO 715
         IF(KVRBL .GT. NSPECS) GO TO 715
C
C WRITE THE WEST BOUNDARY RECORD
C
         KEDGE = 1
         CALL FLBVWR(IPRINT, IOUTFL, NAMLEN, NYCELL, NZCELL,
     $      KEDGE, NSGMNT, MVARBL(1, KVRBL), BCONCW(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 992
C
C WRITE THE EAST BOUNDARY RECORD
C
         KEDGE = 2
         CALL FLBVWR(IPRINT, IOUTFL, NAMLEN, NYCELL, NZCELL,
     $      KEDGE, NSGMNT, MVARBL(1, KVRBL), BCONCE(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 992
C
C WRITE THE SOUTH BOUNDARY RECORD
C
         KEDGE = 3
         CALL FLBVWR(IPRINT, IOUTFL, NAMLEN, NXCELL, NZCELL,
     $      KEDGE, NSGMNT, MVARBL(1, KVRBL), BCONCS(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 992
C
C WRITE THE NORTH BOUNDARY RECORD
C
         KEDGE = 4
         CALL FLBVWR(IPRINT, IOUTFL, NAMLEN, NXCELL, NZCELL,
     $      KEDGE, NSGMNT, MVARBL(1, KVRBL), BCONCN(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 992
C
C IF PRINT NOT WANTED, SKIP TO END OF LOOP
  715    IF (.NOT. LGRIDP) GO TO 730
C
C SET UP FOR PRINTING WITH 10F10.4 FORMAT, 30 LINES PER PAGE
C
         KFRMT = 125
            KZCLL = 0
C
C CALL THE GRID PRINT ROUTINE FOR EACH BOUNDARY
C
          KZCLL = 1
         CALL GRIDPR(IPRINT, NAMLEN, NIDLEN, NTILEN, NYCELL,
     $       NZCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM,
     $       STPTIM, MFILNM, MFILID, MTITLE,
     $       BCONCW(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 993
          KZCLL = 2
         CALL GRIDPR(IPRINT, NAMLEN, NIDLEN, NTILEN, NYCELL,
     $       NZCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM,
     $       STPTIM, MFILNM, MFILID, MTITLE,
     $       BCONCE(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 994
          KZCLL = 3
         CALL GRIDPR(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL,
     $       NZCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM,
     $       STPTIM, MFILNM, MFILID, MTITLE,
     $       BCONCS(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 995
          KZCLL = 4
         CALL GRIDPR(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL,
     $       NZCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM,
     $       STPTIM, MFILNM, MFILID, MTITLE,
     $       BCONCN(1, 1, KVRBL), JFLAG)
         IF (JFLAG .LT. 0) GO TO 996
C
C END LOOPS
C
  730 CONTINUE
C
C SEE WHETHER THIS PACKET ENDS THE FILE -- IF NOT, GET NEXT PACKET
C
      IF (JSTPDT .NE. JENDDT) GO TO 105
      IF (STPTIM .NE. ENDTIM) GO TO 105
C
C REWIND ALL OPEN FILES
C
      IF (IOUTFL .GT. 0) REWIND IOUTFL
      IF (IDFBRK .GT. 0) REWIND IDFBRK
      IF (IRGTOP .GT. 0) REWIND IRGTOP
      IF (ITPCON .GT. 0) REWIND ITPCON
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NAME LENGTH
C
  901 WRITE (IPRINT, 2901) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF VARIABLES
C
  902 WRITE (IPRINT, 2902) NVARBL
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF BOUNDARY LINES
C
  903 WRITE (IPRINT, 2903) NBLINE
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF X-CELLS
C
  904 WRITE (IPRINT, 2904) NXCELL
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF Y-CELLS
C
  905 WRITE (IPRINT, 2905) NYCELL
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF Z-CELLS
C
  906 WRITE (IPRINT, 2906) NZCELL
      JFLAG = -6
      GO TO 1000
C
C ERROR MESSAGE FOR INSUFFICIENT SCRATCH STORAGE FOR FILES
C
  907 WRITE (IPRINT, 2907) NSCRTC
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TXTPAK OF TIME-INVARIANT HEADER
C
  911 WRITE (IPRINT, 2911) JFLAG
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COMPAR OF TIME-INVARIANT HEADER
C
  912 WRITE (IPRINT, 2912) JFLAG
      JFLAG = -12
      GO TO 1000
C
C ERROR MESSAGE FOR NO MATCH OF TIME-INVARIANT HEADER
C
  913 WRITE (IPRINT, 2913) (MHEADR(I), I=1, NAMLEN)
      JFLAG = -13
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN UNITRD
C
  914 WRITE (IPRINT, 2914) JFLAG
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN BLINRD
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -15
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLBIWR
C
  916 WRITE (IPRINT, 2916) JFLAG,KEDGE
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TIMERD
C
  917 WRITE (IPRINT, 2917) JFLAG
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR GAP IN TIMING
C
  918 WRITE (IPRINT, 2918) JCURDT, CURTIM, JSTRDT, STRTIM
      JFLAG = -18
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN DFBKRD
C
  921 WRITE (IPRINT, 2921) JFLAG
      JFLAG = -21
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RGTPRD
C
  922 WRITE (IPRINT, 2922) JFLAG
      JFLAG = -22
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TPCNRD
C
  923 WRITE (IPRINT, 2923) JFLAG
      JFLAG = -23
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TPUVRD
C
  924 WRITE (IPRINT, 2924) JFLAG
      JFLAG = -24
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN HTPRRD
C
  925 WRITE (IPRINT, 2925) JFLAG
      JFLAG = -25
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TXTPAK
C
  931 WRITE (IPRINT, 2931) JFLAG
      JFLAG = -31
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COMPAR OF TIME-VARIANT HEADER
C
  932 WRITE (IPRINT, 2932) JFLAG
      JFLAG = -32
      GO TO 1000
C
C ERROR MESSAGE FOR NO MATCH FOR TIME-VARIANT HEADER
C
  933 WRITE (IPRINT, 2933) (MHEADR(I), I = 1,NAMLEN)
      JFLAG = -33
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MTHDRD
C
  942 WRITE (IPRINT, 2942) JFLAG
      JFLAG = -42
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VERTICAL MTHDRD
C
  943 WRITE (IPRINT, 2943) JFLAG
      JFLAG = -43
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN CNSTRD
C
  944 WRITE (IPRINT, 2944) JFLAG
      JFLAG = -44
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN BLVLRD
C
  946 WRITE (IPRINT, 2946) JFLAG
      JFLAG = -46
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VPRFRD
C
  947 WRITE (IPRINT, 2947) JFLAG
      JFLAG = -47
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATGET FOR TOP CONCENTRATION
C
  949 WRITE (IPRINT, 2949) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -49
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL METHOD -- WEST OR EAST BOUNDARY
C
  952 WRITE (IPRINT, 2952) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -52
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON SPLIT/COMBINATION -- W-E
C
  953 WRITE (IPRINT, 2953) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -53
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON SPLIT/COMBINATION -- W-E
C
  954 WRITE (IPRINT, 2954) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -54
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SPLITC -- WEST OR EAST
C
  955 WRITE (IPRINT, 2955) JFLAG
      JFLAG = -55
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER SUBROUTINE -- W-E
C
  956 WRITE (IPRINT, 2956) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -56
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER SUBROUTINE -- W-E
C
  957 WRITE (IPRINT, 2957) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -57
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN BNDUSR -- WEST OR EAST
C
  958 WRITE (IPRINT, 2958) JFLAG
      JFLAG = -58
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL METHOD -- SOUTH OR NORTH BOUNDARY
C
  962 WRITE (IPRINT, 2962) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -62
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON SPLIT/COMBINATION -- S-N
C
  963 WRITE (IPRINT, 2963) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -63
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON SPLIT/COMBINATION -- S-N
C
  964 WRITE (IPRINT, 2964) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -64
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SPLITC -- SOUTH OR NORTH
C
  965 WRITE (IPRINT, 2965) JFLAG
      JFLAG = -65
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER SUBROUTINE -- S-N
C
  966 WRITE (IPRINT, 2966) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -66
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER SUBROUTINE -- S-N
C
  967 WRITE (IPRINT, 2967) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -67
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN BNDUSR -- SOUTH OR NORTH
C
  968 WRITE (IPRINT, 2968) JFLAG
      JFLAG = -68
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL X-CELL -- WEST OR EAST BOUNDARY
C
  971 WRITE (IPRINT, 2971) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $     (MBLINE(I, KBLIN), I = 1, NAMLEN), KYCLL, KXCLL
      JFLAG = -71
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL VERTICAL METHOD -- WEST OR EAST
C
  972 WRITE (IPRINT, 2972) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -72
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN ABSPRF -- WEST OR EAST
C
  973 WRITE (IPRINT, 2973) JFLAG
      JFLAG = -73
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RELPRF -- WEST OR EAST
C
  974 WRITE (IPRINT, 2974) JFLAG
      JFLAG = -74
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN ABPRFR -- WEST OR EAST
C
  975 WRITE (IPRINT, 2975) JFLAG
      JFLAG = -75
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RLPRFR -- WEST OR EAST
C
  976 WRITE (IPRINT, 2976) JFLAG
      JFLAG = -76
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE -- W-E
C
  977 WRITE (IPRINT, 2977) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -77
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTINE -- W-E
C
  978 WRITE (IPRINT, 2978) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -78
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN BNDVUS -- WEST OR EAST
C
  979 WRITE (IPRINT, 2979) JFLAG
      JFLAG = -79
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL Y-CELL -- SOUTH OR NORTH BOUNDARY
C
  981 WRITE (IPRINT, 2981) (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $     (MBLINE(I, KBLIN), I = 1, NAMLEN), KXCLL, KYCLL
      JFLAG = -81
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL VERTICAL METHOD -- SOUTH OR NORTH
C
  982 WRITE (IPRINT, 2982) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -82
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN ABSPRF -- SOUTH OR NORTH
C
  983 WRITE (IPRINT, 2983) JFLAG
      JFLAG = -83
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RELPRF -- SOUTH OR NORTH
C
  984 WRITE (IPRINT, 2984) JFLAG
      JFLAG = -84
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN ABPRFR -- SOUTH OR NORTH
C
  985 WRITE (IPRINT, 2985) JFLAG
      JFLAG = -85
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RLPRFR -- SOUTH OR NORTH
C
  986 WRITE (IPRINT, 2986) JFLAG
      JFLAG = -86
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE -- S-N
C
  987 WRITE (IPRINT, 2987) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -87
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTINE -- S-N
C
  988 WRITE (IPRINT, 2988) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MBLINE(I,KBLIN), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -88
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN BNDVUS -- SOUTH OR NORTH
C
  989 WRITE (IPRINT, 2989) JFLAG
      JFLAG = -89
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLTMWR
C
  991 WRITE (IPRINT, 2991) JFLAG
      JFLAG = -91
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLBVWR
C
  992 WRITE (IPRINT, 2992) JFLAG , KEDGE
      JFLAG = -92
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GRIDPR -- WEST BOUNDARY
C
  993 WRITE (IPRINT, 2993) JFLAG
      JFLAG = -93
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GRIDPR -- EAST BOUNDARY
C
  994 WRITE (IPRINT, 2994) JFLAG
      JFLAG = -94
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GRIDPR -- SOUTH BOUNDARY
C
  995 WRITE (IPRINT, 2995) JFLAG
      JFLAG = -95
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GRIDPR -- NORTH BOUNDARY
C
  996 WRITE (IPRINT, 2996) JFLAG
      JFLAG = -96
      GO TO 1000
C
C RETURN TO CALLING PROGRAM
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (60A1, 20A1)
 1205 FORMAT (60A1, 20A1)
 2105 FORMAT (1X, 60A1, 20A1)
 2205 FORMAT (1X, 60A1, 20A1)
 2145 FORMAT (38H ****** NOTE ****** THE STARTING DATE , I10,
     $        10H AND TIME , F10.2, 16H FOR THIS PACKET , //,
     $        33H ARE PRIOR TO THE STARTING DATE , I10, 10H AND TIME ,
     $        F10.2, 14H FOR THIS FILE , //, 21H THE PACKET DATE AND ,
     $        46HTIME HAVE BEEN RESET TO THE FILE DATE AND TIME , //)
 2155 FORMAT (38H ****** NOTE ****** THE STOPPING DATE , I10,
     $        10H AND TIME , F10.2, 16H FOR THIS PACKET , //,
     $        29H ARE AFTER THE STOPPING DATE , I10, 10H AND TIME ,
     $        F10.2, 14H FOR THIS FILE , //, 21H THE PACKET DATE AND ,
     $        46HTIME HAVE BEEN RESET TO THE FILE DATE AND TIME , //)
 2315 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON WEST BOUNDARY  , //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2317 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON WEST BOUNDARY  , //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2365 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON EAST BOUNDARY  , //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2367 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON EAST BOUNDARY  , //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2415 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON SOUTH BOUNDARY  , //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2417 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON SOUTH BOUNDARY  , //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2465 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON NORTH BOUNDARY  , //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2467 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE  , 10A1,
     $        10H IN CELL (, I10, 20H) ON NORTH BOUNDARY  , //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2901 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        22H NAME LENGTH VALUE IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2902 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        24H NUMBER OF VARIABLES IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2903 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        29H NUMBER OF BOUNDARY LINES IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2904 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN X-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2905 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN Y-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2906 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN Z-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2907 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        41H NUMBER OF WORDS OF SCRATCH STORAGE IS   , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2911 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TXTPAK , //,
     $        44H DURING READ OF TIME-INVARIANT PACKET HEADER, //)
 2912 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE COMPAR , //,
     $        44H DURING READ OF TIME-INVARIANT PACKET HEADER, //)
 2913 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H PACKET HEADER , 10A1, //, 23H DOES NOT MATCH ANY OF ,
     $        47HTHE ALLOWABLE NAMES FOR TIME-INVARIANT HEADERS   , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2914 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE UNITRD , //)
 2915 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE BLINRD , //)
 2916 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        46H WAS RETURNED FROM SUBROUTINE FLBIWR FOR EDGE , I10,//)
 2917 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TIMERD , //)
 2918 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        39H THE PREVIOUS PACKET STOPPED WITH DATE, I10,
     $        10H AND TIME , F10.2, //, 25H THIS PACKET STARTS WITH ,
     $        5HDATE , I10, 10H AND TIME , F10.2, //, 11H.  PACKETS ,
     $        47HMUST FOLLOW CONSECUTIVELY IN TIME, WITH NO GAPS, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2921 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE DFBKRD , //)
 2922 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RGTPRD , //)
 2923 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TPCNRD , //)
 2924 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TPUVRD , //)
 2925 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE HTPRRD , //)
 2931 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TXTPAK , //,
     $        42H DURING READ OF TIME-VARIANT PACKET HEADER, //)
 2932 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE COMPAR , //,
     $        42H DURING READ OF TIME-VARIANT PACKET HEADER, //)
 2933 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H PACKET HEADER , 10A1, //, 23H DOES NOT MATCH ANY OF ,
     $        45HTHE ALLOWABLE NAMES FOR TIME-VARIANT HEADERS   , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2942 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MTHDRD , //)
 2943 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        46H WAS RETURNED FROM SUBROUTINE VERTICAL MTHDRD , //)
 2944 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE CNSTRD , //)
 2946 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE BLVLRD , //)
 2947 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE VPRFRD , //)
 2949 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MATGET ,
     $        35H FOR TOP CONCENTRATION OF VARIABLE , 10A1, //)
 2952 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        32H THE METHOD NUMBER FOR VARIABLE , 10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2953 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER COUNTER FOR VARIABLE , 10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2954 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER POINTER FOR VARIABLE , 10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2955 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE SPLITC ,
     $        29H FOR WEST  OR EAST  BOUNDARY  , //)
 2956 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER COUNTER FOR VARIABLE ,10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2957 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER POINTER FOR VARIABLE ,10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2958 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE BNDUSR ,
     $        29H FOR WEST  OR EAST  BOUNDARY  , //)
 2962 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        32H THE METHOD NUMBER FOR VARIABLE , 10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2963 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER COUNTER FOR VARIABLE , 10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2964 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER POINTER FOR VARIABLE , 10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2965 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE SPLITC ,
     $        29H FOR SOUTH OR NORTH BOUNDARY  , //)
 2966 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER COUNTER FOR VARIABLE ,10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2967 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER POINTER FOR VARIABLE ,10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2968 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE BNDUSR ,
     $        29H FOR SOUTH OR NORTH BOUNDARY  , //)
 2971 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        26H THE CELL WITH X-LOCATION , I10, 16H AND Y-LOCATION ,
     $        I10, //, 40H CONTAINS THE BOUNDARY LINE DESIGNATION , I10,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2972 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        41H THE VERTICAL METHOD NUMBER FOR VARIABLE , 10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2973 FORMAT (' ****** ERROR TRACE ******  ERROR FLAG ', I10,
     $        ' WAS RETURNED FROM SUBROUTINE ABSPRF OR ABSPRV ',
     $        ' FOR WEST  OR EAST  BOUNDARY  ', //)
 2974 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RELPRF ,
     $        29H FOR WEST  OR EAST  BOUNDARY  , //)
 2975 FORMAT (' ****** ERROR TRACE ******  ERROR FLAG ', I10,
     $        ' WAS RETURNED FROM SUBROUTINE ABPRFR OR ABPRVR ',
     $        ' FOR WEST  OR EAST  BOUNDARY  ', //)
 2976 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RLPRFR ,
     $        29H FOR WEST  OR EAST  BOUNDARY  , //)
 2977 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        48H THE USER VERTICAL ROUTINE PARAMETER COUNTER FOR ,
     $        9H VARIABLE , 10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2978 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        48H THE USER VERTICAL ROUTINE PARAMETER POINTER FOR ,
     $        9HVARIABLE , 10A1,
     $        //, 33H IN WEST  OR EAST  BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2979 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE BNDVUS ,
     $        29H FOR WEST  OR EAST  BOUNDARY  , //)
 2981 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        26H THE CELL WITH X-LOCATION , I10, 16H AND Y-LOCATION ,
     $        I10, //, 40H CONTAINS THE BOUNDARY LINE DESIGNATION , I10,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2982 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        41H THE VERTICAL METHOD NUMBER FOR VARIABLE , 10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2983 FORMAT (' ****** ERROR TRACE ******  ERROR FLAG ', I10,
     $        ' WAS RETURNED FROM SUBROUTINE ABSPRF OR ABSPRV ',
     $        ' FOR SOUTH OR NORTH BOUNDARY  ', //)
 2984 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RELPRF ,
     $        29H FOR SOUTH OR NORTH BOUNDARY  , //)
 2985 FORMAT (' ****** ERROR TRACE ******  ERROR FLAG ', I10,
     $        ' WAS RETURNED FROM SUBROUTINE ABPRFR OR ABPRVR ',
     $        ' FOR SOUTH OR NORTH BOUNDARY  ', //)
 2986 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RLPRFR ,
     $        29H FOR SOUTH OR NORTH BOUNDARY  , //)
 2987 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        57H THE USER VERTICAL ROUTINE PARAMETER COUNTER FOR ,
     $        9HVARIABLE , 10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2988 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        57H THE USER VERTICAL ROUTINE PARAMETER POINTER FOR ,
     $        9HVARIABLE , 10A1,
     $        //, 33H IN SOUTH OR NORTH BOUNDARY LINE , 10A1, 4H IS ,
     $        I10, 37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2989 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE BNDVUS ,
     $        29H FOR SOUTH OR NORTH BOUNDARY  , //)
 2991 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE FLTMWR , //)
 2992 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        46H WAS RETURNED FROM SUBROUTINE FLBVWR FOR EDGE , I10,//)
 2993 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE GRIDPR ,
     $        25H FOR THE WEST  BOUNDARY  , //)
 2994 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE GRIDPR ,
     $        25H FOR THE EAST  BOUNDARY  , //)
 2995 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE GRIDPR ,
     $        25H FOR THE SOUTH BOUNDARY  , //)
 2996 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE GRIDPR ,
     $        25H FOR THE NORTH BOUNDARY  , //)
      END
