      SUBROUTINE SPLTBC (IPRINT, NAMLEN, NVARBL, NECELL, NZCELL, NPARAM,
     $    KVRBL, KECLL, KZCLL, RMISSV, VALMIN, VALMAX, PARAMS, MVARBL,
     $    MPARAM, OUTMAT, JFLAG)
      SAVE
C
C NAME -- SPLIT/COMBINATION
C
C DESRCRIPTION -- CALCULATES THE VALUE OF A VARIABLE AS A FUNCTION
C                 OF VALUES OF A SET OF OTHER VARIABLES
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NECELL    I  NUMBER OF EDGE CELLS
C         NZCELL    I  NUMBER OF Z-CELLS
C         NPARAM    I  NUMBER OF PARAMETERS
C         KECLL     I  EDGE CELL NUMBER
C         KZCLL     I  Z-CELL NUMBER
C         KVRBL     I  VARIABLE NUMBER
C         RMISSV    R  MISSING VARIABLE VALUE
C         VALMIN    R  MINIMUM VALUE FOR VARIABLE
C         VALMAX    R  MAXIMUM VALUE FOR VARIABLE
C         PARAMS    I  PARAMETER VALUES
C         MVARBL    I  VARIABLE NAMES
C         MPARAM    I  PARAMETER NAMES
C
C OUTPUTS --
C         OUTMAT    R  THE OUTPUT VALUE MATRIX
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         KPARM     I  POINTER TO THE PARAMETER IN THE PARAMETER LIST
C         KCOMP     I  POINTER TO THE COMPONENT IN THE VARIABLE LIST
C         MBLANK    I  BLANK CHARACTER
C         VARVAL    R  VALUE OF THE OUTPUT VARIABLE
C         CMPVAL    R  VALUE OF THE COMPONENT VARIABLE
C
C ROUTINES CALLED --
C         COMPAR    COMPARES CONTENTS OF TWO ALPHABETIC STRINGS
C
C ERROR CONDITIONS --
C         -10       MISSING VARIABLE NAME
C         -11       MISSING COMPONENT VALUE
C         -12       MISSING PARAMETER VALUE
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION PARAMS(NPARAM)
      CHARACTER*4 MVARBL(NAMLEN,NVARBL)
      CHARACTER*4 MPARAM(NAMLEN,NPARAM)
      DIMENSION OUTMAT(NECELL, NZCELL, NVARBL)
      CHARACTER*4 MBLANK
C
C SET LOCAL DATA VALUES
C
      DATA MBLANK /' '/
C
C SET COMPLETION FLAG AND VARIABLE TO INITIAL VALUE
C
      JFLAG = 0
      VARVAL = 0.0
C
C SET A LOOP OVER ALL PARAMETERS AND CHECK FOR BLANK PARAMETER NAME
C
      DO 200 J = 1, NPARAM
         KPARM = J
         IF (MPARAM(1,J) .NE. MBLANK) GO TO 75
C
C BLANK NAME -- SET COMPONENT VALUE TO UNITY AND SKIP TO PROCESSING
C
         CMPVAL = 1.0
         GO TO 125
C
C SET A LOOP OVER ALL VARIABLES AND COMPARE NAMES
C
   75    DO 100 N = 1,NVARBL
            CALL COMPAR(IPRINT, NAMLEN, MVARBL(1,N), MPARAM(1,KPARM),
     $                  JFLAG)
C
C IF MATCH, SAVE LOCATION FOR COMPONENT
C
            IF (JFLAG .EQ. 0) GO TO 100
            KCOMP = N
            GO TO 115
C
C END LOOP -- ERROR EXIT IF NO MATCH
C
  100    CONTINUE
         GO TO 950
C
C EXTRACT COMPONENT VALUE FROM OUTPUT MATRIX AND TEST FOR MISSING
C
  115    CMPVAL = OUTMAT(KECLL, KZCLL, KCOMP)
         IF (CMPVAL .EQ. RMISSV) GO TO 955
C
C CHECK PARAMTER VALUE -- IF OK, COLLECT THIS FRACTION INTO TOTAL
C
  125    IF (PARAMS(KPARM) .EQ. RMISSV) GO TO 960
         VARVAL = VARVAL + CMPVAL * PARAMS(KPARM)
C
C END LOOP AND TEST VALUE
C
  200 CONTINUE
      IF (VARVAL .GE. VALMIN) GO TO 215
      WRITE (IPRINT, 2215) VARVAL, (MVARBL(I, KVRBL), I = 1,NAMLEN),
     $                     KECLL, KZCLL, VALMIN
      VARVAL = VALMIN
  215 IF (VARVAL .LE. VALMAX) GO TO 225
      WRITE (IPRINT, 2225) VARVAL, (MVARBL(I, KVRBL), I = 1, NAMLEN),
     $                     KECLL, KZCLL, VALMAX
      VARVAL = VALMAX
C
C LOAD VALUE INTO OUTPUT MATRIX AND RETURN
C
  225 OUTMAT(KECLL, KZCLL, KVRBL) = VARVAL
      GO TO 1000
C
C ERROR MESSAGE FOR MISSING VARIABLE NAME
C
  950 WRITE (IPRINT, 2950) (MPARAM(I, KPARM), I = 1, NAMLEN)
      JFLAG = -10
      GO TO 1000
C
C ERROR MESSAGE FOR MISSING COMPONENT VALUE
C
  955 WRITE (IPRINT, 2955) (MVARBL (I, KCOMP), I = 1, NAMLEN)
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR MISSING PARAMETER VALUE
C
  960 WRITE (IPRINT, 2960) (MPARAM(I, KPARM), I= 1, NAMLEN)
      JFLAG = -12
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2215 FORMAT (31H ****** NOTE ****** THE VALUE, ,F14.8,
     $        14H, OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2225 FORMAT (31H ****** NOTE ****** THE VALUE, ,F14.8,
     $        14H, OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2950 FORMAT (1H1, 36H****** SYSTEM OF INPUT ERROR ****** ,
     $        33H UNABLE TO LOCATE PARAMETER NAME , 10A1, //,
     $        27H IN LIST OF VARIABLE NAMES. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2955 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        34H MISSING VALUE FOR COMPONENT NAME , 10A1, //,
     $        27H IN LIST OF VARIABLE NAMES. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2960 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        34H MISSING VALUE FOR PARAMETER NAME , 10A1, //,
     $        27H IN LIST OF VARIABLE NAMES. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
      END
