c---------------------------------------------------------------------c
c             ATDM POSTPROCESSING SYSTEM: EXTRACT                     c
c             11/21/95 CAE                                            c
c---------------------------------------------------------------------c
c
      subroutine visrng
c
c     This program calculates gridded total and species-dependent
c     extinction coefficients, visual range and deciviews for each
c     period specified in XYVIS.  
c
c     Extinction coefficients (1/Mm) are determined by multiplying species 
c     concentrations (ug/m3) with their respective extinction efficiencies
c     (m2/g):
c
c        SPECIES (ug/m3)                     EXTINCTION EFFICIENCY (m2/g)
c        ---------------------               ----------------------------
c        RAYLEIGH SCATTERING                 10 1/Mm (CONSTANT EXTINCTION)
c        NO2                                 0.17
c        SULFATE = NH4S + GSO4 + ASO4        RH DEPENDENT (MINIMUM = 2.0)
c        NITRATE = NH4N + PNO3               RH DEPENDENT (MINIMUM = 3.1)
c        SOA                                 RH DEPENDENT (MINIMUM = 4.0)
c        POA                                 6.20
c        PEC                                 10.50
c        PMFINE                              1.00
c        PMCOARS                             0.60
c
c     Total extinction BEXT is found by summing all species extinction 
c     coefficients; BEXT is transformed to visual range (km) using
c
c          VR = 1000*3.00/BEXT
c
c     Deciview is determnined from BEXT using
c          
c          DV = 10*ln[BEXT/(10 1/Mm)]
c
      include 'xtract.inc'
      include 'xtrvis.inc'
      real cin(11)

c-----Loop over non-boundary cells and sum

      do 20 j = js1,js2
         do 20 i = is1,is2
           do 22 n = 1,nvspc
             ll = idspc(name(n),spec,nvar)
             if (cnc1(i,j,ll,1).lt.-998.) then
               do k=1,nvis
                 vis(i,j,k) = -999.
               enddo
               goto 20
             endif
             cin(n) = fact(ll)*cnc1(i,j,ll,1)
  22       continue
c
c ---  vis(1) = BEXT
c ---  vis(2) = VR
c ---  vis(3) = DV
c
c  Following are visibilty measures using the IMPROVE methodology
c   Note that extinction coefficient in this case does not include
c   Rayleigh scattering (=10 1/Mm) -- Calculations of Deciview (DVI) and 
c   Visual Range (VRI) are modified here to include the constant value due to 
c   Rayleigh Scattering ...
c
c ---  vis(4) = BEXTI
c ---  vis(5) = VRI
c ---  vis(6) = DVI
c
           if ( limprv ) then
             call extinct_imprv(cin,rh(i,j),bext_imprv)
             vis(i,j,4) = bext_imprv
             vis(i,j,5) = 1000.*3./(bext_imprv+10.)
             vis(i,j,6) = 10.*alog((bext_imprv+10.)/10.)
           else
             call extinct(cin,rh(i,j),bext)
             vis(i,j,1) = bext
             vis(i,j,2) = 1000.*3./bext
             vis(i,j,3) = 10.*alog(bext/10.)
           endif
c
c
  20  continue
c
      return
      end

c--------------------------------------------------------------------------

      subroutine extinct(cin,rh,btot)

c-----Calculates b(ext) = b(sr) + b(sp) + b(ap) + b(ag) (1/Mm)

      real cin(11)
      data bray /10.00/
c
      rrh = amin1(rh/100.,0.95)
c     fso4 = 4.04*(1.+(0.053+0.183*rrh)*(rrh/(1.-rrh)))
c     fno3 = 4.28*(1.+(0.053+0.183*rrh)*(rrh/(1.-rrh)))
      fso4 = 1.0 + 1.0/(1.-rrh)
      fno3 = 1.8 + 1.3/(1.-rrh)
      fsoa = 3.4 + 0.6/(1.-rrh)
c
      bno2 =  0.17*cin(1)
      bso4 =  fso4*(cin(3) + cin(4) + cin(6))
      bno3 =  fno3*(cin(2) + cin(5))
      bsoa =  fsoa*cin(7)
      bpoa =  6.20*cin(8)
      bpec = 10.50*cin(9)
      bpmf =  1.00*cin(10)
      bpmc =  0.60*cin(11)
      btot = bray+bno2+bso4+bno3+bsoa+bpoa+bpec+bpmf+bpmc
c
      return
      end
c--------------------------------------------------------------------------

      subroutine extinct_imprv(cin,rh,btot_i)

c-----Calculates b(ext) as used for comparison w/ IMPROVE network

      real cin(11)
c
      rrh = amin1(rh,99.)
      call get_frh(rrh,frh)
c
      bso4 =  3.0*frh*(cin(3) + cin(4) + cin(6))
      bno3 =  3.0*frh*(cin(2) + cin(5))
      borg =  4.0*(cin(7)+cin(8))
      bpec = 10.0*cin(9)
      bpmf =  1.00*cin(10)
      bpmc =  0.60*cin(11)
      btot_i = bso4+bno3+borg+bpec+bpmf+bpmc

c
      return
      end
c
      subroutine get_frh(rrh,frh)
c
      real rrh,frh
      real rh0(100),frh0(100)
c
      data rh0 /  
     &          1.,2.,3.,4.,5.,6.,7.,8.,9.,10.,
     &          11.,12.,13.,14.,15.,16.,17.,18.,19.,20.,
     &          21.,22.,23.,24.,25.,26.,27.,28.,29.,30.,
     &          31.,32.,33.,34.,35.,36.,37.,38.,39.,40.,
     &          41.,42.,43.,44.,45.,46.,47.,48.,49.,50.,
     &          51.,52.,53.,54.,55.,56.,57.,58.,59.,60.,
     &          61.,62.,63.,64.,65.,66.,67.,68.,69.,70.,
     &          71.,72.,73.,74.,75.,76.,77.,78.,79.,80.,
     &          81.,82.,83.,84.,85.,86.,87.,88.,89.,90.,
     &          91.,92.,93.,94.,95.,96.,97.,98.,99.,100./
c
      data frh0/  
     &          1.0000,1.0000,1.0000,1.0000,1.0000,
     &          1.0000,1.0000,1.0000,1.0000,1.0000,
     &          1.0000,1.0000,1.0000,1.0001,1.0001,
     &          1.0004,1.0006,1.0024,1.0056,1.0089,
     &          1.0097,1.0105,1.0111,1.0115,1.0118,
     &          1.0122,1.0126,1.0130,1.0135,1.0139,
     &          1.0173,1.0206,1.0254,1.0315,1.0377,
     &          1.0486,1.0596,1.0751,1.0951,1.1151,
     &          1.1247,1.1343,1.1436,1.1525,1.1615,
     &          1.1724,1.1833,1.1955,1.2090,1.2224,
     &          1.2368,1.2512,1.2671,1.2844,1.3018,
     &          1.3234,1.3450,1.3695,1.3969,1.4243,
     &          1.4628,1.5014,1.5468,1.5992,1.6516,
     &          1.6991,1.7466,1.7985,1.8549,1.9113,
     &          1.9596,2.0080,2.0596,2.1146,2.1695,
     &          2.2630,2.3565,2.4692,2.6011,2.7330,
     &          2.8461,2.9592,3.0853,3.2245,3.3637,
     &          3.5743,3.7849,4.0466,4.3594,4.6721,
     &          5.3067,5.9412,6.9627,8.3710,9.7793,
     &          12.4288,15.0783,18.0590,21.3709,1.0000/
c
      if ( rrh .lt. rh0(1) ) then
	 frh=1.0
	 return
      endif
      if ( rrh .gt. rh0(99) ) then
	 frh=frh0(99)
	 return
      endif
      do 10 k=2,99
	 if ( rh0(k-1) .le. rrh .and. 
     &        rrh .le. rh0(k) ) then
            frh=frh0(k-1)+(frh0(k)-frh0(k-1))*(rrh-rh0(k-1))/
     &                    (rh0(k)-rh0(k-1))
	    return
	 endif
 10   continue
c
      end
