      SUBROUTINE FLHDWR (IPRINT, IOUTFL, NAMLEN, NIDLEN, NSEGMT, NSPECS,
     $   JBEGDT, JENDDT, BEGTIM, ENDTIM, MFILNM, MFILID, JFLAG)
C
C NAME -- FILE HEADER WRITE
C
C DESCRIPTION -- WRITES THE FILE HEADER AT THE BEGINNING OF
C         EVERY FILE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NIDLEN    I  NUMBER OF WORDS IN IDENTIFICATION FIELD
C         NSEGMT    I  NUMBER OF SEGMENTS
C         NSPECS    I  NUMBER OF SPECIES
C         JBEGDT    I  BEGINNING DATE
C         JENDDT    I  ENDING DATE
C         BEGTIM    R  BEGINNING TIME
C         ENDTIM    R  ENDING TIME
C         MFILNM    I  FILE NAME (LENGTH)
C         MFILID    I  FILE IDENTIFICATION (ID.LENGTH)
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        NONPOSITIVE VALUE FOR FILE IDENTIFICATION LENGTH
C         -3        ERROR IN SYSTEM WRITE ROUTINE
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MFILNM(NAMLEN)
      character*4 MFILNM(NAMLEN)
Ctcm  DIMENSION MFILID(NIDLEN)
      character*4 MFILID(NIDLEN)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C VERIFY THAT THE NAME LENGTH AND ID LENGTH ARE POSITIVE
C
      IF (NAMLEN .LE. 0) GO TO 905
      IF (NIDLEN .LE. 0) GO TO 910
C
C WRITE THE FILE HEADER RECORD
C
      WRITE (IOUTFL) (MFILNM(I),I=1,NAMLEN), (MFILID(I),I=1,NIDLEN), 
     $                NSEGMT, NSPECS, JBEGDT, BEGTIM,
     $                JENDDT, ENDTIM
C
C CHECK FOR ERROR ON WRITE, ELSE RETURN
C
      IF (JFLAG .NE. 0) GO TO 915
      GO TO 1000
C
C ERROR MESSAGE FOR NAME LENGTH
C
  905 WRITE (IPRINT, 2905) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR FILE ID
C
  910 WRITE (IPRINT, 2910) NIDLEN
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON WRITE
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -3
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        46H SUBROUTINE FLHDWR CALLED WITH NAME LENGTH OF , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE FLHDWR CALLED WITH FILE ID LENGTH OF , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        45H RETURNED TO FLHDWR FROM SYSTEM WRITE ROUTINE, //)
      END
