      SUBROUTINE FLMSRD (IPRINT, INFILE, NAMLEN, NVARBL, MVARBL,
     $                   OUTMAT, JFLAG)
C
C NAME -- METSCALARS FILE RECORDS READ
C
C DESCRIPTION -- READS THE METSCALARS FILE RECORD
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         MVARBL    I  VARIABLES NAMES
C         OUTMAT    R  OUTPUT VALUE MATRIX
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        NONPOSITIVE VALUE FOR NUMBER OF VARIABLES
C         -3        ERROR IN SYSTEM READ ROUTINE
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAY
C
      DIMENSION OUTMAT(NVARBL)
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C VERIFY THAT THE NAME LENGTH AND NUMBER OF VARIABLES ARE POSITIVE
C
      IF (NAMLEN .LE. 0) GO TO 905
      IF (NVARBL .LE. 0) GO TO 910
C
C READ THE METSCALARS FILE RECORD
C
      READ (INFILE)((MVARBL(I,J),I=1,NAMLEN), OUTMAT(J), J=1,NVARBL)
C
C CHECK FOR ERROR ON READ, ELSE RETURN
C
      IF (JFLAG .NE. 0) GO TO 915
      GO TO 1000
C
C ERROR MESSAGE FOR NONPOSITIVE NAME LENGTH
C
  905 WRITE (IPRINT, 2905) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NONPOSITIVE NUMBER OF VARIABLES
C
  910 WRITE (IPRINT, 2910) NVARBL
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON RECORD READ FROM FILE
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -3
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        46H SUBROUTINE FLMSRD CALLED WITH NAME LENGTH OF , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        50H SUBROUTINE FLMSRD CALLED WITH NUMBER OF VARIABLES,I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        44H RETURNED TO FLMSRD FROM SYSTEM READ ROUTINE, //)
      END
