      SUBROUTINE FLPIRD (IPRINT, INFILE, NPTSRC, KSGMT, XPTSRC, YPTSRC,
     $ STKHGT, STKDIA, STKTMP, STKVEL, JFLAG)
C
C NAME -- POINT SOURCE TIME-INVARIANT FILE RECORD READ
C
C DESCRIPTION -- READS THE POINT SOURCE TIME-INVARIANT FILE RECORD
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         NPTSRC    I  NUMBER OF POINT SOURCES
C         KSGMT     I  SEGMENT NUMBER
C         XPTSRC    R  X-LOCATION OF POINT SOURCE
C         YPTSRC    R  Y-LOCATION OF POINT SOURCE
C         STKHGT    R  STACK HEIGHT OF POINT SOURCE
C         STKDIA    R  STACK DIAMETER OF POINT SOURCE
C         STKTMP    R  STACK TEMPERATURE OF POINT SOURCE
C         STKVEL    R  STACK VELOCITY OF POINT SOURCE
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR SEGMENT NUMBER
C         -2        ERROR IN SYSTEM READ ROUTINE FOR COUNTER
C         -3        ERROR IN SYSTEM READ ROUTINE FOR DEFINITION
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAY
C
      DIMENSION XPTSRC(NPTSRC)
      DIMENSION YPTSRC(NPTSRC)
      DIMENSION STKHGT(NPTSRC)
      DIMENSION STKDIA(NPTSRC)
      DIMENSION STKTMP(NPTSRC)
      DIMENSION STKVEL(NPTSRC)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C VERIFY THAT THE SEGMENT LENGTH IS POSITIVE
C
C
C READ THE COUNTER RECORD AND CHECK FOR ERROR
C
      READ (INFILE) KSGMT, NPTSRC
      IF (JFLAG .NE. 0) GO TO 910
C
C IF NO SOURCES FOR THIS SEGMENT, RETURN
C
      IF (NPTSRC .LE. 0) GO TO 1000
C
C READ THE POINT SOURCE TIME-INVARIANT FILE RECORD RECORD
C
      READ (INFILE) (XPTSRC(J), YPTSRC(J), STKHGT(J), STKDIA(J),
     $                STKTMP(J), STKVEL(J), J = 1, NPTSRC)
C
C CHECK FOR ERROR ON READ, ELSE RETURN
C
      IF (JFLAG .NE. 0) GO TO 915
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON READ OF COUNTER RECORD
C
  910 WRITE (IPRINT, 2910) JFLAG
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON READ OF DEFINITION RECORD
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -3
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2910 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        44H RETURNED TO FLPIRD FROM SYSTEM READ ROUTINE ,
     $        20H FOR COUNTER RECORD , //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        44H RETURNED TO FLPIRD FROM SYSTEM READ ROUTINE,
     $        23H FOR DEFINITION RECORD , //)
      END
