      SUBROUTINE FLRGWR (IPRINT, IOUTFL, NXCELL, NYCELL, NZCELL, NZLOWR,
     $   NZUPPR, JUTMZN, XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD, YCELLD,
     $   ZHTSUR, ZMINLW, ZMINUP, JFLAG)
C
C NAME -- FILE REGION READ
C
C DESCRIPTION -- WRITES THE FILE REGION AT THE BEGINNING OF
C         EVERY FILE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         IOUTFL    I  FORTRAN INPUT FILE UNIT
C         NXCELL     I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL     I  NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL     I  NUMBER OF CELLS IN Z-DIRECTION
C         NZLOWR     I  NUMBER OF CELLS IN LOWER VERTICAL LAYER
C         NZUPPR     I  NUMBER OF CELLS IN UPPER VERTICAL LAYER
C         JUTMZN     I  UTM ZONE NUMBER
C         XUTMOR     R  X-COORDINATE OF UTM ORIGIN
C         YUTMOR     R  Y-COORDINATE OF UTM ORIGIN
C         XREGOR     R  X-COORDINATE OF REGION ORIGIN
C         YREGOR     R  Y-COORDINATE OF REGION ORIGIN
C         XCELLD     R  NUMBER OF CELLS IN X-DIRECTION
C         YCELLD     R  NUMBER OF CELLS IN Y-DIRECTION
C         ZHTSUR     R  CELL HEIGHT, SURFACE LAYER
C         ZMINLW     R  MINIMUM CELL HEIGHT, LOWER LAYER
C         ZMINUP     R  MINIMUM CELL HEIGHT, UPPER LAYER
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        ERROR IN SYSTEM WRITE ROUTINE
C
C OTHER INFORMATION --
C
C
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C WRITE THE FILE REGION RECORD
C
      WRITE (IOUTFL) XUTMOR, YUTMOR, JUTMZN, XREGOR, YREGOR, XCELLD,
     $               YCELLD, NXCELL, NYCELL, NZCELL, NZLOWR, NZUPPR,
     $               ZHTSUR, ZMINLW, ZMINUP
C
C CHECK FOR ERROR ON WRITE, ELSE RETURN
C
      IF (JFLAG .NE. 0) GO TO 905
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON READ
C
  905 WRITE (IPRINT, 2905) JFLAG
      JFLAG = -1
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        45H RETURNED TO FLRGWR FROM SYSTEM WRITE ROUTINE, //)
      END
