      SUBROUTINE FLSPWR (IPRINT, IOUTFL, NAMLEN, NSPECS, MSPECS, JFLAG)
C
C NAME -- FILE SPECIES NAMES WRITE
C
C DESCRIPTION -- WRITES THE FILE SPECIES NAMES AT THE BEGINNING OF
C         EVERY FILE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         IOUTFL    I  FORTRAN INPUT FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NSPECS    I  NUMBER OF SPECIES
C         MSPECS    I  SPECIES NAMES
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        NONPOSITIVE VALUE FOR NUMBER OF SPECIES
C         -3        ERROR IN SYSTEM WRITE ROUTINE
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAY
C
Ctcm  DIMENSION MSPECS(NAMLEN,NSPECS)
      character*4 MSPECS(NAMLEN,NSPECS)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C VERIFY THAT THE NAME LENGTH AND NUMBER OF SPECIES ARE POSITIVE
C
      IF (NAMLEN .LE. 0) GO TO 905
      IF (NSPECS .LE. 0) GO TO 910
C
C WRITE THE FILE SPECIES NAMES RECORD
C
      WRITE (IOUTFL) MSPECS
C
C CHECK FOR ERROR ON WRITE, ELSE RETURN
C
      IF (JFLAG .NE. 0) GO TO 915
      GO TO 1000
C
C ERROR MESSAGE FOR NAME LENGTH
C
  905 WRITE (IPRINT, 2905) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NUMBER OF SPECIES
C
  910 WRITE (IPRINT, 2910) NSPECS
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON WRITE
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -3
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        46H SUBROUTINE FLSPWR CALLED WITH NAME LENGTH OF , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        49H SUBROUTINE FLSPWR CALLED WITH NUMBER OF SPECIES , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        45H RETURNED TO FLSPWR FROM SYSTEM WRITE ROUTINE, //)
      END
