      subroutine lccone (fsplat,ssplat,sign)
                                           
C*****************************************************************************C
C  lccone   - This is a MAPDRV routine                                        C
C  Section  - Design                                                          C
C  Purpose  - To calculate the cone factor to use in a Lambert Conformal Pro- C
C             jection.                                                        C
C                                                                             C
C  On entry - FSPLAT is the first standard parallel to use in the calculation C
C             of the cone factor.  SSPLAT is the second such parallel.   SIGN C
C             indicates what hemisphere the projection is in.                 C
C                                                                             C
C  On exit  - CONFAC is calculated and stored in the common block LAMSTF with C
C             FSPLAT and SSPLAT.                                              C
C                                                                             C
C  Assume   - Nothing.                                                        C
C                                                                             C
C  Author   - Jeremy Asbill       Date - October 10, 1990    for the MM4 club C
C*****************************************************************************C

C  Parameters 
             
      parameter       (conv = 0.01745329251994)
                    
C  Integer variables
                   
      integer          sign              ! indicates which hemisphere      (in)
  
C  Real variables  
                  
      real             fsplat,           ! first standard parallel lat.    (in)
     *                 ssplat            ! second standard parallel lat.   (in)
      real             confac,           ! for common block LAMSTF 
     *                 fsparl,           ! for common block LAMSTF
     *                 ssparl            ! for common block LAMSTF
  
C  Common blocks 
                
      include 'lamstf.inc'

        
C****************************  subroutine begin  *****************************C
       
C  Calculate CONFAC using input parameters
      
      write(*,*) 'fsplat, ssplat, sign, conv:'
      write(*,*) fsplat, ssplat, sign, conv
      confac = alog10(cos(fsplat * conv)) - alog10(cos(ssplat * conv)) 
      write(*,*) 'confac: ', confac
      confac = confac/(alog10(tan((45.0 - float(sign) *               
     *                             fsplat/2.0) * conv)) -            
     *                 alog10(tan((45.0 - float(sign) *             
     *                             ssplat/2.0) * conv)))           
                
C  Stuff it all into the common block
                                    
      fsparl = fsplat              
      ssparl = ssplat             
                                 
C*****************************  subroutine end  ******************************C
                 
      return    
      end      
