      subroutine xytoll (j,i,lat,lon,project)
                                                                                 
C*****************************************************************************C  
C  xytoll   - This is a MAPDRV routine 
C  Section  - Labels    
C  Purpose  - To  transform  mesoscale gird point coordinates into  latitude,
C             longitude coordinates.
C
C  On entry - J  and  I are an ordered pair representing a grid point in  the
C             mesoscale grid.  XYLLON is a common block that contains the in-
C             formation necessary for describing the domain.
C
C  On exit  - LAT, LON contain  the latitude and longitude respectively  that
C             resulted from the transformation.
C
C  Assume   - Nothing.
C
C  Notes    - The formula's used in this routine were taken from the  PROGRAM
C             TERRAIN DOCUMENTATION AND USER'S GUIDE. 
C 
C  Author   - Jeremy Asbill   Date - September 17, 1990      for the MM4 club
C*****************************************************************************C  

C  Parameters 
             
      parameter       (pi = 3.14159265)  ! you know!  pi = 180 degrees 
      parameter       (re = 6370.)       ! the radius of the earth in km
      parameter       (ce = 40029.85315) ! the circumference of the earth in km
  
C  Character variables 
                      
      character*2      project           ! projection indicator
   
C  Integer variables  
                     
      integer          imax,             ! for common block XYLLON 
     *                 jmax              ! for common block XYLLON
 
C  Real variables  
                  
      real             j,                ! x coord. to be changed 
     *                 i                 ! y coord. to be changed
      real             lat,              ! resulting latitude             (out)  
     *                 lon               ! resulting longitude            (out)  
      real             grds,             ! for common block XYLLON
     *                 clat,             ! for common block XYLLON
     *                 clon              ! for common block XYLLON
      real             confac,           ! for common block LAMSTF
     *                 fsparl,           ! for common block LAMSTF
     *                 ssparl            ! for common block LAMSTF
      real             rcln,             ! center longitude in radians  (local)
     *                 rclt,             ! center latitude in radians   (local)
     *                 cj,               ! center x coord. for grid     (local)
     *                 ci,               ! center y coord. for grid     (local)
     *                 dj,               ! distance from the central
C                                          meridian to the point        (local)
     *                 di,               ! distance from pole to point  (local)
     *                 bm                ! calculation variable         (local)
    
      include 'xyllon.inc'
      include 'lamstf.inc'

C****************************  subroutine begin  *****************************C  
    
C  Convert the center latitude and longitude of the domain to radians  
                            
      rclt = clat * pi/180.0
      rcln = clon * pi/180.0
                           
C  Find the center values of the grid in mesoscale grid coordinates 
                                
      cj = float(jmax + 1) * 0.5
      ci = float(imax + 1) * 0.5
                               
C  Calculate the distance from the vertical axis to (J,I) 
                            
      dj = (j - cj) * grds 
                          
C  The rest is figured out differently for each type of projection, so ... 
C  If the projection is mercator ('ME') then ...
    
      if (project(1:2) .eq. 'ME') then
                                    
C  Calculate the distance the point in question is from the pole  
                                                                 
        di = -re * log(cos(rclt)/(1 + sin(rclt))) +
     *       (i - ci) * grds    
     
C  Calculate the latitude desired in radians
                                           
        lat = 2.0 * atan(exp(di/re)) - pi * 0.5 
                                               
C  Calculate the longitude desired in radians 
                                             
        lon = rcln + dj/re 
                          
C  If the projection is cylindrical equidistant ('CE') then ... 
   
      else if (project(1:2) .eq. 'CE') then
                                          
C  Calculate the distance from the horizontal axis to (J,I)
 
        di = (i - ci) * grds 
     
C  Determine the shift north-south
                                 
        lat = rclt + (pi * di/(ce * 0.5))
                                        
C  Determine the shift east-west       
                                      
        lon = rcln + (2 * pi * dj/ce)
                                    
C  If the projection is lambert conic conformal ('LC') then ...
                                                              
      else if (project(1:2) .eq. 'LC') then 
                                           
C  Calculate the distance from the pole to J,I
                                             
        if (clat .ge. 0.0) then
          di = -re/confac * sin(pi * 0.5 - (fsparl * pi/180.0)) *
     *         (tan((pi * 0.5 - rclt) * 0.5) /
     *          tan((pi * 0.5 - (fsparl * pi/180.0)) * 0.5))**confac +
     *         (i - ci) * grds
        else 
          di = -re/confac * sin(-pi * 0.5 - (fsparl * pi/180.0)) * 
     *         (tan((-pi * 0.5 - rclt) * 0.5) /
     *          tan((-pi * 0.5 - (fsparl * pi/180.0)) * 0.5))**confac +
     *         (i - ci) * grds
        end if 
              
C  Calculate out the Big Messy equation refered to as c1 in the document
C  from which this formula was taken
                                   
        bm = tan((pi * 0.5 - abs(fsparl * pi/180.0))/2.0) *  
     *       (confac/re * sqrt(dj**2 + di**2) / 
     *        sin(pi * 0.5 - abs(fsparl * pi/180.0)))**(1.0/confac)
                                                                  
C  Calculate the desired latitude in radians
                                           
        if (clat .ge. 0.0) then 
          lat = pi * 0.5 - 2.0 * atan(bm)
        else 
          lat = -pi * 0.5 + 2.0 * atan(bm)
        end if 
              
C  Calculate the desired longitude in radians 
    
        if (clat .ge. 0.0) then
          lon = rcln + (1.0/confac) * atan2(dj,-di)
        else
          lon = rcln + (1.0/confac) * atan2(dj,di)  
        end if
             
C  If the projection is polar stereographic ('ST') then ... 

      else if (project(1:2) .eq. 'ST') then
                                          
C  Calculate the distance J,I lies from the "true" point 

        if (clat .gt. 0.0) then 
          di = -re * sin(pi * 0.5 - rclt) *
     *         (1.0 + cos(pi * 0.5 - (fsparl * pi/180.0))) / 
     *         (1.0 + cos(pi * 0.5 - rclt)) +
     *         (i - ci) * grds
        else
          di = -re * sin(-pi * 0.5 - rclt) *
     *         (1.0 + cos(-pi * 0.5 - (fsparl * pi/180.0))) / 
     *         (1.0 + cos(-pi * 0.5 - rclt)) +
     *         (i - ci) * grds
        end if
             
C  Calculate the Big Messy quantity as would be done, for lambert conformal 
C  projections.  This quantity is different in value, same in purpose of
C  BM above   
             
        if (clat .ge. 0.0) then 
          bm = (1/re) * sqrt(dj**2 + di**2) / 
     *         (1.0 + cos(pi * 0.5 - (fsparl * pi/180.0)))
        else  
          bm = (1/re) * sqrt(dj**2 + di**2) /
     *         (1.0 + cos(-pi * 0.5 - (fsparl * pi/180.0)))
        end if 
              
C  Calculate the desired latitude in radians
                                           
        if (clat .ge. 0.0) then           
          lat = pi * 0.5 - 2.0 * atan(bm)
        else   
          lat = -pi * 0.5 + 2.0 * atan(bm)
        end if 
              
C  Calculate the desired longitude in radians  
                                              
        if (clat .ge. 0.0) then
          lon = rcln + atan2(dj,-di) 
        else 
          lon = rcln + atan2(dj,di)
        end if  
      end if   
              
C  Convert the calculated lat,lon pair into degrees
                         
      lat = lat * 180.0/pi
      lon = lon * 180.0/pi
                         
C  Make sure no values are greater than 180 degrees and none
C  are less than -180 degrees  
                              
      if (lon .gt. 180.0)  lon = lon - 360.0 
      if (lon .lt. -180.0) lon = lon + 360.0
     
C*****************************  Subroutine End  ******************************C  
    
      return 
      end   
