      SUBROUTINE PSEMRD (INCARD, IPRINT, NAMLEN, NVARBL, NPTSRC, NPTSRT,
     $           LINPTP, LPSRDP, RMISSV, FACMLT, FACADD, SMOLWT, MVARBL,
     $           MPTSRC, MPTSRT, JPTSRT, FLWRAT, PSEMVL, JFLAG)
      SAVE
C
C NAME -- POINT SOURCE EMISSIONS VALUES PACKET READ
C
C DESCRIPTION -- READS THE POINT SOURCE EMISSIONS VALUES PACKET AS PART
C                OF TIME-VARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NPTSRC    I  NUMBER OF POINT SOURCES
C         NPTSRT    I  NUMBER OF POINT SOURCE TYPES
C         LINPTP    I  INPUT PRINT FLAG
C         LPSRDP    I  POINT SOURCE VALUES TABLE PRINT FLAG
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MPTSRC    I  POINT SOURCE NAMES
C         MPTSRT    I  POINT SOURCE TYPE NAMES
C         JPTSRT    I  POINT SOURCE TYPES
C
C OUTPUTS --
C         FLWRAT    R  FLOW RATE FOR EACH PT SOURCE
C         PSEMVL    R  POINT SOURCE VALUES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         MENDPF    I  PACKET TRAILER NAME
C         MCRDID    I  CARD IDENTIFICATION
C         MPTSNM    I  POINT SOURCE NAME
C         MVARNM    I  VARIABLE NAME
C         MALLNM    I  REFERENCE NAME FOR 'ALL'
C         KBEGV     I  POINTER TO BEGINNING VARIABLE LOCATION
C         KENDV     I  POINTER TO ENDING VARIABLE LOCATION
C         KBEGP     I  POINTER TO BEGINNING POINT SOURCE LOCATION
C         KENDP     I  POINTER TO ENDING POINT SOURCE LOCATION
C         KPTSR     I  POINT SOURCE POINTER
C         KVRBL     I  VARIABLE POINTER
C         VALEMS    R  POINT SOURCE VALUE
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS FACTORS TO STANDARD UNITS
C         SEARCH    PERFORMS BINARY SEARCH ON STACK NAMES
C
C ERROR CONDITIONS --
C         -8        POINT SOURCE NAME NOT IN POINT SOURCE LIST
C         -10       POINT SOURCE NAME NOT IN TYPE LIST
C         -14       VARIABLE NAME NOT IN VARIABLE LIST
C
C OTHER INFORMATION --
C
C INFORMATION FOR BINARY SEARCH USING SEARCH
C
      INTEGER*4 INDEX,NUM
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LPSRDP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NVARBL)
      DIMENSION FACADD(NVARBL)
      DIMENSION SMOLWT(NVARBL)
      DIMENSION JPTSRT(NPTSRC)
      DIMENSION FLWRAT(NPTSRC)
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
Ctcm  DIMENSION MPTSRC(NAMLEN,NPTSRC)
      character*4 MPTSRC(NAMLEN,NPTSRC)
Ctcm  DIMENSION MPTSRT(NAMLEN,NPTSRT)
      character*4 MPTSRT(NAMLEN,NPTSRT)
      DIMENSION PSEMVL(NPTSRC,NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MENDPE(10), MPTSNM(10), MVARNM(10), MCRDID(20)
      character*4 MENDPE(10), MPTSNM(10), MVARNM(10), MCRDID(20)
Ctcm  DIMENSION MALLNM(10)
      character*4 MALLNM(10)
Ctcm  DIMENSION MFLWRT(10)
      character*4 MFLWRT(10)
Ctcm  DIMENSION MPTPNM(10)
      character*4 MPTPNM(10)
C
C DECLARE PACKET TRAILER AND 'ALL' REFERENCE
C
      DATA MALLNM /'A', 'L', 'L', 7*' '/
C
C INFORMATION FOR BINARY SEARCH USING SEARCH
C
      DATA INDEX/0/,NUM/0/
C
C SET UP PARAMETERS FOR SEARCH - SIZE OF TABLE
C
      NUM=NPTSRC
C
C FILL IN VARIABLE NAME 'FLOWRATE'
C
      DATA KFLRT /6/
      DATA MFLWRT /'F', 'L', 'O', 'W', 'R', 'A', 'T', 'E', ' ', ' '/
C
C DECLARE PACKET TRAILER
C
      DATA MENDPE /'E', 'N', 'D', 7*' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MPTSNM, MVARNM, VALEMS, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MPTSNM, MVARNM, VALEMS, MCRDID
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MENDPE, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 210
C
C COMPARE POINT SOURCE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET POINT SOURCE POINTER TO ZERO TO INDICATE 'ALL'
C
      KPTSR = 0
      GO TO 140
C
C COMPARE INPUT POINT SOURCE NAME WITH THE LIST OF POINT SOURCE NAMES
C
  113 CONTINUE
C
C MAKE SURE STACK NUMBER HAS CHANGED
C
      CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MPTPNM, JFLAG)
      IF (JFLAG.EQ.1) THEN
         KPTSR=INDEX
         GO TO 140
      ENDIF
C
C NOW GO AHEAD AND SEARCH FOR POSITION IN TABLE
C
      CALL SEARCH(MPTSRC,MPTSNM,NUM,INDEX)
C
C PLACE NAME JUST SEARCHED FOR AS PRIOR NAME
C
      DO 114 I=1,10
         MPTPNM(I)=MPTSNM(I)
  114 CONTINUE
      IF (INDEX.GT.0) THEN
         KPTSR=INDEX
      ELSE
         WRITE(IPRINT,1003) INDEX
         GO TO 950
      ENDIF
C
C PACK VARIABLE NAME
C
  140 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'FLOWRATE'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MFLWRT, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 141
C
C SET KVRBL TO -1 TO INDICATE FLOWRATE
C
      KVRBL = -1
      GO TO 150
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
  141 CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 143
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 150
C
C SET LOOP TO FIND VARIABLE NAME
C
  143 DO 145 J = 1, NVARBL
C
C FIND THIS VARIABLE NAME IN LIST OF STANDARD VARIABLES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 145
C
C SAVE LOCATION AND SKIP TO UNIT CONVERSION
C
         KVRBL = J
         GO TO 150
C
C END LOOP AND ERROR MESSAGE
C
  145 CONTINUE
      GO TO 970
C
C DO UNIT CONVERSION ON INPUT VALUE, UNLESS MISSING
C
  150 IF (VALEMS .EQ. RMISSV) GO TO 160
      KVCON = KVRBL
      IF (KVRBL .EQ. 0) KVCON = 1
      IF (KVRBL .EQ. -1) KVCON = NVARBL + KFLRT
      CALL UNTCNV(VALEMS, FACMLT(KVCON), FACADD(KVCON), SMOLWT(KVCON),
     $    RMISSV, RMISSV, VALEMS)
C
C TEST FOR SOURCE TYPE
C
  160 IF (KPTSR .LT. 0) GO TO 190
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
      KBEGV = KVRBL
      KENDV = KVRBL
      KBEGP = KPTSR
      KENDP = KPTSR
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KPTSR .EQ. 0) KBEGP = 1
      IF (KPTSR .EQ. 0) KENDP = NPTSRC
C
C  FOLLOWING STATEMENT COMMENTED OUT TO ALLOW FLOW THROUGH THE FOLLOWING
C  DO LOOP USING FORTRAN 77    (KKW)  12/6/85
C
C     IF (KVRBL .EQ. -1) KBEGV = 1
C
C SET LOOPS FOR STORING INPUT AND DO SO
C
C     IF (KBEGV.LT.1.AND.KENDV.GT.0) THEN
C        WRITE(IPRINT,1020) KVRBL,KENDV
C     ENDIF
C1020 FORMAT(1X,'ERROR - KVRBL = ',I8,'  KENDV = ',I8)
      DO 185 KVRBL = KBEGV, KENDV
         DO 175 KPTSR = KBEGP, KENDP
            IF (KENDV .EQ. -1) FLWRAT(KPTSR) = VALEMS
            IF (KENDV .GT. 0) PSEMVL(KPTSR, KVRBL) = VALEMS
C
C END LOOPS AND GET NEXT CARD
C
  175    CONTINUE
  185 CONTINUE
      GO TO 105
C
C REMOVE FLAG AND SET LOOP PARAMETERS
C
C 190 KPTSR = -KPTSR
  190 CONTINUE
      KBEGV = KVRBL
      KENDV = KVRBL
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
C
C  FOLLOWING STATEMENT COMMENTED OUT TO ALLOW FLOW THROUGH THE FOLLOWING
C  DO LOOP USING FORTRAN 77    (KKW)  12/6/85
C
C     IF (KVRBL .EQ. -1) KBEGV = 1
C
C SET LOOPS TO STORE ALL SOURCES OF THIS TYPE
C
C     IF (KBEGV.LT.1.AND.KENDV.GT.0) THEN
C        WRITE(IPRINT,1020) KVRBL,KENDV
C     ENDIF
      DO 205 KVRBL = KBEGV, KENDV
         DO 195 J = 1, NPTSRC
C
C IF PROPER TYPE, SAVE VALUE IN OUTPUT MATRIX
C
            IF (JPTSRT(J) .NE. KPTSR) GO TO 195
            IF(KENDV .EQ. -1) FLWRAT(KPTSR) = VALEMS
            IF (KENDV .GT. 0) PSEMVL(J, KVRBL) = VALEMS
C
C END LOOPS AND GET NEXT CARD
C
  195    CONTINUE
  205 CONTINUE
      GO TO 105
C
C END OF PACKET -- PRINT VALUES TABLE IF WANTED, ELSE RETURN
C
  210 IF (.NOT. LPSRDP) GO TO 1000
      WRITE (IPRINT, 2210)
C
C PRINT VALUES IN LOOP
C
      DO 225 K = 1, NPTSRC
         DO 215 J = 1, NVARBL
            WRITE (IPRINT, 2215)(MPTSRC(I,K), I=1,NAMLEN),
     $                       (MVARBL(I,J), I = 1, NAMLEN), PSEMVL(K,J)
  215    CONTINUE
  225 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR POINT SOURCE NAME NOT IN POINT SOURCE LIST
C
  940 WRITE (IPRINT, 2940) MPTSNM
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR POINT SOURCE NAME NOT IN TYPE LIST
C
  950 WRITE (IPRINT, 2950) MPTSNM
      JFLAG = -10
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT IN VARIABLE LIST
C
  970 WRITE (IPRINT, 2970) MVARNM
      JFLAG = -14
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1003 FORMAT(1X,'RETURN ',I4,' POS ',I4)
 1005 FORMAT(6A2,A1,39X)
 1006 FORMAT(6I6,A1)
 1007 FORMAT(10A1)
 1008 FORMAT(2A2)
 1105 FORMAT (10A1, 10A1, F10.0, 30X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, F10.4, 30X, 20A1)
 2210 FORMAT (1H1, 8X, 28HPOINT SOURCE EMISSIONS TABLE, //,
     $        46H  SOURCE NAME   VARIABLE NAME    SOURCE VALUE , //)
 2215 FORMAT (1X, 10A1, 5X, 10A1, F15.4, /)
 2940 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        36H UNABLE TO LOCATE POINT SOURCE NAME , 10A1,
     $        23H IN POINT SOURCES TABLE, //,
     $        32H CHECK POINT SOURCE SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2950 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        36H UNABLE TO LOCATE POINT SOURCE NAME , 10A1,
     $        28H IN POINT SOURCE TYPES TABLE, //,
     $        32H CHECK POINT SOURCE SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        19H IN VARIABLES TABLE, //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
