      SUBROUTINE PTSPRC(NAMLEN, NIDLEN, NVARBL, NSPECS, NUNITS, NPTSRC,
     $  NPTSRT,
     $  NPARAM, NVPARM, NMETSC, NSCRTC, NXCELL, NYCELL, NZCELL,
     $  INFILE, MFILNM, MFILID, LPRINT, JINTSC,
     $  JSCRTC, JSTKPT, STKVEC, REALSC, FACMLT, FACADD, SMOLWT,
     $  JPTSRT, JPTSXC, JPTSYC, JPTSZC, XPTSRC, YPTSRC,
     $  PLMHGT, FLWRAT, PARAMS, VPARAM, XMETSC, MVARBL, MUNITS,
     $  MPTSRC, MPTSRT, MPARAM, MVPARM, JMTHDN, JPARMP, JPARMC,
     $  JVMTHN, JVPRMP, JVPRMC, OUTGRD, EMSVAL, EMSFAC, EMSFLX,
     $  SMTHMN, SMTHMX, VMTHMN, VMTHMX, DIFBRK, REGTOP, TEMPER,
     $  UVECTR, VVECTR, JFLAG)
      SAVE
C
C NAME -- POINT SOURCE PROCESS
C
C DESCRIPTION -- PROCESSES ALL INPUT PACKETS AND CALCULATES
C         POINT SOURCE VALUES
C
C PROGRAMMER -- DAVID C WHITNEY/SAI  JULY 1977
C
C  ---- MODIFIED TO CHECK FOR X AND Y CELLS OUT OF REGION
C       (TCM, 1/11/89)
C
C  ---- MODIFIED TO SET DEFAULT VALUES FOR DIFBRK AND REGTOP WHEN
C       THOSE FILES ARE MISSING.  (TCM, 9/14/92)
C
C  ---- MODIFIED TO CALL BEH084 PLUME RISE ALGORITHM
C       (CAE, 9/20/93)
C
C  ---- MODIFIED TO USE 3D TEMPERATURE DATA IF AVAILABLE
C       (CHANGES TO FILVER, SCRPRT, NEW ROUTINE TMP3RD, ADDED
C       COMMON BLOCK TMPCON)
C       (TCM, 6/15/94)
C
C INPUTS --
C         INCARD    I  INPUT UNIT (FROM JINTSC)
C         IPRINT    I  OUTPUT UNIT (FROM JINTSC)
C         IOUTFL    I  OUTPUT FILE NUMBER (FROM JINTSC)
C         IDFBRK    I  DIFFUSION BREAK FILE NUMBER (FROM INFILE)
C         IRGTOP    I  REGION TOP FILE NUMBER (FROM INFILE)
C         ITEMPS    I  TEMPERATURE FILE NUMBER (FROM INFILE)
C         IMETSC    I  METEOROLOGICAL SCALARS FILE NUMBER (FROM INFILE)
C         IWINDS    I  WIND FILE NUMBER (FROM INFILE)
C         NAMLEN    I  NAME LENGTH
C         NIDLEN    I  IDENTIFICATION FIELD LENGTH
C         NVARBL    I  TOTAL NUMBER OF VARIABLES
C         NUNITS    I  NUMBER OF UNITS
C         NPTSRC    I  NUMBER OF POINT SOURCES
C         NPTSRT    I  NUMBER OF POINT SOURCE TYPES
C         NPARAM    I  NUMBER OF PARAMETERS
C         NVPARM    I  NUMBER OF VERTICAL PARAMETERS
C         NMETSC    I  NUMBER OF METEOROLOGICAL SCALARS
C         NSCRTC    I  NUMBER OF AVAILABLE SCRATCH WORDS
C         NXCELL    I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL    I  NUMBER OF CELLS IN Y-DIRECTION
C         NZCELL    I  NUMBER OF CELLS IN Z-DIRECTION
C         NZLOWR    I  NUMBER OF CELLS IN LOWER VERTICAL LAYER (FROM JIN
C         NZUPPR    I  NUMBER OF CELLS IN UPPER VERTICAL LAYER (FROM JIN
C         JBEGDT    I  BEGINNING DATE (FROM JINTSC)
C         JENDDT    I  ENDING DATE (FROM JINTSC)
C         JUTMZN    I  UTM ZONE NUMBER (FROM JINTSC)
C         JMISSV    I  MISSING VALUE (FROM JINTSC)
C         LINPTP    I  PRINT FLAG FOR INPUT CARD (FROM LPRINT)
C         LPSEGP    I  PRINT FLAG FOR POINT SOURCE EMISSIONS GRID (FROM
C         LPGRDP    I  PRINT FLAG FOR GRIDDED PRINT (FROM LPRINT)
C         LUNITP    I  PRINT FLAG FOR UNITS TABLE (FROM LPRINT)
C         LPSLTP    I  PRINT FLAG FOR POINT SOURCE LOCATION TABLE (FROM
C         LPSLMP    I  PRINT FLAG FOR POINT SOURCE LOCATION MAP (FROM LP
C         LMTHDP    I  PRINT FLAG FOR METHOD TABLE (FROM LPRINT)
C         LPSRDP    I  PRINT FLAG FOR POINT SOURCE READING (FROM LPRINT)
C         LVMTHP    I  PRINT FLAG FOR VERTICAL METHOD TABLE (FROM LPRINT
C         BEGTIM    R  BEGINNING TIME (FROM REALSC)
C         ENDTIM    R  ENDING TIME (FROM REALSC)
C         XUTMOR    R  X-COORDINATE OF UTM ORIGIN (FROM REALSC)
C         YUTMOR    R  Y-COORDINATE OF UTM ORIGIN (FROM REALSC)
C         XREGOR    R  X-COORDINATE OF REGION ORIGIN (FROM REALSC)
C         YREGOR    R  Y-COORDINATE OF REGION ORIGIN (FROM REALSC)
C         XCELLD    R  LENGTH OF CELL IN X-DIRECTION (FROM REALSC)
C         YCELLD    R  LENGTH OF CELL IN Y-DIRECTION (FROM REALSC)
C         ZHTSUR    R  CELL HEIGHT, SURFACE LAYER (FROM REALSC)
C         ZMINLW    R  MINIMUM CELL HEIGHT, LOWER LAYER (FROM REALSC)
C         ZMINUP    R  MINIMUM CELL HEIGHT, UPPER LAYER (FROM REALSC)
C         RMISSV    R  MISSING VALUE (FROM REALSC)
C         INFILE    I  FILE UNIT NUMBERS
C         MFILNM    I  FILE NAME
C         MFILID    I  FILE IDENTIFICATION
C         LPRINT    I  PRINT FLAGS
C         JINTSC    I  INTEGER SCALARS FOR PASSING TO PROCESSING ROUTINE
C         JSCRTC    I  SCRATCH FOR PARTITIONING
C         JSTKPT    I  VECTOR OF POINTERS TO STACK PARAMETER VECTORS
C         STKVEC    I  STACK PARAMETER VECTORS
C         REALSC    R  REAL SCALARS FOR PASSING TO PROCESSING ROUTINE
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         JPTSRT    I  POINT SOURCE TYPE NUMBERS
C         JPTSXC    I  POINT SOURCE X-LOCATION
C         JPTSYC    I  POINT SOURCE Y-LOCATION
C         JPTSZC    I  POINT SOURCE Z-LOCATION
C         XPTSRC    R  POINT SOURCE X-LOCATIONS
C         YPTSRC    R  POINT SOURCE Y-LOCATIONS
C         STKHGT    R  POINT SOURCE STACK HEIGHT (IN STKVEC)
C         STKDIA    R  POINT SOURCE STACK DIAMETER (IN STKVEC)
C         STKTMP    R  POINT SOURCE STACK TEMPERATURE (IN STKVEC)
C         STKVEL    R  POINT SOURCE STACK VELOCITY (IN STKVEC)
C         PLMHGT    R  POINT SOURCE PLUME HEIGHT
C         FLWRAT    R  POINT SOURCE FLOW RATE
C         PARAMS    R  METHOD PARAMETERS
C         VPARAM    R  VERTICAL METHOD PARAMETERS
C         XMETSC    R  METEOROLOGICAL SCALARS
C         MVARBL    I  VARIABLE NAMES
C         MUNITS    I  UNIT NAMES
C         MPTSRC    I  POINT SOURCE NAMES
C         MPTSRT    I  POINT SOURCE TYPE NAMES
C         MPARAM    I  PARAMETER NAMES
C         MVPARM    I  VERTICAL PARAMETER NAMES
C         JMTHDN    I  METHOD NUMBERS
C         JPARMP    I  PARAMETER POINTERS
C         JPARMC    I  PARAMETER COUNTERS
C         JVMTHN    I  VERTICAL METHOD NUMBERS
C         JVPRMP    I  VERTICAL PARAMETER POINTERS
C         JVPRMC    I  VERTICAL PARAMTER COUNTERS
C         OUTGRD    I  PRINT GRID
C         EMSVAL    R  POINT SOURCE EMISSIONS VALUES
C         EMSFAC    R  POINT SOURCE EMISSIONS FACTORS
C         EMSFLX    R  POINT SOURCE EMISSIONS FLUX
C         SMTHMN    R  METHOD MINIMUM
C         SMTHMX    R  METHOD MAXIMUM
C         VMTHMN    R  VERTICAL METHOD MINIMUM
C         VMTHMX    R  VERTICAL METHOD MAXIMUM
C         DIFBRK    R  DIFFUSION BREAK
C         REGTOP    R  REGION TOP
C         TEMPER    R  TEMPERATURE
C         UVECTR    R  WIND U-VECTOR
C         VVECTR    R  WIND V-VECTOR
C
C OUTPUTS --
C         JFLAG
C
C LOCAL VARIABLES --
C
C         NTILEN    I  NUMBER OF WORDS IN TITLE
C         NTIHDR    I  NUMBER OF TIME-INVARIANT HEADERS
C         NTVHDR    I  NUMBER OF TIME VARIANT HEADERS
C         NMETHD    I  NUMBER OF METHODS
C         NVMTHD    I  NUMBER OF VERTICAL METHODS
C         NSGMNT    I  NUMBER OF SEGMENTS
C         NPACKD    I  NUMBER OF WORDS IN PACKED NAME
C         NPARMC    I  NUMBER OF PARAMETERS FOR THIS METHOD
C         NVPRMC    I  NUMBER OF VERTICAL PARAMETERS FOR THIS METHOD
C         NWINDS    I  NUMBER OF WIND VARIABLES
C         NFILSC    I  NUMBER OF WORDS NEEDED BY FILE SCRATCH
C         NFLVAR    I  NUMBER OF VARIABLES FOR FILE WRITE
C         NWORDS    I  NUMBER OF WORDS IN GRID
C         KSTKH     I  POINTER TO STACK HEIGHT IN STACK VECTOR
C         KSTKD     I  POINTER TO STACK DIAMETER IN STACK VECTOR
C         KSTKT     I  POINTER TO STACK TEMPERATURE IN STACK VECTOR
C         KSTKV     I  POINTER TO STACK VELOCITY IN STACK VECTOR
C         KVRBL     I  POINTER TO CURRENT VARIABLE
C         KUNIT     I  POINTER TO CURRENT UNIT
C         KPTSR     I  POINTER TO CURRENT POINT SOURCE
C         KPTST     I  POINTER TO CURRENT POINT SOURCE TYPE
C         KMTHD     I  POINTER TO CURRENT METHOD
C         KPRMP     I  POINTER TO CURRENT PARAMETER
C         KVMTH     I  POINTER TO CURRENT VERTICAL METHOD
C         KVPRP     I  POINTER TO CURRENT VERTICAL PARAMETER
C         KXCLL     I  POINTER TO CURRENT X-CELL
C         KYCLL     I  POINTER TO CURRENT Y-CELL
C         KZCLL     I  POINTER TO CURRENT Z-CELL
C         KTITL     I  POINTER TO CURRENT LOCATION IN TITLE
C         KFRMT     I  POINTER TO CURRENT FORMAT FOR PRINTED GRID OUTPUT
C         KSBTN     I  POINTER TO CURRENT SUBROUTINE
C         JCURDT    I  CURRENT DATE
C         JSTRDT    I  STARTING DATE
C         JSTPDT    I  STOPPING DATE
C         CURTIM    R  CURRENT TIME
C         STRTIM    R  STARTING TIME
C         STPTIM    R  STOPPING TIME
C         ZEROES    R  FLOATING POINT ZERO
C         MHEADR    I  CURRENT PACKET HEADER
C         MCRDID    I  CURRENT CARD IDENTIFICATION
C         MTITLE    I  TITLE OF OUTPUT PRINT GRID
C         MTIHDR    I  TIME-INVARIANT HEADER LIST
C         MTVHDR    I  TIME-VARIANT HEADER LIST
C         MMETHD    I  METHOD NAME LIST
C         MVMTHD    I  VERTICAL METHOD NAME LIST
C         MDFBRK    I  DIFFUSION BREAK VARIABLE NAME
C         MRGTOP    I  REGION TOP VARIABLE NAME
C         MTEMPS    I  TEMPERATURE VARIABLE NAME
C         MMETSC    I  METEOROLOGICAL SCALARS VARIABLE NAMES
C         MWINDS    I  WIND VARIABLE NAMES
C         STKHT     R  STACK HEIGHT (M)
C         STKD      R  STACK DIAMETER (M)
C         VEXIT     R  STACK EFFLUENT VELOCITY (M/S)
C         TEXIT0    R  STACK EFFLUENT TEMPERATURE (K)
C         SCALH     R  MEAN SCALE HEIGHT BETWEEN 1013.25 AND 700 MB
C         ZS        R  ARRAY OF LAYER INTERFACES (M)
C         W         R  ARRAY OF LAYER WINDS (M/S)
C         TEMP      R  ARRAY OF LAYER INTERFACE TEMPERATURE (K)
C         PRESS     R  ARRAY OF LAYER INTERFACE PRESSURE (MB)
C
C
C ROUTINES CALLED --
C         TXTPAK    LEFT JUSTIFIES NAME FIELD
C         COMPAR    COMPARES TWO FIELDS
C         UNITRD    UNITS PACKET
C         PTSRRD    POINT SOURCES PACKET
C         TIMERD    TIME CARD PACKET
C         DFBKRD    READS FROM DIFFUSION BREAK FILE
C         RGTPRD    READS FROM REGION TOP FILE
C         MTSCRD    READS FROM METEOROLOGICAL SCALARS FILE
C         TMPSRD    READS FROM TEMPERATURE FILE
C         WINDRD    READS FROM WIND FILE
C         PSMTHD    METHOD DEFINITION PACKET
C         PSEMRD    CONSTANTS DEFINITION PACKET
C         PSFCRD    GRID VALUES DEFINITION PACKET
C         SPLITC    SPLIT-COMBINATION
C         PTSUSR    USER-SUPPLIED SUBROUTINE
C         STACKH    SETS EMISSIONS POINT AT STACK HEIGHT
C         PLMRIS    CALCULATES HEIGHT OF TOP OF PLUME
C         PTSVUS    USER-SUPPLIED VERTICAL SUBROUTINE
C         FLTMWR    WRITES TIME RECORD
C         FLPVWR    WRITES POINT SOURCE RECORDS
C         SINVAL    INSERTS SINGLE VALUE INTO ALL ARRAY MEMBERS
C         GRIDPR    PRINTS POINT SOURCE GRIDS
C
C ERROR CONDITIONS --
C         -1        NON-POSITIVE NAME LENGTH
C         -2        NON-POSITIVE NUMBER OF VARIABLES
C         -3        NON-POSITIVE NUMBER OF POINT SOURCES
C         -4        NON-POSITIVE NUMBER OF POINT SOURCE TYPES
C         -5        NON-POSITIVE NUMBER OF X-CELLS
C         -6        NON-POSITIVE NUMBER OF Y-CELLS
C         -7        NON-POSITIVE NUMBER OF Z-CELLS
C         -8        INSUFFICIENT SCRATCH STORAGE
C         -11       ERROR IN TXTPAK OF TIME-INVARIANT HEADER
C         -12       ERROR IN COMPAR OF TIME-INVARIANT HEADER
C         -13       NO MATCH OF TIME-INVARIANT HEADER
C         -14       ERROR IN UNITRD
C         -15       ERROR IN PTSRRD
C         -16       ERROR IN FLPIWR
C         -17       ERROR IN TIMERD
C         -18       GAP IN TIMING
C         -21       ERROR IN DFBKRD
C         -22       ERROR IN RGTPRD
C         -24       ERROR IN TMPSRD
C         -25       ERROR IN MTSCRD
C         -26       ERROR IN WINDRD
C         -31       ERROR IN TIME-VARIANT HEADER
C         -32       ERROR IN COMPAR OF TIME-VARIANT HEADER
C         -33       NO MATCH FOR TIME-VARIANT HEADER
C         -42       ERROR IN PSMTHD
C         -43       ERROR IN VERTICAL PSMTHD
C         -44       ERROR IN PSEMRD
C         -45       ERROR IN PSFCRD
C         -52       ILLEGAL METHOD
C         -56       ILLEGAL PARAMETER COUNT ON SPLIT/COMBINATION
C         -57       ILLEGAL PARAMETER POINTER ON SPLIT/COMBINATION
C         -58       ERROR IN SPLITC
C         -63       ILLEGAL PARAMETER COUNT ON USER SUBROUTINE
C         -64       ILLEGAL PARAMETER POINTER ON USER SUBROUTINE
C         -65       ERROR IN PTSUSR
C         -72       ILLEGAL VERTICAL METHOD
C         -73       ERROR IN HTCELL FOR STACK HEIGHT
C         -74       ERROR IN PLMRIS
C         -75       ERROR IN HTCELL FOR PLUME RISE
C         -77       ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE
C         -78       ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTIN
C         -79       ERROR IN PTSVUS
C         -91       ERROR IN FLTMWR
C         -92       ERROR IN FLPVWR
C         -93       ERROR IN SINVAL
C         -94       ERROR IN GRIDPR
C
C OTHER INFORMATION --
C
C
C
C DECLARE PRINT FLAG ARRAY AND MEMBERS
C
      LOGICAL LPRINT
      LOGICAL LINPTP
      LOGICAL LPSEGP
      LOGICAL LUNITP
      LOGICAL LPSLTP
      LOGICAL LPSLMP
      LOGICAL LMTHDP
      LOGICAL LPSRDP
      LOGICAL LVMTHP
      LOGICAL LPGRDP
C
C SET DIMENSIONS ON INPUT VARIABLES
C
      DIMENSION INFILE(6)
      DIMENSION LPRINT(9)
      DIMENSION JINTSC(9)
      DIMENSION JSTKPT(4)
      DIMENSION REALSC(12)
Ctcm  DIMENSION MFILNM(NAMLEN)
      character*4 MFILNM(NAMLEN)
Ctcm  DIMENSION MFILID(NIDLEN)
      character*4 MFILID(NIDLEN)
      DIMENSION JSCRTC(NSCRTC)
      DIMENSION STKVEC(NSCRTC)
      DIMENSION FACMLT(NUNITS)
      DIMENSION FACADD(NUNITS)
      DIMENSION SMOLWT(NUNITS)
      DIMENSION JPTSRT(NPTSRC)
      DIMENSION JPTSXC(NPTSRC)
      DIMENSION JPTSYC(NPTSRC)
      DIMENSION JPTSZC(NPTSRC)
      DIMENSION XPTSRC(NPTSRC)
      DIMENSION YPTSRC(NPTSRC)
      DIMENSION PLMHGT(NPTSRC)
      DIMENSION FLWRAT(NPTSRC)
      DIMENSION PARAMS(NPARAM)
      DIMENSION VPARAM(NVPARM)
      DIMENSION XMETSC(NMETSC)
Ctcm  DIMENSION MVARBL(NAMLEN, NUNITS)
      character*4 MVARBL(NAMLEN, NUNITS)
Ctcm  DIMENSION MUNITS(NAMLEN, NUNITS)
      character*4 MUNITS(NAMLEN, NUNITS)
Ctcm  DIMENSION MPTSRC(NAMLEN, NPTSRC)
      character*4 MPTSRC(NAMLEN, NPTSRC)
Ctcm  DIMENSION MPTSRT(NAMLEN, NPTSRT)
      character*4 MPTSRT(NAMLEN, NPTSRT)
Ctcm  DIMENSION MPARAM(NAMLEN, NPARAM)
      character*4 MPARAM(NAMLEN, NPARAM)
Ctcm  DIMENSION MVPARM(NAMLEN, NVPARM)
      character*4 MVPARM(NAMLEN, NVPARM)
      DIMENSION JMTHDN(NPTSRT, NVARBL)
      DIMENSION JPARMP(NPTSRT, NVARBL)
      DIMENSION JPARMC(NPTSRT, NVARBL)
      DIMENSION JVMTHN(NPTSRT, NVARBL)
      DIMENSION JVPRMP(NPTSRT, NVARBL)
      DIMENSION JVPRMC(NPTSRT, NVARBL)
      DIMENSION OUTGRD(NXCELL, NYCELL)
      DIMENSION EMSVAL(NPTSRC, NVARBL)
      DIMENSION EMSFAC(NPTSRC, NVARBL)
      DIMENSION EMSFLX(NPTSRC, NVARBL)
      DIMENSION SMTHMN(NPTSRT, NVARBL)
      DIMENSION SMTHMX(NPTSRT, NVARBL)
      DIMENSION VMTHMN(NPTSRT, NVARBL)
      DIMENSION VMTHMX(NPTSRT, NVARBL)
      DIMENSION DIFBRK(NXCELL, NYCELL)
      DIMENSION REGTOP(NXCELL, NYCELL)
C
C  NOTE, TEMPER IS ONLY ACTUALLY LARGE ENOUGH FOR 3D ARRAY
C  IF L3DTMP IS TRUE.  OTHERWISE, IT IS REALLY ONLY 
C  TEMPER(NXCELL,NYCELL,1)
      DIMENSION TEMPER(NXCELL, NYCELL, NZCELL)
      DIMENSION UVECTR(NXCELL, NYCELL, NZCELL)
      DIMENSION VVECTR(NXCELL, NYCELL, NZCELL)
C
C SET DIMENSIONS OF LOCAL VARIABLES
C
Ctcm  DIMENSION MTIHDR(10,4)
      character*4 MTIHDR(10,4)
Ctcm  DIMENSION MTVHDR(10,6)
      character*4 MTVHDR(10,6)
Ctcm  DIMENSION MMETHD(10,4)
      character*4 MMETHD(10,4)
Ctcm  DIMENSION MVMTHD(10,3)
      character*4 MVMTHD(10,3)
Ctcm  DIMENSION MHEADR(60)
      character*4 MHEADR(60)
Ctcm  DIMENSION MCRDID(20)
      character*4 MCRDID(20)
Ctcm  DIMENSION MTITLE(60)
      character*4 MTITLE(60)
Ctcm  DIMENSION MDFBRK(10)
      character*4 MDFBRK(10)
Ctcm  DIMENSION MRGTOP(10)
      character*4 MRGTOP(10)
Ctcm  DIMENSION MTEMPS(10)
      character*4 MTEMPS(10)
Ctcm  DIMENSION MMETSC(10,6)
      character*4 MMETSC(10,6)
Ctcm  DIMENSION MWINDS(10,2)
      character*4 MWINDS(10,2)
      DIMENSION TH(20), AVHT(20)
      DIMENSION ZS(20), W(20), TEMP(20), PRESS(20)
C
C COMMON FOR 3D TEMPERATURE FLAG
C
      COMMON /TMPCON/ L3DTMP
      LOGICAL L3DTMP
C
C SET LOCAL SCALARS
C
      DATA NTIHDR /4/
      DATA NTVHDR /6/
      DATA NMETHD /4/
      DATA NVMTHD /3/
      DATA NFLVAR /1/
      DATA NWINDS /2/
      DATA NFILSC /100/
      DATA NTILEN /60/
      DATA KPRML /1/
      DATA KVPRL /1/
      DATA KTITL /50/
      DATA KZCLL /1/
      DATA KTGRB /1/
      DATA KTGRA /2/
      DATA KATPR /6/
      DATA NSGMNT /1/
      DATA ZEROES /0.0/
      DATA DBDEF /1000./
      DATA RTDEF /2000./
      DATA SCALH /8144./
      DATA PI /3.1415927/
C
C SET TIME-INVARIANT PACKET HEADER NAMES
C
      DATA  MTIHDR             /'U','N','I','T','S',' ',' ',' ',' ',' ',
     &                          'P','O','I','N','T','S','O','U','R','C',
     &                          'P','O','I','N','T','S','O','U','R','X',
     &                          'T','I','M','E','I','N','T','E','R','V'/
C
C SET TIME VARIANT PACKET HEADER NAMES
C
      DATA  MTVHDR             /'M','E','T','H','O','D',' ',' ',' ',' ',
     &                          'V','E','R','T','I','C','A','L','M','E',
     &                          'E','M','I','S','S','I','O','N','S','V',
     &                          'E','M','I','S','S','I','O','N','S','X',
     &                          'E','M','I','S','S','I','O','N','S','F',
     &                          'E','N','D','T','I','M','E',' ',' ',' '/
C
C SET METHOD NAMES
C
      DATA  MMETHD             /'E','M','V','A','L','U','E','S',' ',' ',
     &                          'E','M','F','A','C','T','O','R','S',' ',
     &                          'S','P','L','I','T','/','C','O','M','B',
     &                          'U','S','E','R',' ',' ',' ',' ',' ',' '/
C
C SET VERTICAL METHOD NAMES
C
      DATA  MVMTHD             /'S','T','A','C','K','H','G','T',' ',' ',
     &                          'P','L','U','M','E','R','I','S','E',' ',
     &                          'V','E','R','T','U','S','E','R',' ',' '/
C
C SET TITLE
C
      DATA MTITLE /'P', 'O', 'I', 'N', 'T', ' ', 'S', 'O', 'U', 'R',
     $             'C', 'E', ' ', 'E', 'M', 'I', 'S', 'S', 'I', 'O',
     $             'N', 'S', ' ', '(', 'G', 'R', 'A', 'M', '-', 'M',
     $             'O', 'L', 'E', 'S', '/', 'H', 'O', 'U', 'R', ')',
     $             ' ', 'S', 'P', 'E', 'C', 'I', 'E', 'S', ' ', ' ',
     $             ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' '/
C
C SET INPUT FILE VARIABLE NAMES
C
      DATA MDFBRK /'D', 'I', 'F', 'F', 'B', 'R', 'E', 'A', 'K', ' '/
      DATA MRGTOP /'R', 'E', 'G', 'I', 'O', 'N', 'T', 'O', 'P', ' '/
      DATA MTEMPS /'T', 'E', 'M', 'P', 'E', 'R', 'A', 'T', 'U', 'R'/
C
      DATA  MWINDS             /'W','I','N','D','X',' ',' ',' ',' ',' ',
     &                          'W','I','N','D','Y',' ',' ',' ',' ',' '/
C
      DATA  MMETSC             /'T','G','R','A','D','B','E','L','O','W',
     &                          'T','G','R','A','D','A','B','O','V','E',
     &                          'E','X','P','C','L','A','S','S',' ',' ',
     &                          'R','A','D','F','A','C','T','O','R',' ',
     &                          'C','O','N','C','W','A','T','E','R',' ',
     &                          'A','T','M','O','S','P','R','E','S','S'/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C TEST NAME LENGTH FOR POSITIVE VALUE
C
      IF (NAMLEN .LE. 0) GO TO 901
C
C TEST NUMBER OF VARIABLES FOR POSITIVE VALUE
C
      IF (NVARBL .LE. 0) GO TO 902
C
C TEST NUMBER OF POINT SOURCES FOR POSITIVE VALUE
C
      IF (NPTSRC .LE. 0) GO TO 903
C
C TEST NUMBER OF POINT SOURCE TYPES FOR POSITIVE VALUE
C
      IF (NPTSRT .LE. 0) GO TO 904
C
C TEST NUMBER OF X-CELLS FOR POSITIVE VALUE
C
      IF (NXCELL .LE. 0) GO TO 905
C
C TEST NUMBER OF Y-CELLS FOR POSITIVE VALUE
C
      IF (NYCELL .LE. 0) GO TO 906
C
C TEST NUMBER OF Z CELLS FOR POSITIVE VALUE
C
      IF (NZCELL .LE. 0) GO TO 907
C
C TEST AVAILABLE SCRATCH
C
      IF (NSCRTC .LT. MAX0(NAMLEN * NVARBL, NFILSC)) GO TO 908
C
C TAKE APART THE FILE UNIT NUMBER VECTOR
C
      IDFBRK = INFILE(1)
      IRGTOP = INFILE(2)
      ITEMPS = INFILE(4)
      IMETSC = INFILE(5)
      IWINDS = INFILE(6)
C
C TAKE APART THE PRINT FLAG VECTOR
C
      LINPTP = LPRINT(1)
      LPSEGP = LPRINT(2)
      LUNITP = LPRINT(3)
      LPSLTP = LPRINT(4)
      LPSLMP = LPRINT(5)
      LMTHDP = LPRINT(6)
      LPSRDP = LPRINT(7)
      LVMTHP = LPRINT(8)
      LPGRDP = LPRINT(9)
C
C TAKE APART THE STACK PARAMETERS VECTOR POINTERS VECTOR
C
      KSTKH = JSTKPT(1)
      KSTKD = JSTKPT(2)
      KSTKT = JSTKPT(3)
      KSTKV = JSTKPT(4)
C
C TAKE APART THE INTEGER SCALARS VECTOR
C
      INCARD = JINTSC(1)
      IPRINT = JINTSC(2)
      IOUTFL = JINTSC(3)
      NZLOWR = JINTSC(4)
      NZUPPR = JINTSC(5)
      JBEGDT = JINTSC(6)
      JENDDT = JINTSC(7)
      JUTMZN = JINTSC(8)
      JMISSV = JINTSC(9)
C
C TAKE APART THE REAL SCALARS VECTOR
C
      BEGTIM = REALSC( 1)
      ENDTIM = REALSC( 2)
      XUTMOR = REALSC( 3)
      YUTMOR = REALSC( 4)
      XREGOR = REALSC( 5)
      YREGOR = REALSC( 6)
      XCELLD = REALSC( 7)
      YCELLD = REALSC( 8)
      ZHTSUR = REALSC( 9)
      ZMINLW = REALSC(10)
      ZMINUP = REALSC(11)
      RMISSV = REALSC(12)
C
C SET CURRENT DATE AND TIME TO BEGINNING DATE AND TIME
C
      JCURDT = JBEGDT
      CURTIM = BEGTIM
C
C READ AND PRINT A TIME-INVARIANT HEADER CARD
C
  105 READ (INCARD,1105) MHEADR, MCRDID
      WRITE(IPRINT,2105) MHEADR, MCRDID
C
C PACK HEADER AND SET COMPARISON LOOP
C
      CALL TXTPAK(IPRINT, NIDLEN, MHEADR, NPACKD, JFLAG)
      IF (JFLAG .LT. 0) GO TO 911
      DO 110 J = 1, NTIHDR
C
C COMPARE THIS HEADER VALUE WITH THE ACCEPTABLE ONES
C
         CALL COMPAR(IPRINT, NAMLEN, MHEADR, MTIHDR(1,J), JFLAG)
         IF (JFLAG .LT. 0) GO TO 912
         IF (JFLAG .EQ. 0) GO TO 110
C
C SAVE MODULE NUMBER AND SKIP TO TRANSFER
C
         KSBTN = J
         GO TO 115
C
C END LOOP -- IF NO MATCH, TERMINATE
C
  110 CONTINUE
      GO TO 913
C
C TRANSFER TO THE APPROPRIATE SUBROUTINE CALL
C
  115 GO TO (125, 135, 137, 145), KSBTN
C
C UNITS PACKET TO BE PROCESSED
C
  125 CALL UNITRD(INCARD, IPRINT, NAMLEN, NUNITS, LINPTP, LUNITP,
     $    RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MUNITS, JFLAG)
      IF (JFLAG .LT. 0) GO TO 914
C
C GO BACK FOR ANOTHER TIME-INVARIANT HEADER CARD
C
      GO TO 105
C
C POINT SOURCE IDENTIFICATION PACKET TO BE PROCESSED
C
  135 CALL PTSRRD(INCARD, IPRINT, NAMLEN, NUNITS, NPTSRC, NPTSRT,
     $    LINPTP, LPSLTP, XREGOR, YREGOR, XCELLD, YCELLD, RMISSV,
     $    FACMLT, FACADD, SMOLWT, JPTSRT, MVARBL, XPTSRC, YPTSRC,
     $    STKVEC(KSTKH), STKVEC(KSTKD), STKVEC(KSTKT), STKVEC(KSTKV),
     $    MPTSRC, MPTSRT, JFLAG)
      IF (JFLAG .LT. 0) GO TO 915
C
C IF WANTED, WRITE TIME-INVARIANT OUTPUT FILE VECTOR
C
      IF (IOUTFL .LE. 0) GO TO 105
      CALL FLPIWR(IPRINT, IOUTFL, NPTSRC, NSGMNT, XPTSRC, YPTSRC,
     $    STKVEC(KSTKH), STKVEC(KSTKD), STKVEC(KSTKT), STKVEC(KSTKV),
     $    JFLAG)
      IF (JFLAG .LT. 0) GO TO 916
C
C GO BACK FOR ANOTHER TIME-INVARIANT HEADER CARD
C
      GO TO 105
C
C POINT SOURCE IDENTIFICATION PACKET TO BE PROCESSED USING SORT
C
  137 CALL PTSRRX(INCARD, IPRINT, NAMLEN, NUNITS, NPTSRC, NPTSRT,
     $    LINPTP, LPSLTP, XREGOR, YREGOR, XCELLD, YCELLD, RMISSV,
     $    FACMLT, FACADD, SMOLWT, JPTSRT, MVARBL, XPTSRC, YPTSRC,
     $    STKVEC(KSTKH), STKVEC(KSTKD), STKVEC(KSTKT), STKVEC(KSTKV),
     $    MPTSRC, MPTSRT, JFLAG)
      IF (JFLAG .LT. 0) GO TO 915
C
C IF WANTED, WRITE TIME-INVARIANT OUTPUT FILE VECTOR
C
      IF (IOUTFL .LE. 0) GO TO 105
      CALL FLPIWR(IPRINT, IOUTFL, NPTSRC, NSGMNT, XPTSRC, YPTSRC,
     $    STKVEC(KSTKH), STKVEC(KSTKD), STKVEC(KSTKT), STKVEC(KSTKV),
     $    JFLAG)
      IF (JFLAG .LT. 0) GO TO 916
C
C GO BACK FOR ANOTHER TIME-INVARIANT HEADER CARD
C
      GO TO 105
C
C TIME INTERVAL PACKET HEADER -- READ AND CHECK DATES AND TIMES
C
  145 CALL TIMERD(INCARD, IPRINT, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 917
      IF (JSTRDT .EQ. JCURDT .AND. STRTIM .EQ. CURTIM) GO TO 155
      IF (JSTRDT .GT. JCURDT .AND. STRTIM+24.*FLOAT(JSTRDT-JCURDT)
     $                         .EQ. CURTIM) GO TO 155
C
C IF INTERVAL START IS AFTER CURRENT TIME, NOTE ERROR
C
      IF (JSTRDT .GT. JCURDT) GO TO 918
      IF (JSTRDT .EQ. JCURDT .AND. STRTIM .GT. CURTIM) GO TO 918
C
C RESET STARTING DATE AND TIME WITH MESSAGE
C
      WRITE (IPRINT, 2145) JSTRDT, STRTIM, JCURDT, CURTIM
      JSTRDT = JCURDT
      STRTIM = CURTIM
C
C VERIFY THAT ENDING DATE AND TIME ARE WITHIN FILE VALUES
C
  155 IF (JENDDT .GT. JSTPDT) GO TO 165
      IF (JENDDT .EQ. JSTPDT .AND. ENDTIM .GE. STPTIM) GO TO 165
C
C THIS TIME INTERVAL TOO LONG -- RESET TO FILE VALUE WITH MESSAGE
C
      WRITE (IPRINT, 2155) JSTPDT, STPTIM,JENDDT, ENDTIM
      JSTPDT = JENDDT
      STPTIM = ENDTIM
C
C SET CURRENT DATE AND TIME TO THE END OF THIS PACKET INTERVAL
C
  165 JCURDT = JSTPDT
      CURTIM = STPTIM
C
C GET  DIFFUSION BREAK VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IDFBRK .GT. 0)
     $     CALL DFBKRD(IPRINT, IDFBRK, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $         JSTRDT, STRTIM, MDFBRK, JSCRTC, DIFBRK, JFLAG)
      IF (JFLAG .LT. 0) GO TO 921
C
C GET REGION TOP VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IRGTOP .GT. 0)
     $     CALL RGTPRD(IPRINT, IRGTOP, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $         JSTRDT, STRTIM, MRGTOP, JSCRTC, REGTOP, JFLAG)
      IF (JFLAG .LT. 0) GO TO 922
C
C GET TEMPERATURE VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (ITEMPS .GT. 0) THEN
        IF (L3DTMP) THEN
          CALL TMP3RD(IPRINT, ITEMPS, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $        NZCELL, JSTRDT, STRTIM, MTEMPS, JSCRTC, TEMPER, JFLAG)
        ELSE 
          CALL TMPSRD(IPRINT, ITEMPS, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $        JSTRDT, STRTIM, MTEMPS, JSCRTC, TEMPER, JFLAG)
        ENDIF
      ENDIF
      IF (JFLAG .LT. 0) GO TO 924

C
C GET METEOROLOGICAL SCALARS FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IMETSC .GT. 0)
     $     CALL MTSCRD(IPRINT, IMETSC, NAMLEN, NMETSC,
     $         JSTRDT, STRTIM, MMETSC, JSCRTC, XMETSC, JFLAG)
      IF (JFLAG .LT. 0) GO TO 925
C
C GET WIND VECTOR VALUES FOR THE BEGINNING OF THIS TIME PERIOD
C
      IF (IWINDS .GT. 0)
     $     CALL WINDRD(IPRINT, IWINDS, NXCELL, NYCELL,
     $         NZCELL, JSTRDT, STRTIM, STRFHT, XMAXSP, YMAXSP, AVESPW,
     $         AVESPE, AVESPS, AVESPN, UVECTR, VVECTR,
     $         JFLAG)
      IF (JFLAG .LT. 0) GO TO 926
C
C    DEFINE SOME VERTICAL PARAMETERS
C
      KBLOW = 1
      IF (ZHTSUR .GT. 0.) KBLOW = 2
      KELOW = KBLOW + NZLOWR - 1
      KBUPP = KELOW + 1
      KEUPP = NZCELL
      FNZLOW = FLOAT(NZLOWR)
      FNZUP = FLOAT(NZUPPR)
      DZS = ZHTSUR
      DZS2 = ZHTSUR/2.
      ZMINL = FNZLOW*ZMINLW
      ZMINU = FNZUP*ZMINUP
C
C READ AND PRINT A TIME-VARIANT HEADER CARD
C
  205 READ (INCARD,1205) MHEADR, MCRDID
      WRITE(IPRINT,2205) MHEADR, MCRDID
C
C PACK HEADER AND SET COMPARISON LOOP
C
      CALL TXTPAK(IPRINT, NIDLEN, MHEADR, NPACKD, JFLAG)
      IF (JFLAG .LT. 0) GO TO 931
      DO 210 J = 1, NTVHDR
C
C COMPARE THIS HEADER VALUE WITH THE ACCEPTABLE ONES
C
         CALL COMPAR(IPRINT, NAMLEN, MHEADR, MTVHDR(1,J), JFLAG)
         IF (JFLAG .LT. 0) GO TO 932
         IF (JFLAG .EQ. 0) GO TO 210
C
C SET MODULE NUMBER AND SKIP TO TRANSFER
C
         KSBTN = J
         GO TO 215
C
C END LOOP -- IF NO MATCH, TERMINATE
C
  210 CONTINUE
      GO TO 933
C
C TRANSFER TO THE APPROPRIATE SUBROUTINE CALL
C
  215 GO TO (235, 245, 255, 258, 265, 295), KSBTN
C
C METHOD PACKET TO BE PROCESSED
C
  235 CALL MTHDRD(INCARD, IPRINT, NAMLEN, NVARBL, NPTSRT, NMETHD,
     $    NPARAM, KPRML, LINPTP, LMTHDP, RMISSV, FACMLT, FACADD,
     $    SMOLWT,
     $    MVARBL, MPTSRT, MMETHD, PARAMS, MPARAM, JMTHDN, JPARMP,
     $    JPARMC, SMTHMN, SMTHMX, JFLAG)
      IF (JFLAG .LT. 0) GO TO 942
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C VERTICAL METHOD PACKET TO BE PROCESSED
C
  245 CALL MTHDRD(INCARD, IPRINT, NAMLEN, NVARBL, NPTSRT, NVMTHD,
     $    NVPARM, KVPRL, LINPTP, LVMTHP, RMISSV, FACMLT, FACADD,
     $    SMOLWT,
     $    MVARBL, MPTSRT, MVMTHD, VPARAM, MVPARM, JVMTHN, JVPRMP,
     $    JVPRMC, VMTHMN, VMTHMX, JFLAG)
      IF (JFLAG .LT. 0) GO TO 943
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C EMISSIONS VALUES PACKET TO BE PROCESSED
C
  255 CALL PSEMRD(INCARD, IPRINT, NAMLEN, NVARBL, NPTSRC, NPTSRT,
     $    LINPTP, LPSRDP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MPTSRC, MPTSRT, JPTSRT, FLWRAT, EMSVAL,
     $    JFLAG)
      IF (JFLAG .LT. 0) GO TO 944
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C EMISSIONS VALUES PACKET TO BE PROCESSED USING BINARY SEARCH
C
  258 CALL PSEMRX(INCARD, IPRINT, NAMLEN, NVARBL, NPTSRC, NPTSRT,
     $    LINPTP, LPSRDP, RMISSV, FACMLT, FACADD,
     $    SMOLWT, MVARBL, MPTSRC, MPTSRT, JPTSRT, FLWRAT, EMSVAL,
     $    JFLAG)
      IF (JFLAG .LT. 0) GO TO 944
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C EMISSION FACTORS PACKET TO BE PROCESSED
C
  265 CALL PSFCRD(INCARD, IPRINT, NAMLEN, NVARBL, NPTSRC, NPTSRT,
     $    LINPTP, LPSRDP, RMISSV, FACMLT, FACADD, SMOLWT,
     $    MVARBL, MPTSRC, MPTSRT, JPTSRT, EMSFAC, JFLAG)
      IF (JFLAG .LT. 0) GO TO 945
C
C GO BACK FOR NEXT TIME-VARIANT HEADER
C
      GO TO 205
C
C END TIME PACKET TERMINATOR -- SET REVERSE LOOP FOR VARIABLES
C
  295 DO 500 N = 1, NVARBL
         KVRBL = NVARBL - N + 1
C
C FIRST PASS AT SURFACE LEVEL -- SET Y AND X LOOPS
C
         DO 390 J = 1, NPTSRC
            KPTSR = J
            KPSRT = JPTSRT(J)
         IF (KPSRT .EQ. JMISSV) GO TO 951
C
C ISOLATE AND CHECK THE METHOD NUMBER
C
            KMTHD = JMTHDN(KPSRT, KVRBL)
            IF (KMTHD .EQ. 0) GO TO 952
            IF (KMTHD .GT. NMETHD) GO TO 952
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
            GO TO (315, 325, 335, 375), KMTHD
C
C EMISSIONS VALUES -- ASSIGN AS APPROPRIATE AND SKIP TO END OF LOOP
C
  315       EMSFLX(KPTSR, KVRBL) = EMSVAL(KPTSR, KVRBL)
            GO TO 390
C
C EMISSIONS FACTORS -- ASSIGN AS APPROPRIATE AND SKIP TO END OF LOOP
C
  325       EMSFLX(KPTSR, KVRBL) = EMSVAL(KPTSR, KVRBL) *
     $                             EMSFAC(KPTSR, KVRBL)
            GO TO 390
C
C SPLIT/COMBINE -- LOCATE PARAMETERS FOR THIS POINT SOURCE AND VARIABLE
C
  335       NPARMC = JPARMC(KPSRT, KVRBL)
            IF (NPARMC .LT. 1) GO TO 956
            IF (NPARMC .GT. NPARAM) GO TO 956
            KPRMP = JPARMP(KPSRT, KVRBL)
            IF (KPRMP .LT. 1) GO TO 957
            IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 957
C
C CALL THE SPLIT/COMBINE PROCESSING ROUTINE
C
            CALL SPLTPS(IPRINT, NAMLEN, NVARBL, NPTSRC,
     $          NPARMC, KVRBL, KPTSR, RMISSV,
     $          SMTHMN(KPSRT, KVRBL), SMTHMX(KPSRT, KVRBL),
     $          PARAMS(KPRMP), MVARBL, MPTSRC, MPARAM(1, KPRMP),
     $          EMSFLX, JFLAG)
            IF (JFLAG .LT. 0) GO TO 958
C
C SKIP TO END OF INNERMOST LOOP
C
            GO TO 390
C
C USER SUBROUTINE -- LOCATE PARAMETERS FOR THIS POINT SOURCE AND VARIABL
C
  375       NPARMC = JPARMC(KPSRT, KVRBL)
            IF (NPARMC .LT. 1) GO TO 376
            IF (NPARMC .GT. NPARAM) GO TO 963
            KPRMP = JPARMP(KPSRT, KVRBL)
            IF (KPRMP .LT. 1) GO TO 964
            IF (KPRMP .GT. NPARAM - NPARMC + 1) GO TO 964
C
C CALL THE USER SUBROUTINE PROCESSING ROUTINE
C
  376       CALL PTSUSR(INCARD, IPRINT, NAMLEN, NIDLEN,
     $          NPTSRC, NPTSRT, NPARMC, NXCELL, NYCELL, NSCRTC,
     $          JMISSV, JSTRDT, JSTPDT, JUTMZN, STRTIM, STPTIM,
     $          XUTMOR, YUTMOR, XREGOR, YREGOR, XCELLD, YCELLD,
     $          RMISSV, SMTHMN(KPSRT, KVRBL), SMTHMX(KPSRT, KVRBL),
     $          MFILNM, MFILID,
     $          MVARBL(1, KVRBL), INFILE, JSCRTC, JPTSRT(KPTSR),
     $          XPTSRC(KPTSR), YPTSRC(KPTSR), PARAMS(KPRMP), OUTGRD,
     $          EMSVAL(KPTSR, KVRBL), EMSFAC(KPTSR, KVRBL),
     $          EMSFLX(KPTSR, KVRBL), JFLAG)
            IF (JFLAG .LT. 0) GO TO 965
C
C END LOOPS
C
  390    CONTINUE
C
C     ****** CONVERT MISSING VALUES TO ZERO
C
         DO 400 J = 1,NPTSRC
            IF (EMSFLX(J,KVRBL) .LT. 0.) EMSFLX(J,KVRBL) = 0.
  400       CONTINUE
C
  500 CONTINUE
C
C SET POINT SOURCE LOOPS
C
      KVRBL = 1
         DO 590 J = 1, NPTSRC
            KPTSR = J
            KPSRT = JPTSRT(J)
C
C ISOLATE AND CHECK THE METHOD NUMBER
C
            KVMTH = JVMTHN(KPSRT, KVRBL)
            IF (KVMTH .EQ. 0) GO TO 972
            IF (KVMTH .GT. NVMTHD) GO TO 972
C
C TRANSFER TO APPROPRIATE SUBROUTINE CALL FOR THIS METHOD
C
            GO TO (505, 515, 575), KVMTH
C
C EMISSION AT STACK HEIGHT -- SET COORDINATES AND PLUME HEIGHT
C
  505       KXCLL = IFIX((XPTSRC(KPTSR) - XREGOR) / XCELLD) + 1
            KYCLL = IFIX((YPTSRC(KPTSR) - YREGOR) / YCELLD) + 1
C
C    CHECK FOR X AND Y CELLS INSIDE OF REGION
C
            IF (KXCLL .LE. 0 .OR. KXCLL .GT. NXCELL .OR.
     $          KYCLL .LE. 0 .OR. KYCLL .GT. NYCELL) THEN
              WRITE (IPRINT,2504) (MPTSRC(I, KPTSR),I=1,NAMLEN),
     $           KXCLL, KYCLL
              KYCLL = KYCLL + 10000
              GO TO 506
            ENDIF
            PLMHGT(KPTSR) = STKVEC(KSTKH + KPTSR - 1)
            IF (PLMHGT(KPTSR) .EQ. 0.) GO TO 506
C
C  SET DEFAULT FOR DIFBRK AND REGTOP
C
            IF (IDFBRK .GT. 0) THEN
              DBCLL = DIFBRK(KXCLL,KYCLL)
            ELSE
              DBCLL = DBDEF
            ENDIF
            IF (IRGTOP .GT. 0) THEN
              RTCLL = REGTOP(KXCLL,KYCLL)
            ELSE
              RTCLL = RTDEF
            ENDIF
C
C GET Z-CELL NUMBER FOR THIS HEIGHT
C
            CALL HTZCLL(IPRINT, NZCELL, NZLOWR, NZUPPR, JMISSV, ZHTSUR,
     $          ZMINLW, ZMINUP, DBCLL,
     $          RTCLL, PLMHGT(KPTSR), KZCLL, JFLAG)
            IF (JFLAG .LT. 0) GO TO 973
C
C CHECK FOR HEIGHT ABOVE REGION TOP -- IF NOT, SKIP TO END OF LOOP
C
            IF (KZCLL .GT. 0) GO TO 585
C
C WRITE WARNING MESSAGE AND SET FLUX TO ZERO
C
            WRITE (IPRINT, 2505) (MPTSRC(I, KPTSR), I = 1, NAMLEN),
     $           KXCLL, KYCLL, PLMHGT(KPTSR), RTCLL
            DO 5055 K=1, NVARBL
               KVRBL = K
               EMSFLX(KPTSR, KVRBL) = 0.0
 5055       CONTINUE
            KVRBL = 1
C
C SKIP TO END OF INNER LOOP
C
               GO TO 585
C
C SET CELL INDEX TO 1 IF HEIGHT EQUALS ZERO
C
  506       KZCLL = 1
            GO TO 585
C
C PLUME RISE ALGORITHM -- GET CELL COORDINATES
C
  515       KXCLL = IFIX((XPTSRC(KPTSR) - XREGOR) / XCELLD) + 1
            KYCLL = IFIX((YPTSRC(KPTSR) - YREGOR) / YCELLD) + 1
C
C    CHECK FOR X AND Y CELLS INSIDE OF REGION
C
            IF (KXCLL .LE. 0 .OR. KXCLL .GT. NXCELL .OR.
     $          KYCLL .LE. 0 .OR. KYCLL .GT. NYCELL) THEN
              WRITE (IPRINT,2504) (MPTSRC(I, KPTSR),I=1,NAMLEN),
     $           KXCLL, KYCLL
              KYCLL = KYCLL + 10000
              PLMHGT(KPTSR) = 0.
              GO TO 516
            ENDIF
C
C  SET DEFAULT FOR DIFBRK AND REGTOP
C
            IF (IDFBRK .GT. 0) THEN
              DBCLL = DIFBRK(KXCLL,KYCLL)
            ELSE
              DBCLL = DBDEF
            ENDIF
            IF (IRGTOP .GT. 0) THEN
              RTCLL = REGTOP(KXCLL,KYCLL)
            ELSE
              RTCLL = RTDEF
            ENDIF
C
C GET Z-CELL NUMBER FOR THIS HEIGHT
C
            CALL HTZCLL(IPRINT, NZCELL, NZLOWR, NZUPPR, JMISSV, ZHTSUR,
     $          ZMINLW, ZMINUP, DBCLL,
     $          RTCLL,STKVEC(KSTKH+KPTSR-1),KZCLL,JFLAG)
            IF (JFLAG .LT. 0) GO TO 973
            IF (KZCLL .GT. NZCELL) KZCLL = NZCELL
            IF (KZCLL .LT. 1) KZCLL = 1
            CALL VERTCL(NZCELL,KBLOW,KELOW,KBUPP,KEUPP,FNZLOW,FNZUP,
     $         DZS, DZS2, ZMINL, ZMINU,
     $         DBCLL, RTCLL, TH, AVHT)
C
C PREPARE ARRAYS FOR INPUT TO BEH084; CONVERT UNITS TO MKS
C ASSUME DP/DZ EQUALS -0.1 MB/M
C
            IF (L3DTMP) THEN
              TSFC = TEMPER(KXCLL,KYCLL,1) 
     $               - AVHT(1)*(TEMPER(KXCLL,KYCLL,2)
     $               -TEMPER(KXCLL,KYCLL,1))/(AVHT(2)-AVHT(1))
            ELSE
              TSFC = TEMPER(KXCLL,KYCLL,1)
            ENDIF
C
            PSFC = 1013.25*XMETSC(KATPR)
            DO 550 K = 1,NZCELL
               ZS(K) = TH(K)
               IF (K.GT.1) ZS(K) = ZS(K-1) + TH(K)
               W(K) = SQRT(UVECTR(KXCLL,KYCLL,K)**2 
     &                   + VVECTR(KXCLL,KYCLL,K)**2)/3600.
               PRESS(K) = PSFC*EXP(-ZS(K)/SCALH)
  550       CONTINUE   
C
            IF (L3DTMP) THEN
              DO 552 K = 1,NZCELL-1
                TEMP(K) = TEMPER(KXCLL,KYCLL,K)
     $               + (ZS(K)-AVHT(K))*(TEMPER(KXCLL,KYCLL,K+1)
     $               -TEMPER(KXCLL,KYCLL,K))/(AVHT(K+1)-AVHT(K))
  552         CONTINUE   
              TEMP(NZCELL) = TEMPER(KXCLL,KYCLL,NZCELL)
     $             + (ZS(NZCELL)-AVHT(NZCELL))
     $             *(TEMPER(KXCLL,KYCLL,NZCELL)
     $             -TEMPER(KXCLL,KYCLL,NZCELL-1))
     $             /(AVHT(NZCELL)-AVHT(NZCELL-1))
            ELSE
              DO 554 K = 1,NZCELL
                TEMP(K) = TSFC + AMIN1(ZS(K),DBCLL)*XMETSC(KTGRB)
     &                    + AMAX1(ZS(K)-DBCLL,0.)*XMETSC(KTGRA)
  554         CONTINUE   
            ENDIF
C
            STKHT  = STKVEC(KSTKH+KPTSR-1)
            STKD   = STKVEC(KSTKD+KPTSR-1)
            IF (FLWRAT(KPTSR) .LE. 0.) THEN
              VEXIT  = STKVEC(KSTKV+KPTSR-1)/3600.
            ELSE
              VEXIT  = FLWRAT(KPTSR)/(3600.*PI*(STKD*0.5)**2)
            ENDIF
            TEXIT0 = STKVEC(KSTKT+KPTSR-1)
C
C CALL THE PLUME RISE ROUTINE
C
            CALL BEH084(STKHT,STKD,VEXIT,TEXIT0,TSFC,PSFC,
     &              ZS,AVHT,W,TEMP,PRESS,NZCELL,KPTSR,PLMHGT(KPTSR))
C
C GET Z-CELL NUMBER FOR THIS HEIGHT
C
            IF (PLMHGT(KPTSR) .EQ. 0.) GO TO 516
            CALL HTZCLL(IPRINT, NZCELL, NZLOWR, NZUPPR, JMISSV, ZHTSUR,
     $          ZMINLW, ZMINUP, DBCLL,
     $          RTCLL, PLMHGT(KPTSR), KZCLL, JFLAG)
            IF (JFLAG .LT. 0) GO TO 975
C
C CHECK FOR HEIGHT ABOVE REGION TOP -- IF NOT, SKIP TO END OF LOOP
C
            IF (KZCLL .GT. 0) GO TO 585
C
C WRITE WARNING MESSAGE AND SET FLUX TO ZERO
C
            WRITE (IPRINT, 2515) (MPTSRC(I, KPTSR), I = 1, NAMLEN),
     $           KXCLL, KYCLL, PLMHGT(KPTSR), RTCLL
            DO 5155 K=1,NVARBL
               KVRBL = K
               EMSFLX(KPTSR, KVRBL) = 0.0
 5155       CONTINUE
            KVRBL = 1
C
C SKIP TO END OF INNER LOOP
C
               GO TO 585
C
C SET CELL INDEX TO 1 IF HEIGHT EQUALS ZERO
C
  516       KZCLL = 1
            GO TO 585
C
C USER VERT. SUBROUTINE -- LOCATE PARAMETERS FOR THIS POINT SOURCE AND V
C
  575       NVPRMC = JVPRMC(KPSRT, KVRBL)
            IF (NVPRMC .LT. 1) GO TO 576
            IF (NVPRMC .GT. NVPARM) GO TO 977
            KVPRP = JVPRMP(KPSRT, KVRBL)
            IF (KVPRP .LT. 1) GO TO 978
            IF (KVPRP .GT. NVPARM - NVPRMC + 1) GO TO 978
C
C CALL THE USER VERT. SUBROUTINE PROCESSING ROUTINE
C
C SUBROUTINE CALL REMOVED BY PDA 11/3/86
C      (NULL SUBROUTINE)
C
  576 CONTINUE
C 576       CALL PTSVUS(INCARD, IPRINT, NAMLEN, NIDLEN, NPTSRC,
C    $          NPTSRT, NVPRMC, NXCELL, NYCELL,
C    $          NZCELL, NZLOWR, NZUPPR, NSCRTC, KPTSR,
C    $          NVPRMC, KZCLL, JSTRDT, JSTPDT, JUTMZN, JMISSV,
C    $          STRTIM, STPTIM, XUTMOR, YUTMOR, XREGOR,
C    $          YREGOR, XCELLD, YCELLD, ZHTSUR,
C    $          ZMINLW, ZMINUP, RMISSV, VMTHMN(KPSRT, KVRBL),
C    $          VMTHMX(KPSRT, KVRBL), MFILNM, MFILID,
C    $          MVARBL(1, KVRBL), INFILE, JSCRTC,
C    $          JPTSRT(KPTSR), JPTSXC(KPTSR), JPTSYC(KPTSR),
C    $          JPTSZC(KPTSR), XMETSC,
C    $          STKVEC(KSTKH + KPTSR - 1), STKVEC(KSTKD + KPTSR - 1),
C    $          STKVEC(KSTKT + KPTSR - 1), STKVEC(KSTKV + KPTSR - 1),
C    $          FLWRAT(KPTSR), VPARAM(KVPRP),
C    $          DIFBRK, REGTOP, TEMPER, UVECTR, VVECTR, OUTGRD,
C    $          EMSVAL(KPTSR, KVRBL), EMSFAC(KPTSR, KVRBL),
C    $          EMSFLX(KPTSR, KVRBL), PLMHGT(KPTSR), JFLAG)
C           IF (JFLAG .LT. 0) GO TO 979
C
C SAVE EMISSIONS INJECTION CELL
C
  585       JPTSXC(KPTSR) = KXCLL
            JPTSYC(KPTSR) = KYCLL
            JPTSZC(KPTSR) = KZCLL
C     UV2=SQRT(UU**2+VV**2)/3600.
C     UVX=UU/3600.
C     UVY=VV/3600.
C     VFMT=FLWRAT(KPTSR)/3600.
C     VVMT=STKVEC(KSTKV+KPTSR-1)/3600.
C     WRITE(*,1379) JCURDT,CURTIM,KPTSR,KXCLL,KYCLL,KZCLL,
C    &PLMHGT(KPTSR),VFMT,STKVEC(KSTKH+KPTSR-1),STKVEC(KSTKD+KPTSR-1),
C    &STKVEC(KSTKT+KPTSR-1),VVMT,XMETSC(KTGRB),XMETSC(KTGRA),UVX,UVY,
C    &UV2,NZCELL,NZLOWR,NZUPPR,ZHTSUR,ZMINLW,ZMINUP,DIFBRK(KXCLL,KYCLL),
C    &REGTOP(KXCLL,KYCLL),EMSFLX(KPTSR,1),EMSFLX(KPTSR,2),
C    &EMSFLX(KPTSR,3),EMSFLX(KPTSR,4),EMSFLX(KPTSR,5),EMSFLX(KPTSR,6),
C    &EMSFLX(KPTSR,7),EMSFLX(KPTSR,8)
C1379 FORMAT(I6,F10.2,I5,3I3,F6.1,5F8.2,2F8.6,3F5.2,3I3,5F7.1,
C    &10F8.1)
C
C END ALL LOOPS
C
  590    CONTINUE
C
C IF THE OUTPUT FILE IS TO BE WRITTEN, PUT OUT THE TIME RECORD
C
      IF (IOUTFL .LE. 0) GO TO 705
      CALL FLTMWR(IPRINT, IOUTFL, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 991
C
C WRITE THE POINT SOURCE RECORD
C
      WRITE (*,3710) JCURDT, CURTIM
 3710 FORMAT( ' CURRENT DATE AND TIME  -- ',I6, F10.2)
      CALL FLPVWR(IPRINT, IOUTFL, NAMLEN, NSPECS, NPTSRC, NSGMNT,
     $    JPTSXC, JPTSYC, JPTSZC, FLWRAT, PLMHGT,
     $    MVARBL, EMSFLX, JFLAG)
      IF(JFLAG .LT. 0) GO TO 992
C
C IF PRINTOUT IS WANTED, SET VARIABLE LOOP
C
  705 IF (.NOT. LPSEGP) GO TO 735
      KZCLL = 0
      DO 730 N = 1, NVARBL
         KVRBL = N
C
C LOAD VARIABLE NAME INTO TITLE
C
         DO 710 I = 1, NAMLEN
            MTITLE(I + KTITL) = MVARBL(I,KVRBL)
  710    CONTINUE
C
C WRITE TABLE HEADING
C
         WRITE (IPRINT, 2710) MTITLE
C
C SET OUTPUT GRID TO ZERO
C
         NWORDS = NXCELL * NYCELL
         CALL SINVAL(IPRINT, NWORDS, ZEROES, OUTGRD, JFLAG)
         IF (JFLAG .LT. 0) GO TO 993
C
C SET LOOP TO FILL GRID AND GET CELL LOCATION
C
         DO 720 K = 1, NPTSRC
      KPTSR = K
            KXCLL = JPTSXC(KPTSR)
            KYCLL = JPTSYC(KPTSR)
C
C    CHECK FOR X AND Y CELLS INSIDE OF REGION
C
            IF (KXCLL .LE. 0 .OR. KXCLL .GT. NXCELL .OR.
     $          KYCLL .LE. 0 .OR. KYCLL .GT. NYCELL) GO TO 720
C
C TEST FOR VALUE AND STASH IN GRID CELL
C
            IF (EMSFLX(KPTSR, KVRBL) .LE. 0.0001) GO TO 720
            OUTGRD(KXCLL, KYCLL) = OUTGRD(KXCLL, KYCLL) +
     $                             EMSFLX(KPTSR, KVRBL)
C
C PRINT TABLE ENTRY AND END LOOP
C
            IF (EMSFLX(K, KVRBL) .LT. 0.1) GO TO 720
            KPTST = JPTSRT(KPTSR)
            WRITE(IPRINT, 2720) (MPTSRC(I , KPTSR), I = 1, NAMLEN),
     $          (MPTSRT(I, KPTST), I = 1, NAMLEN), JPTSXC(K), JPTSYC(K),
     $          JPTSZC(K), FLWRAT(K), PLMHGT(K), EMSVAL(K, KVRBL),
     $          EMSFAC(K, KVRBL), EMSFLX(K, KVRBL)
  720    CONTINUE
C
C CALL THE GRID PRINT ROUTINE WITH 10F10.4 FORMAT, 30 LINES PER PAGE
C
         IF (.NOT.LPGRDP) GO TO 730
         KFRMT = 124
         CALL GRIDPR(IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL,
     $       NYCELL, KZCLL, KFRMT, JSTRDT, JSTPDT, STRTIM,
     $       STPTIM, MFILNM, MFILID, MTITLE, OUTGRD, JFLAG)
         IF (JFLAG .LT. 0) GO TO 994
C
C END LOOP
C
  730 CONTINUE
C
C SEE WHETHER THIS PACKET ENDS THE FILE -- IF NOT, GET NEXT PACKET
C
  735 IF (JSTPDT .NE. JENDDT) GO TO 105
      IF (STPTIM .NE. ENDTIM) GO TO 105
C
C REWIND ALL OPEN FILES
C
C     IF (IOUTFL .GT. 0) REWIND IOUTFL
C     IF (IDFBRK .GT. 0) REWIND IDFBRK
C     IF (IRGTOP .GT. 0) REWIND IRGTOP
C     IF (ITEMPS .GT. 0) REWIND ITEMPS
C     IF (IMETSC .GT. 0) REWIND IMETSC
C     IF (IWINDS .GT. 0) REWIND IWINDS
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NAME LENGTH
C
  901 WRITE (IPRINT, 2901) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF VARIABLES
C
  902 WRITE (IPRINT, 2902) NVARBL
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF POINT SOURCES
C
  903 WRITE (IPRINT, 2903) NPTSRC
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF POINT SOURCE TYPES
C
  904 WRITE (IPRINT, 2904) NPTSRT
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF X-CELLS
C
  905 WRITE (IPRINT, 2905) NXCELL
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF Y-CELLS
C
  906 WRITE (IPRINT, 2906) NYCELL
      JFLAG = -6
      GO TO 1000
C
C ERROR MESSAGE FOR NON-POSITIVE NUMBER OF Z-CELLS
C
  907 WRITE (IPRINT, 2907) NZCELL
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR INSUFFICIENT SCRATCH STORAGE FOR FILES
C
  908 WRITE (IPRINT, 2908) NSCRTC
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TXTPAK OF TIME-INVARIANT HEADER
C
  911 WRITE (IPRINT, 2911) JFLAG
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COMPAR OF TIME-INVARIANT HEADER
C
  912 WRITE (IPRINT, 2912) JFLAG
      JFLAG = -12
      GO TO 1000
C
C ERROR MESSAGE FOR NO MATCH OF TIME-INVARIANT HEADER
C
  913 WRITE (IPRINT, 2913) (MHEADR(I), I=1, NAMLEN)
      JFLAG = -13
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN UNITRD
C
  914 WRITE (IPRINT, 2914) JFLAG
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN PTSRRD
C
  915 WRITE (IPRINT, 2915) JFLAG
      JFLAG = -15
      GO TO 1000
C
C ERROR MESAGE FOR ERROR IN FLPIWR
C
  916 WRITE (IPRINT, 2916) JFLAG
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TIMERD
C
  917 WRITE (IPRINT, 2917) JFLAG
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR GAP IN TIMING
C
  918 WRITE (IPRINT, 2918) JCURDT, CURTIM, JSTRDT, STRTIM
      JFLAG = -18
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN DFBKRD
C
  921 WRITE (IPRINT, 2921) JFLAG
      JFLAG = -21
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN RGTPRD
C
  922 WRITE (IPRINT, 2922) JFLAG
      JFLAG = -22
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TMPSRD
C
  924 WRITE (IPRINT, 2924) JFLAG
      JFLAG = -24
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MTSCRD
C
  925 WRITE (IPRINT, 2925) JFLAG
      JFLAG = -25
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN WINDRD
C
  926 WRITE (IPRINT, 2926) JFLAG
      JFLAG = -26
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN TIME-VARIANT HEADER
C
  931 WRITE (IPRINT, 2931) JFLAG
      JFLAG = -31
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN COMPAR OF TIME-VARIANT HEADER
C
  932 WRITE (IPRINT, 2932) JFLAG
      JFLAG = -32
      GO TO 1000
C
C ERROR MESSAGE FOR NO MATCH FOR TIME-VARIANT HEADER
C
  933 WRITE (IPRINT, 2933) (MHEADR(I), I = 1,NAMLEN)
      JFLAG = -33
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN PSMTHD
C
  942 WRITE (IPRINT, 2942) JFLAG
      JFLAG = -42
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN VERTICAL PSMTHD
C
  943 WRITE (IPRINT, 2943) JFLAG
      JFLAG = -43
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN PSEMRD
C
  944 WRITE (IPRINT, 2944) JFLAG
      JFLAG = -44
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN PSFCRD
C
  945 WRITE (IPRINT, 2945) JFLAG
      JFLAG = -45
      GO TO 1000
C
C ERRONEOUS POINT SOURCE TYPE NUMBER
C
  951 WRITE (IPRINT, 2951) KPTSR, (MPTSRC(I, KPTSR), I = 1, 10), KPSRT
      JFLAG = -51
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL METHOD
C
  952 WRITE (IPRINT, 2952) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -52
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON SPLIT/COMBINATION
C
  956 WRITE (IPRINT, 2956) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -56
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON SPLIT/COMBINATION
C
  957 WRITE (IPRINT, 2957) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -57
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SPLITC
C
  958 WRITE (IPRINT, 2958) JFLAG
      JFLAG = -58
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER SUBROUTINE
C
  963 WRITE (IPRINT, 2963) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -63
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER SUBROUTINE
C
  964 WRITE (IPRINT, 2964) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), KMTHD, NPARAM
      JFLAG = -64
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN PTSUSR
C
  965 WRITE (IPRINT, 2965) JFLAG
      JFLAG = -65
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL VERTICAL METHOD
C
  972 WRITE (IPRINT, 2972) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -72
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN HTCELL FOR STACK HEIGHT
C
  973 WRITE (IPRINT, 2973) JFLAG
      JFLAG = -73
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN PLMRIS
C
  974 WRITE (IPRINT, 2974) JFLAG
      JFLAG = -74
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN HTCELL FOR PLUME RISE
C
  975 WRITE (IPRINT, 2975) JFLAG
      JFLAG = -75
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER COUNT ON USER VERTICAL SUBROUTINE
C
  977 WRITE (IPRINT, 2977) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), NVRPMC, NVPARM
      JFLAG = -77
      GO TO 1000
C
C ERROR MESSAGE FOR ILLEGAL PARAMETER POINTER ON USER VERTICAL SUBROUTIN
C
  978 WRITE (IPRINT, 2978) (MVARBL(I,KVRBL), I =1,NAMLEN),
     $     (MPTSRT(I,KPTSR), I = 1,NAMLEN), KVMTH, NVPARM
      JFLAG = -78
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN PTSVUS
C
  979 WRITE (IPRINT, 2979) JFLAG
      JFLAG = -79
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLTMWR
C
  991 WRITE (IPRINT, 2991) JFLAG
      JFLAG = -91
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN FLPVWR
C
  992 WRITE (IPRINT, 2992) JFLAG
      JFLAG = -92
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN SINVAL
C
  993 WRITE (IPRINT, 2993) JFLAG
      JFLAG = -93
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN GRIDPR
C
  994 WRITE (IPRINT, 2994) JFLAG
      JFLAG = -94
      GO TO 1000
C
C RETURN TO CALLING PROGRAM
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (60A1, 20A1)
 1205 FORMAT (60A1, 20A1)
 2105 FORMAT (1X, 60A1, 20A1)
 2205 FORMAT (1X, 60A1, 20A1)
 2145 FORMAT (38H ****** NOTE ****** THE STARTING DATE , I10,
     $        10H AND TIME , F10.2, 16H FOR THIS PACKET , //,
     $        33H ARE PRIOR TO THE STARTING DATE , I10, 10H AND TIME ,
     $        F10.2, 14H FOR THIS FILE , //, 21H THE PACKET DATE AND ,
     $        46HTIME HAVE BEEN RESET TO THE FILE DATE AND TIME , //)
 2155 FORMAT (38H ****** NOTE ****** THE STOPPING DATE , I10,
     $        10H AND TIME , F10.2, 16H FOR THIS PACKET , //,
     $        29H ARE AFTER THE STOPPING DATE , I10, 10H AND TIME ,
     $        F10.2, 14H FOR THIS FILE , //, 21H THE PACKET DATE AND ,
     $        46HTIME HAVE BEEN RESET TO THE FILE DATE AND TIME , //)
 2504 FORMAT (1X, 32H****** NOTE ****** POINT SOURCE ,
     $        10A1, 10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        24H IS OUTSIDE THE REGION  ,/,
     $        50H EMISSIONS FROM THIS SOURCE WILL NOT BE INCLUDED. ,//)
 2505 FORMAT (1X, 47H****** NOTE ****** EMISSIONS FROM POINT SOURCE ,
     $        10A1, 10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        24H HAVE A STACK HEIGHT OF , F10.2,
     $        41H.  THIS IS ABOVE THE REGION TOP VALUE OF , F10.2, //,
     $        50H EMISSIONS FROM THIS SOURCE HAVE BEEN SET TO ZERO ,//)
 2515 FORMAT (1X, 47H****** NOTE ****** EMISSIONS FROM POINT SOURCE ,
     $        10A1, 10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        24H HAVE A PLUME HEIGHT OF , F10.2,
     $        41H.  THIS IS ABOVE THE REGION TOP VALUE OF , F10.2, //,
     $        50H EMISSIONS FROM THIS SOURCE HAVE BEEN SET TO ZERO ,//)
 2710 FORMAT (1H1, 20X, 60A1, ///, 31H PT. SOURCE     PT. SOURCE     ,
     $        50HX-CELL  Y-CELL  Z-CELL   FLOW RATE      PLUME HGT.,
     $        44H     EMS. VALUE     EMS. FACTOR    EMS. FLUX, /,
     $        25H    NAME        TYPE NAME, 30X, 11H(M**3/HOUR), 6X,
     $        8H(METERS), 6X, 25H(G-MOL/HR)     (G-MOL/HR) , ///)
 2720 FORMAT (1X, 2(10A1, 5X), 3(I4, 4X), F10.0, 5X, F10.4, 5X,
     $        3(F10.2, 5X) )
 2901 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        22H NAME LENGTH VALUE IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2902 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        24H NUMBER OF VARIABLES IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2903 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        28H NUMBER OF POINT SOURCES IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2904 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        33H NUMBER OF POINT SOURCE TYPES IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2905 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN X-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2906 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN Y-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2907 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        35H NUMBER OF CELLS IN Z-DIRECTION IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2908 FORMAT (1H1, 27H****** SYSTEM ERROR ****** ,
     $        41H NUMBER OF WORDS OF SCRATCH STORAGE IS , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2911 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TXTPAK , //,
     $        44H DURING READ OF TIME-INVARIANT PACKET HEADER, //)
 2912 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE COMPAR , //,
     $        44H DURING READ OF TIME-INVARIANT PACKET HEADER, //)
 2913 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H PACKET HEADER , 10A1, //, 23H DOES NOT MATCH ANY OF ,
     $        47HTHE ALLOWABLE NAMES FOR TIME-INVARIANT HEADERS   , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2914 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE UNITRD , //)
 2915 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE PTSRRD , //)
 2916 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE FLPIWR , //)
 2917 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TIMERD , //)
 2918 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        39H THE PREVIOUS PACKET STOPPED WITH DATE, I10,
     $        10H AND TIME , F10.2, //, 25H THIS PACKET STARTS WITH ,
     $        5HDATE , I10, 10H AND TIME , F10.2, //, 11H.  PACKETS ,
     $        47HMUST FOLLOW CONSECUTIVELY IN TIME, WITH NO GAPS, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2921 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE DFBKRD , //)
 2922 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE RGTPRD , //)
 2924 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TMPSRD , //)
 2925 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE MTSCRD , //)
 2926 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE WINDRD , //)
 2931 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE TXTPAK , //,
     $        42H DURING READ OF TIME-VARIANT PACKET HEADER, //)
 2932 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE STACKH , //,
     $        42H DURING READ OF TIME-VARIANT PACKET HEADER, //)
 2933 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        15H PACKET HEADER , 10A1, //, 23H DOES NOT MATCH ANY OF ,
     $        45HTHE ALLOWABLE NAMES FOR TIME-VARIANT HEADERS   , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2942 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE PSMTHD , //)
 2943 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        46H WAS RETURNED FROM SUBROUTINE VERTICAL PSMTHD , //)
 2944 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE PSEMRD , //)
 2945 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE PSFCRD , //)
 2951 FORMAT(1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        20HPOINT SOURCE NUMBER , I10,2H, ,10A1, 1X, //, 1X,
     $        29HHAS POINT SOURCE TYPE NUMBER , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2952 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        32H THE METHOD NUMBER FOR VARIABLE , 10A1,
     $        17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2956 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER COUNTER FOR VARIABLE , 10A1,
     $        17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2957 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        47H THE SPLIT-COMB PARAMETER POINTER FOR VARIABLE , 10A1,
     $        17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2958 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE SPLITC , //)
 2963 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER COUNTER FOR VARIABLE ,10A1,
     $        17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2964 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE USER ROUTINE PARAMETER POINTER FOR VARIABLE ,10A1,
     $        17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2965 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE PTSUSR , //)
 2972 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        41H THE VERTICAL METHOD NUMBER FOR VARIABLE , 10A1,
     $        17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2973 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE HTZCLL ,
     $        18H FOR STACK HEIGHT , //)
 2974 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE PLMRIS , //)
 2975 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE HTZCLL ,
     $        18H FOR PLUME HEIGHT, //)
 2977 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        57H THE USER VERTICAL ROUTINE PARAMETER COUNTER FOR VARIAB
     $        10A1, 17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2978 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        57H THE USER VERTICAL ROUTINE PARAMETER POINTER FOR VARIAB
     $        10A1, 17H IN POINT SOURCE , 10A1, //, 4H IS , I10,
     $        37H.  THIS NUMBER MUST BE BETWEEN 1 AND , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2979 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE PTSVUS , //)
 2991 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE FLTMWR , //)
 2992 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE FLPVWR , //)
 2993 FORMAT (39H ****** ERROR TRACE ****** ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE SINVAL , //)
 2994 FORMAT (39H ****** ERROR TRACE ******  ERROR FLAG , I10,
     $        37H WAS RETURNED FROM SUBROUTINE GRIDPR , //)
      END
