      SUBROUTINE PTSRRD (INCARD, IPRINT, NAMLEN, NUNITS, NPTSRC,
     $   NPTSRT, LINPTP, LPTSRP, XREGOR, YREGOR, XCELLD, YCELLD,
     $   RMISSV, FACMLT, FACADD, SMOLWT, JPTSRT, MVARBL, XPTSRL, YPTSRL,
     $   STKHGT, STKDIA, STKTMP, STKVEL, MPTSRC, MPTSRT, JFLAG)
      SAVE
C     COMMON/STIME/STIME,PRETIM
C
C NAME -- POINT SOURCE IDENTIFICATION PACKET READ
C
C DESCRIPTION -- READS THE POINT SOURCE IDENTIFICATION PACKET AS PART OF
C                TIME-INVARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C    MODIFICATION  DAMON BLOM ARB 10/17/86
C    STORE NAME DIRECTLY
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NUNITS    I  NUMBER OF UNITS
C         NPTSRC    I  NUMBER OF POINT SOURCES
C         NPTSRT    I  NUMBER OF POINT SOURCE TYPES
C         LINPTP    I  INPUT PRINT FLAG
C         LPTSRP    I  POINT SOURCES TABLE PRINT FLAG
C         XREGOR    R  X-COORDINATE OF MODELING REGION
C         YREGOR    R  Y-COORDINATE OF MODELING REGION
C         XCELLD    R  CELL DISTANCE IN X-DIRECTION
C         YCELLD    R  CELL DISTANCE IN Y-DIRECTION
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         JPTSRT    I POINT SOURCE TYPE NUMBERS
C         MVARBL    I  VARIABLE NAMES
C
C OUTPUTS --
C         XPTSRL    R  POINT SOURCE LOCATION X-COORDINATE
C         YPTSRL    R  POINT SOURCE LOCATION Y-COORDINATE
C         STKHGT    R  STACK HEIGHT
C         STKDIA    R  STACK DIAMETER
C         STKTMP    R  STACK EXIT TEMPERATURE
C         STKVEL    R  STACK EXIT VELOCITY
C         MPTSRC    I  POINT SOURCE NAMES
C         MPTSRT    I  POINT SOURCE TYPE NAMES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         KCOOR     I  POINTER TO 'COORD' IN VARIABLE NAME LIST
C         KHGHT     I  POINTER TO 'HEIGHT' IN VARIABLE NAME LIST
C         KDIAM     I  POINTER TO 'DIAMETER' IN VARIABLE NAME LIST
C         KTEMP     I  POINTER TO 'STACKTEMP' IN VARIABLE NAME LIST
C         KVLCT     I  POINTER TO 'STACKVEL' IN VARIABLE NAME LIST
C         KPTSR     I  POINTER TO POINT SOURCE NAME
C         MENDPS    I  PACKET TRAILER NAME
C         MPTSNM    I  INPUT POINT SOURCE NAME
C         MPTTNM    I  INPUT POINT SOURCE TYPE NAME
C         MCOORD    I  REFERENCE NAME FOR 'COORD'
C         MSTHGT    I  REFERENCE NAME FOR 'HEIGHT'
C         MSTDIA    I  REFERENCE NAME FOR 'DIAMETER'
C         MSTTMP    I  REFERENCE NAME FOR 'STACKTEMP'
C         MSTVEL    I  REFERENCE NAME FOR 'STACKVEL'
C         MBLANK    I  BLANK CHARACTER
C         MCRDID    I  CARD IDENTIFICATION
C         PTSRXL    R  X-LOCATION OF POINT SOURCE
C         PTSRYL    R  Y-LOCATION OF POINT SOURCE
C         HGTSTK    R  INPUT STACK HEIGHT
C         DIASTK    R  INPUT STACK DIAMETER
C         TMPSTK    R  INPUT STACK TEMPERATURE
C         VELSTK    R  INPUT STACK VELOCITY
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -8        'COORD' NOT IN VARIABLE NAME LIST
C         -10       'HEIGHT' NOT IN VARIABLE NAME LIST
C         -12       'DIAMETER' NOT IN VARIABLE NAME LIST
C         -14       'STACKTEMP' NOT IN VARIABLE NAME LIST
C         -16       'STACKVEL' NOT IN VARIABLE NAME LIST
C         -18       BLANK NAME
C         -21       NO SPACE FOR NEW POINT SOURCE NAME
C         -23       BLANK NAME
C         -25       NO SPACE FOR NEW POINT SOURCE TYPE NAME
C
C  OTHER INFORMATION
C  
C  --  CORRECTED UNITS LABELS FOR X-LOC, Y-LOC, AND STACK VEL IN
C      FORMAT 2210 (TCM, 3/24/94)
C
C DECLARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LPTSRP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NUNITS)
      DIMENSION FACADD(NUNITS)
      DIMENSION SMOLWT(NUNITS)
      DIMENSION JPTSRT(NPTSRC)
      DIMENSION XPTSRL(NPTSRC)
      DIMENSION YPTSRL(NPTSRC)
      DIMENSION STKHGT(NPTSRC)
      DIMENSION STKDIA(NPTSRC)
      DIMENSION STKTMP(NPTSRC)
      DIMENSION STKVEL(NPTSRC)
Ctcm  DIMENSION MVARBL(NAMLEN,NUNITS)
      character*4 MVARBL(NAMLEN,NUNITS)
Ctcm  DIMENSION MPTSRC(NAMLEN,NPTSRC)
      character*4 MPTSRC(NAMLEN,NPTSRC)
Ctcm  DIMENSION MPTSRT(NAMLEN, NPTSRT)
      character*4 MPTSRT(NAMLEN, NPTSRT)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MENDPS(10), MPTSNM(10), MCOORD(10), MSTHGT(10)
      character*4 MENDPS(10), MPTSNM(10), MCOORD(10), MSTHGT(10)
Ctcm  DIMENSION MCRDID(20), MPTTNM(10), MSTDIA(10), MSTTMP(10)
      character*4 MCRDID(20), MPTTNM(10), MSTDIA(10), MSTTMP(10)
Ctcm  DIMENSION MSTVEL(10)
      character*4 MSTVEL(10)
      character*4 MBLANK
C
C DECLARE PACKET TRAILER, DISTANCE, AND STACK UNIT NAMES
C
      DATA MENDPS /'E', 'N', 'D', 7*' '/
      DATA MCOORD /'C', 'O', 'O', 'R', 'D', ' ', ' ', ' ', ' ', ' '/
      DATA MSTHGT /'H', 'E', 'I', 'G', 'H', 'T', ' ', ' ', ' ', ' '/
      DATA MSTDIA /'D', 'I', 'A', 'M', 'E', 'T', 'E', 'R', ' ', ' '/
      DATA MSTTMP /'S', 'T', 'A', 'C', 'K', 'T', 'E', 'M', 'P', ' '/
      DATA MSTVEL /'S', 'T', 'A', 'C', 'K', 'V', 'E', 'L', ' ', ' '/
C
C DECLARE MISCELLANEOUS SCALARS
C
      DATA MBLANK /' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
C
      JFLAG = 0
C
C FIND COORD IN VARIABLE LIST
C
      DO 45 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MCOORD, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 45
C
C FOUND IT -- SAVE LOCATION
C
         KCOOR = J
         GO TO 50
C
C END LOOP -- IF NOT FOUND, COORD IS MISSING FROM LIST
C
   45 CONTINUE
      GO TO 934
C
C FIND HEIGHT IN VARIABLE LIST
C
   50 DO 55 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MSTHGT, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 55
C
C FOUND IT -- SAVE LOCATION
C
         KHGHT = J
         GO TO 60
C
C END LOOP -- IF NOT FOUND, HEIGHT IS MISSING FROM LIST
C
   55 CONTINUE
      GO TO 938
C
C FIND DIAMETER IN VARIABLE LIST
C
   60 DO 65 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MSTDIA, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 65
C
C FOUND IT -- SAVE LOCATION
C
         KDIAM = J
         GO TO 70
C
C END LOOP -- IF NOT FOUND, DIAMETER IS MISSING FROM LIST
C
   65 CONTINUE
      GO TO 944
C
C FIND TEMPERATURE IN VARIABLE LIST
C
   70 DO 75 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MSTTMP, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 75
C
C FOUND IT -- SAVE LOCATION
C
         KTEMP = J
         GO TO 80
C
C END LOOP -- IF NOT FOUND, TEMPERATURE IS MISSING FROM LIST
C
   75 CONTINUE
      GO TO 948
C
C FIND VELOCITY IN VARIABLE LIST
C
   80 DO 85 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MSTVEL, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 85
C
C FOUND IT -- SAVE LOCATION
C
         KVLCT = J
C        GO TO 105
C  MODIFIED 10/20/86 - DMB
C
         GO TO 104
C
C END LOOP -- IF NOT FOUND, VELOCITY IS MISSING FROM LIST
C
   85 CONTINUE
      GO TO 952
C
C READ AND, IF WANTED, PRINT THE INPUT CARDS
C
 104  CONTINUE
C104  WRITE(IPRINT,1011)
C     CALL SECOND (STIME)
C     ELAPS = STIME - PRETIM
C     WRITE (6,1009) STIME, ELAPS
C
C   LOOP TO READ IN FIXED POINT SOURCE DATA
C
      DO 200 ICNT = 1,NPTSRC+1
         READ (INCARD, 1105) MPTSNM, MPTTNM, PTSRXL, PTSRYL, MCRDID
         IF (LINPTP) WRITE (IPRINT, 2105) MPTSNM, MPTTNM, PTSRXL,
     *            PTSRYL,MCRDID
C
C CHECK FOR END OF PACKET
C
         CALL COMPAR(IPRINT, NAMLEN, MPTSNM, MENDPS, JFLAG)
         IF (JFLAG .EQ. 1) GO TO 210
         READ (INCARD, 1106) HGTSTK, DIASTK, TMPSTK, VELSTK, MCRDID
         IF (LINPTP) WRITE (IPRINT,2106) HGTSTK,DIASTK,TMPSTK,VELSTK,
     $                                 MCRDID
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
         KPTSR = ICNT
C
C PACK POINT SOURCE TYPE NAME AND CHECK FOR BLANK
C
      CALL TXTPAK(IPRINT, NAMLEN, MPTTNM, NPACKD, JFLAG)
      IF (NPACKD .EQ. 0) GO TO 980
C
C SET LOOP TO FIND POINT SOURCE TYPE NAME
C
      DO 121 K = 1, NPTSRT
C
C COMPARE INPUT POINT SOURCE TYPE NAME WITH THE LIST OF TYPE NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MPTTNM, MPTSRT(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 121
C
C FOUND POINT SOURCE TYPE NAME -- SAVE LOCATION AND SKIP OUT
C
         KPTST = K
         GO TO 124
  121 CONTINUE
C
C NAME NOT FOUND -- SET LOOP TO FIND BLANK SPOT
C
      DO 123 K = 1, NPTSRT
C
C COMPARE FIRST LETTER WITH BLANK
C
         IF (MPTSRT(1,K) .NE. MBLANK) GO TO 123
C
C FOUND ONE -- SAVE LOCATION AND GO STUFF THE NAME IN
C
         KPTST = K
         GO TO 124
  123    CONTINUE
         GO TO 990
  124    CONTINUE
         DO 125 J = 1, NAMLEN
            MPTSRC(J,KPTSR) = MPTSNM(J)
            MPTSRT(J,KPTST) = MPTTNM(J)
  125    CONTINUE
C
C DO UNIT CONVERSION FOR X-AND Y-LOCATIONS AND POINT SOURCE HEIGHT
C
         CALL UNTCNV(PTSRXL,FACMLT(KCOOR),FACADD(KCOOR),RMISSV, RMISSV,
     $            RMISSV, PTSRXL)
         CALL UNTCNV(PTSRYL,FACMLT(KCOOR),FACADD(KCOOR),RMISSV, RMISSV,
     $            RMISSV, PTSRYL)
C
C DO UNIT CONVERSION FOR STACK PARAMETERS
C
         CALL UNTCNV(HGTSTK,FACMLT(KHGHT),FACADD(KHGHT),RMISSV, RMISSV,
     $            RMISSV, STKHGT(KPTSR))
         CALL UNTCNV(DIASTK,FACMLT(KDIAM),FACADD(KDIAM),RMISSV, RMISSV,
     $           RMISSV, STKDIA(KPTSR))
         CALL UNTCNV(TMPSTK,FACMLT(KTEMP),FACADD(KTEMP),RMISSV, RMISSV,
     $           RMISSV, STKTMP(KPTSR))
         CALL UNTCNV(VELSTK,FACMLT(KVLCT),FACADD(KVLCT),RMISSV, RMISSV,
     $           RMISSV, STKVEL(KPTSR))
C
C STORE COORDINATES
C
         JPTSRT(KPTSR) = KPTST
         XPTSRL(KPTSR) = PTSRXL
         YPTSRL(KPTSR) = PTSRYL
  200 CONTINUE
C
C END OF PACKET, PRINT POINT SOURCES TABLE IF WANTED, ELSE RETURN
C
  210 IF (.NOT. LPTSRP) GO TO 1000
      WRITE (IPRINT, 2210)
C
C PRINT VALUES IN LOOP
C
      DO 215 J = 1, NPTSRC
         KPTST = JPTSRT(J)
         WRITE (IPRINT, 2215) (MPTSRC(I, J), I = 1, NAMLEN),
     $                        (MPTSRT(I,KPTST), I = 1, NAMLEN),
     $                        XPTSRL(J), YPTSRL(J),
     $                        STKHGT(J), STKDIA(J), STKTMP(J), STKVEL(J)
  215 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR 'COORD' NOT IN VARIABLE NAME LIST
C
  934 WRITE (IPRINT, 2934) MCOORD
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR 'HEIGHT' NOT IN VARIABLE NAME LIST
C
  938 WRITE (IPRINT, 2938) MSTHGT
      JFLAG = -10
      GO TO 1000
C
C ERROR MESSAGE FOR 'DIAMETER' NOT IN VARIABLE NAME LIST
C
  944 WRITE (IPRINT, 2944) MSTDIA
      JFLAG = -12
      GO TO 1000
C
C ERROR MESSAGE FOR 'STACKTEMP' NOT IN VARIABLE NAME LIST
C
  948 WRITE (IPRINT, 2948) MSTTMP
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR 'STACKVEL' NOT IN VARIABLE NAME LIST
C
  952 WRITE (IPRINT, 2952) MSTVEL
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR BLANK NAME
C
  955 WRITE (IPRINT, 2955)
      JFLAG = -18
      GO TO 1000
C
C ERROR MESSAGE FOR NO SPACE FOR NEW POINT SOURCE NAME
C
  970 WRITE (IPRINT, 2970) MPTSNM
      JFLAG = -21
      GO TO 1000
C
C ERROR MESSAGE FOR BLANK NAME
C
  980 WRITE (IPRINT, 2980)
      JFLAG = -23
      GO TO 1000
C
C ERROR MESSAGE FOR NO SPACE FOR NEW POINT SOURCE TYPE NAME
C
  990 WRITE (IPRINT, 2990) MPTTNM
      JFLAG = -25
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 CONTINUE
      RETURN
C
C FORMATS
C
 1003 FORMAT(1X,'RETURN ',I4,' POS ',I4)
 1005 FORMAT(6A2,A1,39X)
 1006 FORMAT(1X,A52)
 1008 FORMAT(2A2)
 1009 FORMAT (1X,'TIME = ',F18.3, 3X,
     $  2X, 25HTOTAL ELAPSED CPU TIME = , F15.5, 5H SECS )
 1010 FORMAT(1X,'FINISHED POINT SOURCE NAME LOADING')
 1011 FORMAT(1X,'BEGIN STUFFING IN POINT SOURCE NAME')
 1105 FORMAT (10A1, 10A1, 2F10.0, 20X, 20A1)
 1106 FORMAT (4F10.0, 20X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, 2F10.0, 20X, 20A1)
 2106 FORMAT (1X, 4F10.2, 20X, 20A1)
 2210 FORMAT (1H1, 40X, 33HPOINT SOURCE IDENTIFICATION TABLE, //,
     $        46H SOURCE NAME    SOURCE TYPE    X-LOC(UTM, M)   ,
     $        45H Y-LOC(UTM, M)   HEIGHT(M)      DIAMETER(M)    ,
     $        32H TEMPERATURE(K) VELOCITY(M/HR)  , //)
 2215 FORMAT (1X, 2(5X, 10A1), 6(5X, F10.2), /)
 2934 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2938 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2944 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2948 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2952 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE , //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        45H BLANK POINT SOURCE NAMES ARE NOT ACCEPTABLE,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        51H INSUFFICIENT SPACE IN POINT SOURCE NAME TABLE FOR ,
     $        13HPOINT SOURCE , 10A1, //, 26H TOTAL POINT SOURCE COUNT ,
     $        46H MAY BE TOO SMALL, OR A NAME MAY BE MISSPELLED, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2980 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        50H BLANK POINT SOURCE TYPE NAMES ARE NOT ACCEPTABLE,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2990 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        51H INSUFFICIENT SPACE IN POINT SOURCE TYPE NAME TABLE ,
     $        22HFOR POINT SOURCE TYPE , 10A1, //,
     $        31H TOTAL POINT SOURCE TYPE COUNT ,
     $        46H MAY BE TOO SMALL, OR A NAME MAY BE MISSPELLED, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
