      SUBROUTINE ABSPRF (IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL, NZCELL,
     $     NZLOWR, NZUPPR, KXCLL, KYCLL, KZCLL, ZHTSUR, ZMINLW,
     $     ZMINUP, GLEVEL, RMISSV, VALMIN, VALMAX, MVARBL, MSBRGN,
     $     PRFHGT, PRFVAL, DIFBRK, REGTOP, OUTVAL, JFLAG)
C
C NAME -- ABSOLUTE PROFILE METHOD
C
C DESCRIPTION -- CALCULATES VALUE AT LEVEL ALOFT FROM USER PROFILE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NPRFHT    I  NUMBER OF PROFILE VALUES
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         NZCELL    I  NUMBER OF Z-CELLS
C         NZLOWR    I  NUMBER OF LOWER-LEVEL VERTICAL CELLS
C         NZUPPR    I  NUMBER OF UPPER-LEVEL VERTICAL CELLS
C         KXCLL     I  CURRENT X-CELL COORDINATE
C         KYCLL     I  CURRENT Y-CELL COORDINATE
C         KZCLL     I  CURRENT Z-CELL COORDINATE
C         ZHTSUR    R  HEIGHT OF SURFACE LAYER CELL
C         ZMINLW    R  HEIGHT OF LOWER LAYER CELL
C         ZMINUP    R  HEIGHT OF UPPER LAYER CELL
C         GLEVEL    R  VARIABLE VALUE AT GROUND LEVEL
C         RMISSV    R  MISSING VALUE
C         VALMIN    R  MINIMUM ALLOWABLE VALUE
C         VALMAX    R  MAXIMUM ALLOWABLE VALUE
C         MSBRGN    I  SUBREGION NAME
C         MVARBL    I  VARIABLE NAMES
C         PRFHGT    R  PROFILE HEIGHTS
C         PRFVAL    R  PROFILE VALUES
C         DIFBRK    R  HEIGHT OF DIFFUSION BREAK
C         REGTOP    R  HEIGHT OF TOP OF REGION
C
C OUTPUTS --
C         OUTVAL    R  THE OUTPUT VALUE
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         ZHTCLL    R  HEIGHT OF CENTER OF Z-CELL
C         GRNDHT    R  ELEVATION OF GROUND LEVEL
C         PROFIL    R  PROFILE VALUE AT Z-CELL HEIGHT
C
C ROUTINES CALLED --
C         CELLHT    CALCULATES HEIGHT OF CENTER OF Z-CELL
C
C ERROR CONDITIONS --
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN)
      character*4 MVARBL(NAMLEN)
Ctcm  DIMENSION MSBRGN(NAMLEN)
      character*4 MSBRGN(NAMLEN)
      DIMENSION PRFHGT(NPRFHT)
      DIMENSION PRFVAL(NPRFHT)
      DIMENSION DIFBRK(NXCELL, NYCELL)
      DIMENSION REGTOP(NXCELL, NYCELL)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C GET HEIGHT OF CENTER OF CELL
C
      CALL CELLHT(IPRINT, NZCELL, NZLOWR, NZUPPR, KZCLL, ZHTSUR, ZMINLW,
     $     ZMINUP, DIFBRK(KXCLL, KYCLL), REGTOP(KXCLL, KYCLL), RMISSV,
     $     ZHTCLL, JFLAG)
C
C CAPTURE THE GROUND LEVEL ELEVATION AND SET LOOP OVER PROFILE HEIGHTS
C
      GRNDHT = PRFHGT(1)
      DO 150 J = 2, NPRFHT
C
C TEST FOR LAST VALUE -- IF SO, SAVE IT AND SKIP TO SIZE TEST
C
         IF (PRFHGT(J) .NE. RMISSV) GO TO 125
         PROFIL = PRFVAL(J - 1)
         GO TO 175
C
C IF PROFILE HEIGHT EXCEEDS CELL HEIGHT, INTERPOLATE, SKIP TO SIZE TEST
C
  125    IF (PRFHGT(J) - GRNDHT .LT. ZHTCLL) GO TO 150
         PROFIL =  (PRFVAL(J - 1) * (PRFHGT(J) - GRNDHT - ZHTCLL) +
     $              PRFVAL(J) * (ZHTCLL - PRFHGT(J - 1) + GRNDHT)) /
     $            (PRFHGT(J) - PRFHGT(J-1) )
         GO TO 175
C
C FINISH LOOP -- IF SO, SET VALUE TO HIGHEST PROFILE VALUE
C
  150 CONTINUE
      PROFIL = PRFVAL(NPRFHT)
C
C CALCULATE CELL VALUE AS RATIO TO PROFILE VALUE
C
  175 OUTVAL = (PROFIL*GLEVEL) / PRFVAL(1)
C
C VERIFY THE VALUE -- MESSAGE IF OUTSIDE RANGE -- AND RETURN
C
      IF (OUTVAL .GE. VALMIN) GO TO 215
      WRITE (IPRINT, 2215) MVARBL, KXCLL, KYCLL, KZCLL, MSBRGN, VALMIN
      OUTVAL = VALMIN
      GO TO 1000
  215 IF (OUTVAL .LE. VALMAX) GO TO 1000
      WRITE (IPRINT, 2225) MVARBL, KXCLL, KYCLL, KZCLL, MSBRGN, VALMAX
      OUTVAL = VALMAX
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2215 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H,, I10, 1H), //,
     $        14H IN SUBREGION , 10A1, //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2225 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H,, I10, 1H), //,
     $        14H IN SUBREGION , 10A1, //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
      END
