      SUBROUTINE ABSTPC (IPRINT, NAMLEN, NPRFHT, NXCELL, NYCELL,
     $     KXCLL, KYCLL, RMISSV, VALMIN, VALMAX, MVARBL, MSBRGN,
     $     PRFHGT, PRFVAL, REGTOP, OUTVAL, JFLAG)
C
C NAME -- ABSOLUTE PROFILE TOP CONCENTRATION METHOD
C
C DESCRIPTION -- CALCULATES VALUE AT REGION TOP FROM USER PROFILE
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NPRFHT    I  NUMBER OF PROFILE VALUES
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         KXCLL     I  CURRENT X-CELL COORDINATE
C         KYCLL     I  CURRENT Y-CELL COORDINATE
C         RMISSV    R  MISSING VALUE
C         VALMIN    R  MINIMUM ALLOWABLE VALUE
C         VALMAX    R  MAXIMUM ALLOWABLE VALUE
C         MSBRGN    I  SUBREGION NAME
C         MVARBL    I  VARIABLE NAMES
C         PRFHGT    R  PROFILE HEIGHTS
C         PRFVAL    R  PROFILE VALUES
C         REGTOP    R  HEIGHT OF TOP OF REGION
C
C OUTPUTS --
C         OUTVAL    R  THE OUTPUT VALUE
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         GRNDHT    R  ELEVATION OF GROUND LEVEL
C         TOPHGT    R  ELEVATION OF REGION TOP
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN)
      character*4 MVARBL(NAMLEN)
Ctcm  DIMENSION MSBRGN(NAMLEN)
      character*4 MSBRGN(NAMLEN)
      DIMENSION PRFHGT(NPRFHT)
      DIMENSION PRFVAL(NPRFHT)
      DIMENSION REGTOP(NXCELL, NYCELL)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C CAPTURE AND VERIFY PROFILE GROUND AND REGION TOP HEIGHTS
      GRNDHT = PRFHGT(1)
      TOPHGT = REGTOP(KXCLL, KYCLL)
C
C
C SET LOOP OVER PROFILE HEIGHTS
C
      GRNDHT = PRFHGT(1)
      DO 150 J = 2, NPRFHT
C
C TEST FOR LAST VALUE -- IF SO, SAVE IT AND SKIP TO SIZE TEST
C
         IF (PRFHGT(J) .NE. RMISSV) GO TO 125
         OUTVAL = PRFVAL(J - 1)
         GO TO 175
C
C IF PROFILE HEIGHT EXCEEDS REGION TOP, INTERPOLATE, SKIP TO SIZE TEST
C
  125    IF (PRFHGT(J) - GRNDHT .LT. TOPHGT) GO TO 150
         OUTVAL =  (PRFVAL(J - 1) * (PRFHGT(J) - GRNDHT - TOPHGT) +
     $              PRFVAL(J) * (TOPHGT - PRFHGT(J - 1) + GRNDHT)) /
     $            (PRFVAL(J) - PRFVAL(J - 1))
         GO TO 175
C
C FINISH LOOP -- IF SO, SET VALUE TO HIGHEST PROFILE VALUE
C
  150 CONTINUE
      OUTVAL = PRFVAL(NPRFHT)
C
C VERIFY THE VALUE -- MESSAGE IF OUTSIDE RANGE -- AND RETURN
C
  175 IF (OUTVAL .GE. VALMIN) GO TO 215
      WRITE (IPRINT, 2215) MVARBL, KXCLL, KYCLL, MSBRGN, VALMIN
      OUTVAL = VALMIN
      GO TO 1000
  215 IF (OUTVAL .LE. VALMAX) GO TO 1000
      WRITE (IPRINT, 2225) MVARBL, KXCLL, KYCLL, MSBRGN, VALMAX
      OUTVAL = VALMAX
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2215 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H,, I10, 1H), //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2225 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H,, I10, 1H), //,
     $        42H IS BELOW THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
      END
