      SUBROUTINE EWINTR (IPRINT, NAMLEN, NXCELL, NYCELL, KXCLL, KYCLL,
     $    RMISSV, VALMIN, VALMAX, MVARBL, MSBRGN, JRGRID, OUTMAT, JFLAG)
C
C NAME -- EAST-WEST GRID INTERPOLATION
C
C DESCRIPTION -- INTERPOLATES A VALUE ON AN EAST-WEST LINE FROM VALUES
C         IN ADJACENT SUBREGIONS
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         KXCLL     I  X-CELL LOCATION
C         KYCLL     I  Y-CELL LOCATION
C         RMISSV    R  MISSING VALUE
C         VALMIN    R  MINIMUM ALLOWABLE VALUE
C         VALMAX    R  MAXIMUM ALLOWABLE VALUE
C         MVARBL    I  VARIABLE NAME
C         MSBRGN    I  SUBREGION NAME
C         JRGRID    I  REGIONAL GRID
C
C OUTPUTS --
C         OUTVAL    R  THE OUTPUT VALUE
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NLMOVE    I  NUMBER OF CELLS MOVED TO THE LEFT
C         NRMOVE    I  NUMBER OF CELLS MOVED TO THE RIGHT
C         KSBRG     I  CURRENT SUBREGION NUMBER
C         KLEFT     I  X-CELL LOCATION OF LEFT-SIDE VALUE
C         KRGHT     I  X-CELL LOCATION OF RIGHT-SIDE VALUE
C         VALLFT    R  LEFT-SIDE VALUE
C         VALRGT    R  RIGHT-SIDE VALUE
C         VALOUT    R  OUTPUT VALUE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -8        CROSSING OF LEFT BOUNDARY
C         -10       CROSSING OF RIGHT BOUNDARY
C         -12       MISSING LEFT-SIDE VALUE
C         -14       MISSING RIGHT-SIDE VALUE
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN)
      character*4 MVARBL(NAMLEN)
Ctcm  DIMENSION MSBRGN(NAMLEN)
      character*4 MSBRGN(NAMLEN)
      DIMENSION JRGRID(NXCELL, NYCELL)
      DIMENSION OUTMAT(NXCELL, NYCELL)
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C SAVE SUBREGION NUMBER AND SET LOOP TO MOVE LEFT
C
      KSBRG = JRGRID(KXCLL, KYCLL)
      KLEFT = KXCLL
      DO 200 J = 1, NXCELL
C
C DECREMENT LOCATION AND TEST FOR EDGE OR DIFFERENT SUBREGION
C
         KLEFT = KLEFT - 1
         IF (KLEFT .LE. 0) GO TO 940
         IF (JRGRID(KLEFT, KYCLL) .EQ. KSBRG) GO TO 200
C
C CHANGE OF SUBREGION -- SAVE DISTANCE AND VALUE AND SKIP TO RIGHT MOVE
C
         NLMOVE = J
         VALLFT = OUTMAT(KLEFT, KYCLL)
         GO TO 205
C
C END LOOP -- IF NOT FOUND, ERROR MESSAGE
C
  200 CONTINUE
      GO TO 940
C
C SET LOOP TO MOVE RIGHT
C
  205 KRGHT = KXCLL
      DO 300 J = 1, NXCELL
C
C INCREMENT LOCATION AND TEST FOR EDGE OR DIFFERENT SUBREGION
C
         KRGHT = KRGHT + 1
         IF (KRGHT .GT. NXCELL) GO TO 950
         IF (JRGRID(KRGHT, KYCLL) .EQ. KSBRG) GO TO 300
C
C CHANGE OF SUBREGION -- SAVE DISTANCE AND VALUE AND SKIP TO VERIFY
C
         NRMOVE = J
         VALRGT = OUTMAT(KRGHT, KYCLL)
         GO TO 305
C
C END LOOP -- IF NOT FOUND, ERROR MESSAGE
C
  300 CONTINUE
      GO TO 950
C
C VERIFY THE EXISTENCE OF BOTH VALUES
C
  305 IF (VALLFT .EQ. RMISSV) GO TO 960
      IF (VALRGT .EQ. RMISSV) GO TO 970
C
C DO A LINEAR INTERPOLATION
C
      VALOUT = (VALLFT * FLOAT(NRMOVE) + VALRGT * FLOAT(NLMOVE)) /
     $     FLOAT(NLMOVE + NRMOVE)
C
C VERIFY THE VALUE -- MESSAGE IF OUTSIDE RANGE
C
      IF (VALOUT .GE. VALMIN) GO TO 315
      WRITE (IPRINT, 2315) MVARBL, KXCLL, KYCLL, MSBRGN, VALMIN
      VALOUT = VALMIN
      GO TO 325
  315 IF (VALOUT .LE. VALMAX) GO TO 325
      WRITE (IPRINT, 2325) MVARBL, KXCLL, KYCLL, MSBRGN, VALMAX
      VALOUT = VALMAX
C
C
C SET THE VALUUE INTO THE OUTPUT MATRIX AND RETURN
C
  325 OUTMAT(KXCLL, KYCLL) = VALOUT
      GO TO 1000
C
C ERROR MESSAGE FOR CROSSING LEFT BOUNDARY
C
  940 WRITE (IPRINT, 2940) MSBRGN
      JFLAG = -8
      GO TO 1000
C
C ERROR MESSAGE FOR CROSSING RIGHT BOUNDARY
C
  950 WRITE (IPRINT, 2950) MSBRGN
      JFLAG = -10
      GO TO 1000
C
C ERROR MESSAGE FOR MISSING LEFT-SIDE VALUE
C
  960 WRITE (IPRINT, 2960) MVARBL, KLEFT, KYCLL, MSBRGN
      JFLAG = -12
      GO TO 1000
C
C ERROR MESSAGE FOR MISSING RIGHT-SIDE VALUE
C
  970 WRITE (IPRINT, 2970) MVARBL, KRGHT, KYCLL, MSBRGN
      JFLAG = -14
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2315 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2325 FORMAT (43H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2940 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        11H SUBREGION , 10A1, 26H IS ON THE LEFT BOUNDARY. , //,
     $        49H EAST-WEST INTERPOLATION CANNOT BE ACCOMPLISHED. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2950 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        11H SUBREGION , 10A1, 27H IS ON THE RIGHT BOUNDARY. , //,
     $        49H EAST-WEST INTERPOLATION CANNOT BE ACCOMPLISHED. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2960 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        10H VARIABLE , 10A1, //, 23H HAS NO VALUE IN CELL (, I10,
     $        1H,, I10, 28H) ON LEFT SIDE OF SUBREGION , 10A1, //,
     $        49H EAST-WEST INTERPOLATION CANNOT BE ACCOMPLISHED. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2970 FORMAT (1H1, 36H****** SYSTEM OR INPUT ERROR ****** ,
     $        10H VARIABLE , 10A1, //, 23H HAS NO VALUE IN CELL (, I10,
     $        1H,, I10, 29H) ON RIGHT SIDE OF SUBREGION , 10A1, //,
     $        49H EAST-WEST INTERPOLATION CANNOT BE ACCOMPLISHED. ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
      END
