      SUBROUTINE FXDHGT(IPRINT, NZLOWR, NZUPPR, ZHTSUR, ZMINLW,
     $     VALMIN, VALMAX, DIFBRK, CLLHGT, OUTVAL, JFLAG)
C
C NAME -- REGION TOP FIXED HEIGHT
C
C DESCRIPTION -- SETS TOP OF REGION AT A FIXED HEIGHT ABOVE THE
C         DIFFUSION BREAK
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NZLOWR    I  NUMBER OF CELLS IN LOWER LAYER
C         NZUPPR    I  NUMBER OF CELLS IN UPPER LAYER
C         ZHTSUR    R  HEIGHT OF SURFACE LAYER
C         ZMINLW    R  MINIMUM HEIGHT OF LOWER LAYER CELL
C         VALMIN    R  MINIMUM ALLOWABLE OUTPUT VALUE
C         VALMAX    R  MAXIMUM ALLOWABLE OUTPUT VALUE
C         DIFBRK    R  HEIGHT OF DIFFUSION BREAK
C         CLLHGT    R  HEIGHT OF UPPER LAYER CELL
C OUTPUTS --
C         OUTVAL    R  THE OUTPUT VALUE
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -6        NONPOSITIVE VALUE FOR CELL HEIGHT
C
C OTHER INFORMATION --
C
C
      DATA IHI /0/,ILOW /0/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C TEST WHETHER DIFFUSION BREAK IS ABOVE MINIMUM
C
      IF (DIFBRK .GT. ZHTSUR + FLOAT(NZLOWR) * ZMINLW) GO TO 205
C
C IT IS NOT -- SET REGION TOP BEGINNING AT THIS LEVEL
C
      OUTVAL = ZHTSUR + FLOAT(NZLOWR) * ZMINLW + FLOAT(NZUPPR) * CLLHGT
      GO TO 305
C
C IT IS -- SET REGION TOP ABOVE DIFFUSION BREAK
C
  205 OUTVAL = DIFBRK + FLOAT(NZUPPR) * CLLHGT
C
C CHECK AGAINST MINIMUM AMD MAXIMUM -- RESET WITH MESSAGE
C
  305 IF (OUTVAL .GE. VALMIN) GO TO 405
      ILOW = ILOW + 1
      IF (ILOW - (ILOW/10*10) .EQ. 1)
     $      WRITE (IPRINT,2305) OUTVAL, VALMIN
      OUTVAL = VALMIN
      GO TO 1000
  405 IF (OUTVAL .LE. VALMAX) GO TO 1000
      IHI = IHI + 1
      IF (IHI - (IHI/10*10) .EQ. 1)
     $       WRITE (IPRINT,2315) OUTVAL, VALMAX
      OUTVAL = VALMAX
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2305 FORMAT (48H ****** NOTE ****** CALCULATED HEIGHT OF TOP OF  ,
     $        7HREGION , F10.2, 28H IS LESS THAN THE ALLOWABLE ,
     $        14HMINIMUM VALUE , F10.2, /, 19H TOP OF REGION HAS ,
     $        33HBEEN RESET TO THIS MINIMUM VALUE , /)
 2315 FORMAT (48H ****** NOTE ****** CALCULATED HEIGHT OF TOP OF  ,
     $        7HREGION , F10.2, 31H IS GREATER THAN THE ALLOWABLE ,
     $        14HMAXIMUM VALUE , F10.2, /, 19H TOP OF REGION HAS ,
     $        33HBEEN RESET TO THIS MAXIMUM VALUE , /)
      END
