      SUBROUTINE GDVLRD(INCARD, IPRINT, IMATFL, NAMLEN, NVARBL,
     $     NSBRGN, NXCELL, NYCELL, KGDVL, LINPTP,
     $  RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MSBRGN,
     $  JRGRID, JMTHDN, SMTHMN, SMTHMX, BASGRD, OUTMAT, JFLAG)
C
C NAME -- GRID VALUES PACKET READ
C
C DESCRIPTION -- READS THE GRID VALUES PACKET AS PART OF TIME-VARIANT
C                DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         IMATFL    I  OUTPUT MATRIX FILE UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NSBRGN    I  NUMBER OF SUBREGIONS
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF YCELLS
C         KGDVL     I  METHOD NUMBER FOR GRID VALUES
C         LINPTP    I  INPUT PRINT FLAG
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MSBRGN    I  SUBREGION NAMES
C         JRGRID    I  REGIONAL GRID
C         JMTHDN    I  METHOD NUMBERS
C         BASGRD    R  OUTPUT GRID
C         SMTHMN    R  MINUMUM ALLOWABLE VALUES
C         SMTHMX    R  MAXIMUM ALLOWABLE VALUES
C
C OUTPUTS --
C         OUTMAT    R  OUTPUT VALUES MATRIX
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         KVRBL     I  VARIABLE NUMBER
C         KZCLL     I VERTICAL LEVEL NUMBER
C         KSBRG     I  SUBREGION NUMBER
C         KXCLL     I  X-COORDINATE OF GRID CELL
C         KYCLL     I  Y-COORDINATE OF GRID CELL
C         KBEGV     I  POINTER TO BEGINNING VARIABLE LOCATION
C         KENDV     I  POINTER TO ENDING VARIABLE LOCATION
C         KBEGS     I  POINTER TO BEGINNING SUBREGION LOCATION
C         KENDS     I  POINTER TO ENDING SUBREGION LOCATION
C         GRIDVL    R  INPUT VALUE FOR CONSTANT
C         MENDGV    I  PACKET TRAILER NAME
C         MVARNM    I  INPUT VARIABLE NAME
C         MSBRNM    I  INPUT SUBREGION NAME
C         MALLNM    I  REFERENCE NAME FOR 'ALL'
C         MCRDID    I  CARD IDENTIFICATION
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -11       SUBREGION NAME NOT IN LIST
C         -15       VARIABLE NAME NOT IN VARIABLE LIST
C         -16       X-COORDINATE OUT OF REGION
C         -17       Y-COORDINATE OUT OF REGION
C         -18       INCORRECT METHOD REQUEST
C         -19       ERROR IN MATGET
C         -20       ERROR IN MATPUT
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION OUTMAT(1)
      DIMENSION FACMLT(NVARBL)
      DIMENSION FACADD(NVARBL)
      DIMENSION SMOLWT(NVARBL)
Ctcm  DIMENSION MVARBL(NAMLEN,NVARBL)
      character*4 MVARBL(NAMLEN,NVARBL)
Ctcm  DIMENSION MSBRGN(NAMLEN,NSBRGN)
      character*4 MSBRGN(NAMLEN,NSBRGN)
      DIMENSION JRGRID(NXCELL, NYCELL)
      DIMENSION JMTHDN(NSBRGN, NVARBL)
      DIMENSION BASGRD(NXCELL, NYCELL)
      DIMENSION SMTHMN(NSBRGN, NVARBL)
      DIMENSION SMTHMX(NSBRGN, NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MVARNM(10), MENDGV(10), MSBRNM(10), MCRDID(20)
      character*4 MVARNM(10), MENDGV(10), MSBRNM(10), MCRDID(20)
Ctcm  DIMENSION MALLNM(10)
      character*4 MALLNM(10)
C
C DECLARE PACKET TRAILER AND 'ALL' REFERENCE
C
      DATA MALLNM /'A', 'L', 'L', 7*' '/
      DATA MENDGV /'E', 'N', 'D', 7*' '/
C
C SET VERTICAL LEVEL NUMBER
C
      DATA KZCLL /1/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MSBRNM, MVARNM, KXCLL, KYCLL, GRIDVL, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MSBRNM, MVARNM, KXCLL, KYCLL,
     $                                 GRIDVL, MCRDID
C
C PACK SUBREGION NAME
C
      CALL TXTPAK(IPRINT, NAMLEN, MSBRNM, NPACKD, JFLAG)
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MENDGV, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 1000
C
C COMPARE SUBREGION NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET SUBREGION POINTER TO ZERO TO INDICATE 'ALL'
C
      KSBRG = 0
      GO TO 140
C
C SET LOOP TO FIND SUBREGION NAME
C
  113 DO 115 K = 1, NSBRGN
C
C COMPARE INPUT SUBREGION NAME WITH THE LIST OF SUBREGION NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MSBRGN(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND SUBREGION NAME -- SAVE LOCATION AND SKIP OUT
C
         KSBRG = K
         GO TO 140
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  115 CONTINUE
      GO TO 955
C
C PACK VARIABLE NAME
C
  140 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 143
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 150
C
C SET LOOP TO FIND VARIABLE NAME
C
  143 DO 145 J = 1, NVARBL
C
C FIND THIS VARIABLE NAME IN LIST OF VARIABLES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 145
C
C FOUND VARIABLE NAME -- SAVE LOCATION AND SKIP OUT
C
         KVRBL = J
         GO TO 150
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  145 CONTINUE
      GO TO 975
C
C VERIFY THAT THE X AND Y COORDINATES ARE WITHIN THE GRID
C
  150 IF (KXCLL .LE. 0) GO TO 980
      IF (KXCLL .GT. NXCELL) GO TO 980
      IF (KYCLL .LE. 0) GO TO 985
      IF (KYCLL .GT. NYCELL) GO TO 985
C
C VERIFY METHOD NUMBER AND DO UNIT CONVERSION ON INPUT VALUE
C (USE CONVERSIONS FOR FIRST VARIABLE IF ALL)
C
      KBEGV = KVRBL
      IF(KVRBL .EQ. 0) KVRBL = 1
      KBEGS = KSBRG
      IF (KSBRG .EQ. 0) KSBRG = 1
      IF (KGDVL .NE. JMTHDN(KSBRG, KVRBL)) GO TO 990
      CALL UNTCNV(GRIDVL, FACMLT(KVRBL), FACADD(KVRBL), SMOLWT(KVRBL),
     $            RMISSV, RMISSV, GRIDVL)
C
C CHECK THE VALUE AGAINST RANGE -- MESSAGE IF OUTSIDE
C
      IF (GRIDVL .GE. SMTHMN(KSBRG, KVRBL)) GO TO 160
      WRITE (IPRINT, 2150) MVARNM, KXCLL, KYCLL, SMTHMN(KSBRG,KVRBL)
      GRIDVL = SMTHMN(KSBRG, KVRBL)
      GO TO 170
  160 IF (GRIDVL .LE. SMTHMX(KSBRG, KVRBL)) GO TO 170
      WRITE (IPRINT, 2160) MVARNM, KXCLL, KYCLL, SMTHMX(KSBRG,KVRBL)
      GRIDVL = SMTHMX(KSBRG, KVRBL)
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
  170 KVRBL = KBEGV
      KENDV = KVRBL
      KSBRG = KBEGS
      KENDS = KSBRG
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KSBRG .EQ. 0) KBEGS = 1
      IF (KSBRG .EQ. 0) KENDS = NSBRGN
C
C SET VARIABLE LOOP
C
      DO 185 K = KBEGV, KENDV
         KVRBL = K
C
C GET OUTPUT GRID FOR THIS VARIABLE
C
         CALL MATGET(IPRINT, IMATFL, NXCELL, NYCELL, KZCLL, NVARBL,
     $       KZCLL, KVRBL, BASGRD, OUTMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 995
C
C SET SUBREGION LOOP
C
         DO 175 KSBRG = KBEGS, KENDS
C
C IF CORRECT SUBREGION, STORE VALUE AND GET NEXT CARD
C
            IF (JRGRID(KXCLL, KYCLL) .NE. KSBRG) GO TO 175
            BASGRD(KXCLL, KYCLL) = GRIDVL
C
C END SUBREGION LOOP AND REPLACE OUTPUT GRID
C
  175    CONTINUE
         CALL MATPUT(IPRINT, IMATFL, NXCELL, NYCELL, KZCLL, NVARBL,
     $       KZCLL, KVRBL, BASGRD, OUTMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 997
C
C END VARIABLE LOOP AND GET NEXT CARD
C
C
  185 CONTINUE
      GO TO 105
C
C ERROR MESSAGE FOR SUBREGION NAME NOT IN LIST
C
  955 WRITE (IPRINT, 2955) MSBRNM
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT IN VARIABLE LIST
C
  975 WRITE (IPRINT, 2975) MVARNM
      JFLAG = -15
      GO TO 1000
C
C ERROR MESSAHE FOR X-COORDINATE OUTSIDE OF REGION
C
  980 WRITE (IPRINT, 2980) KXCLL, NXCELL
      JFLAG = -16
      GO TO 1000
C
C ERROR MESSAGE FOR Y-COORDINATE OUTSIDE OF REGION
C
  985 WRITE (IPRINT, 2985) KYCLL, NYCELL
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR INCORRECT METHOD REQUEST
C
  990 WRITE (IPRINT, 2990) MVARNM, MSBRNM
      JFLAG = -18
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATGET
C
  995 WRITE (IPRINT, 2995) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -19
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR IN MATPUT
C
  997 WRITE (IPRINT, 2997) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -20
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 10A1, 2I10, F10.0, 10X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, 2I10, F14.4, 6X, 20A1)
 2150 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        42H IS BELOW THE MINIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MINIMUM , //)
 2160 FORMAT (42H ****** NOTE ****** THE VALUE OF VARIABLE , 10A1,
     $        10H IN CELL (, I10, 1H,, I10, 1H), //,
     $        42H IS ABOVE THE MAXIMUM ACCEPTABLE VALUE OF , F12.4,
     $        39H.  VALUE HAS BEEN RESET TO THE MAXIMUM , //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        33H UNABLE TO LOCATE SUBREGION NAME , 10A1,
     $        18H IN SUBREGION LIST, //,
     $        34H CHECK SUBREGION NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2975 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        19H IN VARIABLE LIST, //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2980 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ****** ,
     $        20H INPUT X-COORDINATE , I10, 16H IS OUTSIDE THE ,
     $        21HREGION RANGE OF 1 TO , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2985 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ****** ,
     $        20H INPUT Y-COORDINATE , I10, 16H IS OUTSIDE THE ,
     $        21HREGION RANGE OF 1 TO , I10, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2990 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ****** ,
     $        49H THE METHOD 'GRIDVALUES' HAS NOT BEEN SPECIFIED ,
     $        //, 14H FOR VARIABLE , 10A1, 14H IN SUBREGION , 10A1,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE , //)
 2995 FORMAT (26H ****** ERROR TRACE ****** , 12H ERROR FLAG , I10,
     $        42H RETURNED TO GDVLRD FROM SUBROUTINE MATGET ,
     $        14H FOR VARIABLE , 10A1, //)
 2997 FORMAT (26H ****** ERROR TRACE ****** , 12H ERROR FLAG , I10,
     $        42H RETURNED TO CNSTRD FROM SUBROUTINE MATPUT ,
     $        14H FOR VARIABLE , 10A1, //)
      END
