      SUBROUTINE GRIDPI (IPRINT, NAMLEN, NIDLEN, NTILEN, NXCELL, NYCELL,
     $   KZCLL, KFRMT, JBEGDT, JENDDT, BEGTIM, ENDTIM, MFILNM, MFILID,
     $   MTITLE, JPGRID, JFLAG)
C
C NAME -- GRID PRINT
C
C DESCRIPTION -- PRINTS A GRID OF OUTPUT VALUES IN ACCORDANCE WITH
C                A SELECTABLE FORMAT - FOR INTERGERS ONLY
C
C PROGRAMMER -- DC WHITNEY /SAI AUGUST 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NIDLEN    I  NUMBER OF WORDS IN IDENTIFICATION FIELD
C         NOPTIN    I  NUMBER OF WORD IN TITLE
C         NXCELL    I  NUMBER OF CELLS IN X-DIRECTION
C         NYCELL    I  NUMBER OF CELLS IN Y-DIRECTION
C         KZCLL     I  CELL NUMBER IN Z-DIRECTION
C         KFRMT     I  FORMAT NUMBER POINTER
C         JBEGDT    I  BEGINNING DATE
C         JENDDT    I  ENDING DATE
C         BEGTIM    R  BEGINNING TIME
C         ENDTIM    R  ENDING TIME
C         MFILNM    I  FILE NAME (LENGTH)
C         MFILID    I  FILE IDENTIFICATION (ID.LENGTH)
C         MTITLE    I  TITLE OF PRINTOUT (TITLE LENGTH)
C         JPGRID    I  GRID OF VALUES TO BE PRINTED (N.X-CELL,N.Y-CELL)
C
C OUTPUTS --
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NCOLCT    I  NUMBER OF COLUMNS
C         NROWCT    I  NUMBER OF ROWS
C         NPAGES    I  NUMBER OF PAGES
C         NXFRST    I  FIRST COLUMN NUMBER
C         NYFRST    I  FIRST ROW NUMBER
C         NXLAST    I  LAST COLUMN NUMBER
C         NYLAST    I  LAST ROW NUMBER
C         KSIZE     I  FORMAT SIZE POINTER
C         KPACK     I  FORMAT DENSITY POINTER
C         KTYPE     I  FORMAT TYPE POINTER
C         JMAXSZ    I  MAXIMUM SIZE VALUE
C         JMAXPK    I  MAXIMUM DENSITY VALUE
C         JMAXTP    I  MAXIMUM TYPE VALUE
C         JCOLCT    I  COLUMN COUNTS FOR EACH TYPE
C         JROWCT    I  ROW COUNTS FOR EACH TYPE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C         -6        ILLEGAL FORMAT NUMBER
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MFILNM(NAMLEN)
      character*4 MFILNM(NAMLEN)
Ctcm  DIMENSION MFILID(NIDLEN)
      character*4 MFILID(NIDLEN)
Ctcm  DIMENSION MTITLE(NTILEN)
      character*4 MTITLE(NTILEN)
      DIMENSION JPGRID(NXCELL,NYCELL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
      DIMENSION JCOLCT(3,2), JROWCT(3,2)
C
C SET SIZES OF COLUMNS AND ROWS FOR EACH OPTION
C
      DATA JCOLCT /10, 12, 12, 20, 24, 24/
      DATA JROWCT /10, 25, 50, 20, 25, 50/
C
C SET MAXIMUM NUMBER FOR FORMAT STRUCTURE
C
      DATA JMAXSZ /2/
      DATA JMAXPK /3/
      DATA JMAXTP /7/
C
C SET COMPLETION FLAG AND NUMBER OF PAGES TO ZERO
C
      JFLAG = 0
      NPAGES = 0
C
C DISSECT THE FORMAT NUMBER INTO ITS COMPONENT PARTS
C
      KSIZE = KFRMT / 100
      KPACK = KFRMT / 10 - KSIZE * 10
      KTYPE = KFRMT - KSIZE * 100 - KPACK * 10
       IF (KTYPE .GT. 2) GO TO 940
C
C VERIFY THAT THESE ARE ACCEPTABLE VALUES
C
      IF (KSIZE .GT. JMAXSZ) GO TO 930
      IF (KPACK .GT. JMAXPK) GO TO 930
      IF (KTYPE .GT. JMAXTP) GO TO 930
      IF (KSIZE .LE. 0) GO TO 930
      IF (KPACK .LE. 0) GO TO 930
      IF (KTYPE .LE. 0) GO TO 930
C
C SET THE LOOPS TO PRINT HEADINGS AND PAGE NUMBERS
C
      NCOLCT = JCOLCT(KPACK,KSIZE)
      NROWCT = JROWCT(KPACK,KSIZE)
      DO 800 KK = 1, NYCELL, NROWCT
C
C SET FIRST AND LAST Y-VALUES
C
         NYLAST = KK + NROWCT - 1
         IF (NYLAST .GT. NYCELL) NYLAST = NYCELL
         NYFRST = KK
         DO 700 II = 1, NXCELL, NCOLCT
C
C SET FIRST AND LAST X-VALUES
C
            NXLAST = II + NCOLCT - 1
            IF (NXLAST .GT. NXCELL) NXLAST = NXCELL
            NXFRST = II
C
C INCREMENT PAGE COUNTER AND PRINT HEADINGS
C
            NPAGES = NPAGES + 1
            WRITE (IPRINT, 2005) MFILNM, MFILID, NPAGES
            WRITE (IPRINT, 2010) MTITLE, KZCLL, JBEGDT, BEGTIM,
     $                           JENDDT, ENDTIM
C
C PRINT THE CELL NUMBER -- NOTE FORMAT SELECTION VIA COMPUTED GOTO
C
            GO TO (110, 120), KSIZE
  110       GO TO (130, 140, 150), KPACK
  120       GO TO (160, 170, 180), KPACK
  130       WRITE (IPRINT, 2130) (I, I = NXFRST, NXLAST)
            GO TO 190
  140       WRITE (IPRINT, 2140) (I, I = NXFRST, NXLAST)
            GO TO 190
  150       WRITE (IPRINT, 2150) (I, I = NXFRST, NXLAST)
            GO TO 190
  160       WRITE (IPRINT, 2160) (I, I = NXFRST, NXLAST)
            GO TO 190
  170       WRITE (IPRINT, 2170) (I, I = NXFRST, NXLAST)
            GO TO 190
  180       WRITE (IPRINT, 2180) (I, I = NXFRST, NXLAST)
C
C SET LOOP OVER THIS SET OF Y-CELLS AND REVERSE INDEX
C
  190       DO 600 JJ = NYFRST, NYLAST
               J = NYCELL - JJ + 1
C
C PRINT THE ROW OF VALUES -- NOTE FORMAT SELECTION VIA COMPUTED GOTO
C
               GO TO (210, 220), KSIZE
  210          GO TO (230, 240, 250), KPACK
  220          GO TO (260, 270, 280), KPACK
  230          GO TO (311, 312, 313, 314, 315, 316, 317), KTYPE
  240          GO TO (321, 322, 323, 324, 325, 326, 327), KTYPE
  250          GO TO (331, 332, 333, 334, 335, 336, 337), KTYPE
  260          GO TO (411, 412, 413, 414, 415, 416, 417), KTYPE
  270          GO TO (421, 422, 423, 424, 425, 426, 427), KTYPE
  280          GO TO (431, 432, 433, 434, 435, 436, 437), KTYPE
  311          WRITE (IPRINT, 3111) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  312          WRITE (IPRINT, 3112) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  313          WRITE (IPRINT, 3113) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  314          WRITE (IPRINT, 3114) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  315          WRITE (IPRINT, 3115) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  316          WRITE (IPRINT, 3116) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  317          WRITE (IPRINT, 3117) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  321          WRITE (IPRINT, 3121) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  322          WRITE (IPRINT, 3122) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  323          WRITE (IPRINT, 3123) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  324          WRITE (IPRINT, 3124) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  325          WRITE (IPRINT, 3125) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  326          WRITE (IPRINT, 3126) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  327          WRITE (IPRINT, 3127) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  331          WRITE (IPRINT, 3131) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  332          WRITE (IPRINT, 3132) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  333          WRITE (IPRINT, 3133) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  334          WRITE (IPRINT, 3134) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  335          WRITE (IPRINT, 3135) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  336          WRITE (IPRINT, 3136) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  337          WRITE (IPRINT, 3137) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  411          WRITE (IPRINT, 4111) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  412          WRITE (IPRINT, 4112) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  413          WRITE (IPRINT, 4113) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  414          WRITE (IPRINT, 4114) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  415          WRITE (IPRINT, 4115) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  416          WRITE (IPRINT, 4116) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  417          WRITE (IPRINT, 4117) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  421          WRITE (IPRINT, 4121) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  422          WRITE (IPRINT, 4122) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  423          WRITE (IPRINT, 4123) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  424          WRITE (IPRINT, 4124) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  425          WRITE (IPRINT, 4125) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  426          WRITE (IPRINT, 4126) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  427          WRITE (IPRINT, 4127) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  431          WRITE (IPRINT, 4131) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  432          WRITE (IPRINT, 4132) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  433          WRITE (IPRINT, 4133) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  434          WRITE (IPRINT, 4134) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  435          WRITE (IPRINT, 4135) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  436          WRITE (IPRINT, 4136) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  437          WRITE (IPRINT, 4137) J, (JPGRID(I,J), I=NXFRST,NXLAST)
               GO TO 600
  600       CONTINUE
  700    CONTINUE
  800 CONTINUE
C
C END OF GRID -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR FORMAT NUMBER OUT OF BOUNDS
C
  930 WRITE (IPRINT, 2930) KFRMT
      JFLAG = -6
      GO TO 1000
C
  940 WRITE (IPRINT, 2930) KFRMT
      JFLAG = -7
      GO TO 1000
C
C RETURN TO CALLING PROGRAM
C
 1000 RETURN
C
C FORMATS
C
 2005 FORMAT (1H1, 13HFILE NAME -- , 10A1,5X,60A1, 35X, 5HPAGE ,I2, /)
 2010 FORMAT (1H , 60A1, 13H VERT.  LEVEL , I2,
     $        17H START DATE/TIME , I5, F6.2,
     $        16H STOP DATE/TIME , I5, F6.2, /)
 2130 FORMAT (1H , 10H GRID CELL, 10I10)
 2140 FORMAT (1H , 10H GRID CELL, 12I10)
 2150 FORMAT (1H , 10H GRID CELL, 12I10)
 2160 FORMAT (1H , 10H GRID CELL, 20I5)
 2170 FORMAT (1H , 10H GRID CELL, 24I5)
 2180 FORMAT (1H , 10H GRID CELL, 24I5)
 2930 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        45H SUBROUTINE GRIDPI CALLED WITH FORMAT NUMBER , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 3111 FORMAT (////, 1H , I7, 3X, 10I10)
 3112 FORMAT (////, 1H , I7, 3X, 10(10A1) )
 3113 FORMAT (////, 1H , I7, 3X, 10F10.0 )
 3114 FORMAT (////, 1H , I7, 3X, 10F10.2 )
 3115 FORMAT (////, 1H , I7, 3X, 10F10.4)
 3116 FORMAT (////, 1H , I7, 3X, 10F10.6)
 3117 FORMAT (////, 1H , I7, 3X, 10E10.8)
 3121 FORMAT (/, 1H , I7, 3X, 12(3X, I7) )
 3122 FORMAT (/, 1H , I7, 3X, 12(10A1))
 3123 FORMAT (/, 1H , I7, 3X, 12F10.0)
 3124 FORMAT (/, 1H , I7, 3X, 12F10.2)
 3125 FORMAT (/, 1H , I7, 3X, 12F10.4)
 3126 FORMAT (/, 1H , I7, 3X, 12F10.6)
 3127 FORMAT (/, 1H , I7, 3X, 12E10.8)
 3131 FORMAT (1H , I7, 3X, 12(3X, I7) )
 3132 FORMAT (1H , I7, 3X, 12(10A1))
 3133 FORMAT (1H , I7, 3X, 12F10.0)
 3134 FORMAT (1H , I7, 3X, 12F10.2)
 3135 FORMAT (1H , I7, 3X, 12F10.4)
 3136 FORMAT (1H , I7, 3X, 12F10.6)
 3137 FORMAT (1H , I7, 3X, 12E10.8)
 4111 FORMAT (/, 1H , I7, 3X, 20I5 )
 4112 FORMAT (/, 1H , I7, 3X, 20(5A1) )
 4113 FORMAT (/, 1H , I7, 3X, 20F5.0)
 4114 FORMAT (/, 1H , I7, 3X, 20F5.1)
 4115 FORMAT (/, 1H , I7, 3X, 20F5.2)
 4116 FORMAT (/, 1H , I7, 3X, 20F5.3)
 4117 FORMAT (/, 1H , I7, 3X, 20F5.4)
 4121 FORMAT (/, 1H , I7, 3X, 24I5)
 4122 FORMAT (/, 1H , I7, 3X, 24(5A1))
 4123 FORMAT (/, 1H , I7, 3X, 24F5.0)
 4124 FORMAT (/, 1H , I7, 3X, 24F5.1)
 4125 FORMAT (/, 1H , I7, 3X, 24F5.2)
 4126 FORMAT (/, 1H , I7, 3X, 24F5.3)
 4127 FORMAT (/, 1H , I7, 3X, 24F5.4)
 4131 FORMAT (1H , I7, 3X, 24I5)
 4132 FORMAT (1H , I7, 3X, 24(5A1))
 4133 FORMAT (1H , I7, 3X, 24F5.0)
 4134 FORMAT (1H , I7, 3X, 24F5.1)
 4135 FORMAT (1H , I7, 3X, 24F5.2)
 4136 FORMAT (1H , I7, 3X, 24F5.3)
 4137 FORMAT (1H , I7, 3X, 24F5.4)
      END
