      SUBROUTINE HTZCLL(IPRINT, NZCELL, NZLOWR, NZUPPR, JMISSV,
     $     ZHTSUR, ZMINLW, ZMINUP, ZHTDIF, ZHTTOP, HEIGHT,
     $     KZCLL, JFLAG)
C
C NAME --  VERTICAL CELL FOR GIVEN HEIGHT
C
C DESCRIPTION -- CALCULATES THE VERTICAL CELL NUMBER FOR A GIVEN CELL HEIGHT
C      ABOVE GROUND LEVEL
C
C PROGRAMMER -- DC WHITNEY, JUNE 1977
C
C INPUTS --
C         IPRINT     I   FORTRAN OUTPUT UNIT
C         NZCELL     I   NUMBER OF Z-CELLS
C         NZLOWR     I   NUMBER OF Z-CELLS IN LOWER LAYER
C         NZUPPR     I   NUMBER OF Z-CELLS IN UPPER LAYER
C         JMISSV     I   VALUE FOR MISSING VARIABLE
C         ZHTSUR     R   HEIGHT OF THE SURFACE LAYER
C         ZMINLW     R   MINIMUM HEIGHT OF A LOWER LAYER CELL
C         ZMINUP     R   MINIMUM HEIGHT OF AN UPPER LAYER CELL
C         ZHTDIF     R   HEIGHT OF DIFFUSION BREAK
C         ZHTTOP     R   HEIGHT OF TOP OF THE REGION
C         HEIGHT     R   HEIGHT OF THE CENTER OF THIS CELL
C
C OUTPUT --
C         KZCLL      I   LEVEL NUMBER OF THIS CELL
C         JFLAG      I   COMPLETION FLAG
C
C LOCAL VARIABLES -- NONE
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C
C OTHER INFORMATION --
C
C
C
C
C INITIALIZE COMPLETION FLAG AND RETURN VALUE
C
      JFLAG = 0
      KZCLL = JMISSV
C
C TEST FOR WITHIN SURFACE LAYER
C
      IF (HEIGHT .GT. ZHTSUR) GO TO 110
C
C SET CELL NUMBER TO SURFACE LAYER AND RETURN
C
      KZCLL = 1
      GO TO 1000
C
C LOWER LAYER -- CHECK FOR DIFFUSION BELOW MINIMUM LOWER VALUE
C
  110 IF (ZHTDIF .GT. ZHTSUR + FLOAT(NZLOWR) * ZMINLW) GO TO 120
C
C IT IS TOO LOW -- SET LOOP TO TEST MINIMUM LOWER LEVELS
C
      IF (NZLOWR .LE. 0) GO TO 210
      DO 115 J = 1, NZLOWR
         IF (HEIGHT .GT. FLOAT(J) * ZMINLW + ZHTSUR) GO TO 115
C
C FOUND LEVEL -- SET VERTICAL CELL NUMBER AND RETURN
C
         KZCLL = J
         IF (ZHTSUR .GT. 0.0) KZCLL = KZCLL + 1
         GO TO 1000
C
C END LOOP AND SKIP TO UPPER LEVEL
C
  115 CONTINUE
      GO TO 210
C
C CHECK FOR DIFFUSION BREAK ABOVE MINIMUM UPPER VALUE
C
  120 IF (ZHTDIF .GT. ZHTTOP - FLOAT(NZUPPR) * ZMINUP) GO TO 130
C
C BREAK BETWEEN SURFACE AND TOP -- SET LOOP TO TEST LOWER LEVELS
C
      IF (NZLOWR .LE. 0) GO TO 210
      DO 125 J = 1, NZLOWR
         IF (HEIGHT .GT. FLOAT(J) * (ZHTDIF - ZHTSUR) /
     $       FLOAT(NZLOWR) + ZHTSUR) GO TO 125
C
C FOUND LEVEL -- SET VERTICAL CELL NUMBER AND RETURN
C
         KZCLL = J
         IF (ZHTSUR .GT. 0.0) KZCLL = KZCLL + 1
         GO TO 1000
C
C END LOOP AND SKIP TO UPPER LEVEL
C
  125 CONTINUE
      GO TO 210
C
C BREAK IS ABOVE TOP -- SET LOOP TO TEST MAXIMUM LOWER LEVELS
C
  130 IF (NZLOWR .LE. 0) GO TO 210
      DO 135 J = 1, NZLOWR
         IF (HEIGHT .GT. FLOAT(J) * (ZHTTOP - FLOAT(NZUPPR) * ZMINUP) /
     $       FLOAT(NZLOWR) + ZHTSUR) GO TO 135
C
C FOUND LEVEL -- SET VERTICAL CELL NUMBER AND RETURN
C
         KZCLL = J
         IF (ZHTSUR .GT. 0.0) KZCLL = KZCLL + 1
         GO TO 1000
C
C END LOOP AND SKIP TO UPPER LEVEL
C
  135 CONTINUE
      GO TO 210
C
C UPPER LAYER -- CHECK FOR DIFFUSION HEIGHT BELOW SURFACE LAYER
C
  210 IF (ZHTDIF .GT. ZHTSUR + FLOAT(NZLOWR) * ZMINLW) GO TO 220
C
C BREAK TOO LOW -- SET LOOP TO TEST MAXIMUM UPPER LEVELS
C
      IF (NZUPPR .LE. 0) GO TO 310
      DO 215 J = 1, NZUPPR
         IF (HEIGHT .GT. FLOAT(J) * (ZHTTOP - FLOAT(NZLOWR) *
     $       ZMINLW - ZHTSUR) / FLOAT(NZUPPR) + FLOAT(NZLOWR) * ZMINLW +
     $       ZHTSUR) GO TO 215
C
C FOUND LEVEL -- SET VERTICAL CELL NUMBER AND RETURN
C
         KZCLL = J + NZLOWR
         IF (ZHTSUR .GT. 0.0) KZCLL = KZCLL + 1
         GO TO 1000
C
C END LOOP AND SKIP TO UPPER LEVEL
C
  215 CONTINUE
      GO TO 310
C
C CHECK FOR BREAK ABOVE MINIMUM UPPER VALUE
C
  220 IF (ZHTDIF .GT. ZHTTOP - FLOAT(NZUPPR) * ZMINUP) GO TO 230
C
C BREAK BETWEEN SURFACE AND TOP -- SET LOOP TO TEST UPPER LEVELS
C
      IF (NZUPPR .LE. 0) GO TO 310
      DO 225 J = 1, NZUPPR
         IF (HEIGHT .GT. FLOAT(J) * (ZHTTOP - ZHTDIF - ZHTSUR) /
     $       FLOAT(NZUPPR) + ZHTDIF + ZHTSUR) GO TO 225
C
C FOUND LEVEL -- SET VERTICAL CELL NUMBER AND RETURN
C
         KZCLL = J + NZLOWR
         IF (ZHTSUR .GT. 0.0) KZCLL = KZCLL + 1
         GO TO 1000
C
C END LOOP AND SKIP TO UPPER LEVEL
C
  225 CONTINUE
      GO TO 310
C
C BREAK ABOVE TOP -- SET LOOP TO TEST MINIMUM UPPER LEVELS
C
  230 IF (NZUPPR .LE. 0) GO TO 310
      DO 235 J = 1, NZUPPR
         IF (HEIGHT .GT. ZHTTOP + FLOAT(J - NZUPPR)*ZMINUP) GO TO 235
C
C FOUND LEVEL -- SET VERTICAL CELL NUMBER AND RETURN
C
         KZCLL = J + NZLOWR
         IF (ZHTSUR .GT. 0.0) KZCLL = KZCLL + 1
         GO TO 1000
C
C END LOOP AND SKIP TO UPPER LEVEL
C
  235 CONTINUE
C
C CELL IS ABOVE TOP OF REGION
C
  310 KZCLL = 0
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
      END
