      SUBROUTINE MTHDRD (INCARD, IPRINT, NAMLEN, NVARBL,
     $    NSBRGN, NMETHD, NPARAM, KPRML, LINPTP, LMTHDP,
     $    RMISSV, FACMLT, FACADD, SMOLWT, MVARBL,
     $    MSBRGN, MMETHD, PARAMS, MPARAM, JMTHDN,
     $    JPARMP, JPARMC, SMTHMN, SMTHMX, JFLAG)
C
C NAME -- METHOD DEFINITION PACKET READ
C
C DESCRIPTION -- READS THE METHOD DEFINITION PACKET AS PART OF
C                TIME-VARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES
C         NSBRGN    I  NUMBER OF SUBREGIONS
C         NMETHD    I  NUMBER OF METHODS
C         NPARAM    I  NUMBER OF PARAMETERS
C         KPRML     I  CURRENT LOCATION IN PARAMETER LIST
C         LINPTP    I  INPUT PRINT FLAG
C         LMTHDP    I  METHOD TABLE PRINT FLAG
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C         MSBRGN    I  SUBREGION NAMES
C         MMETHD    I  METHOD NAMES
C
C OUTPUTS --
C         PARAMS    R  METHOD PARAMETERS
C         MPARAM    I  PARAMETER NAMES
C         JMTHDN    I  METHOD NUMBERS
C         JPARMP    I  PARAMETER LIST POINTERS
C         JPARMC    I  PARAMETER LIST COUNTERS
C         SMTHMN    R  MINIMUM ALLOWABLE VALUES
C         SMTHMX    R  MAXUMUM ALLOWABLE VALUES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         NMTHPR    I  NUMBER OF PARAMETERS FOR THIS METHOD
C         KSBRG     I  CURRENT SUBREGION NUMBER
C         KVRBL     I  CURRENT VARIABLE NUMBER
C         KMTHD     I  CURRENT METHOD NUMBER
C         KPRMP     I  CURRENT PARAMETER POINTER
C         KPRMC     I  CURRENT PARAMETER COUNTER
C         KVLOC     I  LOCAL VARIABLE POINTER
C         KBEGS     I  BEGINNING LOCATION FOR SUBREGION LOOP
C         KENDS     I  ENDING LOCATION FOR SUBREGION LOOP
C         KBEGV     I  BEGINNING LOCATION FOR VARIABLE LOOP
C         KENDV     I  ENDING LOCATION FOR VARIABLE LOOP
C         KBEGP     I  BEGINNING LOCATION FOR PARAMETER LOOP
C         KENDP     I  ENDING LOCATION FOR PARAMETER LOOP
C         MVARNM    I  INPUT VARIABLE NAME
C         MSBRNM    I  INPUT SUBREGION NAME
C         MMTHNM    I  INPUT METHOD NAME
C         MALLNM    I  REFERENCE NAME FOR 'ALL'
C         MENDMD    I  PACKET TRAILER NAME
C         MCRDID    I  CARD IDENTIFICATION
C         VALMIN    R  MINIMUM ALLOWABLE VALUE
C         VALMAX    R  MAXIMUM ALLOWABLE VALUE
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -10       SUBREGION NAME NOT FOUND
C         -14       VARIABLE NAME NOT FOUND
C         -17       METHOD NAME NOT FOUND
C         -18       OVERFLOW OF PARAMETER VECTORS
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LMTHDP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NVARBL)
      DIMENSION FACADD(NVARBL)
      DIMENSION SMOLWT(NVARBL)
      DIMENSION PARAMS(NPARAM)
Ctcm  DIMENSION MVARBL(NAMLEN, NVARBL)
      character*4 MVARBL(NAMLEN, NVARBL)
Ctcm  DIMENSION MSBRGN(NAMLEN, NSBRGN)
      character*4 MSBRGN(NAMLEN, NSBRGN)
Ctcm  DIMENSION MMETHD(NAMLEN, NMETHD)
      character*4 MMETHD(NAMLEN, NMETHD)
Ctcm  DIMENSION MPARAM(NAMLEN, NPARAM)
      character*4 MPARAM(NAMLEN, NPARAM)
      DIMENSION JMTHDN(NSBRGN, NVARBL)
      DIMENSION JPARMP(NSBRGN, NVARBL)
      DIMENSION JPARMC(NSBRGN, NVARBL)
      DIMENSION SMTHMN(NSBRGN, NVARBL)
      DIMENSION SMTHMX(NSBRGN, NVARBL)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MVARNM(10), MENDMD(10), MMTHNM(10), MCRDID(20)
      character*4 MVARNM(10), MENDMD(10), MMTHNM(10), MCRDID(20)
Ctcm  DIMENSION MSBRNM(10), MALLNM(10)
      character*4 MSBRNM(10), MALLNM(10)
C
C DECLARE PACKET TRAILER AND 'ALL'
C
      DATA MENDMD /'E', 'N', 'D', 7*' '/
      DATA MALLNM /'A', 'L', 'L', 7*' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MSBRNM, MVARNM, MMTHNM,
     $     VALMIN, VALMAX, NMTHPR, MCRDID
      IF (LINPTP) WRITE(IPRINT,2105) MSBRNM, MVARNM, MMTHNM,
     $     VALMIN, VALMAX, NMTHPR, MCRDID
C
C PACK SUBREGION NAME
C
      CALL TXTPAK(IPRINT, NAMLEN, MSBRNM, NPACKD, JFLAG)
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MENDMD, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 410
C
C COMPARE SUBREGION NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 113
C
C SET SUBREGION POINTER TO ZERO TO INDICATE 'ALL'
C
      KSBRG = 0
      GO TO 120
C
C SET LOOP TO FIND SUBREGION NAME
C
  113 DO 115 K = 1, NSBRGN
C
C COMPARE INPUT SUBREGION NAME WITH THE LIST OF SUBREGION NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MSBRNM, MSBRGN(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND SUBREGION NAME -- SAVE LOCATION AND SKIP OUT
C
         KSBRG = K
         GO TO 120
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  115 CONTINUE
      GO TO 950
C
C PACK VARIABLE NAME
C
  120 CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)
C
C COMPARE VARIABLE NAME WITH 'ALL'
C
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MALLNM, JFLAG)
      IF (JFLAG .EQ. 0) GO TO 123
C
C SET VARIABLE POINTER TO ZERO TO INDICATE 'ALL'
C
      KVRBL = 0
      GO TO 140
C
C SET LOOP TO FIND VARIABLE NAME
C
  123 DO 125 K = 1, NVARBL
C
C COMPARE INPUT VARIABLE NAME WITH THE LIST OF VARIABLE NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 125
C
C FOUND VARIABLE NAME -- SAVE LOCATION AND SKIP OUT
C
         KVRBL = K
         GO TO 140
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  125 CONTINUE
      GO TO 970
C
C PACK METHOD NAME
C
  140 CALL TXTPAK(IPRINT, NAMLEN, MMTHNM, NPACKD, JFLAG)
C
C SET LOOP TO FIND METHOD NAME IN LIST
C
      DO 145 J = 1, NMETHD
C
C FIND THIS METHOD NAME IN LIST OF STANDARD METHODS
C
         CALL COMPAR(IPRINT, NAMLEN, MMTHNM, MMETHD(1,J), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 145
C
C FOUND NAME -- SAVE LOCATION AND SKIP OUT
C
         KMTHD = J
         GO TO 150
C
C END LOOP -- ERROR IF NAME NOT FOUND
C
  145 CONTINUE
      GO TO 985
C
C IF MINIMUM VALUE IS DESIRED, DO UNIT CONVERSION
C
  150 IF (VALMIN .EQ. RMISSV) GO TO 160
C
C SET VARIABLE NUMBER -- IF 'ALL', ASSUME FIRST FOR FACTORS
C
      KVLOC = KVRBL
      IF (KVLOC .EQ. 0) KVLOC = 1
      CALL UNTCNV(VALMIN, FACMLT(KVLOC), FACADD(KVLOC), SMOLWT(KVLOC),
     $      RMISSV, RMISSV, VALMIN)
C
C IF MAXIMUM VALUE IS DESIRED, DO UNIT CONVERSION
C
  160 IF (VALMAX .EQ. RMISSV) GO TO 170
C
C SET VARIABLE NUMBER -- IF 'ALL', ASSUME FIRST FOR FACTORS
C
      KVLOC = KVRBL
      IF (KVLOC .EQ. 0) KVLOC = 1
      CALL UNTCNV(VALMAX, FACMLT(KVLOC), FACADD(KVLOC), SMOLWT(KVLOC),
     $     RMISSV, RMISSV, VALMAX)
C
C CHECK FOR PARAMETERS -- IF NONE, SET POINTER AND COUNTER TO ZERO
C
  170 IF (NMTHPR .GT. 0) GO TO 180
      KPRMP = 0
      KPRMC = 0
      GO TO 210
C
C VERIFY THAT THERE IS ROOM FOR THESE PARAMETERS AND SET POINT/COUNT
C
  180 IF (NMTHPR + KPRML .GT. NPARAM) GO TO 990
      KPRMP = KPRML
      KPRMC = NMTHPR
C
C SET READ LOOP FOR PARAMETER CARDS
C
      DO 185 J = 1, NMTHPR
C
C READ AND, IF WANTED, PRINT THE PARAMETER CARD
C
         READ (INCARD, 1185) (MPARAM(I, KPRML), I = 1, NAMLEN),
     $         PARAMS(KPRML), MCRDID
         IF (LINPTP) WRITE (IPRINT, 2185) (MPARAM(I, KPRML), I = 1,
     $         NAMLEN), PARAMS(KPRML), MCRDID
C
C RESET PARAMETER POINTER AND END LOOP
C
         KPRML = KPRML + 1
  185 CONTINUE
C
C SET LOOP PARAMETERS FOR STORING INPUT
C
  210 KBEGV = KVRBL
      KENDV = KVRBL
      KBEGS = KSBRG
      KENDS = KSBRG
      IF (KVRBL .EQ. 0) KBEGV = 1
      IF (KVRBL .EQ. 0) KENDV = NVARBL
      IF (KSBRG .EQ. 0) KBEGS = 1
      IF (KSBRG .EQ. 0) KENDS = NSBRGN
C
C SET LOOPS FOR STORING INPUT
C
      DO 235 KVRBL = KBEGV, KENDV
         DO 225 KSBRG = KBEGS, KENDS
C
C STORE METHOD NUMBER, PARAMETER POINTER/COUNTER, AND RANGE LIMITS
C
            JMTHDN(KSBRG, KVRBL) = KMTHD
            JPARMP(KSBRG, KVRBL) = KPRMP
            JPARMC(KSBRG, KVRBL) = KPRMC
            SMTHMN(KSBRG, KVRBL) = VALMIN
            SMTHMX(KSBRG, KVRBL) = VALMAX
C
C END LOOPS AND GET NEXT CARD
C
  225    CONTINUE
  235 CONTINUE
      GO TO 105
C
C END OF PACKET -- PRINT METHOD TABLE IF WANTED, ELSE RETURN
C
  410 IF (.NOT. LMTHDP) GO TO 1000
      WRITE (IPRINT, 2405)
C
C SET LOOPS FOR VARIABLE AND SUBREGION AND ISOLATE METHOD NUMBER
C
      DO 435 J = 1, NSBRGN
         DO 425 K = 1, NVARBL
            KMTHD = JMTHDN(J,K)
C
C WRITE THIS ENTRY
C
            WRITE (IPRINT, 2410) (MSBRGN(I,J), I = 1, NAMLEN),
     $                            (MVARBL(I,K), I = 1,NAMLEN),
     $                            (MMETHD(I,KMTHD), I = 1, NAMLEN),
     $                            SMTHMN(J,K), SMTHMX(J,K)
C
C IF THERE ARE PARAMETERS, SET LOOP CONTROLS
C
            IF (JPARMC(J,K) .EQ. 0) GO TO 425
            KBEGP = JPARMP(J,K)
            KENDP = KBEGP + JPARMC(J,K) - 1
C
C WRITE PARAMETERS IN LOOP
C
            DO 415 N = KBEGP, KENDP
               WRITE (IPRINT, 2415) (MPARAM(I,N), I = 1,NAMLEN),
     $                               PARAMS(N)
C
C END ALL LOOPS
C
  415       CONTINUE
  425    CONTINUE
  435 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR SUBREGION NAME NOT FOUND
C
  950 WRITE (IPRINT, 2950) MSBRNM
      JFLAG = -10
      GO TO 1000
C
C ERROR MESSAGE FOR VARIABLE NAME NOT FOUND
C
  970 WRITE (IPRINT, 2970) MVARNM
      JFLAG = -14
      GO TO 1000
C
C ERROR MESSAGE FOR METHOD NAME NOT IN STANDARD METHOD LIST
C
  985 WRITE (IPRINT, 2985) MMTHNM
      JFLAG = -17
      GO TO 1000
C
C ERROR MESSAGE FOR OVERFLOW OF PARAMETER VECTOR
C
  990 WRITE (IPRINT, 2990) NPARAM
      JFLAG = -18
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 10A1, 10A1, 2F10.0, I10, 20A1)
 1185 FORMAT (10A1, F10.0, 40X, 20A1)
 2105 FORMAT (1X, 10A1, 10A1, 10A1, 2F10.4, I10, 20A1)
 2185 FORMAT (1X, 10A1, F12.4, 38X, 20A1)
 2405 FORMAT (1H1, 50X, 13HMETHODS TABLE, //,
     $        46H  SUBREGION      VARIABLE        METHOD       ,
     $        46H MIN. VALUE     MAX. VALUE      PARAMETER     ,
     $        11H PAR. VALUE , //)
 2410 FORMAT (1X, 10A1, 5X, 10A1, 5X, 10A1, 2F15.4)
 2415 FORMAT (1X, 75X, 10A1, F15.4)
 2950 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        33H UNABLE TO LOCATE SUBREGION NAME , 10A1,
     $        19H IN SUBREGION TABLE, //,
     $        34H CHECK SUBREGION NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,
     $        18H IN VARIABLE TABLE , //,
     $        33H CHECK VARIABLE NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2985 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        30H UNABLE TO LOCATE METHOD NAME , 10A1,
     $        25H IN STANDARD METHOD TABLE, //,
     $        31H CHECK METHOD NAME SPELLING OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2990 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        45H THE NUMBER OF INPUT PARAMETERS HAS EXCEEDED ,
     $        32H THE ORIGINAL ESTIMATED VALUE OF , I10, //,
     $        49H RESUBMIT WITH LARGER VALUE IN CONTROL PACKET OR ,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
