      SUBROUTINE STATRD (INCARD, IPRINT, NAMLEN, NUNITS, NSTATS, LINPTP,
     $                   LSTATP, XREGOR, YREGOR, XCELLD, YCELLD,
     $                   RMISSV, FACMLT, FACADD, SMOLWT, MVARBL,
     $                   XSTATL, YSTATL, STATHT, MSTATS, JFLAG)
C
C NAME -- STATION IDENTIFICATION PACKET READ
C
C DESCRIPTION -- READS THE STATION IDENTIFICATION PACKET AS PART OF
C                TIME-INVARIANT DATA PREPARATION PROGRAM INPUT
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NUNITS    I  NUMBER OF UNITS
C         LINPTP    I  INPUT PRINT FLAG
C         LSTATP    I  STATIONS TABLE PRINT FLAG
C         XREGOR    R  X-COORDINATE OF MODELING REGION
C         YREGOR    R  Y-COORDINATE OF MODELING REGION
C         XCELLD    R  CELL DISTANCE IN X-DIRECTION
C         YCELLD    R  CELL DISTANCE IN Y-DIRECTION
C         RMISSV    R  MISSING VALUE INDICATOR
C         FACMLT    R  MULTIPLICATIVE FACTOR
C         FACADD    R  ADDITIVE FACTOR
C         SMOLWT    R  MOLECULAR WEIGHT
C         MVARBL    I  VARIABLE NAMES
C
C OUTPUTS --
C         XSTATL    R  STATION LOCATION X-COORDINATE
C         YSTATL    R  STATION LOCATION Y-COORDINATE
C         STATHT    R  HEIGHT OF STATION ABOVE GROUND
C         MSTATS    I  STATION NAMES
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR
C         KCOOR     I  POINTER TO 'COORD' IN VARIABLE NAME LIST
C         KHGHT     I  POINTER TO 'HEIGHT' IN VARIABLE NAME LIST
C         KSTAT     I  POINTER TO STATION NAME
C         MENDST    I  PACKET TRAILER NAME
C         MSTANM    I  INPUT STATION NAME
C         MCOORD    I  REFERENCE NAME FOR 'COORD'
C         MHIGHT    I  REFERENCE NAME FOR 'HEIGHT'
C         MBLANK    I  BLANK CHARACTER
C         MCRDID    I  CARD IDENTIFICATION
C         STATXL    R  X-LOCATION OF STATION
C         STATYL    R  Y-LOCATION OF STATION
C         STATZL    R  Z-LOCATION OF STATION
C
C ROUTINES CALLED --
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         UNTCNV    CONVERTS VALUES TO STANDARD UNITS
C
C ERROR CONDITIONS --
C         -7        'COORD' NOT IN VARIABLE NAME LIST
C         -9        'HEIGHT' NOT IN VARIABLE NAME LIST
C         -11       BLANK NAME
C         -14       NO SPACE FOR NEW STATION NAME
C
C OTHER INFORMATION --
C
C
C
C DECARE LOGICALS
C
      LOGICAL LINPTP
      LOGICAL LSTATP
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
      DIMENSION FACMLT(NUNITS)
      DIMENSION FACADD(NUNITS)
      DIMENSION SMOLWT(NUNITS)
      DIMENSION XSTATL(NSTATS)
      DIMENSION YSTATL(NSTATS)
      DIMENSION STATHT(NSTATS)
Ctcm  DIMENSION MVARBL(NAMLEN,NUNITS)
      character*4 MVARBL(NAMLEN,NUNITS)
Ctcm  DIMENSION MSTATS(NAMLEN,NSTATS)
      character*4 MSTATS(NAMLEN,NSTATS)
C
C SET DIMENSIONS OF INTERNAL ARRAYS
C
Ctcm  DIMENSION MENDST(10), MSTANM(10), MCOORD(10), MHIGHT(10)
      character*4 MENDST(10), MSTANM(10), MCOORD(10), MHIGHT(10)
Ctcm  DIMENSION MCRDID(20)
      character*4 MCRDID(20)
      character*4 MBLANK
C
C DECLARE PACKET TRAILER AND DISTANCE UNIT NAMES
C
      DATA MENDST /'E', 'N', 'D', 7*' '/
      DATA MCOORD /'C', 'O', 'O', 'R', 'D', ' ', ' ', ' ', ' ', ' '/
      DATA MHIGHT /'H', 'E', 'I', 'G', 'H', 'T', ' ', ' ', ' ', ' '/
C
C DECLARE MISCELLANEOUS SCALARS
C
      DATA MBLANK /' '/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
C
C FIND COORD IN VARIABLE LIST
C
      DO 45 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MCOORD, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 45
C
C FOUND IT -- SAVE LOCATION
C
         KCOOR = J
         GO TO 50
C
C END LOOP -- IF NOT FOUND, COORD IS MISSING FROM LIST
C
   45 CONTINUE
      GO TO 935
C
C FIND HEIGHT IN VARIABLE LIST
C
   50 DO 55 J = 1,NUNITS
         CALL COMPAR(IPRINT, NAMLEN, MHIGHT, MVARBL(1,J), JFLAG)
         IF (JFLAG .NE. 1) GO TO 55
C
C FOUND IT -- SAVE LOCATION
C
         KHGHT = J
         GO TO 105
C
C END LOOP -- IF NOT FOUND, HEIGHT IS MISSING FROM LIST
C
   55 CONTINUE
      GO TO 945
C
C READ AND, IF WANTED, PRINT THE INPUT CARD
C
  105 READ (INCARD, 1105) MSTANM, STATXL, STATYL, STATZL, MCRDID
      IF (LINPTP) WRITE (IPRINT, 2105) MSTANM, STATXL, STATYL,
     $                   STATZL, MCRDID
C
C PACK STATION NAME AND CHECK FOR BLANK
C
      CALL TXTPAK(IPRINT, NAMLEN, MSTANM, NPACKD, JFLAG)
      IF (NPACKD .EQ. 0) GO TO 955
C
C CHECK FOR END OF PACKET
C
      CALL COMPAR(IPRINT, NAMLEN, MSTANM, MENDST, JFLAG)
      IF (JFLAG .EQ. 1) GO TO 210
C
C SET LOOP TO FIND STATION NAME
C
      DO 115 K = 1, NSTATS
C
C COMPARE INPUT STATION NAME WITH THE LIST OF STATION NAMES
C
         CALL COMPAR(IPRINT, NAMLEN, MSTANM, MSTATS(1,K), JFLAG)
         IF (JFLAG .EQ. 0) GO TO 115
C
C FOUND STATION NAME -- SAVE LOCATION AND SKIP OUT
C
         KSTAT = K
         GO TO 140
  115 CONTINUE
C
C NAME NOT FOUND -- SET LOOP TO FIND BLANK SPOT
C
      DO 135 K = 1, NSTATS
C
C COMPARE FIRST LETTER WITH BLANK
C
         IF (MSTATS(1,K) .NE. MBLANK) GO TO 135
C
C FOUND ONE -- STUFF THE NAME IN HERE
C
         KSTAT = K
         DO 125 J = 1, NAMLEN
            MSTATS(J,K) = MSTANM(J)
C
C END INNER LOOP AND SKIP TO LOCATION PROCESSING
C
  125    CONTINUE
         GO TO 140
C
C FINISH OUTER LOOP -- IF NO BLANKS, ERROR IN COUNT OR SPELLING
C
  135 CONTINUE
      GO TO 970
C
C DO UNIT CONVERSION FOR X-AND Y-LOCATIONS AND STATION HEIGHT
C
  140 CALL UNTCNV(STATXL, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, STATXL)
      CALL UNTCNV(STATYL, FACMLT(KCOOR), FACADD(KCOOR), RMISSV, RMISSV,
     $            RMISSV, STATYL)
      CALL UNTCNV(STATZL, FACMLT(KHGHT), FACADD(KHGHT), RMISSV, RMISSV,
     $            RMISSV, STATHT(KSTAT))
C
C CONVERT COORDINATES TO GRID UNITS AND GO BACK FOR NEXT STATION
C
      XSTATL(KSTAT) = (STATXL - XREGOR) / XCELLD
      YSTATL(KSTAT) = (STATYL - YREGOR) / YCELLD
      GO TO 105
C
C END OF PACKET, PRINT STATIONS TABLE IF WANTED, ELSE RETURN
C
  210 IF (.NOT. LSTATP) GO TO 1000
      WRITE (IPRINT, 2210)
C
C PRINT VALUES IN LOOP
C
      DO 215 J = 1, NSTATS
         WRITE (IPRINT, 2215)(MSTATS(I,J), I=1,NAMLEN),
     $       XSTATL(J), YSTATL(J), STATHT(J)
  215 CONTINUE
C
C END OF PACKET -- RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR 'COORD' NOT IN VARIABLE NAME LIST
C
  935 WRITE (IPRINT, 2935) MCOORD
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR 'HEIGHT' NOT IN VARIABLE NAME LIST
C
  945 WRITE (IPRINT, 2945) MHIGHT
      JFLAG = -9
      GO TO 1000
C
C ERROR MESSAGE FOR BLANK NAME
C
  955 WRITE (IPRINT, 2955)
      JFLAG = -11
      GO TO 1000
C
C ERROR MESSAGE FOR NO SPACE FOR NEW STATION NAME
C
  970 WRITE (IPRINT, 2970) MSTANM
      JFLAG = -14
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 1105 FORMAT (10A1, 3F10.0, 20X, 20A1)
 2105 FORMAT (1X, 10A1, 2F10.0, F10.2, 20X, 20A1)
 2210 FORMAT (1H1, 40X, 28HSTATION IDENTIFICATION TABLE, //,
     $        52H STATION NAME       X-LOCATION(GRID SQ)  Y-LOCATION ,
     $        33H(GRID SQ)  STATION HEIGHT(METERS), //)
 2215 FORMAT (1X, 5X, 10A1, 10X, F10.2, 10X, F10.2, 10X, F10.2, /)
 2935 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2945 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H UNABLE TO LOCATE , 10A1,
     $        24H IN VARIABLE NAMES TABLE, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2955 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        39H BLANK STATION NAMES ARE NOT ACCEPTABLE,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2970 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,
     $        46H INSUFFICIENT SPACE IN STATION NAME TABLE FOR ,
     $        8HSTATION , 10A1, //, 21H TOTAL STATION COUNT ,
     $        46H MAY BE TOO SMALL, OR A NAME MAY BE MISSPELLED, //,
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
