      SUBROUTINE TIMERD (INCARD, IPRINT, JBEGDT, JENDDT, BEGTIM, ENDTIM,
     $                   JFLAG)
C
C NAME -- DATE AND TIME READ
C
C DESCRIPTION -- READS THE BEGINNING AND ENDING DATES AND TIMES
C         FROM A CARD
C
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977
C
C INPUTS --
C         INCARD    I  FORTRAN INPUT UNIT
C         IPRINT    I  FORTRAN OUTPUT UNIT
C
C OUTPUTS --
C         JBEGDT    I  BEGINNING DATE
C         JENDDT    I  ENDING DATE
C         BEGTIM    R  BEGINNING TIME
C         ENDTIM    R  ENDING TIME
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         JMINDT    I   EARLIEST ALLOWABLE DATE
C         JMAXDT    I   LATEST ALLOWABLE DATE
C         JMINTM    I   EARLIEST ALLOWABLE TIME
C         JMAXTM    I   LATEST ALLOWABLE TIME
C         JBEGTM    I   BEGINNING TIME
C         JENDTM    I   ENDING TIME
C
C ROUTINES CALLED -- NONE
C
C ERROR CONDITIONS --
C
C         -1        BEGINNING DATE OUT OF RANGE
C         -2        BEGINNING TIME OUT OF RANGE
C         -3        ENDING DATE OUT OF RANGE
C         -4        ENDING TIME OUT OF RANGE
C         -5        TIME FLOWS BACKWARDS
C
C OTHER INFORMATION --
C
C
C SET DIMENSION ON CARD IDENTIFICATION
C
Ctcm  DIMENSION MCRDID(20)
      character*4 MCRDID(20)
C
C SET THE MINIMUM AND MAXIMUM DATES AND TIMES
C
      DATA JMINDT /00001/
      DATA JMAXDT /99365/
      DATA JMINTM /0000/
      DATA JMAXTM /2400/
C
C SET COMPLETION FLAG TO INITIALIZE VALUE
C
      JFLAG = 0
C
C READ AND PRINT THE INPUT CARDS
C
      READ (INCARD,1005) JBEGDT, JBEGTM, JENDDT, JENDTM, MCRDID
      WRITE(IPRINT,2005) JBEGDT, JBEGTM, JENDDT, JENDTM, MCRDID
C
C CHECK EACH DATE AND TIME FOR BEING WITHIN RANGE
C
      IF (JBEGDT .LT. JMINDT .OR. JBEGDT .GT. JMAXDT) GO TO 905
      IF (JBEGTM .LT. JMINTM .OR. JBEGTM .GT. JMAXTM) GO TO 910
      IF (JENDDT .LT. JMINDT .OR. JENDDT .GT. JMAXDT) GO TO 915
      IF (JENDTM .LT. JMINTM .OR. JENDTM .GT. JMAXTM) GO TO 920
C
C CHECK THAT TIME FLOWS FORWARD
C
      IF (JBEGDT * 10000 + JBEGTM .GT. JENDDT * 10000 + JENDTM)
     $    GO TO 925
C
C CONVERT TIMES FROM HOURS AND MINUTES TO FRACTIONAL HOURS
C
      BEGTIM = FLOAT(JBEGTM / 100) + FLOAT(MOD(JBEGTM, 100)) / 60.
      ENDTIM = FLOAT(JENDTM / 100) + FLOAT(MOD(JENDTM, 100)) / 60.
C
C RETURN TO CALLING PROGRAM
C
      GO TO 1000
C
C ERROR MESSAGE FOR BEGINNING DATE OUT OF RANGE
C
  905 WRITE (IPRINT,2905) JBEGDT, JMINDT, JMAXDT
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR BEGINNING TIME OUT OF RANGE
C
  910 WRITE(IPRINT, 2910) JBEGTM, JMINTM, JMAXTM
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ENDING DATE OUT OF RANGE
C
  915 WRITE (IPRINT,2915) JENDDT, JMINDT, JMAXDT
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR ENDING TIME OUT OF RANGE
C
  920 WRITE (IPRINT,2920) JENDTM, JMINTM, JMAXTM
      JFLAG = -4
      GO TO 1000
C
C ERROR MESSAGE FOR TIME FLOWING BACKWARDS
C
  925 WRITE (IPRINT,2925)
      JFLAG = -5
      GO TO 1000
C
C RETURN TO CALLING PROGRAM
C
 1000 RETURN
C
C FORMATS
C
 1005 FORMAT (4I10,20X,20A1)
 2005 FORMAT (1X,4I10,20X,20A1)
 2905 FORMAT (1H1, 25H****** INPUT ERROR ******,
     $        16H BEGINNING DATE , I10, 25H IS OUTSIDE THE RANGE OF ,
     $        I10, 4H TO , I10, //, 24H VALUE MUST BE CORRECTED, //)
 2910 FORMAT (1H1, 25H****** INPUT ERROR ******,
     $        13H ENDING DATE ,I10, 25H IS OUTSIDE THE RANGE OF ,
     $        I10, 4H TO , I10, //, 24H VALUE MUST BE CORRECTED, //)
 2915 FORMAT (1H1, 25H****** INPUT ERROR ******,
     $        16H BEGINNING TIME , I10, 25H IS OUTSIDE THE RANGE OF ,
     $        I10, 4H TO , I10, //, 24H VALUE MUST BE CORRECTED, //)
 2920 FORMAT (1H1, 25H****** INPUT ERROR ******,
     $        13H ENDING TIME , I10, 25H IS OUTSIDE THE RANGE OF ,
     $        I10, 4H TO , I10, //, 24H VALUE MUST BE CORRECTED, //)
 2925 FORMAT (1H1, 25H****** INPUT ERROR ******,
     $        53H BEGINNING DATE AND TIME FOLLOWS ENDING DATE AND TIME,
     $        //, 39H PLACE DATES AND TIMES IN CORRECT ORDER, //)
      END
