      SUBROUTINE TPCNRD(IPRINT, INFILE, ITCFIL, NAMLEN, NVARBL,
     $    NXCELL, NYCELL, JCURDT, CURTIM, MVARBL, MVARNM,
     $    OUTMAT, TOPMAT, JFLAG)
C
C NAME -- TOP CONCENTRATION FILE READ
C
C DESCRIPTION -- READS THE TIME-VARIANT TOP CONCENTRATION FILE RECORD
C                WHEN TIME UPDATE IS NEEDED
C
C PROGRAMMER -- DC WHITNEY /SAI JULY 1977
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         ITCFIL    I  OFF CORE STORAGE FILE FOR TOPCON
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES TO BE READ
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         JCURDT    I  CURRENT DATE
C         CURTIM    R  CURRENT TIME
C         MVARBL    I  VARIABLE NAMES
C
C OUTPUTS --
C         MVARNM    I  FILE VARIABLE NAME
C         OUTMAT    R  THE OUTPUT VALUE MATRIX
C         TOPMAT    R  THREE - D TOPCON ARRAY
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         NSGMNT    I  NUMBER OF SEGMENTS
C         KSGMT     I  FILE SEGMENT NUMBER
C         KVRBL     I  VARIABLE NUMBER
C         JSTRDT    I  STARTING DATE FOR CURRENT RECORD
C         JSTPDT    I  STOPPING DATE FOR CURRENT RECORD
C         STRTIM    R  STARTING TIME FOR CURRENT RECORD
C         STPTIM    R  STOPPING TIME FOR CURRENT RECORD
C
C ROUTINES CALLED --
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         FLTCRD    READS A TOP CONCENTRATION RECORD
C         FLTMRD    READS A TIME SPAN RECORD
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        ERROR IN FILE TIME READ
C         -3        ERROR IN FILE RECORD READ
C         -4        MISMATCH ON SEGMENT NUMBER
C         -5        ERROR IN VARIABLE NAME COMPARISON ROUTINE
C         -6        MISMATCH ON VARIABLE NAME
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN, NVARBL)
      character*4 MVARBL(NAMLEN, NVARBL)
Ctcm  DIMENSION MVARNM(NAMLEN, NVARBL)
      character*4 MVARNM(NAMLEN, NVARBL)
      DIMENSION OUTMAT (NXCELL, NYCELL)
      DIMENSION TOPMAT (1)
C
C INITIALIZE DATE AND TIME VALUES
C
      DATA JSTRDT /0/
      DATA JSTPDT /0/
      DATA STRTIM /0.0/
      DATA STPTIM /0.0/
      DATA NSGMNT /1/
      DATA NFLVAR /1/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
      KZCLL = 1
      NFLZCL = 1
C
C
C TEST DATE AND TIME FOR BEING IN CURRENT SPAN
C
C 105 IF (JCURDT .GE. JSTRDT .AND. JCURDT .LE. JSTPDT .AND.
C    $    CURTIM .GE. STRTIM .AND. CURTIM .LT. STPTIM) GO TO 1000
105   CONTINUE
      IF(CURTIM.GE.STRTIM+24.*FLOAT(JSTRDT-JCURDT).AND.
     $CURTIM.LT.STPTIM+24.*FLOAT(JSTPDT-JCURDT)) GO TO 1000
C
C TEST DATE AND TIME FOR BEING PRIOR TO CURRENT SPAN
C
      IF (JCURDT .LT. JSTRDT) GO TO 905
      IF (JCURDT .EQ. JSTRDT .AND. CURTIM .LT. STRTIM) GO TO 905
C
C READ NEXT DATE AND TIME
C
      CALL FLTMRD(IPRINT, INFILE, JSTRDT, JSTPDT, STRTIM, STPTIM, JFLAG)
      IF (JFLAG .LT. 0) GO TO 910
C
C SET LOOP OVER ALL VARIABLES
C
      DO 110 J = 1, NVARBL
         KVRBL = J
C
C READ THE NEXT FILE RECORD
C
         CALL FLTCRD(IPRINT, INFILE, NAMLEN, NFLVAR, NXCELL, NYCELL,
     $    KSGMT, MVARNM, OUTMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 915
C
C CHECK THE SEGMENT NUMBER
C
         IF (KSGMT .NE. NSGMNT) GO TO 920
C
C STORE TOP CONCENTRATION VALUES IN MATRIX
C
         CALL MATPUT(IPRINT, ITCFIL, NXCELL, NYCELL, NFLZCL, NVARBL,
     $        KZCLL, KVRBL, OUTMAT, TOPMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 922
C
C CHECK THE FILE NAME AGAINST THE INPUT NAME
C
         CALL COMPAR(IPRINT, NAMLEN, MVARBL(1, J), MVARNM, JFLAG)
         IF (JFLAG .LT. 0) GO TO 925
         IF (JFLAG .EQ. 1) GO TO 110
         GO TO 930
C
C END LOOP AND GO BACK TO TIME TEST
C
  110 CONTINUE
      GO TO 105
C
C ERROR MESSAGE FOR TIME PRIOR TO CURRENT
C
  905 WRITE (IPRINT, 2905) NAMLEN
      JFLAG = -1
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON FILE TIME READ
C
  910 WRITE (IPRINT, 2910) JFLAG
      JFLAG = -2
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON FILE RECORD READ
C
  915 WRITE (IPRINT, 2915) JFLAG, (MVARBL(I, KVRBL), I = 1, NAMLEN)
      JFLAG = -3
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON SEGMENT NUMBER
C
  920 WRITE (IPRINT, 2920) KSGMT, NSGMNT
      JFLAG = -4
      GO TO 1000
C
C ERROR IN MATPUT
C
  922 WRITE(IPRINT, 2922) JFLAG
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON VARIABLE NAMES COMPARISON
C
  925 WRITE (IPRINT, 2925) JFLAG
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON VARIABLE NAME
C
  930 WRITE(IPRINT, 2930) (MVARNM(I,1), I = 1, NAMLEN),
     $                     (MVARBL(I,KVRBL), I = 1,NAMLEN)
      JFLAG = -6
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2905 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        18H THE CURRENT DATE , I10, 10H AND TIME , F10.2, //,
     $        28H ARE PRIOR TO THE FILE DATE , I10, 10H AND TIME ,F10.2,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2910 FORMAT(26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURN TO TPCNRD FROM SUBROUTINE FLTMRD , //)
 2915 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURNED TO TPCNRD FROM SUBROUTINE FLTCRD ,
     $        14H FOR VARIABLE , 10A1, //)
 2920 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        25H THE FILE SEGMENT NUMBER , I10, //,
     $        43H DOES NOT MATCH THE CURRENT SEGMENT NUMBER , I10,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
 2922 FORMAT (26H ****** ERROR TRACE ****** ,12H ERROR FLAG , I10,
     $        43H RETURNED TO TPCNRD FROM SUBROUTINE MATPUT , // )
 2925 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURND TO TPCNRD FROM SUBROUTINE COMPAR , //)
 2930 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        24H THE FILE VARIABLE NAME , 10A1, //,
     $        42H DOES NOT MATCH THE CURRENT VARIABLE NAME , 10A1,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
