      SUBROUTINE TPUVRD(IPRINT, INFILE, ITCFIL, NAMLEN, NVARBL,
     $    NXCELL, NYCELL, JCURDT, CURTIM, MVARBL, MVARNM,
     $    OUTMAT, TOPMAT, JFLAG)
C
C NAME -- TOP CONCENTRATION FILE READ
C
C DESCRIPTION -- READS THE UAM-V INVARIANT TOP CONCENTRATION FILE
C
C PROGRAMMER -- TC MYERS /SAI DECEMBER 1996
C
C INPUTS --
C         IPRINT    I  FORTRAN OUTPUT UNIT
C         INFILE    I  FORTRAN INPUT FILE UNIT
C         ITCFIL    I  OFF CORE STORAGE FILE FOR TOPCON
C         NAMLEN    I  NUMBER OF WORDS IN A NAME
C         NVARBL    I  NUMBER OF VARIABLES TO BE READ
C         NXCELL    I  NUMBER OF X-CELLS
C         NYCELL    I  NUMBER OF Y-CELLS
C         JCURDT    I  CURRENT DATE
C         CURTIM    R  CURRENT TIME
C         MVARBL    I  VARIABLE NAMES
C
C OUTPUTS --
C         MVARNM    I  FILE VARIABLE NAME
C         OUTMAT    R  THE OUTPUT VALUE MATRIX
C         TOPMAT    R  THREE - D TOPCON ARRAY
C         JFLAG     I  COMPLETION FLAG
C
C LOCAL VARIABLES --
C         KVRBL     I  VARIABLE NUMBER
C         JSTRDT    I  STARTING DATE FOR CURRENT RECORD
C         JSTPDT    I  STOPPING DATE FOR CURRENT RECORD
C         STRTIM    R  STARTING TIME FOR CURRENT RECORD
C         STPTIM    R  STOPPING TIME FOR CURRENT RECORD
C
C ROUTINES CALLED --
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS
C         FLTCRD    READS A TOP CONCENTRATION RECORD
C         FLTMRD    READS A TIME SPAN RECORD
C
C ERROR CONDITIONS --
C         -1        NONPOSITIVE VALUE FOR NAME LENGTH
C         -2        ERROR IN FILE TIME READ
C         -3        ERROR IN FILE RECORD READ
C         -4        MISMATCH ON SEGMENT NUMBER
C         -5        ERROR IN VARIABLE NAME COMPARISON ROUTINE
C         -6        MISMATCH ON VARIABLE NAME
C
C OTHER INFORMATION --
C
C
C
C SET DIMENSIONS OF EXTERNAL ARRAYS
C
Ctcm  DIMENSION MVARBL(NAMLEN, NVARBL)
      character*4 MVARBL(NAMLEN, NVARBL)
Ctcm  DIMENSION MVARNM(NAMLEN, NVARBL)
      character*4 MVARNM(NAMLEN, NVARBL)
      DIMENSION OUTMAT (NXCELL, NYCELL)
      DIMENSION TOPMAT (1)
C
C INITIALIZE DATE AND TIME VALUES
C
      DATA JSTPDT /0/
      DATA NFLVAR /1/
C
C SET COMPLETION FLAG TO INITIAL VALUE
C
      JFLAG = 0
      KZCLL = 1
      NFLZCL = 1
C
C
C TEST DATE AND TIME FOR BEING IN CURRENT SPAN
C
      IF(JCURDT .LT. JSTPDT) GO TO 1000
C
C UPDATE STOP DATE TO INDICATE FILE HAS BEEN READ
C
      JSTPDT = 999999
C
C SET LOOP OVER ALL VARIABLES
C
      DO 110 J = 1, NVARBL
         KVRBL = J
C
C READ THE NEXT FILE RECORD
C
         READ(INFILE,'(10A1,F10.7)') (MVARNM(I,NFLVAR),I=1,10), XVAL
         DO 45 JJ=1,NYCELL
           DO 40 II=1,NXCELL
             OUTMAT(II,JJ) = XVAL
   40      CONTINUE
   45    CONTINUE
C
C STORE TOP CONCENTRATION VALUES IN MATRIX
C
         CALL MATPUT(IPRINT, ITCFIL, NXCELL, NYCELL, NFLZCL, NVARBL,
     $        KZCLL, KVRBL, OUTMAT, TOPMAT, JFLAG)
         IF (JFLAG .LT. 0) GO TO 922
C
C CHECK THE FILE NAME AGAINST THE INPUT NAME
C
         CALL COMPAR(IPRINT, NAMLEN, MVARBL(1, J), MVARNM, JFLAG)
         IF (JFLAG .LT. 0) GO TO 925
         IF (JFLAG .EQ. 1) GO TO 110
         GO TO 930
C
C END LOOP
C
  110 CONTINUE
      GO TO 1000
C
C ERROR IN MATPUT
C
  922 WRITE(IPRINT, 2922) JFLAG
      JFLAG = -7
      GO TO 1000
C
C ERROR MESSAGE FOR ERROR ON VARIABLE NAMES COMPARISON
C
  925 WRITE (IPRINT, 2925) JFLAG
      JFLAG = -5
      GO TO 1000
C
C ERROR MESSAGE FOR MISMATCH ON VARIABLE NAME
C
  930 WRITE(IPRINT, 2930) (MVARNM(I,1), I = 1, NAMLEN),
     $                     (MVARBL(I,KVRBL), I = 1,NAMLEN)
      JFLAG = -6
      GO TO 1000
C
C RETURN TO CALLING ROUTINE
C
 1000 RETURN
C
C FORMATS
C
 2922 FORMAT (26H ****** ERROR TRACE ****** ,12H ERROR FLAG , I10,
     $        43H RETURNED TO TPUVRD FROM SUBROUTINE MATPUT , // )
 2925 FORMAT (26H ****** ERROR TRACE ******, 12H ERROR FLAG , I10,
     $        43H RETURND TO TPUVRD FROM SUBROUTINE COMPAR , //)
 2930 FORMAT (1H1, 26H****** SYSTEM ERROR ******,
     $        24H THE FILE VARIABLE NAME , 10A1, //,
     $        42H DOES NOT MATCH THE CURRENT VARIABLE NAME , 10A1,
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)
      END
