      SUBROUTINE UNITRD (INCARD, IPRINT, NAMLEN, NUNITS, LINPTP, LUNITP,00000010
     $                   RMISSV, FACMLT, FACADD, SMOLWT, MVARBL, MUNITS,00000020
     $                   JFLAG)                                         00000030
C                                                                       00000040
C NAME -- UNIT PACKET READ                                              00000050
C                                                                       00000060
C DESCRIPTION -- READS THE UNITS PACKET AS PART OF TIME-INVARIANT       00000070
C                DATA PREPARATION PROGRAM INPUT                         00000080
C                                                                       00000090
C PROGRAMMER -- DC WHITNEY /SAI JUNE 1977                               00000100
C
C-- MODIFIED 2/20/90, TCM:  UPDATE HYDROCARBON SPECIES TO CB-IV
C   SPECIES WITH APPROPRIATE MOLECULAR WEIGHTS.  WEIGHTS USED ARE
C   CARBON NUMBER TIMES MOL. WT OF CH4 (16).
C
C                                                                       00000110
C INPUTS --                                                             00000120
C         INCARD    I  FORTRAN INPUT UNIT                               00000130
C         IPRINT    I  FORTRAN OUTPUT UNIT                              00000140
C         NAMLEN    I  NUMBER OF WORDS IN A NAME                        00000150
C         NUNITS    I  NUMBER OF INPUT PRINT FLAG                       00000160
C         LINPTP    I  INPUT PRINT FLAG                                 00000170
C         LUNITP    I  UNITS TABLE PRINT FLAG                           00000180
C         RMISSV    R  MISSING VALUE INDICATOR                          00000190
C                                                                       00000200
C OUTPUTS --                                                            00000210
C         FACMLT    R  MULTIPLICATIVE FACTOR                            00000220
C         FACADD    R  ADDITIVE FACTOR                                  00000230
C         SMOLWT    R  MOLECULAR WEIGHT                                 00000240
C         MVARBL    I  VARIABLE NAMES                                   00000250
C         MUNITS    I  UNIT NAMES                                       00000260
C         JFLAG     I  COMPLETION FLAG                                  00000270
C                                                                       00000280
C LOCAL VARIABLES --                                                    00000290
C         NPACKD    I  NUMBER OF WORDS PACKED INTO VECTOR               00000300
C         NSTDUN    I  NUMBER OF STANDARD UNIT NAMES                    00000310
C         NSTDVR    I  NUMBER OF STANDARD VARIABLE NAMES                00000320
C         KUNIT     I  CURRENT UNIT NUMBER                              00000330
C         KVRBL     I  CURRENT VARIABLE NUMBER                          00000340
C         MUNTNM    I  CURRENT UNIT NAME                                00000350
C         MVARNM    I  CURRENT VARIABLE NAME                            00000360
C         MBLANK    I  THE CHARACTER 'BLANK'                            00000370
C         MENDUN    I  PACKET TRAILER NAME                              00000380
C         MCRDID    I  CARD IDENTIFICATION                              00000390
C         MSTDVR    I  LIST OF STANDARD VARIABLE NAMES                  00000400
C         MSTDUN    I  LIST OF STANDARD UNIT NAMES                      00000410
C         MUNITA    I  EQUIVALENCE ARRAY FOR STANDARD UNIT NAMES        00000420
C         MUNITB    I  EQUIVALENCE ARRAY FOR STANDARD UNIT NAMES        00000430
C         FACMIN    R  INPUT VALUE FOR MULTIPLICATIVE FACTOR            00000440
C         FACAIN    R  INPUT VALUE FOR ADDITIVE FACTOR                  00000450
C         SMOLIN    R  INPUT VALUE FOR MOLECULAR WEIGHT                 00000460
C         STDMLT    R  MULTIPLICATIVE FACTOR FOR STANDARD UNITS         00000470
C         STDADD    R  ADDTIVE FACTOR FOR STANDARD UNITS                00000480
C         STDMWT    R  MOLECULAR WEIGHT FOR STANDARD VARIABLES          00000490
C                                                                       00000500
C ROUTINES CALLED --                                                    00000510
C         TXTPAK    LEFT-JUSTIFIES ALPHABETIC INPUT                     00000520
C         COMPAR    COMPARES TWO ALPHABETIC ITEMS                       00000530
C                                                                       00000540
C ERROR CONDITIONS --                                                   00000550
C         -4        BLANK NAME                                          00000560
C         -7        NO SPACE FOR NEW VARIABLE NAME                      00000570
C         -10       UNIT NAME NOT IN STANDARD UNIT LIST                 00000580
C         -12       VARIABLE NAME NOT IN STANDARD LIST                  00000590
C                                                                       00000600
C OTHER INFORMATION --                                                  00000610
C                                                                       00000620
C                                                                       00000630
C                                                                       00000640
C DECARE LOGICALS                                                       00000650
C                                                                       00000660
      LOGICAL LINPTP                                                    00000670
      LOGICAL LUNITP                                                    00000680
C                                                                       00000690
C SET DIMENSIONS OF EXTERNAL ARRAYS                                     00000700
C                                                                       00000710
      DIMENSION FACMLT(NUNITS)                                          00000720
      DIMENSION FACADD(NUNITS)                                          00000730
      DIMENSION SMOLWT(NUNITS)                                          00000740
Ctcm  DIMENSION MVARBL(NAMLEN,NUNITS)                                   00000750
      character*4 MVARBL(NAMLEN,NUNITS)                                   00000750
Ctcm  DIMENSION MUNITS(NAMLEN,NUNITS)                                   00000760
      character*4 MUNITS(NAMLEN,NUNITS)                                   00000760
C                                                                       00000770
C SET DIMENSIONS OF INTERNAL ARRAYS                                     00000780
C                                                                       00000790
Ctcm  DIMENSION MVARNM(10), MENDUN(10), MUNTNM(10), MCRDID(20)          00000800
      character*4 MVARNM(10), MENDUN(10), MUNTNM(10), MCRDID(20)          00000800
Ctcm  DIMENSION MSTDUN(10,100), MSTDVR(10,40)                           00000810
      character*4 MSTDUN(10,100), MSTDVR(10,40)                           00000810
Ctcm  DIMENSION MUNITA(10,100)                                          00000820
      character*4 MUNITA(10,100)                                          00000820
      DIMENSION STDMLT(100)   , STDADD(100)  , STDMWT(40)               00000830
      character*4 MBLANK
C                                                                       00000840
C SET EQUIVALENCE FOR UNIT NAMES                                        00000850
C                                                                       00000860
      EQUIVALENCE (MSTDUN(1,1), MUNITA(1,1))                            00000870
C                                                                       00000880
C SET THE STANDARD UNIT NAMES FOR TEMPERATURE                           00000890
C                                                                       00000900
      DATA ((MUNITA(I,J),I=1,10),J=1,14)                                00000910
     $                         /'D','E','G','K',' ',' ',' ',' ',' ',' ',00000920
     $                          'D','E','G','C',' ',' ',' ',' ',' ',' ',00000930
     $                          'D','E','G','F',' ',' ',' ',' ',' ',' ',00000940
     $                          'D','E','G','R',' ',' ',' ',' ',' ',' ',00000950
C                                                                       00000960
C SET THE STANDARD UNIT NAMES FOR DISTANCE                              00000970
C                                                                       00000980
     $                          'M',' ',' ',' ',' ',' ',' ',' ',' ',' ',00000990
     $                          'C','M',' ',' ',' ',' ',' ',' ',' ',' ',00001000
     $                          'K','M',' ',' ',' ',' ',' ',' ',' ',' ',00001010
     $                          'I','N',' ',' ',' ',' ',' ',' ',' ',' ',00001020
     $                          'F','T',' ',' ',' ',' ',' ',' ',' ',' ',00001030
     $                          'M','I',' ',' ',' ',' ',' ',' ',' ',' ',00001040
     $ 40 *' '/                                                         00001050
C                                                                       00001060
C SET THE STANDARD UNIT NAMES FOR VELOCITY                              00001070
C                                                                       00001080
      DATA ((MUNITA(I,J),I=1,10),J=15,26)                               00001090
     $/                         'M','/','H','R',' ',' ',' ',' ',' ',' ',00001100
     $                          'K','M','/','H','R',' ',' ',' ',' ',' ',00001110
     $                          'M','I','/','H','R',' ',' ',' ',' ',' ',00001120
     $                          'M','/','M','I','N',' ',' ',' ',' ',' ',00001130
     $                          'F','T','/','M','I','N',' ',' ',' ',' ',00001140
     $                          'M','/','S',' ',' ',' ',' ',' ',' ',' ',00001150
     $                          'F','T','/','S',' ',' ',' ',' ',' ',' ',00001160
     $                          'K','N','O','T','S',' ',' ',' ',' ',' ',00001170
     $                          40 *' '/                                00001180
C                                                                       00001190
C SET THE STANDARD UNIT NAMES FOR DIRECTION                             00001200
C                                                                       00001210
      DATA ((MUNITA(I,J),I=1,10),J=27,37)                               00001220
     $/                         'R','A','D','N','=','0',' ',' ',' ',' ',00001230
     $                          'R','A','D','S','=','0',' ',' ',' ',' ',00001240
     $                          'D','E','G','N','=','0',' ',' ',' ',' ',00001250
     $                          'D','E','G','S','=','0',' ',' ',' ',' ',00001260
     $                          '1','6','P','T','S','=','1',' ',' ',' ',00001270
     $                          '1','6','P','T','S','=','1','6',' ',' ',00001280
     $                          '3','6','P','T','S','=','1',' ',' ',' ',00001290
     $                          '3','6','P','T','S','=','3','6',' ',' ',00001300
     $                       30*' '/                                    00001310
C                                                                       00001320
C SET THE STANDARD UNIT NAMES FOR TEMPERATURE GRADIENT                  00001330
C                                                                       00001340
      DATA ((MUNITA(I,J),I=1,10),J=38,49)                               00001350
     $/                         'D','E','G','K','/','M',' ',' ',' ',' ',00001360
     $                          'D','E','G','K','/','K','M',' ',' ',' ',00001370
     $                          'D','E','G','C','/','M',' ',' ',' ',' ',00001380
     $                          'D','E','G','C','/','K','M',' ',' ',' ',00001390
     $                          'D','E','G','F','/','F','T',' ',' ',' ',00001400
     $                          'D','E','G','F','/','M','I',' ',' ',' ',00001410
     $                          'D','E','G','R','/','F','T',' ',' ',' ',00001420
     $                          'D','E','G','R','/','M','I',' ',' ',' ',00001430
     $                       40*' '/                                    00001440
C                                                                       00001450
C SET THE STANDARD UNIT NAMES FOR ATMOSPHERIC PRESSURE                  00001460
C                                                                       00001470
      DATA ((MUNITA(I,J),I=1,10),J=50,63)                               00001480
     $/                         'A','T','M','O','S','P','H','E','R','E',00001490
     $                          'B','A','R','S',' ',' ',' ',' ',' ',' ',00001500
     $                          'M','M','H','G',' ',' ',' ',' ',' ',' ',00001510
     $                          'F','T','H','2','O',' ',' ',' ',' ',' ',00001520
     $                          'K','G','/','C','M','2',' ',' ',' ',' ',00001530
     $                          '1','N','H','G',' ',' ',' ',' ',' ',' ',00001540
     $                          'L','B','/','I','N','2',' ',' ',' ',' ',00001550
     $                          'P','S','I',' ',' ',' ',' ',' ',' ',' ',00001560
     $                          'M','I','L','L','I','B','A','R','S',' ',00001570
     $                          'I','N','H','2','O',' ',' ',' ',' ',' ',00001580
     $                      40* ' '/                                    00001590
C                                                                       00001600
C SET THE STANDARD UNIT NAMES FOR CONCENTRATION                         00001610
C                                                                       00001620
      DATA ((MUNITA(I,J),I=1,10),J=64,76)                               00001630
     $/                         'P','P','M',' ',' ',' ',' ',' ',' ',' ',00001640
     $                          'P','P','T','M',' ',' ',' ',' ',' ',' ',00001650
     $                          'P','P','H','M',' ',' ',' ',' ',' ',' ',00001660
     $                          'P','P','B',' ',' ',' ',' ',' ',' ',' ',00001670
     $                          'G','M','/','M','3',' ',' ',' ',' ',' ',00001680
     $                          'L','B','M','/','F','T','3',' ',' ',' ',00001690
     $                          'M','I','C','R','O','G','/','M','3',' ',00001700
     $                          'G','/','M','3',' ',' ',' ',' ',' ',' ',00001710
     $                          'L','B','/','F','T','3',' ',' ',' ',' ',00001720
     $                      40 *' '/                                    00001730
C                                                                       00001740
C SET THE STANDARD UNIT NAMES FOR POINT EMISSIONS                       00001750
C                                                                       00001760
      DATA ((MUNITA(I,J),I=1,10),J=77,87)                               00001770
     $/                         'G','M','/','H','R',' ',' ',' ',' ',' ',00001780
     $                          'G','M','/','D',' ',' ',' ',' ',' ',' ',00001790
     $                          'L','B','M','/','H','R',' ',' ',' ',' ',00001800
     $                          'L','B','M','/','D',' ',' ',' ',' ',' ',00001810
     $                          'K','G','/','H','R',' ',' ',' ',' ',' ',00001820
     $                          'K','G','/','D',' ',' ',' ',' ',' ',' ',00001830
     $                          'L','B','/','H','R',' ',' ',' ',' ',' ',00001840
     $                          'L','B','/','D',' ',' ',' ',' ',' ',' ',00001850
     $                          'T','O','N','/','H','R',' ',' ',' ',' ',00001860
     $                          'T','O','N','/','D',' ',' ',' ',' ',' ',00001870
     $                          'T','O','N','/','Y','R',' ',' ',' ',' '/00001880
      DATA ((MUNITA(I,J),I=1,10),J=88,100)                              00001890
     $/                         130 *' '/                               00001900
C                                                                       00001910
C SET THE STANDARD SPECIES NAMES                                        00001920
C                                                                       00001930
      DATA ((MSTDVR(I,J),I=1,10),J=1,11)                                00001940
     $                         /'N','O',' ',' ',' ',' ',' ',' ',' ',' ',00001950
     $                          'N','O','2',' ',' ',' ',' ',' ',' ',' ',00001960
     $                          'C','O',' ',' ',' ',' ',' ',' ',' ',' ',00001970
     $                          'O','3',' ',' ',' ',' ',' ',' ',' ',' ',00001980
     $                          'H','2','O','2',' ',' ',' ',' ',' ',' ',00001990
     $                          'S','O','2',' ',' ',' ',' ',' ',' ',' ',00002000
     $                          'H','N','O','2',' ',' ',' ',' ',' ',' ',00002010
     $                          'H','2','O',' ',' ',' ',' ',' ',' ',' ',00002020
     $                          'O','2',' ',' ',' ',' ',' ',' ',' ',' ',00002030
     $                          'C','O','2',' ',' ',' ',' ',' ',' ',' ',00002040
     $                          'S','O','4',' ',' ',' ',' ',' ',' ',' '/00002050
      DATA ((MSTDVR(I,J),I=1,10),J=12,40)                               00002060
     $                         /'P','A','N',' ',' ',' ',' ',' ',' ',' ',00002070
     $                          'P','A','R',' ',' ',' ',' ',' ',' ',' ',00002080
     $                          'O','L','E',' ',' ',' ',' ',' ',' ',' ',00002090
     $                          'E','T','H',' ',' ',' ',' ',' ',' ',' ',00002100
     $                          'T','O','L',' ',' ',' ',' ',' ',' ',' ',00002110
     $                          'X','Y','L',' ',' ',' ',' ',' ',' ',' ',
     $                          'E','T','O','H',' ',' ',' ',' ',' ',' ',
     $                          'M','E','O','H',' ',' ',' ',' ',' ',' ',
     $                          'F','O','R','M',' ',' ',' ',' ',' ',' ',
     $                          'A','L','D','2',' ',' ',' ',' ',' ',' ',
     $                          'I','S','O','P',' ',' ',' ',' ',' ',' ',
     $                          'A','E','R','O',' ',' ',' ',' ',' ',' ',00002120
     $                          'C','H','4',' ',' ',' ',' ',' ',' ',' ',00002130
     $                          'T','O','T','A','L','H','C',' ',' ',' ',00002140
     $                          'S','O','X',' ',' ',' ',' ',' ',' ',' ',00002150
     $                          'N','O','X',' ',' ',' ',' ',' ',' ',' ',00002160
     $                          'O','X','I','D','A','N','T',' ',' ',' ',00002170
     $                          120 * ' '/                              00002180
C                                                                       00002190
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR TEMPERATURE                   00002200
C                                                                       00002210
      DATA STDMLT(001), STDADD(001)/ -9.0, -9.0/                        00002220
      DATA STDMLT(002), STDADD(002)/ -9.0, 273.15/                      00002230
      DATA STDMLT(003), STDADD(003)/ 0.5555556, 255.38/                 00002240
      DATA STDMLT(004), STDADD(004)/ 0.5555556, -9.0/                   00002250
C                                                                       00002260
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR DISTANCE                      00002270
C                                                                       00002280
      DATA STDMLT(005), STDADD(005)/ -9.0, -9.0/                        00002290
      DATA STDMLT(006), STDADD(006)/ 0.01, -9.0/                        00002300
      DATA STDMLT(007), STDADD(007)/ 1000.0, -9.0/                      00002310
      DATA STDMLT(008), STDADD(008)/ 0.0254, -9.0/                      00002320
      DATA STDMLT(009), STDADD(009)/ 0.3048, -9.0/                      00002330
      DATA STDMLT(010), STDADD(010)/ 1609.344, -9.0/                    00002340
C                                                                       00002350
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR VELOCITY                      00002360
C                                                                       00002370
      DATA STDMLT(015), STDADD(015)/ -9.0, -9.0/                        00002380
      DATA STDMLT(016), STDADD(016)/ 1000.0, -9.0/                      00002390
      DATA STDMLT(017), STDADD(017)/ 1609.344, -9.0/                    00002400
      DATA STDMLT(018), STDADD(018)/ 60.0, -9.0/                        00002410
      DATA STDMLT(019), STDADD(019)/ 18.288, -9.0/                      00002420
      DATA STDMLT(020), STDADD(020)/ 3600.0, -9.0/                      00002430
      DATA STDMLT(021), STDADD(021)/ 1097.28, -9.0/                     00002440
      DATA STDMLT(022), STDADD(022)/ 1852.0, -9.0/                      00002450
C                                                                       00002460
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR DIRECTION                     00002470
C                                                                       00002480
      DATA STDMLT(027), STDADD(027)/ -9.0, -9.0/                        00002490
      DATA STDMLT(028), STDADD(028)/ -9.0, 3.141593/                    00002500
      DATA STDMLT(029), STDADD(029)/ 0.01745329, -9.0/                  00002510
      DATA STDMLT(030), STDADD(030)/ 0.01745329, 3.141593/              00002520
      DATA STDMLT(031), STDADD(031)/ 0.392699, 2.748893/                00002530
      DATA STDMLT(032), STDADD(032)/ 0.392699, 3.141593/                00002540
      DATA STDMLT(033), STDADD(033)/ 0.1745329, 2.967059/               00002550
      DATA STDMLT(034), STDADD(034)/ 0.1745329, 3.141593/               00002560
C                                                                       00002570
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR TEMPERATURE GRADIENT          00002580
C                                                                       00002590
      DATA STDMLT(038), STDADD(038)/ -9.0, -9.0/                        00002600
      DATA STDMLT(039), STDADD(039)/ 0.001, -9.0/                       00002610
      DATA STDMLT(040), STDADD(040)/ -9.0, -9.0/                        00002620
      DATA STDMLT(041), STDADD(041)/ 0.001, -9.0/                       00002630
      DATA STDMLT(042), STDADD(042)/ 1.822689, -9.0/                    00002640
      DATA STDMLT(043), STDADD(043)/ 0.0003452, -9.0/                   00002650
      DATA STDMLT(044), STDADD(044)/ 1.822689, -9.0/                    00002660
      DATA STDMLT(045), STDADD(045)/ 0.0003452, -9.0/                   00002670
C                                                                       00002680
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR ATMOSPHERIC PRESSURE          00002690
C                                                                       00002700
      DATA STDMLT(050), STDADD(050)/ -9.0, -9.0/                        00002710
      DATA STDMLT(051), STDADD(051)/ 0.986923, -9.0/                    00002720
      DATA STDMLT(052), STDADD(052)/ 0.0013158, -9.0/                   00002730
      DATA STDMLT(053), STDADD(053)/ 0.029499, -9.0/                    00002740
      DATA STDMLT(054), STDADD(054)/ 0.967841, -9.0/                    00002750
      DATA STDMLT(055), STDADD(055)/ 0.0334211, -9.0/                   00002760
      DATA STDMLT(056), STDADD(056)/ 0.068046, -9.0/                    00002770
      DATA STDMLT(057), STDADD(057)/ 0.068046, -9.0/                    00002780
      DATA STDMLT(058), STDADD(058)/ 0.0009869, -9.0/                   00002790
      DATA STDMLT(059), STDADD(059)/ 0.0024582, -9.0/                   00002800
C                                                                       00002810
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR CONCENTRATION                 00002820
C                                                                       00002830
      DATA STDMLT(064), STDADD(064)/ -9.0, -9.0/                        00002840
      DATA STDMLT(065), STDADD(065)/ 0.1, -9.0/                         00002850
      DATA STDMLT(066), STDADD(066)/ 0.01, -9.0/                        00002860
      DATA STDMLT(067), STDADD(067)/ 0.001, -9.0/                       00002870
      DATA STDMLT(068), STDADD(068)/ 24400.0, -9.0/                     00002880
      DATA STDMLT(069), STDADD(069)/ 387600000000.0, -9.0/              00002890
      DATA STDMLT(070), STDADD(070)/ -0.0244, -9.0/                     00002900
      DATA STDMLT(071), STDADD(071)/ -24400.0, -9.0/                    00002910
      DATA STDMLT(072), STDADD(072)/ -387600000000.0, -9.0/             00002920
C                                                                       00002930
C MULTIPLICATIVE AND ADDITIVE FACTORS FOR POINT EMISSIONS               00002940
C                                                                       00002950
      DATA STDMLT(077), STDADD(077)/ -9.0, -9.0/                        00002960
      DATA STDMLT(078), STDADD(078)/ 0.0416667, -9.0/                   00002970
      DATA STDMLT(079), STDADD(079)/ 453.592, -9.0/                     00002980
      DATA STDMLT(080), STDADD(080)/ 18.89967, -9.0/                    00002990
      DATA STDMLT(081), STDADD(081)/ -1000.0, -9.0/                     00003000
      DATA STDMLT(082), STDADD(082)/ -41.6667, -9.0/                    00003010
      DATA STDMLT(083), STDADD(083)/ -453.592, -9.0/                    00003020
      DATA STDMLT(084), STDADD(084)/ -18.89967, -9.0/                   00003030
      DATA STDMLT(085), STDADD(085)/ -907184.0, -9.0/                   00003040
      DATA STDMLT(086), STDADD(086)/ -37799.3, -9.0/                    00003050
      DATA STDMLT(087), STDADD(087)/ -103.6, -9.0/                      00003060
C                                                                       00003070
C MOLECULAR WIRGHTS FOR STANDARD SPECIES                                00003080
C                                                                       00003090
      DATA STDMWT(01) / 30.0/                                           00003100
      DATA STDMWT(02) /46.0/                                            00003110
      DATA STDMWT(03) /28.0/                                            00003120
      DATA STDMWT(04) /48.0/                                            00003130
      DATA STDMWT(05) /34.0/                                            00003140
      DATA STDMWT(06) /64.0/                                            00003150
      DATA STDMWT(07) /47.0/                                            00003160
      DATA STDMWT(08) /18.0/                                            00003170
      DATA STDMWT(09) /32.0/                                            00003180
      DATA STDMWT(10) /44.0/                                            00003190
      DATA STDMWT(11) /96.0/                                            00003200
      DATA STDMWT(12) /121.0/                                           00003210
      DATA STDMWT(13) /16.0/                                            00003220
      DATA STDMWT(14) /32.0/                                            00003230
      DATA STDMWT(15) /32.0/                                            00003240
      DATA STDMWT(16) /112.0/                                           00003250
      DATA STDMWT(17) /128.0/                                           
      DATA STDMWT(18) /32.0/                                            
      DATA STDMWT(19) /16.0/                                            
      DATA STDMWT(20) /16.0/                                            
      DATA STDMWT(21) /32.0/                                           
      DATA STDMWT(22) /80.0/                                           
      DATA STDMWT(23) /1.0/                                             00003260
      DATA STDMWT(24) /16.0/                                            00003270
      DATA STDMWT(25) /16.0/                                            00003280
      DATA STDMWT(26) /64.0/                                            00003290
      DATA STDMWT(27) /46.0/                                            00003300
      DATA STDMWT(28) /48.0/                                            00003310
C                                                                       00003320
C DECLARE PACKET TRAILER                                                00003330
C                                                                       00003340
      DATA MENDUN /1HE, 1HN, 1HD, 7*1H /                                00003350
C                                                                       00003360
C DECLARE MISCELLANEOUS SCALARS                                         00003370
C                                                                       00003380
      DATA MBLANK /' '/                                                 00003390
      DATA NSTDUN /91/                                                  00003400
      DATA NSTDVR /28/                                                  00003410
C                                                                       00003420
C SET COMPLETION FLAG TO INITIAL VALUE                                  00003430
C                                                                       00003440
      JFLAG = 0                                                         00003450
C                                                                       00003460
C READ AND, IF WANTED, PRINT THE INPUT CARD                             00003470
C                                                                       00003480
  105 READ (INCARD, 1105) MVARNM, MUNTNM, FACMIN, FACAIN, SMOLIN, MCRDID00003490
      IF (LINPTP) WRITE (IPRINT, 2105) MVARNM, MUNTNM, FACMIN, FACAIN,  00003500
     $                   SMOLIN, MCRDID                                 00003510
C                                                                       00003520
C PACK VARIABLE NAME AND CHECK FOR BLANK                                00003530
C                                                                       00003540
      CALL TXTPAK(IPRINT, NAMLEN, MVARNM, NPACKD, JFLAG)                00003550
      IF (NPACKD .EQ. 0) GO TO 920                                      00003560
C                                                                       00003570
C CHECK FOR END OF PACKET                                               00003580
C                                                                       00003590
      CALL COMPAR(IPRINT, NAMLEN, MVARNM, MENDUN, JFLAG)                00003600
      IF (JFLAG .EQ. 1) GO TO 210                                       00003610
C                                                                       00003620
C SET LOOP TO FIND VARIABLE NAME                                        00003630
C                                                                       00003640
      DO 115 K = 1, NUNITS                                              00003650
C                                                                       00003660
C COMPARE INPUT VARIABLE NAME WITH THE LIST OF VARIABLE NAMES           00003670
C                                                                       00003680
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MVARBL(1,K), JFLAG)        00003690
         IF (JFLAG .EQ. 0) GO TO 115                                    00003700
C                                                                       00003710
C FOUND VARIABLE NAME -- SAVE LOCATION AND SKIP OUT                     00003720
C                                                                       00003730
         KVRBL = K                                                      00003740
         GO TO 140                                                      00003750
  115 CONTINUE                                                          00003760
C                                                                       00003770
C NAME NOT FOUND -- SET LOOP TO FIND BLANK SPOT                         00003780
C                                                                       00003790
      DO 135 K = 1, NUNITS                                              00003800
C                                                                       00003810
C COMPARE FIRST LETTER WITH BLANK                                       00003820
C                                                                       00003830
         IF (MVARBL(1,K) .NE. MBLANK) GO TO 135                         00003840
C                                                                       00003850
C FOUND ONE -- STUFF THE NAME IN HERE                                   00003860
C                                                                       00003870
         KVRBL = K                                                      00003880
         DO 125 J = 1, NAMLEN                                           00003890
            MVARBL(J,K) = MVARNM(J)                                     00003900
C                                                                       00003910
C END LOOP AND SKIP TO FACTOR PROCESSING                                00003920
C                                                                       00003930
  125    CONTINUE                                                       00003940
         GO TO 140                                                      00003950
C                                                                       00003960
C FINISH THE LOOP -- IF NO BLANKS, ERROR IN COUNT OR SPELLING           00003970
C                                                                       00003980
  135 CONTINUE                                                          00003990
      GO TO 935                                                         00004000
C                                                                       00004010
C CHECK FOR USER CHANGES TO THESE FACTORS                               00004020
C                                                                       00004030
  140 IF (FACMIN .NE. 0.0) FACMLT(KVRBL) = FACMIN                       00004040
      IF (FACAIN .NE. 0.0) FACADD(KVRBL) = FACAIN                       00004050
      IF (SMOLIN .NE. 0.0) SMOLWT(KVRBL) = SMOLIN                       00004060
C                                                                       00004070
C PACK UNIT NAME                                                        00004080
C                                                                       00004090
      CALL TXTPAK(IPRINT, NAMLEN, MUNTNM, NPACKD, JFLAG)                00004100
C                                                                       00004110
C STORE UNIT NAME IN OUTPUT TABLE                                       00004120
C                                                                       00004130
      DO 142 I=1,NAMLEN                                                 00004140
         MUNITS(I,KVRBL) = MUNTNM(I)                                    00004150
  142 CONTINUE                                                          00004160
C                                                                       00004170
C IF NAME IS BLANK, INTERNAL UNITS ARE WANTED, ELSE SET SEARCH LOOP     00004180
C                                                                       00004190
      IF (NPACKD .EQ. 0) GO TO 105                                      00004200
      DO 145 J = 1, NSTDUN                                              00004210
C                                                                       00004220
C FIND THIS UNIT NAME IN LIST OF STANDARD UNITS                         00004230
C                                                                       00004240
         CALL COMPAR(IPRINT, NAMLEN, MUNTNM, MSTDUN(1,J), JFLAG)        00004250
         IF (JFLAG .EQ. 0) GO TO 145                                    00004260
C                                                                       00004270
C SAVE LOCATION AND, IF USER ALREADY SET FACTORS, SKIP TO MOL. WT. CHECK00004280
C                                                                       00004290
         KUNIT = J                                                      00004300
         IF (FACMIN .NE. 0.0) GO TO 150                                 00004310
         IF (FACAIN .NE. 0.0) GO TO 150                                 00004320
C                                                                       00004330
C MOVE VALUES TO OUTPUT VECTORS AND SKIP TO MOL. WT. CHECK              00004340
C                                                                       00004350
         FACMLT(KVRBL) = STDMLT(KUNIT)                                  00004360
         FACADD(KVRBL) = STDADD(KUNIT)                                  00004370
         GO TO 150                                                      00004380
C                                                                       00004390
C END LOOP -- SET POINTER TO INDICATE NAME NOT PRESENT                  00004400
C                                                                       00004410
  145 CONTINUE                                                          00004420
      KUNIT = 0                                                         00004430
C                                                                       00004440
C IF NAME WAS NEEDED, CHECK FOR SPELLING ERROR                          00004450
C                                                                       00004460
      IF (FACMIN .NE. 0.0) GO TO 160                                    00004470
      IF (FACAIN .NE. 0.0) GO TO 160                                    00004480
      GO TO 950                                                         00004490
C                                                                       00004500
C IF MOLECULAR WEIGHT IS UNNEEDED, GO FOR NEXT CARD                     00004510
C                                                                       00004520
  150 IF (STDMLT(KUNIT) .GT. 0.0) GO TO 105                             00004530
      IF (STDMLT(KUNIT) .EQ. RMISSV) GO TO 105                          00004540
C                                                                       00004550
C REVERSE SIGN ON MULTIPLIER, SINCE SIGN IS MOL. WT. FLAG               00004560
C                                                                       00004570
      FACMLT(KVRBL) = ABS(FACMLT(KVRBL))                                00004580
C                                                                       00004590
C IF MOL. WT. WAS USER-SET, GO FOR NEXT CARD, ELSE SEEK VALUE           00004600
C                                                                       00004610
  160 IF (SMOLIN .NE. 0.0) GO TO 105                                    00004620
      DO 165 J = 1, NSTDVR                                              00004630
C                                                                       00004640
C COMPARE INPUT VARIABLE NAME WITH THE LIST OF STANDARD NAMES           00004650
C                                                                       00004660
         CALL COMPAR(IPRINT, NAMLEN, MVARNM, MSTDVR(1,J), JFLAG)        00004670
         IF (JFLAG .NE. 1) GO TO 165                                    00004680
C                                                                       00004690
C FOUND A SPECIES -- LOAD ITS MOL. WT., CHECK IT, AND GET NEXT CARD     00004700
C                                                                       00004710
         SMOLWT(KVRBL) = STDMWT(J)                                      00004720
         IF (SMOLWT(KVRBL) .EQ. RMISSV) GO TO 960                       00004730
         GO TO 105                                                      00004740
C                                                                       00004750
C AT END OF LOOP, WRITE WARNING MESSAGE                                 00004760
C                                                                       00004770
  165 CONTINUE                                                          00004780
      GO TO 960                                                         00004790
C                                                                       00004800
C END OF PACKET, PRINT UNITS TABLE IF WANTED, ELSE RETURN               00004810
C                                                                       00004820
  210 IF (.NOT. LUNITP) GO TO 1000                                      00004830
      WRITE (IPRINT, 2210)                                              00004840
C                                                                       00004850
C PRINT VALUES IN LOOP                                                  00004860
C                                                                       00004870
      DO 215 J = 1, NUNITS                                              00004880
         WRITE (IPRINT, 2215)(MVARBL(I,J), I=1,NAMLEN), (MUNITS(I,J),   00004890
     $                       I=1,NAMLEN), FACMLT(J), FACADD(J),         00004900
     $                       SMOLWT(J)                                  00004910
  215 CONTINUE                                                          00004920
C                                                                       00004930
C END OF PACKET -- RETURN TO CALLING PROGRAM                            00004940
C                                                                       00004950
      GO TO 1000                                                        00004960
C                                                                       00004970
C ERROR MESSAGE FOR BLANK NAME                                          00004980
C                                                                       00004990
  920 WRITE (IPRINT, 2920)                                              00005000
      JFLAG = -4                                                        00005010
      GO TO 1000                                                        00005020
C                                                                       00005030
C ERROR MESSAGE FOR NO SPACE FOR NEW VARIABLE NAME                      00005040
C                                                                       00005050
  935 WRITE (IPRINT, 2935) MVARNM                                       00005060
      JFLAG = -7                                                        00005070
      GO TO 1000                                                        00005080
C                                                                       00005090
C ERROR MESSAGE FOR UNIT NAME NOT IN STANDARD UNIT LIST                 00005100
C                                                                       00005110
  950 WRITE (IPRINT, 2950) MUNTNM                                       00005120
      JFLAG = -10                                                       00005130
      GO TO 1000                                                        00005140
C                                                                       00005150
C ERROR MESSAGE FOR VARIABLE NAME NOT IN STANDARD LIST                  00005160
C                                                                       00005170
  960 WRITE (IPRINT, 2960) MVARNM                                       00005180
      JFLAG = -12                                                       00005190
      GO TO 1000                                                        00005200
C                                                                       00005210
C RETURN TO CALLING ROUTINE                                             00005220
C                                                                       00005230
 1000 RETURN                                                            00005240
C                                                                       00005250
C FORMATS                                                               00005260
C                                                                       00005270
 1105 FORMAT (10A1, 10A1, 3F10.0, 10X, 20A1)                            00005280
 2105 FORMAT (1X, 10A1, 10A1, 3F10.4, 10X, 20A1)                        00005290
 2210 FORMAT (1H1, 40X, 21HUNIT CONVERSION TABLE, //,                   00005300
     $        54H VARIABLE NAME          UNIT NAME        MULTIPLICATIV,00005310
     $        26HE FACTOR   ADDITIVE FACTOR, //)                        00005320
 2215 FORMAT (1X, 5X, 10A1, 10X, 10A1, 5X, 3F20.8, /)                   00005330
 2920 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,              00005340
     $        40H BLANK VARIABLE NAMES ARE NOT ACCEPTABLE,              00005350
     $        //, 41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)     00005360
 2935 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,              00005370
     $        47H INSUFFICIENT SPACE IN VARIABLE NAME TABLE FOR ,       00005380
     $        9HVARIABLE , 10A1, //, 22H TOTAL VARIABLE COUNT ,         00005390
     $        46H MAY BE TOO SMALL, OR A NAME MAY BE MISSPELLED, //,    00005400
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)         00005410
 2950 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,              00005420
     $        28H UNABLE TO LOCATE UNIT NAME , 10A1,                    00005430
     $        24H IN STANDARD UNITS TABLE, //,                          00005440
     $        29H CHECK UNIT NAME SPELLING OR ,                         00005450
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)         00005460
 2960 FORMAT (1H1, 35H****** SYSTEM OR INPUT ERROR ******,              00005470
     $        32H UNABLE TO LOCATE VARIABLE NAME , 10A1,                00005480
     $        28H IN STANDARD VARIABLES TABLE, //,                      00005490
     $        33H CHECK VARIABLE NAME SPELLING OR ,                     00005500
     $        41H CONSULT PROGRAMMING STAFF FOR ASSISTANCE, //)         00005510
      END                                                               00005520
